#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#ifdef _MSC_VER
#pragma optimize("", off)
#elif defined(__clang__)
#pragma clang optimize off
#elif defined(__GNUC__)
#pragma GCC optimize("O0")
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 1260
#define LARGE_STATE_COUNT 34
#define SYMBOL_COUNT 436
#define ALIAS_COUNT 0
#define TOKEN_COUNT 176
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 12
#define MAX_ALIAS_SEQUENCE_LENGTH 9
#define PRODUCTION_ID_COUNT 14

enum ts_symbol_identifiers {
    anon_sym_short = 1,
    anon_sym_int16 = 2,
    anon_sym_long = 3,
    anon_sym_int32 = 4,
    anon_sym_longlong = 5,
    anon_sym_int64 = 6,
    sym_unsigned_tiny_int = 7,
    sym_boolean_type = 8,
    anon_sym_fixed = 9,
    sym_octet_type = 10,
    sym_signed_tiny_int = 11,
    anon_sym_unsignedshort = 12,
    anon_sym_uint16 = 13,
    anon_sym_unsignedlong = 14,
    anon_sym_uint32 = 15,
    anon_sym_unsignedlonglong = 16,
    anon_sym_uint64 = 17,
    anon_sym_float = 18,
    anon_sym_double = 19,
    anon_sym_longdouble = 20,
    anon_sym_char = 21,
    anon_sym_wchar = 22,
    anon_sym_COLON_COLON = 23,
    anon_sym_string = 24,
    anon_sym_wstring = 25,
    anon_sym_LT = 26,
    anon_sym_GT = 27,
    anon_sym_any = 28,
    anon_sym_COMMA = 29,
    anon_sym_sequence = 30,
    anon_sym_map = 31,
    anon_sym_PIPE = 32,
    anon_sym_CARET = 33,
    anon_sym_AMP = 34,
    anon_sym_GT_GT = 35,
    anon_sym_LT_LT = 36,
    anon_sym_PLUS = 37,
    anon_sym_DASH = 38,
    anon_sym_STAR = 39,
    anon_sym_SLASH = 40,
    anon_sym_PERCENT = 41,
    anon_sym_LPAREN = 42,
    anon_sym_RPAREN = 43,
    anon_sym_TILDE = 44,
    sym_escape_sequence = 45,
    anon_sym_L = 46,
    anon_sym_DQUOTE = 47,
    aux_sym_string_literal_token1 = 48,
    anon_sym_SQUOTE = 49,
    aux_sym_char_literal_token1 = 50,
    anon_sym_TRUE = 51,
    anon_sym_FALSE = 52,
    sym_number_literal = 53,
    anon_sym_POUNDdefine = 54,
    aux_sym_preproc_define_token1 = 55,
    aux_sym_preproc_call_token1 = 56,
    sym_preproc_directive = 57,
    sym_preproc_arg = 58,
    aux_sym_preproc_include_token1 = 59,
    sym_system_lib_path = 60,
    anon_sym_exception = 61,
    anon_sym_LBRACE = 62,
    anon_sym_RBRACE = 63,
    anon_sym_local = 64,
    anon_sym_abstract = 65,
    anon_sym_interface = 66,
    anon_sym_COLON = 67,
    anon_sym_SEMI = 68,
    anon_sym_void = 69,
    anon_sym_in = 70,
    anon_sym_out = 71,
    anon_sym_inout = 72,
    anon_sym_raises = 73,
    anon_sym_readonly = 74,
    anon_sym_attribute = 75,
    anon_sym_getraises = 76,
    anon_sym_setraises = 77,
    anon_sym_bitset = 78,
    anon_sym_bitfield = 79,
    anon_sym_bitmask = 80,
    anon_sym_ATannotation = 81,
    anon_sym_default = 82,
    anon_sym_AT = 83,
    anon_sym_SLASH_SLASH_AT = 84,
    aux_sym_extend_annotation_appl_token1 = 85,
    anon_sym_EQ = 86,
    anon_sym_id = 87,
    anon_sym_autoid = 88,
    anon_sym_SEQUENTIAL = 89,
    anon_sym_HASH = 90,
    anon_sym_optional = 91,
    anon_sym_position = 92,
    anon_sym_value = 93,
    anon_sym_extensibility = 94,
    anon_sym_FINAL = 95,
    anon_sym_APPENDABLE = 96,
    anon_sym_MUTABLE = 97,
    anon_sym_final = 98,
    anon_sym_appendable = 99,
    anon_sym_mutable = 100,
    anon_sym_key = 101,
    anon_sym_must_understand = 102,
    anon_sym_default_literal = 103,
    anon_sym_range = 104,
    anon_sym_min = 105,
    anon_sym_max = 106,
    anon_sym_unit = 107,
    anon_sym_bit_bound = 108,
    anon_sym_external = 109,
    anon_sym_nested = 110,
    anon_sym_verbatim = 111,
    anon_sym_c = 112,
    anon_sym_c_PLUS_PLUS = 113,
    anon_sym_java = 114,
    anon_sym_idl = 115,
    anon_sym_BEGIN_FILE = 116,
    anon_sym_BEFORE_DECLARATION = 117,
    anon_sym_BEGIN_DECLARATION = 118,
    anon_sym_END_DECLARATION = 119,
    anon_sym_AFTER_DECLARATION = 120,
    anon_sym_END_FILE = 121,
    anon_sym_service = 122,
    anon_sym_CORBA = 123,
    anon_sym_DDS = 124,
    anon_sym_oneway = 125,
    anon_sym_ami = 126,
    anon_sym_module = 127,
    anon_sym_typename = 128,
    anon_sym_valuetype = 129,
    anon_sym_eventtype = 130,
    anon_sym_struct = 131,
    anon_sym_union = 132,
    anon_sym_enum = 133,
    anon_sym_const = 134,
    anon_sym_alias = 135,
    anon_sym_custom = 136,
    anon_sym_truncatable = 137,
    anon_sym_supports = 138,
    anon_sym_public = 139,
    anon_sym_private = 140,
    anon_sym_factory = 141,
    anon_sym_typedef = 142,
    anon_sym_LBRACK = 143,
    anon_sym_RBRACK = 144,
    anon_sym_ATdefault_literal = 145,
    anon_sym_ATignore_literal_names = 146,
    anon_sym_switch = 147,
    anon_sym_case = 148,
    anon_sym_typeid = 149,
    anon_sym_typeprefix = 150,
    anon_sym_import = 151,
    anon_sym_Object = 152,
    anon_sym_context = 153,
    sym_value_base_type = 154,
    anon_sym_component = 155,
    anon_sym_provides = 156,
    anon_sym_uses = 157,
    anon_sym_multiple = 158,
    anon_sym_home = 159,
    anon_sym_manages = 160,
    anon_sym_emits = 161,
    anon_sym_publishes = 162,
    anon_sym_consumes = 163,
    anon_sym_primarykey = 164,
    anon_sym_finder = 165,
    anon_sym_porttype = 166,
    anon_sym_port = 167,
    anon_sym_mirrorport = 168,
    anon_sym_connector = 169,
    anon_sym_native = 170,
    sym_identifier = 171,
    anon_sym_SLASH_SLASH = 172,
    aux_sym_comment_token1 = 173,
    anon_sym_SLASH_STAR = 174,
    aux_sym_comment_token2 = 175,
    sym_specification = 176,
    sym_signed_short_int = 177,
    sym_signed_long_int = 178,
    sym_signed_longlong_int = 179,
    sym_unsigned_int = 180,
    sym_fixed_pt_const_type = 181,
    sym_integer_type = 182,
    sym_signed_int = 183,
    sym_unsigned_short_int = 184,
    sym_unsigned_long_int = 185,
    sym_unsigned_longlong_int = 186,
    sym_floating_pt_type = 187,
    sym_char_type = 188,
    sym_scoped_name = 189,
    sym_string_type = 190,
    sym_type_spec = 191,
    sym_simple_type_spec = 192,
    sym_base_type_spec = 193,
    sym_any_type = 194,
    sym_fixed_pt_type = 195,
    sym_template_type_spec = 196,
    sym_sequence_type = 197,
    sym_map_type = 198,
    sym_positive_int_const = 199,
    sym_const_expr = 200,
    sym_or_expr = 201,
    sym_xor_expr = 202,
    sym_and_expr = 203,
    sym_shift_expr = 204,
    sym_add_expr = 205,
    sym_mult_expr = 206,
    sym_unary_expr = 207,
    sym_primary_expr = 208,
    sym_unary_operator = 209,
    sym_literal = 210,
    sym_string_literal = 211,
    sym_char_literal = 212,
    sym_boolean_literal = 213,
    sym_preproc_define = 214,
    sym_preproc_call = 215,
    sym_preproc_include = 216,
    sym_system_lib_string = 217,
    sym_except_dcl = 218,
    sym_interface_dcl = 219,
    sym_interface_kind = 220,
    sym_interface_forward_dcl = 221,
    sym_interface_def = 222,
    sym_interface_header = 223,
    sym_interface_inheritance_spec = 224,
    sym_interface_name = 225,
    sym_interface_body = 226,
    sym_export = 227,
    sym_op_dcl = 228,
    sym_op_type_spec = 229,
    sym_parameter_dcls = 230,
    sym_param_dcl = 231,
    sym_param_attribute = 232,
    sym_raises_expr = 233,
    sym_attr_dcl = 234,
    sym_readonly_attr_spec = 235,
    sym_readonly_attr_declarator = 236,
    sym_attr_spec = 237,
    sym_attr_declarator = 238,
    sym_attr_raises_expr = 239,
    sym_get_excep_expr = 240,
    sym_set_excep_expr = 241,
    sym_exception_list = 242,
    sym_bitset_dcl = 243,
    sym_bitfield = 244,
    sym_bitfield_spec = 245,
    sym_destination_type = 246,
    sym_bitmask_dcl = 247,
    sym_bit_value = 248,
    sym_annotation_dcl = 249,
    sym_annotation_body = 250,
    sym_annotation_member = 251,
    sym_annotation_member_type = 252,
    sym_any_const_type = 253,
    sym_annotation_appl = 254,
    sym_extend_annotation_appl = 255,
    sym_annotation_appl_custom_body = 256,
    sym_annotation_appl_params = 257,
    sym_annotation_appl_param = 258,
    sym_annotation_appl_builtin_body = 259,
    sym_annotation_appl_id = 260,
    sym_annotation_appl_autoid = 261,
    sym_autoid_kind = 262,
    sym_annotation_appl_optional = 263,
    sym_annotation_appl_position = 264,
    sym_annotation_appl_value = 265,
    sym_annotation_appl_extensibility = 266,
    sym_extensibility_kind = 267,
    sym_annotation_appl_final = 268,
    sym_annotation_appl_appendable = 269,
    sym_annotation_appl_mutable = 270,
    sym_annotation_appl_key = 271,
    sym_annotation_appl_must_understand = 272,
    sym_annotation_appl_default_literal = 273,
    sym_annotation_appl_default = 274,
    sym_annotation_appl_range = 275,
    sym_min_expr = 276,
    sym_max_expr = 277,
    sym_annotation_appl_min = 278,
    sym_annotation_appl_max = 279,
    sym_annotation_appl_unit = 280,
    sym_annotation_appl_bit_bound = 281,
    sym_annotation_appl_external = 282,
    sym_annotation_appl_nested = 283,
    sym_annotation_appl_verbatim = 284,
    sym_verbatim_language = 285,
    sym_placement_kind = 286,
    sym_annotation_appl_service = 287,
    sym_service_platform = 288,
    sym_annotation_appl_oneway = 289,
    sym_annotation_appl_ami = 290,
    sym_template_module_dcl = 291,
    sym_formal_parameters = 292,
    sym_formal_parameter = 293,
    sym_formal_parameter_type = 294,
    sym_tpl_definition = 295,
    sym_template_module_inst = 296,
    sym_actual_parameters = 297,
    sym_actual_parameter = 298,
    sym_template_module_ref = 299,
    sym_formal_parameter_names = 300,
    sym_value_dcl = 301,
    sym_value_def = 302,
    sym_value_kind = 303,
    sym_value_header = 304,
    sym_value_inheritance_spec = 305,
    sym_value_inheritance = 306,
    sym_value_supports = 307,
    sym_value_name = 308,
    sym_value_element = 309,
    sym_state_member = 310,
    sym_init_dcl = 311,
    sym_init_param_dcls = 312,
    sym_init_param_dcl = 313,
    sym_value_forward_dcl = 314,
    sym_typedef_dcl = 315,
    sym_type_declarator = 316,
    sym_any_declarators = 317,
    sym_any_declarator = 318,
    sym_simple_declarator = 319,
    sym_declarator = 320,
    sym_declarators = 321,
    sym_array_declarator = 322,
    sym_fixed_array_size = 323,
    sym_enum_dcl = 324,
    sym_enumerator = 325,
    sym_enum_modifier = 326,
    sym_enum_anno = 327,
    sym_union_dcl = 328,
    sym_union_forward_dcl = 329,
    sym_union_def = 330,
    sym_case = 331,
    sym_case_label = 332,
    sym_element_spec = 333,
    sym_switch_type_spec = 334,
    sym_type_id_dcl = 335,
    sym_type_prefix_dcl = 336,
    sym_import_dcl = 337,
    sym_imported_scope = 338,
    sym_object_type = 339,
    sym_op_oneway_dcl = 340,
    sym_in_parameter_dcls = 341,
    sym_in_param_dcl = 342,
    sym_op_with_context = 343,
    sym_context_expr = 344,
    sym_value_box_def = 345,
    sym_value_abs_def = 346,
    sym_component_dcl = 347,
    sym_component_forward_dcl = 348,
    sym_component_def = 349,
    sym_component_header = 350,
    sym_component_inheritance_spec = 351,
    sym_component_body = 352,
    sym_component_export = 353,
    sym_provides_dcl = 354,
    sym_interface_type = 355,
    sym_uses_dcl = 356,
    sym_home_dcl = 357,
    sym_home_header = 358,
    sym_home_inheritance_spec = 359,
    sym_home_body = 360,
    sym_home_export = 361,
    sym_factory_dcl = 362,
    sym_factory_param_dcls = 363,
    sym_factory_param_dcl = 364,
    sym_supported_interface_spec = 365,
    sym_emits_dcl = 366,
    sym_publishes_dcl = 367,
    sym_consumes_dcl = 368,
    sym_primary_key_spec = 369,
    sym_finder_dcl = 370,
    sym_event_dcl = 371,
    sym_event_forward_dcl = 372,
    sym_event_abs_def = 373,
    sym_event_def = 374,
    sym_event_header = 375,
    sym_porttype_dcl = 376,
    sym_porttype_forward_dcl = 377,
    sym_porttype_def = 378,
    sym_port_body = 379,
    sym_port_ref = 380,
    sym_port_export = 381,
    sym_port_dcl = 382,
    sym_connector_dcl = 383,
    sym_connector_header = 384,
    sym_connector_inherit_spec = 385,
    sym_connector_export = 386,
    sym_definition = 387,
    sym_type_dcl = 388,
    sym_constr_type_dcl = 389,
    sym_native_dcl = 390,
    sym_module_dcl = 391,
    sym_struct_dcl = 392,
    sym_struct_forward_dcl = 393,
    sym_struct_def = 394,
    sym_member = 395,
    sym_default = 396,
    sym_const_dcl = 397,
    sym_const_type = 398,
    sym_comment = 399,
    aux_sym_specification_repeat1 = 400,
    aux_sym_string_literal_repeat1 = 401,
    aux_sym_char_literal_repeat1 = 402,
    aux_sym_except_dcl_repeat1 = 403,
    aux_sym_interface_def_repeat1 = 404,
    aux_sym_interface_inheritance_spec_repeat1 = 405,
    aux_sym_interface_body_repeat1 = 406,
    aux_sym_parameter_dcls_repeat1 = 407,
    aux_sym_raises_expr_repeat1 = 408,
    aux_sym_readonly_attr_declarator_repeat1 = 409,
    aux_sym_bitset_dcl_repeat1 = 410,
    aux_sym_bitfield_repeat1 = 411,
    aux_sym_bitmask_dcl_repeat1 = 412,
    aux_sym_annotation_dcl_repeat1 = 413,
    aux_sym_annotation_appl_params_repeat1 = 414,
    aux_sym_template_module_dcl_repeat1 = 415,
    aux_sym_formal_parameters_repeat1 = 416,
    aux_sym_actual_parameters_repeat1 = 417,
    aux_sym_formal_parameter_names_repeat1 = 418,
    aux_sym_value_def_repeat1 = 419,
    aux_sym_value_inheritance_spec_repeat1 = 420,
    aux_sym_init_param_dcls_repeat1 = 421,
    aux_sym_any_declarators_repeat1 = 422,
    aux_sym_declarators_repeat1 = 423,
    aux_sym_array_declarator_repeat1 = 424,
    aux_sym_enum_dcl_repeat1 = 425,
    aux_sym_enumerator_repeat1 = 426,
    aux_sym_union_def_repeat1 = 427,
    aux_sym_in_parameter_dcls_repeat1 = 428,
    aux_sym_context_expr_repeat1 = 429,
    aux_sym_component_body_repeat1 = 430,
    aux_sym_home_body_repeat1 = 431,
    aux_sym_factory_param_dcls_repeat1 = 432,
    aux_sym_port_body_repeat1 = 433,
    aux_sym_connector_dcl_repeat1 = 434,
    aux_sym_module_dcl_repeat1 = 435,
};

static const char *const ts_symbol_names[] = {
    [ts_builtin_sym_end] = "end",
    [anon_sym_short] = "short",
    [anon_sym_int16] = "int16",
    [anon_sym_long] = "long",
    [anon_sym_int32] = "int32",
    [anon_sym_longlong] = "long long",
    [anon_sym_int64] = "int64",
    [sym_unsigned_tiny_int] = "unsigned_tiny_int",
    [sym_boolean_type] = "boolean_type",
    [anon_sym_fixed] = "fixed",
    [sym_octet_type] = "octet_type",
    [sym_signed_tiny_int] = "signed_tiny_int",
    [anon_sym_unsignedshort] = "unsigned short",
    [anon_sym_uint16] = "uint16",
    [anon_sym_unsignedlong] = "unsigned long",
    [anon_sym_uint32] = "uint32",
    [anon_sym_unsignedlonglong] = "unsigned long long",
    [anon_sym_uint64] = "uint64",
    [anon_sym_float] = "float",
    [anon_sym_double] = "double",
    [anon_sym_longdouble] = "long double",
    [anon_sym_char] = "char",
    [anon_sym_wchar] = "wchar",
    [anon_sym_COLON_COLON] = "::",
    [anon_sym_string] = "string",
    [anon_sym_wstring] = "wstring",
    [anon_sym_LT] = "<",
    [anon_sym_GT] = ">",
    [anon_sym_any] = "any",
    [anon_sym_COMMA] = ",",
    [anon_sym_sequence] = "sequence",
    [anon_sym_map] = "map",
    [anon_sym_PIPE] = "|",
    [anon_sym_CARET] = "^",
    [anon_sym_AMP] = "&",
    [anon_sym_GT_GT] = ">>",
    [anon_sym_LT_LT] = "<<",
    [anon_sym_PLUS] = "+",
    [anon_sym_DASH] = "-",
    [anon_sym_STAR] = "*",
    [anon_sym_SLASH] = "/",
    [anon_sym_PERCENT] = "%",
    [anon_sym_LPAREN] = "(",
    [anon_sym_RPAREN] = ")",
    [anon_sym_TILDE] = "~",
    [sym_escape_sequence] = "escape_sequence",
    [anon_sym_L] = "L",
    [anon_sym_DQUOTE] = "\"",
    [aux_sym_string_literal_token1] = "string_content",
    [anon_sym_SQUOTE] = "'",
    [aux_sym_char_literal_token1] = "character",
    [anon_sym_TRUE] = "TRUE",
    [anon_sym_FALSE] = "FALSE",
    [sym_number_literal] = "number_literal",
    [anon_sym_POUNDdefine] = "#define",
    [aux_sym_preproc_define_token1] = "preproc_define_token1",
    [aux_sym_preproc_call_token1] = "preproc_call_token1",
    [sym_preproc_directive] = "preproc_directive",
    [sym_preproc_arg] = "preproc_arg",
    [aux_sym_preproc_include_token1] = "keyword_include",
    [sym_system_lib_path] = "system_lib_path",
    [anon_sym_exception] = "exception",
    [anon_sym_LBRACE] = "{",
    [anon_sym_RBRACE] = "}",
    [anon_sym_local] = "local",
    [anon_sym_abstract] = "abstract",
    [anon_sym_interface] = "interface",
    [anon_sym_COLON] = ":",
    [anon_sym_SEMI] = ";",
    [anon_sym_void] = "void",
    [anon_sym_in] = "in",
    [anon_sym_out] = "out",
    [anon_sym_inout] = "inout",
    [anon_sym_raises] = "raises",
    [anon_sym_readonly] = "readonly",
    [anon_sym_attribute] = "attribute",
    [anon_sym_getraises] = "getraises",
    [anon_sym_setraises] = "setraises",
    [anon_sym_bitset] = "bitset",
    [anon_sym_bitfield] = "bitfield",
    [anon_sym_bitmask] = "bitmask",
    [anon_sym_ATannotation] = "@annotation",
    [anon_sym_default] = "default",
    [anon_sym_AT] = "@",
    [anon_sym_SLASH_SLASH_AT] = "//@",
    [aux_sym_extend_annotation_appl_token1] = "extend_annotation_appl_token1",
    [anon_sym_EQ] = "=",
    [anon_sym_id] = "id",
    [anon_sym_autoid] = "autoid",
    [anon_sym_SEQUENTIAL] = "SEQUENTIAL",
    [anon_sym_HASH] = "HASH",
    [anon_sym_optional] = "optional",
    [anon_sym_position] = "position",
    [anon_sym_value] = "value",
    [anon_sym_extensibility] = "extensibility",
    [anon_sym_FINAL] = "FINAL",
    [anon_sym_APPENDABLE] = "APPENDABLE",
    [anon_sym_MUTABLE] = "MUTABLE",
    [anon_sym_final] = "final",
    [anon_sym_appendable] = "appendable",
    [anon_sym_mutable] = "mutable",
    [anon_sym_key] = "key",
    [anon_sym_must_understand] = "must_understand",
    [anon_sym_default_literal] = "default_literal",
    [anon_sym_range] = "range",
    [anon_sym_min] = "min",
    [anon_sym_max] = "max",
    [anon_sym_unit] = "unit",
    [anon_sym_bit_bound] = "bit_bound",
    [anon_sym_external] = "external",
    [anon_sym_nested] = "nested",
    [anon_sym_verbatim] = "verbatim",
    [anon_sym_c] = "c",
    [anon_sym_c_PLUS_PLUS] = "c++",
    [anon_sym_java] = "java",
    [anon_sym_idl] = "idl",
    [anon_sym_BEGIN_FILE] = "BEGIN_FILE",
    [anon_sym_BEFORE_DECLARATION] = "BEFORE_DECLARATION",
    [anon_sym_BEGIN_DECLARATION] = "BEGIN_DECLARATION",
    [anon_sym_END_DECLARATION] = "END_DECLARATION",
    [anon_sym_AFTER_DECLARATION] = "AFTER_DECLARATION",
    [anon_sym_END_FILE] = "END_FILE",
    [anon_sym_service] = "service",
    [anon_sym_CORBA] = "CORBA",
    [anon_sym_DDS] = "DDS",
    [anon_sym_oneway] = "oneway",
    [anon_sym_ami] = "ami",
    [anon_sym_module] = "module",
    [anon_sym_typename] = "typename",
    [anon_sym_valuetype] = "valuetype",
    [anon_sym_eventtype] = "eventtype",
    [anon_sym_struct] = "struct",
    [anon_sym_union] = "union",
    [anon_sym_enum] = "enum",
    [anon_sym_const] = "const",
    [anon_sym_alias] = "alias",
    [anon_sym_custom] = "custom",
    [anon_sym_truncatable] = "truncatable",
    [anon_sym_supports] = "supports",
    [anon_sym_public] = "public",
    [anon_sym_private] = "private",
    [anon_sym_factory] = "factory",
    [anon_sym_typedef] = "typedef",
    [anon_sym_LBRACK] = "[",
    [anon_sym_RBRACK] = "]",
    [anon_sym_ATdefault_literal] = "@default_literal",
    [anon_sym_ATignore_literal_names] = "@ignore_literal_names",
    [anon_sym_switch] = "switch",
    [anon_sym_case] = "case",
    [anon_sym_typeid] = "typeid",
    [anon_sym_typeprefix] = "typeprefix",
    [anon_sym_import] = "import",
    [anon_sym_Object] = "Object",
    [anon_sym_context] = "context",
    [sym_value_base_type] = "value_base_type",
    [anon_sym_component] = "component",
    [anon_sym_provides] = "provides",
    [anon_sym_uses] = "uses",
    [anon_sym_multiple] = "multiple",
    [anon_sym_home] = "home",
    [anon_sym_manages] = "manages",
    [anon_sym_emits] = "emits",
    [anon_sym_publishes] = "publishes",
    [anon_sym_consumes] = "consumes",
    [anon_sym_primarykey] = "primarykey",
    [anon_sym_finder] = "finder",
    [anon_sym_porttype] = "porttype",
    [anon_sym_port] = "port",
    [anon_sym_mirrorport] = "mirrorport",
    [anon_sym_connector] = "connector",
    [anon_sym_native] = "native",
    [sym_identifier] = "identifier",
    [anon_sym_SLASH_SLASH] = "//",
    [aux_sym_comment_token1] = "comment_token1",
    [anon_sym_SLASH_STAR] = "/*",
    [aux_sym_comment_token2] = "comment_token2",
    [sym_specification] = "specification",
    [sym_signed_short_int] = "signed_short_int",
    [sym_signed_long_int] = "signed_long_int",
    [sym_signed_longlong_int] = "signed_longlong_int",
    [sym_unsigned_int] = "unsigned_int",
    [sym_fixed_pt_const_type] = "fixed_pt_const_type",
    [sym_integer_type] = "integer_type",
    [sym_signed_int] = "signed_int",
    [sym_unsigned_short_int] = "unsigned_short_int",
    [sym_unsigned_long_int] = "unsigned_long_int",
    [sym_unsigned_longlong_int] = "unsigned_longlong_int",
    [sym_floating_pt_type] = "floating_pt_type",
    [sym_char_type] = "char_type",
    [sym_scoped_name] = "scoped_name",
    [sym_string_type] = "string_type",
    [sym_type_spec] = "type_spec",
    [sym_simple_type_spec] = "simple_type_spec",
    [sym_base_type_spec] = "base_type_spec",
    [sym_any_type] = "any_type",
    [sym_fixed_pt_type] = "fixed_pt_type",
    [sym_template_type_spec] = "template_type_spec",
    [sym_sequence_type] = "sequence_type",
    [sym_map_type] = "map_type",
    [sym_positive_int_const] = "positive_int_const",
    [sym_const_expr] = "const_expr",
    [sym_or_expr] = "or_expr",
    [sym_xor_expr] = "xor_expr",
    [sym_and_expr] = "and_expr",
    [sym_shift_expr] = "shift_expr",
    [sym_add_expr] = "add_expr",
    [sym_mult_expr] = "mult_expr",
    [sym_unary_expr] = "unary_expr",
    [sym_primary_expr] = "primary_expr",
    [sym_unary_operator] = "unary_operator",
    [sym_literal] = "literal",
    [sym_string_literal] = "string_literal",
    [sym_char_literal] = "char_literal",
    [sym_boolean_literal] = "boolean_literal",
    [sym_preproc_define] = "preproc_define",
    [sym_preproc_call] = "preproc_call",
    [sym_preproc_include] = "preproc_include",
    [sym_system_lib_string] = "system_lib_string",
    [sym_except_dcl] = "except_dcl",
    [sym_interface_dcl] = "interface_dcl",
    [sym_interface_kind] = "interface_kind",
    [sym_interface_forward_dcl] = "interface_forward_dcl",
    [sym_interface_def] = "interface_def",
    [sym_interface_header] = "interface_header",
    [sym_interface_inheritance_spec] = "interface_inheritance_spec",
    [sym_interface_name] = "interface_name",
    [sym_interface_body] = "interface_body",
    [sym_export] = "export",
    [sym_op_dcl] = "op_dcl",
    [sym_op_type_spec] = "op_type_spec",
    [sym_parameter_dcls] = "parameter_dcls",
    [sym_param_dcl] = "param_dcl",
    [sym_param_attribute] = "param_attribute",
    [sym_raises_expr] = "raises_expr",
    [sym_attr_dcl] = "attr_dcl",
    [sym_readonly_attr_spec] = "readonly_attr_spec",
    [sym_readonly_attr_declarator] = "readonly_attr_declarator",
    [sym_attr_spec] = "attr_spec",
    [sym_attr_declarator] = "attr_declarator",
    [sym_attr_raises_expr] = "attr_raises_expr",
    [sym_get_excep_expr] = "get_excep_expr",
    [sym_set_excep_expr] = "set_excep_expr",
    [sym_exception_list] = "exception_list",
    [sym_bitset_dcl] = "bitset_dcl",
    [sym_bitfield] = "bitfield",
    [sym_bitfield_spec] = "bitfield_spec",
    [sym_destination_type] = "destination_type",
    [sym_bitmask_dcl] = "bitmask_dcl",
    [sym_bit_value] = "bit_value",
    [sym_annotation_dcl] = "annotation_dcl",
    [sym_annotation_body] = "annotation_body",
    [sym_annotation_member] = "annotation_member",
    [sym_annotation_member_type] = "annotation_member_type",
    [sym_any_const_type] = "any_const_type",
    [sym_annotation_appl] = "annotation_appl",
    [sym_extend_annotation_appl] = "extend_annotation_appl",
    [sym_annotation_appl_custom_body] = "annotation_appl_custom_body",
    [sym_annotation_appl_params] = "annotation_appl_params",
    [sym_annotation_appl_param] = "annotation_appl_param",
    [sym_annotation_appl_builtin_body] = "annotation_appl_builtin_body",
    [sym_annotation_appl_id] = "annotation_appl_id",
    [sym_annotation_appl_autoid] = "annotation_appl_autoid",
    [sym_autoid_kind] = "autoid_kind",
    [sym_annotation_appl_optional] = "annotation_appl_optional",
    [sym_annotation_appl_position] = "annotation_appl_position",
    [sym_annotation_appl_value] = "annotation_appl_value",
    [sym_annotation_appl_extensibility] = "annotation_appl_extensibility",
    [sym_extensibility_kind] = "extensibility_kind",
    [sym_annotation_appl_final] = "annotation_appl_final",
    [sym_annotation_appl_appendable] = "annotation_appl_appendable",
    [sym_annotation_appl_mutable] = "annotation_appl_mutable",
    [sym_annotation_appl_key] = "annotation_appl_key",
    [sym_annotation_appl_must_understand] = "annotation_appl_must_understand",
    [sym_annotation_appl_default_literal] = "annotation_appl_default_literal",
    [sym_annotation_appl_default] = "annotation_appl_default",
    [sym_annotation_appl_range] = "annotation_appl_range",
    [sym_min_expr] = "min_expr",
    [sym_max_expr] = "max_expr",
    [sym_annotation_appl_min] = "annotation_appl_min",
    [sym_annotation_appl_max] = "annotation_appl_max",
    [sym_annotation_appl_unit] = "annotation_appl_unit",
    [sym_annotation_appl_bit_bound] = "annotation_appl_bit_bound",
    [sym_annotation_appl_external] = "annotation_appl_external",
    [sym_annotation_appl_nested] = "annotation_appl_nested",
    [sym_annotation_appl_verbatim] = "annotation_appl_verbatim",
    [sym_verbatim_language] = "verbatim_language",
    [sym_placement_kind] = "placement_kind",
    [sym_annotation_appl_service] = "annotation_appl_service",
    [sym_service_platform] = "service_platform",
    [sym_annotation_appl_oneway] = "annotation_appl_oneway",
    [sym_annotation_appl_ami] = "annotation_appl_ami",
    [sym_template_module_dcl] = "template_module_dcl",
    [sym_formal_parameters] = "formal_parameters",
    [sym_formal_parameter] = "formal_parameter",
    [sym_formal_parameter_type] = "formal_parameter_type",
    [sym_tpl_definition] = "tpl_definition",
    [sym_template_module_inst] = "template_module_inst",
    [sym_actual_parameters] = "actual_parameters",
    [sym_actual_parameter] = "actual_parameter",
    [sym_template_module_ref] = "template_module_ref",
    [sym_formal_parameter_names] = "formal_parameter_names",
    [sym_value_dcl] = "value_dcl",
    [sym_value_def] = "value_def",
    [sym_value_kind] = "value_kind",
    [sym_value_header] = "value_header",
    [sym_value_inheritance_spec] = "value_inheritance_spec",
    [sym_value_inheritance] = "value_inheritance",
    [sym_value_supports] = "value_supports",
    [sym_value_name] = "value_name",
    [sym_value_element] = "value_element",
    [sym_state_member] = "state_member",
    [sym_init_dcl] = "init_dcl",
    [sym_init_param_dcls] = "init_param_dcls",
    [sym_init_param_dcl] = "init_param_dcl",
    [sym_value_forward_dcl] = "value_forward_dcl",
    [sym_typedef_dcl] = "typedef_dcl",
    [sym_type_declarator] = "type_declarator",
    [sym_any_declarators] = "any_declarators",
    [sym_any_declarator] = "any_declarator",
    [sym_simple_declarator] = "simple_declarator",
    [sym_declarator] = "declarator",
    [sym_declarators] = "declarators",
    [sym_array_declarator] = "array_declarator",
    [sym_fixed_array_size] = "fixed_array_size",
    [sym_enum_dcl] = "enum_dcl",
    [sym_enumerator] = "enumerator",
    [sym_enum_modifier] = "enum_modifier",
    [sym_enum_anno] = "enum_anno",
    [sym_union_dcl] = "union_dcl",
    [sym_union_forward_dcl] = "union_forward_dcl",
    [sym_union_def] = "union_def",
    [sym_case] = "case",
    [sym_case_label] = "case_label",
    [sym_element_spec] = "element_spec",
    [sym_switch_type_spec] = "switch_type_spec",
    [sym_type_id_dcl] = "type_id_dcl",
    [sym_type_prefix_dcl] = "type_prefix_dcl",
    [sym_import_dcl] = "import_dcl",
    [sym_imported_scope] = "imported_scope",
    [sym_object_type] = "object_type",
    [sym_op_oneway_dcl] = "op_oneway_dcl",
    [sym_in_parameter_dcls] = "in_parameter_dcls",
    [sym_in_param_dcl] = "in_param_dcl",
    [sym_op_with_context] = "op_with_context",
    [sym_context_expr] = "context_expr",
    [sym_value_box_def] = "value_box_def",
    [sym_value_abs_def] = "value_abs_def",
    [sym_component_dcl] = "component_dcl",
    [sym_component_forward_dcl] = "component_forward_dcl",
    [sym_component_def] = "component_def",
    [sym_component_header] = "component_header",
    [sym_component_inheritance_spec] = "component_inheritance_spec",
    [sym_component_body] = "component_body",
    [sym_component_export] = "component_export",
    [sym_provides_dcl] = "provides_dcl",
    [sym_interface_type] = "interface_type",
    [sym_uses_dcl] = "uses_dcl",
    [sym_home_dcl] = "home_dcl",
    [sym_home_header] = "home_header",
    [sym_home_inheritance_spec] = "home_inheritance_spec",
    [sym_home_body] = "home_body",
    [sym_home_export] = "home_export",
    [sym_factory_dcl] = "factory_dcl",
    [sym_factory_param_dcls] = "factory_param_dcls",
    [sym_factory_param_dcl] = "factory_param_dcl",
    [sym_supported_interface_spec] = "supported_interface_spec",
    [sym_emits_dcl] = "emits_dcl",
    [sym_publishes_dcl] = "publishes_dcl",
    [sym_consumes_dcl] = "consumes_dcl",
    [sym_primary_key_spec] = "primary_key_spec",
    [sym_finder_dcl] = "finder_dcl",
    [sym_event_dcl] = "event_dcl",
    [sym_event_forward_dcl] = "event_forward_dcl",
    [sym_event_abs_def] = "event_abs_def",
    [sym_event_def] = "event_def",
    [sym_event_header] = "event_header",
    [sym_porttype_dcl] = "porttype_dcl",
    [sym_porttype_forward_dcl] = "porttype_forward_dcl",
    [sym_porttype_def] = "porttype_def",
    [sym_port_body] = "port_body",
    [sym_port_ref] = "port_ref",
    [sym_port_export] = "port_export",
    [sym_port_dcl] = "port_dcl",
    [sym_connector_dcl] = "connector_dcl",
    [sym_connector_header] = "connector_header",
    [sym_connector_inherit_spec] = "connector_inherit_spec",
    [sym_connector_export] = "connector_export",
    [sym_definition] = "definition",
    [sym_type_dcl] = "type_dcl",
    [sym_constr_type_dcl] = "constr_type_dcl",
    [sym_native_dcl] = "native_dcl",
    [sym_module_dcl] = "module_dcl",
    [sym_struct_dcl] = "struct_dcl",
    [sym_struct_forward_dcl] = "struct_forward_dcl",
    [sym_struct_def] = "struct_def",
    [sym_member] = "member",
    [sym_default] = "default",
    [sym_const_dcl] = "const_dcl",
    [sym_const_type] = "const_type",
    [sym_comment] = "comment",
    [aux_sym_specification_repeat1] = "specification_repeat1",
    [aux_sym_string_literal_repeat1] = "string_literal_repeat1",
    [aux_sym_char_literal_repeat1] = "char_literal_repeat1",
    [aux_sym_except_dcl_repeat1] = "except_dcl_repeat1",
    [aux_sym_interface_def_repeat1] = "interface_def_repeat1",
    [aux_sym_interface_inheritance_spec_repeat1] = "interface_inheritance_spec_repeat1",
    [aux_sym_interface_body_repeat1] = "interface_body_repeat1",
    [aux_sym_parameter_dcls_repeat1] = "parameter_dcls_repeat1",
    [aux_sym_raises_expr_repeat1] = "raises_expr_repeat1",
    [aux_sym_readonly_attr_declarator_repeat1] = "readonly_attr_declarator_repeat1",
    [aux_sym_bitset_dcl_repeat1] = "bitset_dcl_repeat1",
    [aux_sym_bitfield_repeat1] = "bitfield_repeat1",
    [aux_sym_bitmask_dcl_repeat1] = "bitmask_dcl_repeat1",
    [aux_sym_annotation_dcl_repeat1] = "annotation_dcl_repeat1",
    [aux_sym_annotation_appl_params_repeat1] = "annotation_appl_params_repeat1",
    [aux_sym_template_module_dcl_repeat1] = "template_module_dcl_repeat1",
    [aux_sym_formal_parameters_repeat1] = "formal_parameters_repeat1",
    [aux_sym_actual_parameters_repeat1] = "actual_parameters_repeat1",
    [aux_sym_formal_parameter_names_repeat1] = "formal_parameter_names_repeat1",
    [aux_sym_value_def_repeat1] = "value_def_repeat1",
    [aux_sym_value_inheritance_spec_repeat1] = "value_inheritance_spec_repeat1",
    [aux_sym_init_param_dcls_repeat1] = "init_param_dcls_repeat1",
    [aux_sym_any_declarators_repeat1] = "any_declarators_repeat1",
    [aux_sym_declarators_repeat1] = "declarators_repeat1",
    [aux_sym_array_declarator_repeat1] = "array_declarator_repeat1",
    [aux_sym_enum_dcl_repeat1] = "enum_dcl_repeat1",
    [aux_sym_enumerator_repeat1] = "enumerator_repeat1",
    [aux_sym_union_def_repeat1] = "union_def_repeat1",
    [aux_sym_in_parameter_dcls_repeat1] = "in_parameter_dcls_repeat1",
    [aux_sym_context_expr_repeat1] = "context_expr_repeat1",
    [aux_sym_component_body_repeat1] = "component_body_repeat1",
    [aux_sym_home_body_repeat1] = "home_body_repeat1",
    [aux_sym_factory_param_dcls_repeat1] = "factory_param_dcls_repeat1",
    [aux_sym_port_body_repeat1] = "port_body_repeat1",
    [aux_sym_connector_dcl_repeat1] = "connector_dcl_repeat1",
    [aux_sym_module_dcl_repeat1] = "module_dcl_repeat1",
};

static const TSSymbol ts_symbol_map[] = {
    [ts_builtin_sym_end] = ts_builtin_sym_end,
    [anon_sym_short] = anon_sym_short,
    [anon_sym_int16] = anon_sym_int16,
    [anon_sym_long] = anon_sym_long,
    [anon_sym_int32] = anon_sym_int32,
    [anon_sym_longlong] = anon_sym_longlong,
    [anon_sym_int64] = anon_sym_int64,
    [sym_unsigned_tiny_int] = sym_unsigned_tiny_int,
    [sym_boolean_type] = sym_boolean_type,
    [anon_sym_fixed] = anon_sym_fixed,
    [sym_octet_type] = sym_octet_type,
    [sym_signed_tiny_int] = sym_signed_tiny_int,
    [anon_sym_unsignedshort] = anon_sym_unsignedshort,
    [anon_sym_uint16] = anon_sym_uint16,
    [anon_sym_unsignedlong] = anon_sym_unsignedlong,
    [anon_sym_uint32] = anon_sym_uint32,
    [anon_sym_unsignedlonglong] = anon_sym_unsignedlonglong,
    [anon_sym_uint64] = anon_sym_uint64,
    [anon_sym_float] = anon_sym_float,
    [anon_sym_double] = anon_sym_double,
    [anon_sym_longdouble] = anon_sym_longdouble,
    [anon_sym_char] = anon_sym_char,
    [anon_sym_wchar] = anon_sym_wchar,
    [anon_sym_COLON_COLON] = anon_sym_COLON_COLON,
    [anon_sym_string] = anon_sym_string,
    [anon_sym_wstring] = anon_sym_wstring,
    [anon_sym_LT] = anon_sym_LT,
    [anon_sym_GT] = anon_sym_GT,
    [anon_sym_any] = anon_sym_any,
    [anon_sym_COMMA] = anon_sym_COMMA,
    [anon_sym_sequence] = anon_sym_sequence,
    [anon_sym_map] = anon_sym_map,
    [anon_sym_PIPE] = anon_sym_PIPE,
    [anon_sym_CARET] = anon_sym_CARET,
    [anon_sym_AMP] = anon_sym_AMP,
    [anon_sym_GT_GT] = anon_sym_GT_GT,
    [anon_sym_LT_LT] = anon_sym_LT_LT,
    [anon_sym_PLUS] = anon_sym_PLUS,
    [anon_sym_DASH] = anon_sym_DASH,
    [anon_sym_STAR] = anon_sym_STAR,
    [anon_sym_SLASH] = anon_sym_SLASH,
    [anon_sym_PERCENT] = anon_sym_PERCENT,
    [anon_sym_LPAREN] = anon_sym_LPAREN,
    [anon_sym_RPAREN] = anon_sym_RPAREN,
    [anon_sym_TILDE] = anon_sym_TILDE,
    [sym_escape_sequence] = sym_escape_sequence,
    [anon_sym_L] = anon_sym_L,
    [anon_sym_DQUOTE] = anon_sym_DQUOTE,
    [aux_sym_string_literal_token1] = aux_sym_string_literal_token1,
    [anon_sym_SQUOTE] = anon_sym_SQUOTE,
    [aux_sym_char_literal_token1] = aux_sym_char_literal_token1,
    [anon_sym_TRUE] = anon_sym_TRUE,
    [anon_sym_FALSE] = anon_sym_FALSE,
    [sym_number_literal] = sym_number_literal,
    [anon_sym_POUNDdefine] = anon_sym_POUNDdefine,
    [aux_sym_preproc_define_token1] = aux_sym_preproc_define_token1,
    [aux_sym_preproc_call_token1] = aux_sym_preproc_call_token1,
    [sym_preproc_directive] = sym_preproc_directive,
    [sym_preproc_arg] = sym_preproc_arg,
    [aux_sym_preproc_include_token1] = aux_sym_preproc_include_token1,
    [sym_system_lib_path] = sym_system_lib_path,
    [anon_sym_exception] = anon_sym_exception,
    [anon_sym_LBRACE] = anon_sym_LBRACE,
    [anon_sym_RBRACE] = anon_sym_RBRACE,
    [anon_sym_local] = anon_sym_local,
    [anon_sym_abstract] = anon_sym_abstract,
    [anon_sym_interface] = anon_sym_interface,
    [anon_sym_COLON] = anon_sym_COLON,
    [anon_sym_SEMI] = anon_sym_SEMI,
    [anon_sym_void] = anon_sym_void,
    [anon_sym_in] = anon_sym_in,
    [anon_sym_out] = anon_sym_out,
    [anon_sym_inout] = anon_sym_inout,
    [anon_sym_raises] = anon_sym_raises,
    [anon_sym_readonly] = anon_sym_readonly,
    [anon_sym_attribute] = anon_sym_attribute,
    [anon_sym_getraises] = anon_sym_getraises,
    [anon_sym_setraises] = anon_sym_setraises,
    [anon_sym_bitset] = anon_sym_bitset,
    [anon_sym_bitfield] = anon_sym_bitfield,
    [anon_sym_bitmask] = anon_sym_bitmask,
    [anon_sym_ATannotation] = anon_sym_ATannotation,
    [anon_sym_default] = anon_sym_default,
    [anon_sym_AT] = anon_sym_AT,
    [anon_sym_SLASH_SLASH_AT] = anon_sym_SLASH_SLASH_AT,
    [aux_sym_extend_annotation_appl_token1] = aux_sym_extend_annotation_appl_token1,
    [anon_sym_EQ] = anon_sym_EQ,
    [anon_sym_id] = anon_sym_id,
    [anon_sym_autoid] = anon_sym_autoid,
    [anon_sym_SEQUENTIAL] = anon_sym_SEQUENTIAL,
    [anon_sym_HASH] = anon_sym_HASH,
    [anon_sym_optional] = anon_sym_optional,
    [anon_sym_position] = anon_sym_position,
    [anon_sym_value] = anon_sym_value,
    [anon_sym_extensibility] = anon_sym_extensibility,
    [anon_sym_FINAL] = anon_sym_FINAL,
    [anon_sym_APPENDABLE] = anon_sym_APPENDABLE,
    [anon_sym_MUTABLE] = anon_sym_MUTABLE,
    [anon_sym_final] = anon_sym_final,
    [anon_sym_appendable] = anon_sym_appendable,
    [anon_sym_mutable] = anon_sym_mutable,
    [anon_sym_key] = anon_sym_key,
    [anon_sym_must_understand] = anon_sym_must_understand,
    [anon_sym_default_literal] = anon_sym_default_literal,
    [anon_sym_range] = anon_sym_range,
    [anon_sym_min] = anon_sym_min,
    [anon_sym_max] = anon_sym_max,
    [anon_sym_unit] = anon_sym_unit,
    [anon_sym_bit_bound] = anon_sym_bit_bound,
    [anon_sym_external] = anon_sym_external,
    [anon_sym_nested] = anon_sym_nested,
    [anon_sym_verbatim] = anon_sym_verbatim,
    [anon_sym_c] = anon_sym_c,
    [anon_sym_c_PLUS_PLUS] = anon_sym_c_PLUS_PLUS,
    [anon_sym_java] = anon_sym_java,
    [anon_sym_idl] = anon_sym_idl,
    [anon_sym_BEGIN_FILE] = anon_sym_BEGIN_FILE,
    [anon_sym_BEFORE_DECLARATION] = anon_sym_BEFORE_DECLARATION,
    [anon_sym_BEGIN_DECLARATION] = anon_sym_BEGIN_DECLARATION,
    [anon_sym_END_DECLARATION] = anon_sym_END_DECLARATION,
    [anon_sym_AFTER_DECLARATION] = anon_sym_AFTER_DECLARATION,
    [anon_sym_END_FILE] = anon_sym_END_FILE,
    [anon_sym_service] = anon_sym_service,
    [anon_sym_CORBA] = anon_sym_CORBA,
    [anon_sym_DDS] = anon_sym_DDS,
    [anon_sym_oneway] = anon_sym_oneway,
    [anon_sym_ami] = anon_sym_ami,
    [anon_sym_module] = anon_sym_module,
    [anon_sym_typename] = anon_sym_typename,
    [anon_sym_valuetype] = anon_sym_valuetype,
    [anon_sym_eventtype] = anon_sym_eventtype,
    [anon_sym_struct] = anon_sym_struct,
    [anon_sym_union] = anon_sym_union,
    [anon_sym_enum] = anon_sym_enum,
    [anon_sym_const] = anon_sym_const,
    [anon_sym_alias] = anon_sym_alias,
    [anon_sym_custom] = anon_sym_custom,
    [anon_sym_truncatable] = anon_sym_truncatable,
    [anon_sym_supports] = anon_sym_supports,
    [anon_sym_public] = anon_sym_public,
    [anon_sym_private] = anon_sym_private,
    [anon_sym_factory] = anon_sym_factory,
    [anon_sym_typedef] = anon_sym_typedef,
    [anon_sym_LBRACK] = anon_sym_LBRACK,
    [anon_sym_RBRACK] = anon_sym_RBRACK,
    [anon_sym_ATdefault_literal] = anon_sym_ATdefault_literal,
    [anon_sym_ATignore_literal_names] = anon_sym_ATignore_literal_names,
    [anon_sym_switch] = anon_sym_switch,
    [anon_sym_case] = anon_sym_case,
    [anon_sym_typeid] = anon_sym_typeid,
    [anon_sym_typeprefix] = anon_sym_typeprefix,
    [anon_sym_import] = anon_sym_import,
    [anon_sym_Object] = anon_sym_Object,
    [anon_sym_context] = anon_sym_context,
    [sym_value_base_type] = sym_value_base_type,
    [anon_sym_component] = anon_sym_component,
    [anon_sym_provides] = anon_sym_provides,
    [anon_sym_uses] = anon_sym_uses,
    [anon_sym_multiple] = anon_sym_multiple,
    [anon_sym_home] = anon_sym_home,
    [anon_sym_manages] = anon_sym_manages,
    [anon_sym_emits] = anon_sym_emits,
    [anon_sym_publishes] = anon_sym_publishes,
    [anon_sym_consumes] = anon_sym_consumes,
    [anon_sym_primarykey] = anon_sym_primarykey,
    [anon_sym_finder] = anon_sym_finder,
    [anon_sym_porttype] = anon_sym_porttype,
    [anon_sym_port] = anon_sym_port,
    [anon_sym_mirrorport] = anon_sym_mirrorport,
    [anon_sym_connector] = anon_sym_connector,
    [anon_sym_native] = anon_sym_native,
    [sym_identifier] = sym_identifier,
    [anon_sym_SLASH_SLASH] = anon_sym_SLASH_SLASH,
    [aux_sym_comment_token1] = aux_sym_comment_token1,
    [anon_sym_SLASH_STAR] = anon_sym_SLASH_STAR,
    [aux_sym_comment_token2] = aux_sym_comment_token2,
    [sym_specification] = sym_specification,
    [sym_signed_short_int] = sym_signed_short_int,
    [sym_signed_long_int] = sym_signed_long_int,
    [sym_signed_longlong_int] = sym_signed_longlong_int,
    [sym_unsigned_int] = sym_unsigned_int,
    [sym_fixed_pt_const_type] = sym_fixed_pt_const_type,
    [sym_integer_type] = sym_integer_type,
    [sym_signed_int] = sym_signed_int,
    [sym_unsigned_short_int] = sym_unsigned_short_int,
    [sym_unsigned_long_int] = sym_unsigned_long_int,
    [sym_unsigned_longlong_int] = sym_unsigned_longlong_int,
    [sym_floating_pt_type] = sym_floating_pt_type,
    [sym_char_type] = sym_char_type,
    [sym_scoped_name] = sym_scoped_name,
    [sym_string_type] = sym_string_type,
    [sym_type_spec] = sym_type_spec,
    [sym_simple_type_spec] = sym_simple_type_spec,
    [sym_base_type_spec] = sym_base_type_spec,
    [sym_any_type] = sym_any_type,
    [sym_fixed_pt_type] = sym_fixed_pt_type,
    [sym_template_type_spec] = sym_template_type_spec,
    [sym_sequence_type] = sym_sequence_type,
    [sym_map_type] = sym_map_type,
    [sym_positive_int_const] = sym_positive_int_const,
    [sym_const_expr] = sym_const_expr,
    [sym_or_expr] = sym_or_expr,
    [sym_xor_expr] = sym_xor_expr,
    [sym_and_expr] = sym_and_expr,
    [sym_shift_expr] = sym_shift_expr,
    [sym_add_expr] = sym_add_expr,
    [sym_mult_expr] = sym_mult_expr,
    [sym_unary_expr] = sym_unary_expr,
    [sym_primary_expr] = sym_primary_expr,
    [sym_unary_operator] = sym_unary_operator,
    [sym_literal] = sym_literal,
    [sym_string_literal] = sym_string_literal,
    [sym_char_literal] = sym_char_literal,
    [sym_boolean_literal] = sym_boolean_literal,
    [sym_preproc_define] = sym_preproc_define,
    [sym_preproc_call] = sym_preproc_call,
    [sym_preproc_include] = sym_preproc_include,
    [sym_system_lib_string] = sym_system_lib_string,
    [sym_except_dcl] = sym_except_dcl,
    [sym_interface_dcl] = sym_interface_dcl,
    [sym_interface_kind] = sym_interface_kind,
    [sym_interface_forward_dcl] = sym_interface_forward_dcl,
    [sym_interface_def] = sym_interface_def,
    [sym_interface_header] = sym_interface_header,
    [sym_interface_inheritance_spec] = sym_interface_inheritance_spec,
    [sym_interface_name] = sym_interface_name,
    [sym_interface_body] = sym_interface_body,
    [sym_export] = sym_export,
    [sym_op_dcl] = sym_op_dcl,
    [sym_op_type_spec] = sym_op_type_spec,
    [sym_parameter_dcls] = sym_parameter_dcls,
    [sym_param_dcl] = sym_param_dcl,
    [sym_param_attribute] = sym_param_attribute,
    [sym_raises_expr] = sym_raises_expr,
    [sym_attr_dcl] = sym_attr_dcl,
    [sym_readonly_attr_spec] = sym_readonly_attr_spec,
    [sym_readonly_attr_declarator] = sym_readonly_attr_declarator,
    [sym_attr_spec] = sym_attr_spec,
    [sym_attr_declarator] = sym_attr_declarator,
    [sym_attr_raises_expr] = sym_attr_raises_expr,
    [sym_get_excep_expr] = sym_get_excep_expr,
    [sym_set_excep_expr] = sym_set_excep_expr,
    [sym_exception_list] = sym_exception_list,
    [sym_bitset_dcl] = sym_bitset_dcl,
    [sym_bitfield] = sym_bitfield,
    [sym_bitfield_spec] = sym_bitfield_spec,
    [sym_destination_type] = sym_destination_type,
    [sym_bitmask_dcl] = sym_bitmask_dcl,
    [sym_bit_value] = sym_bit_value,
    [sym_annotation_dcl] = sym_annotation_dcl,
    [sym_annotation_body] = sym_annotation_body,
    [sym_annotation_member] = sym_annotation_member,
    [sym_annotation_member_type] = sym_annotation_member_type,
    [sym_any_const_type] = sym_any_const_type,
    [sym_annotation_appl] = sym_annotation_appl,
    [sym_extend_annotation_appl] = sym_extend_annotation_appl,
    [sym_annotation_appl_custom_body] = sym_annotation_appl_custom_body,
    [sym_annotation_appl_params] = sym_annotation_appl_params,
    [sym_annotation_appl_param] = sym_annotation_appl_param,
    [sym_annotation_appl_builtin_body] = sym_annotation_appl_builtin_body,
    [sym_annotation_appl_id] = sym_annotation_appl_id,
    [sym_annotation_appl_autoid] = sym_annotation_appl_autoid,
    [sym_autoid_kind] = sym_autoid_kind,
    [sym_annotation_appl_optional] = sym_annotation_appl_optional,
    [sym_annotation_appl_position] = sym_annotation_appl_position,
    [sym_annotation_appl_value] = sym_annotation_appl_value,
    [sym_annotation_appl_extensibility] = sym_annotation_appl_extensibility,
    [sym_extensibility_kind] = sym_extensibility_kind,
    [sym_annotation_appl_final] = sym_annotation_appl_final,
    [sym_annotation_appl_appendable] = sym_annotation_appl_appendable,
    [sym_annotation_appl_mutable] = sym_annotation_appl_mutable,
    [sym_annotation_appl_key] = sym_annotation_appl_key,
    [sym_annotation_appl_must_understand] = sym_annotation_appl_must_understand,
    [sym_annotation_appl_default_literal] = sym_annotation_appl_default_literal,
    [sym_annotation_appl_default] = sym_annotation_appl_default,
    [sym_annotation_appl_range] = sym_annotation_appl_range,
    [sym_min_expr] = sym_min_expr,
    [sym_max_expr] = sym_max_expr,
    [sym_annotation_appl_min] = sym_annotation_appl_min,
    [sym_annotation_appl_max] = sym_annotation_appl_max,
    [sym_annotation_appl_unit] = sym_annotation_appl_unit,
    [sym_annotation_appl_bit_bound] = sym_annotation_appl_bit_bound,
    [sym_annotation_appl_external] = sym_annotation_appl_external,
    [sym_annotation_appl_nested] = sym_annotation_appl_nested,
    [sym_annotation_appl_verbatim] = sym_annotation_appl_verbatim,
    [sym_verbatim_language] = sym_verbatim_language,
    [sym_placement_kind] = sym_placement_kind,
    [sym_annotation_appl_service] = sym_annotation_appl_service,
    [sym_service_platform] = sym_service_platform,
    [sym_annotation_appl_oneway] = sym_annotation_appl_oneway,
    [sym_annotation_appl_ami] = sym_annotation_appl_ami,
    [sym_template_module_dcl] = sym_template_module_dcl,
    [sym_formal_parameters] = sym_formal_parameters,
    [sym_formal_parameter] = sym_formal_parameter,
    [sym_formal_parameter_type] = sym_formal_parameter_type,
    [sym_tpl_definition] = sym_tpl_definition,
    [sym_template_module_inst] = sym_template_module_inst,
    [sym_actual_parameters] = sym_actual_parameters,
    [sym_actual_parameter] = sym_actual_parameter,
    [sym_template_module_ref] = sym_template_module_ref,
    [sym_formal_parameter_names] = sym_formal_parameter_names,
    [sym_value_dcl] = sym_value_dcl,
    [sym_value_def] = sym_value_def,
    [sym_value_kind] = sym_value_kind,
    [sym_value_header] = sym_value_header,
    [sym_value_inheritance_spec] = sym_value_inheritance_spec,
    [sym_value_inheritance] = sym_value_inheritance,
    [sym_value_supports] = sym_value_supports,
    [sym_value_name] = sym_value_name,
    [sym_value_element] = sym_value_element,
    [sym_state_member] = sym_state_member,
    [sym_init_dcl] = sym_init_dcl,
    [sym_init_param_dcls] = sym_init_param_dcls,
    [sym_init_param_dcl] = sym_init_param_dcl,
    [sym_value_forward_dcl] = sym_value_forward_dcl,
    [sym_typedef_dcl] = sym_typedef_dcl,
    [sym_type_declarator] = sym_type_declarator,
    [sym_any_declarators] = sym_any_declarators,
    [sym_any_declarator] = sym_any_declarator,
    [sym_simple_declarator] = sym_simple_declarator,
    [sym_declarator] = sym_declarator,
    [sym_declarators] = sym_declarators,
    [sym_array_declarator] = sym_array_declarator,
    [sym_fixed_array_size] = sym_fixed_array_size,
    [sym_enum_dcl] = sym_enum_dcl,
    [sym_enumerator] = sym_enumerator,
    [sym_enum_modifier] = sym_enum_modifier,
    [sym_enum_anno] = sym_enum_anno,
    [sym_union_dcl] = sym_union_dcl,
    [sym_union_forward_dcl] = sym_union_forward_dcl,
    [sym_union_def] = sym_union_def,
    [sym_case] = sym_case,
    [sym_case_label] = sym_case_label,
    [sym_element_spec] = sym_element_spec,
    [sym_switch_type_spec] = sym_switch_type_spec,
    [sym_type_id_dcl] = sym_type_id_dcl,
    [sym_type_prefix_dcl] = sym_type_prefix_dcl,
    [sym_import_dcl] = sym_import_dcl,
    [sym_imported_scope] = sym_imported_scope,
    [sym_object_type] = sym_object_type,
    [sym_op_oneway_dcl] = sym_op_oneway_dcl,
    [sym_in_parameter_dcls] = sym_in_parameter_dcls,
    [sym_in_param_dcl] = sym_in_param_dcl,
    [sym_op_with_context] = sym_op_with_context,
    [sym_context_expr] = sym_context_expr,
    [sym_value_box_def] = sym_value_box_def,
    [sym_value_abs_def] = sym_value_abs_def,
    [sym_component_dcl] = sym_component_dcl,
    [sym_component_forward_dcl] = sym_component_forward_dcl,
    [sym_component_def] = sym_component_def,
    [sym_component_header] = sym_component_header,
    [sym_component_inheritance_spec] = sym_component_inheritance_spec,
    [sym_component_body] = sym_component_body,
    [sym_component_export] = sym_component_export,
    [sym_provides_dcl] = sym_provides_dcl,
    [sym_interface_type] = sym_interface_type,
    [sym_uses_dcl] = sym_uses_dcl,
    [sym_home_dcl] = sym_home_dcl,
    [sym_home_header] = sym_home_header,
    [sym_home_inheritance_spec] = sym_home_inheritance_spec,
    [sym_home_body] = sym_home_body,
    [sym_home_export] = sym_home_export,
    [sym_factory_dcl] = sym_factory_dcl,
    [sym_factory_param_dcls] = sym_factory_param_dcls,
    [sym_factory_param_dcl] = sym_factory_param_dcl,
    [sym_supported_interface_spec] = sym_supported_interface_spec,
    [sym_emits_dcl] = sym_emits_dcl,
    [sym_publishes_dcl] = sym_publishes_dcl,
    [sym_consumes_dcl] = sym_consumes_dcl,
    [sym_primary_key_spec] = sym_primary_key_spec,
    [sym_finder_dcl] = sym_finder_dcl,
    [sym_event_dcl] = sym_event_dcl,
    [sym_event_forward_dcl] = sym_event_forward_dcl,
    [sym_event_abs_def] = sym_event_abs_def,
    [sym_event_def] = sym_event_def,
    [sym_event_header] = sym_event_header,
    [sym_porttype_dcl] = sym_porttype_dcl,
    [sym_porttype_forward_dcl] = sym_porttype_forward_dcl,
    [sym_porttype_def] = sym_porttype_def,
    [sym_port_body] = sym_port_body,
    [sym_port_ref] = sym_port_ref,
    [sym_port_export] = sym_port_export,
    [sym_port_dcl] = sym_port_dcl,
    [sym_connector_dcl] = sym_connector_dcl,
    [sym_connector_header] = sym_connector_header,
    [sym_connector_inherit_spec] = sym_connector_inherit_spec,
    [sym_connector_export] = sym_connector_export,
    [sym_definition] = sym_definition,
    [sym_type_dcl] = sym_type_dcl,
    [sym_constr_type_dcl] = sym_constr_type_dcl,
    [sym_native_dcl] = sym_native_dcl,
    [sym_module_dcl] = sym_module_dcl,
    [sym_struct_dcl] = sym_struct_dcl,
    [sym_struct_forward_dcl] = sym_struct_forward_dcl,
    [sym_struct_def] = sym_struct_def,
    [sym_member] = sym_member,
    [sym_default] = sym_default,
    [sym_const_dcl] = sym_const_dcl,
    [sym_const_type] = sym_const_type,
    [sym_comment] = sym_comment,
    [aux_sym_specification_repeat1] = aux_sym_specification_repeat1,
    [aux_sym_string_literal_repeat1] = aux_sym_string_literal_repeat1,
    [aux_sym_char_literal_repeat1] = aux_sym_char_literal_repeat1,
    [aux_sym_except_dcl_repeat1] = aux_sym_except_dcl_repeat1,
    [aux_sym_interface_def_repeat1] = aux_sym_interface_def_repeat1,
    [aux_sym_interface_inheritance_spec_repeat1] = aux_sym_interface_inheritance_spec_repeat1,
    [aux_sym_interface_body_repeat1] = aux_sym_interface_body_repeat1,
    [aux_sym_parameter_dcls_repeat1] = aux_sym_parameter_dcls_repeat1,
    [aux_sym_raises_expr_repeat1] = aux_sym_raises_expr_repeat1,
    [aux_sym_readonly_attr_declarator_repeat1] = aux_sym_readonly_attr_declarator_repeat1,
    [aux_sym_bitset_dcl_repeat1] = aux_sym_bitset_dcl_repeat1,
    [aux_sym_bitfield_repeat1] = aux_sym_bitfield_repeat1,
    [aux_sym_bitmask_dcl_repeat1] = aux_sym_bitmask_dcl_repeat1,
    [aux_sym_annotation_dcl_repeat1] = aux_sym_annotation_dcl_repeat1,
    [aux_sym_annotation_appl_params_repeat1] = aux_sym_annotation_appl_params_repeat1,
    [aux_sym_template_module_dcl_repeat1] = aux_sym_template_module_dcl_repeat1,
    [aux_sym_formal_parameters_repeat1] = aux_sym_formal_parameters_repeat1,
    [aux_sym_actual_parameters_repeat1] = aux_sym_actual_parameters_repeat1,
    [aux_sym_formal_parameter_names_repeat1] = aux_sym_formal_parameter_names_repeat1,
    [aux_sym_value_def_repeat1] = aux_sym_value_def_repeat1,
    [aux_sym_value_inheritance_spec_repeat1] = aux_sym_value_inheritance_spec_repeat1,
    [aux_sym_init_param_dcls_repeat1] = aux_sym_init_param_dcls_repeat1,
    [aux_sym_any_declarators_repeat1] = aux_sym_any_declarators_repeat1,
    [aux_sym_declarators_repeat1] = aux_sym_declarators_repeat1,
    [aux_sym_array_declarator_repeat1] = aux_sym_array_declarator_repeat1,
    [aux_sym_enum_dcl_repeat1] = aux_sym_enum_dcl_repeat1,
    [aux_sym_enumerator_repeat1] = aux_sym_enumerator_repeat1,
    [aux_sym_union_def_repeat1] = aux_sym_union_def_repeat1,
    [aux_sym_in_parameter_dcls_repeat1] = aux_sym_in_parameter_dcls_repeat1,
    [aux_sym_context_expr_repeat1] = aux_sym_context_expr_repeat1,
    [aux_sym_component_body_repeat1] = aux_sym_component_body_repeat1,
    [aux_sym_home_body_repeat1] = aux_sym_home_body_repeat1,
    [aux_sym_factory_param_dcls_repeat1] = aux_sym_factory_param_dcls_repeat1,
    [aux_sym_port_body_repeat1] = aux_sym_port_body_repeat1,
    [aux_sym_connector_dcl_repeat1] = aux_sym_connector_dcl_repeat1,
    [aux_sym_module_dcl_repeat1] = aux_sym_module_dcl_repeat1,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
    [ts_builtin_sym_end] = {
        .visible = false,
        .named = true,
    },
    [anon_sym_short] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_int16] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_long] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_int32] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_longlong] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_int64] = {
        .visible = true,
        .named = false,
    },
    [sym_unsigned_tiny_int] = {
        .visible = true,
        .named = true,
    },
    [sym_boolean_type] = {
        .visible = true,
        .named = true,
    },
    [anon_sym_fixed] = {
        .visible = true,
        .named = false,
    },
    [sym_octet_type] = {
        .visible = true,
        .named = true,
    },
    [sym_signed_tiny_int] = {
        .visible = true,
        .named = true,
    },
    [anon_sym_unsignedshort] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_uint16] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_unsignedlong] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_uint32] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_unsignedlonglong] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_uint64] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_float] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_double] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_longdouble] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_char] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_wchar] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_COLON_COLON] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_string] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_wstring] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_LT] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_GT] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_any] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_COMMA] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_sequence] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_map] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_PIPE] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_CARET] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_AMP] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_GT_GT] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_LT_LT] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_PLUS] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_DASH] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_STAR] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_SLASH] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_PERCENT] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_LPAREN] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_RPAREN] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_TILDE] = {
        .visible = true,
        .named = false,
    },
    [sym_escape_sequence] = {
        .visible = true,
        .named = true,
    },
    [anon_sym_L] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_DQUOTE] = {
        .visible = true,
        .named = false,
    },
    [aux_sym_string_literal_token1] = {
        .visible = true,
        .named = true,
    },
    [anon_sym_SQUOTE] = {
        .visible = true,
        .named = false,
    },
    [aux_sym_char_literal_token1] = {
        .visible = true,
        .named = true,
    },
    [anon_sym_TRUE] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_FALSE] = {
        .visible = true,
        .named = false,
    },
    [sym_number_literal] = {
        .visible = true,
        .named = true,
    },
    [anon_sym_POUNDdefine] = {
        .visible = true,
        .named = false,
    },
    [aux_sym_preproc_define_token1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_preproc_call_token1] = {
        .visible = false,
        .named = false,
    },
    [sym_preproc_directive] = {
        .visible = true,
        .named = true,
    },
    [sym_preproc_arg] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_preproc_include_token1] = {
        .visible = true,
        .named = true,
    },
    [sym_system_lib_path] = {
        .visible = true,
        .named = true,
    },
    [anon_sym_exception] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_LBRACE] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_RBRACE] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_local] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_abstract] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_interface] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_COLON] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_SEMI] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_void] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_in] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_out] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_inout] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_raises] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_readonly] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_attribute] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_getraises] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_setraises] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_bitset] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_bitfield] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_bitmask] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_ATannotation] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_default] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_AT] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_SLASH_SLASH_AT] = {
        .visible = true,
        .named = false,
    },
    [aux_sym_extend_annotation_appl_token1] = {
        .visible = false,
        .named = false,
    },
    [anon_sym_EQ] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_id] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_autoid] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_SEQUENTIAL] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_HASH] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_optional] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_position] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_value] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_extensibility] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_FINAL] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_APPENDABLE] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_MUTABLE] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_final] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_appendable] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_mutable] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_key] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_must_understand] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_default_literal] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_range] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_min] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_max] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_unit] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_bit_bound] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_external] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_nested] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_verbatim] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_c] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_c_PLUS_PLUS] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_java] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_idl] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_BEGIN_FILE] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_BEFORE_DECLARATION] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_BEGIN_DECLARATION] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_END_DECLARATION] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_AFTER_DECLARATION] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_END_FILE] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_service] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_CORBA] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_DDS] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_oneway] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_ami] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_module] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_typename] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_valuetype] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_eventtype] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_struct] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_union] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_enum] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_const] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_alias] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_custom] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_truncatable] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_supports] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_public] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_private] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_factory] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_typedef] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_LBRACK] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_RBRACK] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_ATdefault_literal] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_ATignore_literal_names] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_switch] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_case] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_typeid] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_typeprefix] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_import] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_Object] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_context] = {
        .visible = true,
        .named = false,
    },
    [sym_value_base_type] = {
        .visible = true,
        .named = true,
    },
    [anon_sym_component] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_provides] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_uses] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_multiple] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_home] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_manages] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_emits] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_publishes] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_consumes] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_primarykey] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_finder] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_porttype] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_port] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_mirrorport] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_connector] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_native] = {
        .visible = true,
        .named = false,
    },
    [sym_identifier] = {
        .visible = true,
        .named = true,
    },
    [anon_sym_SLASH_SLASH] = {
        .visible = true,
        .named = false,
    },
    [aux_sym_comment_token1] = {
        .visible = false,
        .named = false,
    },
    [anon_sym_SLASH_STAR] = {
        .visible = true,
        .named = false,
    },
    [aux_sym_comment_token2] = {
        .visible = false,
        .named = false,
    },
    [sym_specification] = {
        .visible = true,
        .named = true,
    },
    [sym_signed_short_int] = {
        .visible = true,
        .named = true,
    },
    [sym_signed_long_int] = {
        .visible = true,
        .named = true,
    },
    [sym_signed_longlong_int] = {
        .visible = true,
        .named = true,
    },
    [sym_unsigned_int] = {
        .visible = true,
        .named = true,
    },
    [sym_fixed_pt_const_type] = {
        .visible = true,
        .named = true,
    },
    [sym_integer_type] = {
        .visible = true,
        .named = true,
    },
    [sym_signed_int] = {
        .visible = true,
        .named = true,
    },
    [sym_unsigned_short_int] = {
        .visible = true,
        .named = true,
    },
    [sym_unsigned_long_int] = {
        .visible = true,
        .named = true,
    },
    [sym_unsigned_longlong_int] = {
        .visible = true,
        .named = true,
    },
    [sym_floating_pt_type] = {
        .visible = true,
        .named = true,
    },
    [sym_char_type] = {
        .visible = true,
        .named = true,
    },
    [sym_scoped_name] = {
        .visible = true,
        .named = true,
    },
    [sym_string_type] = {
        .visible = true,
        .named = true,
    },
    [sym_type_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_simple_type_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_base_type_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_any_type] = {
        .visible = true,
        .named = true,
    },
    [sym_fixed_pt_type] = {
        .visible = true,
        .named = true,
    },
    [sym_template_type_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_sequence_type] = {
        .visible = true,
        .named = true,
    },
    [sym_map_type] = {
        .visible = true,
        .named = true,
    },
    [sym_positive_int_const] = {
        .visible = true,
        .named = true,
    },
    [sym_const_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_or_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_xor_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_and_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_shift_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_add_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_mult_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_unary_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_primary_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_unary_operator] = {
        .visible = true,
        .named = true,
    },
    [sym_literal] = {
        .visible = true,
        .named = true,
    },
    [sym_string_literal] = {
        .visible = true,
        .named = true,
    },
    [sym_char_literal] = {
        .visible = true,
        .named = true,
    },
    [sym_boolean_literal] = {
        .visible = true,
        .named = true,
    },
    [sym_preproc_define] = {
        .visible = true,
        .named = true,
    },
    [sym_preproc_call] = {
        .visible = true,
        .named = true,
    },
    [sym_preproc_include] = {
        .visible = true,
        .named = true,
    },
    [sym_system_lib_string] = {
        .visible = true,
        .named = true,
    },
    [sym_except_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_interface_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_interface_kind] = {
        .visible = true,
        .named = true,
    },
    [sym_interface_forward_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_interface_def] = {
        .visible = true,
        .named = true,
    },
    [sym_interface_header] = {
        .visible = true,
        .named = true,
    },
    [sym_interface_inheritance_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_interface_name] = {
        .visible = true,
        .named = true,
    },
    [sym_interface_body] = {
        .visible = true,
        .named = true,
    },
    [sym_export] = {
        .visible = true,
        .named = true,
    },
    [sym_op_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_op_type_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_parameter_dcls] = {
        .visible = true,
        .named = true,
    },
    [sym_param_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_param_attribute] = {
        .visible = true,
        .named = true,
    },
    [sym_raises_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_attr_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_readonly_attr_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_readonly_attr_declarator] = {
        .visible = true,
        .named = true,
    },
    [sym_attr_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_attr_declarator] = {
        .visible = true,
        .named = true,
    },
    [sym_attr_raises_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_get_excep_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_set_excep_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_exception_list] = {
        .visible = true,
        .named = true,
    },
    [sym_bitset_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_bitfield] = {
        .visible = true,
        .named = true,
    },
    [sym_bitfield_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_destination_type] = {
        .visible = true,
        .named = true,
    },
    [sym_bitmask_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_bit_value] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_body] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_member] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_member_type] = {
        .visible = true,
        .named = true,
    },
    [sym_any_const_type] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl] = {
        .visible = true,
        .named = true,
    },
    [sym_extend_annotation_appl] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_custom_body] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_params] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_param] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_builtin_body] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_id] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_autoid] = {
        .visible = true,
        .named = true,
    },
    [sym_autoid_kind] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_optional] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_position] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_value] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_extensibility] = {
        .visible = true,
        .named = true,
    },
    [sym_extensibility_kind] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_final] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_appendable] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_mutable] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_key] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_must_understand] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_default_literal] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_default] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_range] = {
        .visible = true,
        .named = true,
    },
    [sym_min_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_max_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_min] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_max] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_unit] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_bit_bound] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_external] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_nested] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_verbatim] = {
        .visible = true,
        .named = true,
    },
    [sym_verbatim_language] = {
        .visible = true,
        .named = true,
    },
    [sym_placement_kind] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_service] = {
        .visible = true,
        .named = true,
    },
    [sym_service_platform] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_oneway] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_ami] = {
        .visible = true,
        .named = true,
    },
    [sym_template_module_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_formal_parameters] = {
        .visible = true,
        .named = true,
    },
    [sym_formal_parameter] = {
        .visible = true,
        .named = true,
    },
    [sym_formal_parameter_type] = {
        .visible = true,
        .named = true,
    },
    [sym_tpl_definition] = {
        .visible = true,
        .named = true,
    },
    [sym_template_module_inst] = {
        .visible = true,
        .named = true,
    },
    [sym_actual_parameters] = {
        .visible = true,
        .named = true,
    },
    [sym_actual_parameter] = {
        .visible = true,
        .named = true,
    },
    [sym_template_module_ref] = {
        .visible = true,
        .named = true,
    },
    [sym_formal_parameter_names] = {
        .visible = true,
        .named = true,
    },
    [sym_value_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_value_def] = {
        .visible = true,
        .named = true,
    },
    [sym_value_kind] = {
        .visible = true,
        .named = true,
    },
    [sym_value_header] = {
        .visible = true,
        .named = true,
    },
    [sym_value_inheritance_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_value_inheritance] = {
        .visible = true,
        .named = true,
    },
    [sym_value_supports] = {
        .visible = true,
        .named = true,
    },
    [sym_value_name] = {
        .visible = true,
        .named = true,
    },
    [sym_value_element] = {
        .visible = true,
        .named = true,
    },
    [sym_state_member] = {
        .visible = true,
        .named = true,
    },
    [sym_init_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_init_param_dcls] = {
        .visible = true,
        .named = true,
    },
    [sym_init_param_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_value_forward_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_typedef_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_type_declarator] = {
        .visible = true,
        .named = true,
    },
    [sym_any_declarators] = {
        .visible = true,
        .named = true,
    },
    [sym_any_declarator] = {
        .visible = true,
        .named = true,
    },
    [sym_simple_declarator] = {
        .visible = true,
        .named = true,
    },
    [sym_declarator] = {
        .visible = true,
        .named = true,
    },
    [sym_declarators] = {
        .visible = true,
        .named = true,
    },
    [sym_array_declarator] = {
        .visible = true,
        .named = true,
    },
    [sym_fixed_array_size] = {
        .visible = true,
        .named = true,
    },
    [sym_enum_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_enumerator] = {
        .visible = true,
        .named = true,
    },
    [sym_enum_modifier] = {
        .visible = true,
        .named = true,
    },
    [sym_enum_anno] = {
        .visible = true,
        .named = true,
    },
    [sym_union_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_union_forward_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_union_def] = {
        .visible = true,
        .named = true,
    },
    [sym_case] = {
        .visible = true,
        .named = true,
    },
    [sym_case_label] = {
        .visible = true,
        .named = true,
    },
    [sym_element_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_switch_type_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_type_id_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_type_prefix_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_import_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_imported_scope] = {
        .visible = true,
        .named = true,
    },
    [sym_object_type] = {
        .visible = true,
        .named = true,
    },
    [sym_op_oneway_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_in_parameter_dcls] = {
        .visible = true,
        .named = true,
    },
    [sym_in_param_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_op_with_context] = {
        .visible = true,
        .named = true,
    },
    [sym_context_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_value_box_def] = {
        .visible = true,
        .named = true,
    },
    [sym_value_abs_def] = {
        .visible = true,
        .named = true,
    },
    [sym_component_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_component_forward_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_component_def] = {
        .visible = true,
        .named = true,
    },
    [sym_component_header] = {
        .visible = true,
        .named = true,
    },
    [sym_component_inheritance_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_component_body] = {
        .visible = true,
        .named = true,
    },
    [sym_component_export] = {
        .visible = true,
        .named = true,
    },
    [sym_provides_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_interface_type] = {
        .visible = true,
        .named = true,
    },
    [sym_uses_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_home_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_home_header] = {
        .visible = true,
        .named = true,
    },
    [sym_home_inheritance_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_home_body] = {
        .visible = true,
        .named = true,
    },
    [sym_home_export] = {
        .visible = true,
        .named = true,
    },
    [sym_factory_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_factory_param_dcls] = {
        .visible = true,
        .named = true,
    },
    [sym_factory_param_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_supported_interface_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_emits_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_publishes_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_consumes_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_primary_key_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_finder_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_event_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_event_forward_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_event_abs_def] = {
        .visible = true,
        .named = true,
    },
    [sym_event_def] = {
        .visible = true,
        .named = true,
    },
    [sym_event_header] = {
        .visible = true,
        .named = true,
    },
    [sym_porttype_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_porttype_forward_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_porttype_def] = {
        .visible = true,
        .named = true,
    },
    [sym_port_body] = {
        .visible = true,
        .named = true,
    },
    [sym_port_ref] = {
        .visible = true,
        .named = true,
    },
    [sym_port_export] = {
        .visible = true,
        .named = true,
    },
    [sym_port_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_connector_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_connector_header] = {
        .visible = true,
        .named = true,
    },
    [sym_connector_inherit_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_connector_export] = {
        .visible = true,
        .named = true,
    },
    [sym_definition] = {
        .visible = true,
        .named = true,
    },
    [sym_type_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_constr_type_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_native_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_module_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_struct_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_struct_forward_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_struct_def] = {
        .visible = true,
        .named = true,
    },
    [sym_member] = {
        .visible = true,
        .named = true,
    },
    [sym_default] = {
        .visible = true,
        .named = true,
    },
    [sym_const_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_const_type] = {
        .visible = true,
        .named = true,
    },
    [sym_comment] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_specification_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_string_literal_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_char_literal_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_except_dcl_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_interface_def_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_interface_inheritance_spec_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_interface_body_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_parameter_dcls_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_raises_expr_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_readonly_attr_declarator_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_bitset_dcl_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_bitfield_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_bitmask_dcl_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_annotation_dcl_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_annotation_appl_params_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_template_module_dcl_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_formal_parameters_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_actual_parameters_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_formal_parameter_names_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_value_def_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_value_inheritance_spec_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_init_param_dcls_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_any_declarators_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_declarators_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_array_declarator_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_enum_dcl_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_enumerator_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_union_def_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_in_parameter_dcls_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_context_expr_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_component_body_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_home_body_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_factory_param_dcls_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_port_body_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_connector_dcl_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_module_dcl_repeat1] = {
        .visible = false,
        .named = false,
    },
};

enum ts_field_identifiers {
    field_argument = 1,
    field_directive = 2,
    field_identifier = 3,
    field_language = 4,
    field_max = 5,
    field_min = 6,
    field_name = 7,
    field_parent = 8,
    field_path = 9,
    field_placement = 10,
    field_text = 11,
    field_type = 12,
};

static const char *const ts_field_names[] = {
    [0] = NULL,
    [field_argument] = "argument",
    [field_directive] = "directive",
    [field_identifier] = "identifier",
    [field_language] = "language",
    [field_max] = "max",
    [field_min] = "min",
    [field_name] = "name",
    [field_parent] = "parent",
    [field_path] = "path",
    [field_placement] = "placement",
    [field_text] = "text",
    [field_type] = "type",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
    [1] = { .index = 0, .length = 1 },
    [2] = { .index = 1, .length = 1 },
    [3] = { .index = 2, .length = 2 },
    [4] = { .index = 4, .length = 1 },
    [5] = { .index = 5, .length = 2 },
    [6] = { .index = 7, .length = 2 },
    [7] = { .index = 9, .length = 1 },
    [8] = { .index = 10, .length = 2 },
    [9] = { .index = 12, .length = 3 },
    [10] = { .index = 15, .length = 4 },
    [11] = { .index = 19, .length = 4 },
    [12] = { .index = 23, .length = 1 },
    [13] = { .index = 24, .length = 6 },
};

static const TSFieldMapEntry ts_field_map_entries[] = {
    [0] = { field_directive, 0 },
    [1] = { field_name, 0 },
    [2] = { field_argument, 1 },
    { field_directive, 0 },
    [4] = { field_path, 1 },
    [5] = { field_name, 0 },
    { field_text, 2 },
    [7] = { field_identifier, 1 },
    { field_type, 0 },
    [9] = { field_parent, 3 },
    [10] = { field_identifier, 2 },
    { field_type, 1 },
    [12] = { field_max, 4 },
    { field_min, 2 },
    { field_name, 0 },
    [15] = { field_language, 2 },
    { field_language, 3 },
    { field_name, 0 },
    { field_text, 4 },
    [19] = { field_name, 0 },
    { field_placement, 2 },
    { field_placement, 3 },
    { field_text, 4 },
    [23] = { field_parent, 4 },
    [24] = { field_language, 2 },
    { field_language, 3 },
    { field_name, 0 },
    { field_placement, 4 },
    { field_placement, 5 },
    { field_text, 6 },
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
    [0] = { 0 },
};

static const uint16_t ts_non_terminal_alias_map[] = {
    0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
    [0] = 0,
    [1] = 1,
    [2] = 2,
    [3] = 3,
    [4] = 4,
    [5] = 5,
    [6] = 6,
    [7] = 7,
    [8] = 8,
    [9] = 9,
    [10] = 10,
    [11] = 11,
    [12] = 12,
    [13] = 13,
    [14] = 14,
    [15] = 15,
    [16] = 16,
    [17] = 17,
    [18] = 18,
    [19] = 19,
    [20] = 20,
    [21] = 21,
    [22] = 22,
    [23] = 23,
    [24] = 24,
    [25] = 25,
    [26] = 26,
    [27] = 27,
    [28] = 28,
    [29] = 29,
    [30] = 30,
    [31] = 31,
    [32] = 32,
    [33] = 33,
    [34] = 34,
    [35] = 35,
    [36] = 36,
    [37] = 37,
    [38] = 38,
    [39] = 39,
    [40] = 40,
    [41] = 41,
    [42] = 42,
    [43] = 43,
    [44] = 44,
    [45] = 45,
    [46] = 46,
    [47] = 47,
    [48] = 48,
    [49] = 49,
    [50] = 50,
    [51] = 51,
    [52] = 52,
    [53] = 53,
    [54] = 54,
    [55] = 55,
    [56] = 56,
    [57] = 57,
    [58] = 58,
    [59] = 59,
    [60] = 59,
    [61] = 61,
    [62] = 62,
    [63] = 63,
    [64] = 64,
    [65] = 65,
    [66] = 59,
    [67] = 67,
    [68] = 68,
    [69] = 69,
    [70] = 65,
    [71] = 71,
    [72] = 67,
    [73] = 73,
    [74] = 65,
    [75] = 67,
    [76] = 76,
    [77] = 65,
    [78] = 78,
    [79] = 79,
    [80] = 80,
    [81] = 81,
    [82] = 82,
    [83] = 67,
    [84] = 84,
    [85] = 85,
    [86] = 86,
    [87] = 87,
    [88] = 88,
    [89] = 89,
    [90] = 90,
    [91] = 91,
    [92] = 92,
    [93] = 93,
    [94] = 94,
    [95] = 95,
    [96] = 96,
    [97] = 97,
    [98] = 98,
    [99] = 99,
    [100] = 100,
    [101] = 101,
    [102] = 102,
    [103] = 103,
    [104] = 104,
    [105] = 105,
    [106] = 106,
    [107] = 107,
    [108] = 108,
    [109] = 109,
    [110] = 110,
    [111] = 111,
    [112] = 112,
    [113] = 113,
    [114] = 114,
    [115] = 115,
    [116] = 116,
    [117] = 117,
    [118] = 118,
    [119] = 119,
    [120] = 120,
    [121] = 121,
    [122] = 122,
    [123] = 123,
    [124] = 124,
    [125] = 125,
    [126] = 126,
    [127] = 127,
    [128] = 128,
    [129] = 129,
    [130] = 130,
    [131] = 131,
    [132] = 132,
    [133] = 133,
    [134] = 134,
    [135] = 135,
    [136] = 136,
    [137] = 137,
    [138] = 138,
    [139] = 139,
    [140] = 140,
    [141] = 141,
    [142] = 142,
    [143] = 143,
    [144] = 144,
    [145] = 145,
    [146] = 146,
    [147] = 147,
    [148] = 148,
    [149] = 149,
    [150] = 150,
    [151] = 151,
    [152] = 152,
    [153] = 153,
    [154] = 154,
    [155] = 155,
    [156] = 156,
    [157] = 157,
    [158] = 158,
    [159] = 159,
    [160] = 160,
    [161] = 157,
    [162] = 157,
    [163] = 157,
    [164] = 164,
    [165] = 165,
    [166] = 166,
    [167] = 167,
    [168] = 168,
    [169] = 169,
    [170] = 170,
    [171] = 171,
    [172] = 172,
    [173] = 173,
    [174] = 174,
    [175] = 175,
    [176] = 176,
    [177] = 177,
    [178] = 178,
    [179] = 179,
    [180] = 180,
    [181] = 107,
    [182] = 95,
    [183] = 183,
    [184] = 184,
    [185] = 185,
    [186] = 186,
    [187] = 187,
    [188] = 188,
    [189] = 189,
    [190] = 106,
    [191] = 191,
    [192] = 192,
    [193] = 193,
    [194] = 194,
    [195] = 195,
    [196] = 196,
    [197] = 197,
    [198] = 198,
    [199] = 199,
    [200] = 194,
    [201] = 201,
    [202] = 202,
    [203] = 203,
    [204] = 204,
    [205] = 205,
    [206] = 194,
    [207] = 207,
    [208] = 208,
    [209] = 209,
    [210] = 210,
    [211] = 211,
    [212] = 212,
    [213] = 213,
    [214] = 214,
    [215] = 194,
    [216] = 216,
    [217] = 217,
    [218] = 218,
    [219] = 219,
    [220] = 220,
    [221] = 221,
    [222] = 222,
    [223] = 223,
    [224] = 224,
    [225] = 225,
    [226] = 226,
    [227] = 227,
    [228] = 89,
    [229] = 227,
    [230] = 106,
    [231] = 231,
    [232] = 232,
    [233] = 233,
    [234] = 226,
    [235] = 235,
    [236] = 227,
    [237] = 237,
    [238] = 233,
    [239] = 239,
    [240] = 239,
    [241] = 237,
    [242] = 226,
    [243] = 237,
    [244] = 239,
    [245] = 245,
    [246] = 226,
    [247] = 237,
    [248] = 227,
    [249] = 233,
    [250] = 239,
    [251] = 233,
    [252] = 106,
    [253] = 253,
    [254] = 95,
    [255] = 107,
    [256] = 256,
    [257] = 257,
    [258] = 105,
    [259] = 98,
    [260] = 95,
    [261] = 261,
    [262] = 91,
    [263] = 94,
    [264] = 97,
    [265] = 265,
    [266] = 100,
    [267] = 102,
    [268] = 90,
    [269] = 104,
    [270] = 103,
    [271] = 271,
    [272] = 272,
    [273] = 273,
    [274] = 107,
    [275] = 115,
    [276] = 130,
    [277] = 277,
    [278] = 136,
    [279] = 279,
    [280] = 124,
    [281] = 281,
    [282] = 149,
    [283] = 283,
    [284] = 284,
    [285] = 118,
    [286] = 113,
    [287] = 112,
    [288] = 119,
    [289] = 121,
    [290] = 122,
    [291] = 120,
    [292] = 292,
    [293] = 293,
    [294] = 294,
    [295] = 125,
    [296] = 127,
    [297] = 128,
    [298] = 298,
    [299] = 299,
    [300] = 147,
    [301] = 114,
    [302] = 111,
    [303] = 148,
    [304] = 304,
    [305] = 143,
    [306] = 141,
    [307] = 142,
    [308] = 110,
    [309] = 309,
    [310] = 310,
    [311] = 129,
    [312] = 312,
    [313] = 132,
    [314] = 134,
    [315] = 139,
    [316] = 316,
    [317] = 138,
    [318] = 133,
    [319] = 131,
    [320] = 126,
    [321] = 140,
    [322] = 322,
    [323] = 144,
    [324] = 324,
    [325] = 123,
    [326] = 145,
    [327] = 146,
    [328] = 328,
    [329] = 329,
    [330] = 330,
    [331] = 89,
    [332] = 332,
    [333] = 333,
    [334] = 334,
    [335] = 335,
    [336] = 336,
    [337] = 334,
    [338] = 336,
    [339] = 89,
    [340] = 336,
    [341] = 336,
    [342] = 342,
    [343] = 343,
    [344] = 344,
    [345] = 334,
    [346] = 346,
    [347] = 347,
    [348] = 334,
    [349] = 349,
    [350] = 350,
    [351] = 351,
    [352] = 105,
    [353] = 353,
    [354] = 354,
    [355] = 355,
    [356] = 95,
    [357] = 107,
    [358] = 106,
    [359] = 105,
    [360] = 360,
    [361] = 361,
    [362] = 362,
    [363] = 363,
    [364] = 364,
    [365] = 365,
    [366] = 366,
    [367] = 367,
    [368] = 368,
    [369] = 369,
    [370] = 370,
    [371] = 371,
    [372] = 372,
    [373] = 373,
    [374] = 374,
    [375] = 375,
    [376] = 376,
    [377] = 377,
    [378] = 378,
    [379] = 379,
    [380] = 380,
    [381] = 107,
    [382] = 95,
    [383] = 383,
    [384] = 384,
    [385] = 106,
    [386] = 386,
    [387] = 387,
    [388] = 388,
    [389] = 389,
    [390] = 91,
    [391] = 391,
    [392] = 392,
    [393] = 94,
    [394] = 394,
    [395] = 97,
    [396] = 396,
    [397] = 98,
    [398] = 398,
    [399] = 100,
    [400] = 102,
    [401] = 401,
    [402] = 90,
    [403] = 104,
    [404] = 404,
    [405] = 405,
    [406] = 406,
    [407] = 103,
    [408] = 408,
    [409] = 409,
    [410] = 410,
    [411] = 411,
    [412] = 412,
    [413] = 413,
    [414] = 414,
    [415] = 415,
    [416] = 416,
    [417] = 417,
    [418] = 418,
    [419] = 419,
    [420] = 420,
    [421] = 421,
    [422] = 422,
    [423] = 423,
    [424] = 424,
    [425] = 425,
    [426] = 426,
    [427] = 427,
    [428] = 428,
    [429] = 429,
    [430] = 430,
    [431] = 431,
    [432] = 432,
    [433] = 433,
    [434] = 434,
    [435] = 435,
    [436] = 436,
    [437] = 437,
    [438] = 414,
    [439] = 439,
    [440] = 440,
    [441] = 441,
    [442] = 442,
    [443] = 443,
    [444] = 444,
    [445] = 445,
    [446] = 446,
    [447] = 447,
    [448] = 448,
    [449] = 449,
    [450] = 450,
    [451] = 451,
    [452] = 452,
    [453] = 91,
    [454] = 94,
    [455] = 455,
    [456] = 97,
    [457] = 98,
    [458] = 100,
    [459] = 102,
    [460] = 90,
    [461] = 104,
    [462] = 103,
    [463] = 463,
    [464] = 464,
    [465] = 465,
    [466] = 466,
    [467] = 467,
    [468] = 465,
    [469] = 426,
    [470] = 425,
    [471] = 421,
    [472] = 386,
    [473] = 445,
    [474] = 421,
    [475] = 386,
    [476] = 421,
    [477] = 477,
    [478] = 478,
    [479] = 386,
    [480] = 480,
    [481] = 417,
    [482] = 482,
    [483] = 414,
    [484] = 484,
    [485] = 427,
    [486] = 417,
    [487] = 414,
    [488] = 417,
    [489] = 489,
    [490] = 490,
    [491] = 490,
    [492] = 492,
    [493] = 493,
    [494] = 494,
    [495] = 495,
    [496] = 496,
    [497] = 497,
    [498] = 498,
    [499] = 499,
    [500] = 500,
    [501] = 501,
    [502] = 502,
    [503] = 503,
    [504] = 490,
    [505] = 505,
    [506] = 492,
    [507] = 507,
    [508] = 508,
    [509] = 509,
    [510] = 493,
    [511] = 494,
    [512] = 512,
    [513] = 513,
    [514] = 496,
    [515] = 497,
    [516] = 500,
    [517] = 502,
    [518] = 503,
    [519] = 519,
    [520] = 520,
    [521] = 490,
    [522] = 423,
    [523] = 492,
    [524] = 493,
    [525] = 494,
    [526] = 496,
    [527] = 497,
    [528] = 492,
    [529] = 500,
    [530] = 502,
    [531] = 503,
    [532] = 532,
    [533] = 420,
    [534] = 534,
    [535] = 535,
    [536] = 536,
    [537] = 537,
    [538] = 532,
    [539] = 539,
    [540] = 540,
    [541] = 541,
    [542] = 141,
    [543] = 543,
    [544] = 147,
    [545] = 114,
    [546] = 115,
    [547] = 547,
    [548] = 118,
    [549] = 119,
    [550] = 550,
    [551] = 121,
    [552] = 552,
    [553] = 553,
    [554] = 122,
    [555] = 125,
    [556] = 127,
    [557] = 128,
    [558] = 129,
    [559] = 559,
    [560] = 130,
    [561] = 132,
    [562] = 134,
    [563] = 140,
    [564] = 144,
    [565] = 565,
    [566] = 145,
    [567] = 146,
    [568] = 568,
    [569] = 149,
    [570] = 142,
    [571] = 138,
    [572] = 112,
    [573] = 136,
    [574] = 123,
    [575] = 111,
    [576] = 110,
    [577] = 577,
    [578] = 537,
    [579] = 536,
    [580] = 580,
    [581] = 124,
    [582] = 148,
    [583] = 583,
    [584] = 143,
    [585] = 139,
    [586] = 133,
    [587] = 587,
    [588] = 588,
    [589] = 131,
    [590] = 590,
    [591] = 591,
    [592] = 126,
    [593] = 120,
    [594] = 113,
    [595] = 595,
    [596] = 596,
    [597] = 597,
    [598] = 598,
    [599] = 599,
    [600] = 600,
    [601] = 601,
    [602] = 503,
    [603] = 502,
    [604] = 500,
    [605] = 497,
    [606] = 496,
    [607] = 494,
    [608] = 493,
    [609] = 609,
    [610] = 610,
    [611] = 611,
    [612] = 612,
    [613] = 141,
    [614] = 147,
    [615] = 114,
    [616] = 115,
    [617] = 118,
    [618] = 618,
    [619] = 119,
    [620] = 121,
    [621] = 122,
    [622] = 125,
    [623] = 127,
    [624] = 128,
    [625] = 625,
    [626] = 129,
    [627] = 130,
    [628] = 132,
    [629] = 134,
    [630] = 140,
    [631] = 144,
    [632] = 632,
    [633] = 145,
    [634] = 146,
    [635] = 149,
    [636] = 142,
    [637] = 138,
    [638] = 112,
    [639] = 136,
    [640] = 123,
    [641] = 111,
    [642] = 110,
    [643] = 643,
    [644] = 124,
    [645] = 539,
    [646] = 646,
    [647] = 148,
    [648] = 143,
    [649] = 649,
    [650] = 650,
    [651] = 651,
    [652] = 652,
    [653] = 139,
    [654] = 654,
    [655] = 133,
    [656] = 131,
    [657] = 657,
    [658] = 126,
    [659] = 120,
    [660] = 660,
    [661] = 113,
    [662] = 662,
    [663] = 663,
    [664] = 664,
    [665] = 665,
    [666] = 666,
    [667] = 667,
    [668] = 668,
    [669] = 669,
    [670] = 670,
    [671] = 671,
    [672] = 532,
    [673] = 673,
    [674] = 674,
    [675] = 675,
    [676] = 676,
    [677] = 677,
    [678] = 678,
    [679] = 679,
    [680] = 680,
    [681] = 681,
    [682] = 682,
    [683] = 683,
    [684] = 684,
    [685] = 685,
    [686] = 686,
    [687] = 687,
    [688] = 688,
    [689] = 689,
    [690] = 690,
    [691] = 691,
    [692] = 692,
    [693] = 693,
    [694] = 694,
    [695] = 695,
    [696] = 696,
    [697] = 697,
    [698] = 698,
    [699] = 699,
    [700] = 700,
    [701] = 701,
    [702] = 702,
    [703] = 703,
    [704] = 704,
    [705] = 705,
    [706] = 706,
    [707] = 707,
    [708] = 708,
    [709] = 709,
    [710] = 710,
    [711] = 711,
    [712] = 712,
    [713] = 713,
    [714] = 714,
    [715] = 715,
    [716] = 716,
    [717] = 717,
    [718] = 718,
    [719] = 719,
    [720] = 720,
    [721] = 721,
    [722] = 722,
    [723] = 723,
    [724] = 724,
    [725] = 725,
    [726] = 722,
    [727] = 727,
    [728] = 722,
    [729] = 729,
    [730] = 730,
    [731] = 731,
    [732] = 732,
    [733] = 733,
    [734] = 734,
    [735] = 735,
    [736] = 736,
    [737] = 737,
    [738] = 738,
    [739] = 739,
    [740] = 740,
    [741] = 729,
    [742] = 742,
    [743] = 743,
    [744] = 744,
    [745] = 745,
    [746] = 746,
    [747] = 729,
    [748] = 748,
    [749] = 749,
    [750] = 750,
    [751] = 751,
    [752] = 729,
    [753] = 753,
    [754] = 754,
    [755] = 755,
    [756] = 756,
    [757] = 757,
    [758] = 758,
    [759] = 759,
    [760] = 760,
    [761] = 761,
    [762] = 762,
    [763] = 763,
    [764] = 764,
    [765] = 765,
    [766] = 766,
    [767] = 767,
    [768] = 768,
    [769] = 769,
    [770] = 770,
    [771] = 771,
    [772] = 772,
    [773] = 773,
    [774] = 774,
    [775] = 775,
    [776] = 776,
    [777] = 777,
    [778] = 778,
    [779] = 779,
    [780] = 780,
    [781] = 781,
    [782] = 782,
    [783] = 783,
    [784] = 784,
    [785] = 785,
    [786] = 786,
    [787] = 787,
    [788] = 788,
    [789] = 789,
    [790] = 790,
    [791] = 722,
    [792] = 792,
    [793] = 793,
    [794] = 794,
    [795] = 795,
    [796] = 796,
    [797] = 797,
    [798] = 798,
    [799] = 799,
    [800] = 800,
    [801] = 801,
    [802] = 802,
    [803] = 803,
    [804] = 804,
    [805] = 805,
    [806] = 806,
    [807] = 807,
    [808] = 808,
    [809] = 809,
    [810] = 810,
    [811] = 811,
    [812] = 812,
    [813] = 813,
    [814] = 814,
    [815] = 815,
    [816] = 816,
    [817] = 817,
    [818] = 818,
    [819] = 819,
    [820] = 820,
    [821] = 821,
    [822] = 822,
    [823] = 823,
    [824] = 824,
    [825] = 825,
    [826] = 826,
    [827] = 827,
    [828] = 828,
    [829] = 829,
    [830] = 830,
    [831] = 831,
    [832] = 832,
    [833] = 833,
    [834] = 834,
    [835] = 835,
    [836] = 836,
    [837] = 837,
    [838] = 838,
    [839] = 839,
    [840] = 840,
    [841] = 841,
    [842] = 842,
    [843] = 843,
    [844] = 844,
    [845] = 845,
    [846] = 846,
    [847] = 847,
    [848] = 848,
    [849] = 849,
    [850] = 850,
    [851] = 851,
    [852] = 852,
    [853] = 853,
    [854] = 854,
    [855] = 855,
    [856] = 856,
    [857] = 857,
    [858] = 858,
    [859] = 859,
    [860] = 860,
    [861] = 861,
    [862] = 862,
    [863] = 863,
    [864] = 864,
    [865] = 865,
    [866] = 866,
    [867] = 867,
    [868] = 868,
    [869] = 840,
    [870] = 870,
    [871] = 871,
    [872] = 872,
    [873] = 873,
    [874] = 874,
    [875] = 875,
    [876] = 876,
    [877] = 877,
    [878] = 878,
    [879] = 879,
    [880] = 880,
    [881] = 881,
    [882] = 882,
    [883] = 883,
    [884] = 884,
    [885] = 885,
    [886] = 886,
    [887] = 887,
    [888] = 888,
    [889] = 889,
    [890] = 890,
    [891] = 891,
    [892] = 892,
    [893] = 893,
    [894] = 894,
    [895] = 895,
    [896] = 896,
    [897] = 897,
    [898] = 898,
    [899] = 899,
    [900] = 900,
    [901] = 901,
    [902] = 902,
    [903] = 903,
    [904] = 904,
    [905] = 905,
    [906] = 906,
    [907] = 907,
    [908] = 908,
    [909] = 909,
    [910] = 910,
    [911] = 911,
    [912] = 912,
    [913] = 913,
    [914] = 914,
    [915] = 915,
    [916] = 916,
    [917] = 917,
    [918] = 918,
    [919] = 919,
    [920] = 920,
    [921] = 921,
    [922] = 922,
    [923] = 923,
    [924] = 924,
    [925] = 925,
    [926] = 926,
    [927] = 927,
    [928] = 928,
    [929] = 929,
    [930] = 930,
    [931] = 931,
    [932] = 932,
    [933] = 933,
    [934] = 934,
    [935] = 935,
    [936] = 936,
    [937] = 937,
    [938] = 938,
    [939] = 939,
    [940] = 940,
    [941] = 941,
    [942] = 942,
    [943] = 943,
    [944] = 944,
    [945] = 945,
    [946] = 202,
    [947] = 947,
    [948] = 948,
    [949] = 949,
    [950] = 950,
    [951] = 951,
    [952] = 952,
    [953] = 953,
    [954] = 954,
    [955] = 955,
    [956] = 956,
    [957] = 957,
    [958] = 958,
    [959] = 959,
    [960] = 960,
    [961] = 961,
    [962] = 962,
    [963] = 963,
    [964] = 964,
    [965] = 965,
    [966] = 966,
    [967] = 967,
    [968] = 968,
    [969] = 969,
    [970] = 970,
    [971] = 971,
    [972] = 972,
    [973] = 973,
    [974] = 974,
    [975] = 975,
    [976] = 976,
    [977] = 977,
    [978] = 978,
    [979] = 979,
    [980] = 980,
    [981] = 981,
    [982] = 982,
    [983] = 983,
    [984] = 984,
    [985] = 985,
    [986] = 949,
    [987] = 987,
    [988] = 988,
    [989] = 989,
    [990] = 990,
    [991] = 991,
    [992] = 992,
    [993] = 993,
    [994] = 994,
    [995] = 995,
    [996] = 996,
    [997] = 997,
    [998] = 998,
    [999] = 999,
    [1000] = 1000,
    [1001] = 1001,
    [1002] = 1002,
    [1003] = 1003,
    [1004] = 1004,
    [1005] = 1005,
    [1006] = 1006,
    [1007] = 1007,
    [1008] = 1008,
    [1009] = 1009,
    [1010] = 1010,
    [1011] = 1011,
    [1012] = 1012,
    [1013] = 1013,
    [1014] = 1014,
    [1015] = 1015,
    [1016] = 1016,
    [1017] = 1017,
    [1018] = 1018,
    [1019] = 1019,
    [1020] = 1020,
    [1021] = 1021,
    [1022] = 1022,
    [1023] = 1023,
    [1024] = 1024,
    [1025] = 1025,
    [1026] = 1026,
    [1027] = 1027,
    [1028] = 1028,
    [1029] = 1029,
    [1030] = 1030,
    [1031] = 1031,
    [1032] = 1032,
    [1033] = 1033,
    [1034] = 992,
    [1035] = 1035,
    [1036] = 949,
    [1037] = 1037,
    [1038] = 1038,
    [1039] = 1039,
    [1040] = 933,
    [1041] = 1041,
    [1042] = 1042,
    [1043] = 849,
    [1044] = 1044,
    [1045] = 1045,
    [1046] = 868,
    [1047] = 861,
    [1048] = 1048,
    [1049] = 862,
    [1050] = 1048,
    [1051] = 871,
    [1052] = 880,
    [1053] = 886,
    [1054] = 887,
    [1055] = 891,
    [1056] = 892,
    [1057] = 894,
    [1058] = 904,
    [1059] = 905,
    [1060] = 906,
    [1061] = 909,
    [1062] = 919,
    [1063] = 922,
    [1064] = 923,
    [1065] = 925,
    [1066] = 1066,
    [1067] = 1067,
    [1068] = 901,
    [1069] = 898,
    [1070] = 895,
    [1071] = 1071,
    [1072] = 916,
    [1073] = 1073,
    [1074] = 992,
    [1075] = 1075,
    [1076] = 1076,
    [1077] = 1077,
    [1078] = 933,
    [1079] = 1079,
    [1080] = 849,
    [1081] = 1081,
    [1082] = 868,
    [1083] = 861,
    [1084] = 1048,
    [1085] = 862,
    [1086] = 840,
    [1087] = 871,
    [1088] = 880,
    [1089] = 886,
    [1090] = 887,
    [1091] = 891,
    [1092] = 892,
    [1093] = 894,
    [1094] = 904,
    [1095] = 905,
    [1096] = 906,
    [1097] = 909,
    [1098] = 919,
    [1099] = 922,
    [1100] = 923,
    [1101] = 925,
    [1102] = 901,
    [1103] = 898,
    [1104] = 895,
    [1105] = 916,
    [1106] = 1106,
    [1107] = 992,
    [1108] = 1108,
    [1109] = 1109,
    [1110] = 1110,
    [1111] = 933,
    [1112] = 1112,
    [1113] = 868,
    [1114] = 861,
    [1115] = 1048,
    [1116] = 862,
    [1117] = 840,
    [1118] = 871,
    [1119] = 880,
    [1120] = 886,
    [1121] = 887,
    [1122] = 891,
    [1123] = 892,
    [1124] = 894,
    [1125] = 904,
    [1126] = 905,
    [1127] = 906,
    [1128] = 909,
    [1129] = 919,
    [1130] = 922,
    [1131] = 923,
    [1132] = 925,
    [1133] = 901,
    [1134] = 898,
    [1135] = 895,
    [1136] = 916,
    [1137] = 992,
    [1138] = 992,
    [1139] = 933,
    [1140] = 1140,
    [1141] = 1031,
    [1142] = 1142,
    [1143] = 944,
    [1144] = 943,
    [1145] = 1145,
    [1146] = 1146,
    [1147] = 1147,
    [1148] = 1148,
    [1149] = 1149,
    [1150] = 1150,
    [1151] = 1151,
    [1152] = 938,
    [1153] = 1153,
    [1154] = 1154,
    [1155] = 1155,
    [1156] = 1156,
    [1157] = 1157,
    [1158] = 1158,
    [1159] = 1159,
    [1160] = 1160,
    [1161] = 1161,
    [1162] = 1162,
    [1163] = 1163,
    [1164] = 1164,
    [1165] = 1165,
    [1166] = 1166,
    [1167] = 1167,
    [1168] = 944,
    [1169] = 943,
    [1170] = 1170,
    [1171] = 1171,
    [1172] = 1172,
    [1173] = 1173,
    [1174] = 1174,
    [1175] = 1175,
    [1176] = 1176,
    [1177] = 938,
    [1178] = 1178,
    [1179] = 1179,
    [1180] = 1180,
    [1181] = 1181,
    [1182] = 1182,
    [1183] = 1183,
    [1184] = 1184,
    [1185] = 1185,
    [1186] = 211,
    [1187] = 1187,
    [1188] = 1188,
    [1189] = 1189,
    [1190] = 1190,
    [1191] = 944,
    [1192] = 943,
    [1193] = 1193,
    [1194] = 1194,
    [1195] = 1195,
    [1196] = 1196,
    [1197] = 1197,
    [1198] = 1198,
    [1199] = 1199,
    [1200] = 938,
    [1201] = 1201,
    [1202] = 214,
    [1203] = 1203,
    [1204] = 1204,
    [1205] = 1205,
    [1206] = 1206,
    [1207] = 1207,
    [1208] = 1208,
    [1209] = 1209,
    [1210] = 1210,
    [1211] = 1211,
    [1212] = 991,
    [1213] = 990,
    [1214] = 839,
    [1215] = 988,
    [1216] = 987,
    [1217] = 984,
    [1218] = 983,
    [1219] = 979,
    [1220] = 978,
    [1221] = 975,
    [1222] = 889,
    [1223] = 911,
    [1224] = 913,
    [1225] = 896,
    [1226] = 991,
    [1227] = 990,
    [1228] = 839,
    [1229] = 988,
    [1230] = 987,
    [1231] = 984,
    [1232] = 983,
    [1233] = 979,
    [1234] = 978,
    [1235] = 975,
    [1236] = 889,
    [1237] = 911,
    [1238] = 913,
    [1239] = 896,
    [1240] = 991,
    [1241] = 990,
    [1242] = 839,
    [1243] = 988,
    [1244] = 987,
    [1245] = 984,
    [1246] = 983,
    [1247] = 979,
    [1248] = 978,
    [1249] = 975,
    [1250] = 889,
    [1251] = 911,
    [1252] = 913,
    [1253] = 896,
    [1254] = 1254,
    [1255] = 1255,
    [1256] = 1256,
    [1257] = 949,
    [1258] = 1258,
    [1259] = 1259,
};

static TSCharacterRange sym_number_literal_character_set_13[] = {
    { '0', '9' },
    { 'B', 'B' },
    { 'D', 'D' },
    { 'F', 'F' },
    { 'L', 'L' },
    { 'U', 'U' },
    { 'W', 'W' },
    { 'b', 'b' },
    { 'd', 'd' },
    { 'f', 'f' },
    { 'l', 'l' },
    { 'u', 'u' },
    { 'w', 'w' },
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
    START_LEXER();
    eof = lexer->eof(lexer);
    switch(state) {
        case 0:
            if(eof)
                ADVANCE(816);
            ADVANCE_MAP(
                '"', 895,
                '#', 327,
                '%', 885,
                '&', 875,
                '\'', 899,
                '(', 886,
                ')', 887,
                '*', 882,
                '+', 879,
                ',', 868,
                '-', 881,
                '.', 794,
                '/', 883,
                '0', 915,
                ':', 978,
                ';', 979,
                '<', 863,
                '=', 1011,
                '>', 865,
                '@', 1007,
                'A', 174,
                'B', 157,
                'C', 206,
                'D', 150,
                'E', 201,
                'F', 127,
                'H', 129,
                'L', 893,
                'M', 232,
                'O', 294,
                'S', 158,
                'T', 215,
                'V', 244,
                '[', 1106,
            );
            if(lookahead == '\\')
                SKIP(809);
            if(lookahead == ']')
                ADVANCE(1107);
            if(lookahead == '^')
                ADVANCE(874);
            if(lookahead == 'a')
                ADVANCE(297);
            if(lookahead == 'b')
                ADVANCE(448);
            if(lookahead == 'c')
                ADVANCE(1058);
            if(lookahead == 'd')
                ADVANCE(348);
            if(lookahead == 'e')
                ADVANCE(528);
            if(lookahead == 'f')
                ADVANCE(245);
            if(lookahead == 'g')
                ADVANCE(406);
            if(lookahead == 'h')
                ADVANCE(580);
            if(lookahead == 'i')
                ADVANCE(328);
            if(lookahead == 'j')
                ADVANCE(246);
            if(lookahead == 'k')
                ADVANCE(376);
            if(lookahead == 'l')
                ADVANCE(581);
            if(lookahead == 'm')
                ADVANCE(247);
            if(lookahead == 'n')
                ADVANCE(256);
            if(lookahead == 'o')
                ADVANCE(313);
            if(lookahead == 'p')
                ADVANCE(583);
            if(lookahead == 'r')
                ADVANCE(248);
            if(lookahead == 's')
                ADVANCE(349);
            if(lookahead == 't')
                ADVANCE(636);
            if(lookahead == 'u')
                ADVANCE(445);
            if(lookahead == 'v')
                ADVANCE(287);
            if(lookahead == 'w')
                ADVANCE(309);
            if(lookahead == '{')
                ADVANCE(970);
            if(lookahead == '|')
                ADVANCE(873);
            if(lookahead == '}')
                ADVANCE(971);
            if(lookahead == '~')
                ADVANCE(888);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(0);
            if(('1' <= lookahead && lookahead <= '9'))
                ADVANCE(919);
            END_STATE();
        case 1:
            if(lookahead == '\n')
                SKIP(98);
            END_STATE();
        case 2:
            if(lookahead == '\n')
                SKIP(98);
            if(lookahead == '\r')
                SKIP(1);
            END_STATE();
        case 3:
            if(lookahead == '\n')
                SKIP(99);
            END_STATE();
        case 4:
            if(lookahead == '\n')
                SKIP(99);
            if(lookahead == '\r')
                SKIP(3);
            END_STATE();
        case 5:
            if(lookahead == '\n')
                SKIP(101);
            END_STATE();
        case 6:
            if(lookahead == '\n')
                SKIP(101);
            if(lookahead == '\r')
                SKIP(5);
            END_STATE();
        case 7:
            if(lookahead == '\n')
                SKIP(102);
            END_STATE();
        case 8:
            if(lookahead == '\n')
                SKIP(102);
            if(lookahead == '\r')
                SKIP(7);
            END_STATE();
        case 9:
            if(lookahead == '\n')
                SKIP(86);
            END_STATE();
        case 10:
            if(lookahead == '\n')
                SKIP(86);
            if(lookahead == '\r')
                SKIP(9);
            END_STATE();
        case 11:
            if(lookahead == '\n')
                SKIP(83);
            END_STATE();
        case 12:
            if(lookahead == '\n')
                SKIP(83);
            if(lookahead == '\r')
                SKIP(11);
            END_STATE();
        case 13:
            if(lookahead == '\n')
                SKIP(90);
            END_STATE();
        case 14:
            if(lookahead == '\n')
                SKIP(90);
            if(lookahead == '\r')
                SKIP(13);
            END_STATE();
        case 15:
            if(lookahead == '\n')
                SKIP(104);
            END_STATE();
        case 16:
            if(lookahead == '\n')
                SKIP(104);
            if(lookahead == '\r')
                SKIP(15);
            END_STATE();
        case 17:
            if(lookahead == '\n')
                SKIP(105);
            END_STATE();
        case 18:
            if(lookahead == '\n')
                SKIP(105);
            if(lookahead == '\r')
                SKIP(17);
            END_STATE();
        case 19:
            if(lookahead == '\n')
                SKIP(109);
            END_STATE();
        case 20:
            if(lookahead == '\n')
                SKIP(109);
            if(lookahead == '\r')
                SKIP(19);
            END_STATE();
        case 21:
            if(lookahead == '\n')
                SKIP(106);
            END_STATE();
        case 22:
            if(lookahead == '\n')
                SKIP(106);
            if(lookahead == '\r')
                SKIP(21);
            END_STATE();
        case 23:
            if(lookahead == '\n')
                SKIP(110);
            END_STATE();
        case 24:
            if(lookahead == '\n')
                SKIP(110);
            if(lookahead == '\r')
                SKIP(23);
            END_STATE();
        case 25:
            if(lookahead == '\n')
                SKIP(111);
            END_STATE();
        case 26:
            if(lookahead == '\n')
                SKIP(111);
            if(lookahead == '\r')
                SKIP(25);
            END_STATE();
        case 27:
            if(lookahead == '\n')
                SKIP(79);
            END_STATE();
        case 28:
            if(lookahead == '\n')
                SKIP(79);
            if(lookahead == '\r')
                SKIP(27);
            END_STATE();
        case 29:
            if(lookahead == '\n')
                SKIP(76);
            END_STATE();
        case 30:
            if(lookahead == '\n')
                SKIP(76);
            if(lookahead == '\r')
                SKIP(29);
            END_STATE();
        case 31:
            if(lookahead == '\n')
                SKIP(84);
            END_STATE();
        case 32:
            if(lookahead == '\n')
                SKIP(84);
            if(lookahead == '\r')
                SKIP(31);
            END_STATE();
        case 33:
            if(lookahead == '\n')
                SKIP(77);
            END_STATE();
        case 34:
            if(lookahead == '\n')
                SKIP(77);
            if(lookahead == '\r')
                SKIP(33);
            END_STATE();
        case 35:
            if(lookahead == '\n')
                SKIP(87);
            END_STATE();
        case 36:
            if(lookahead == '\n')
                SKIP(87);
            if(lookahead == '\r')
                SKIP(35);
            END_STATE();
        case 37:
            if(lookahead == '\n')
                SKIP(80);
            END_STATE();
        case 38:
            if(lookahead == '\n')
                SKIP(80);
            if(lookahead == '\r')
                SKIP(37);
            END_STATE();
        case 39:
            if(lookahead == '\n')
                SKIP(78);
            END_STATE();
        case 40:
            if(lookahead == '\n')
                SKIP(78);
            if(lookahead == '\r')
                SKIP(39);
            END_STATE();
        case 41:
            if(lookahead == '\n')
                SKIP(89);
            END_STATE();
        case 42:
            if(lookahead == '\n')
                SKIP(89);
            if(lookahead == '\r')
                SKIP(41);
            END_STATE();
        case 43:
            if(lookahead == '\n')
                SKIP(88);
            END_STATE();
        case 44:
            if(lookahead == '\n')
                SKIP(88);
            if(lookahead == '\r')
                SKIP(43);
            END_STATE();
        case 45:
            if(lookahead == '\n')
                SKIP(81);
            END_STATE();
        case 46:
            if(lookahead == '\n')
                SKIP(81);
            if(lookahead == '\r')
                SKIP(45);
            END_STATE();
        case 47:
            if(lookahead == '\n')
                SKIP(49);
            END_STATE();
        case 48:
            if(lookahead == '\n')
                SKIP(49);
            if(lookahead == '\r')
                SKIP(47);
            END_STATE();
        case 49:
            if(lookahead == '\n')
                ADVANCE(1010);
            if(lookahead == '\r')
                ADVANCE(49);
            if(lookahead == '(')
                ADVANCE(886);
            if(lookahead == '/')
                ADVANCE(91);
            if(lookahead == ':')
                ADVANCE(125);
            if(lookahead == '@')
                ADVANCE(1006);
            if(lookahead == '\\')
                SKIP(48);
            if(('\t' <= lookahead && lookahead <= '\f') ||
               lookahead == ' ')
                SKIP(49);
            END_STATE();
        case 50:
            if(lookahead == '\n')
                SKIP(107);
            END_STATE();
        case 51:
            if(lookahead == '\n')
                SKIP(107);
            if(lookahead == '\r')
                SKIP(50);
            END_STATE();
        case 52:
            if(lookahead == '\n')
                SKIP(108);
            END_STATE();
        case 53:
            if(lookahead == '\n')
                SKIP(108);
            if(lookahead == '\r')
                SKIP(52);
            END_STATE();
        case 54:
            if(lookahead == '\n')
                SKIP(112);
            END_STATE();
        case 55:
            if(lookahead == '\n')
                SKIP(112);
            if(lookahead == '\r')
                SKIP(54);
            END_STATE();
        case 56:
            if(lookahead == '\n')
                SKIP(82);
            if(lookahead == '"')
                ADVANCE(895);
            if(lookahead == '/')
                ADVANCE(896);
            if(lookahead == '\\')
                ADVANCE(57);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                ADVANCE(897);
            if(lookahead != 0)
                ADVANCE(898);
            END_STATE();
        case 57:
            if(lookahead == '\n')
                ADVANCE(890);
            if(lookahead == '\r')
                ADVANCE(889);
            if(lookahead == 'U')
                ADVANCE(806);
            if(lookahead == 'u')
                ADVANCE(802);
            if(lookahead == 'x')
                ADVANCE(800);
            if(('0' <= lookahead && lookahead <= '9'))
                ADVANCE(892);
            if(lookahead != 0)
                ADVANCE(889);
            END_STATE();
        case 58:
            if(lookahead == '\n')
                SKIP(113);
            END_STATE();
        case 59:
            if(lookahead == '\n')
                SKIP(113);
            if(lookahead == '\r')
                SKIP(58);
            END_STATE();
        case 60:
            if(lookahead == '\n')
                SKIP(85);
            if(lookahead == '\'')
                ADVANCE(899);
            if(lookahead == '/')
                ADVANCE(902);
            if(lookahead == '\\')
                ADVANCE(901);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                ADVANCE(903);
            if(lookahead != 0)
                ADVANCE(900);
            END_STATE();
        case 61:
            if(lookahead == '\n')
                SKIP(114);
            END_STATE();
        case 62:
            if(lookahead == '\n')
                SKIP(114);
            if(lookahead == '\r')
                SKIP(61);
            END_STATE();
        case 63:
            if(lookahead == '\n')
                ADVANCE(943);
            if(lookahead == '\r')
                ADVANCE(65);
            if(lookahead == '/')
                ADVANCE(959);
            if(lookahead == '\\')
                ADVANCE(956);
            if(('\t' <= lookahead && lookahead <= '\f') ||
               lookahead == ' ')
                SKIP(103);
            if(lookahead != 0)
                ADVANCE(960);
            END_STATE();
        case 64:
            if(lookahead == '\n')
                ADVANCE(943);
            if(lookahead == '\r')
                ADVANCE(66);
            if(lookahead == '/')
                ADVANCE(92);
            if(lookahead == '\\')
                SKIP(68);
            if(('\t' <= lookahead && lookahead <= '\f') ||
               lookahead == ' ')
                SKIP(115);
            END_STATE();
        case 65:
            if(lookahead == '\n')
                ADVANCE(943);
            if(lookahead == '/')
                ADVANCE(959);
            if(lookahead == '\\')
                ADVANCE(956);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(103);
            if(lookahead != 0)
                ADVANCE(960);
            END_STATE();
        case 66:
            if(lookahead == '\n')
                ADVANCE(943);
            if(lookahead == '/')
                ADVANCE(92);
            if(lookahead == '\\')
                SKIP(68);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(115);
            END_STATE();
        case 67:
            if(lookahead == '\n')
                SKIP(115);
            END_STATE();
        case 68:
            if(lookahead == '\n')
                SKIP(115);
            if(lookahead == '\r')
                SKIP(67);
            END_STATE();
        case 69:
            if(lookahead == '\n')
                ADVANCE(1560);
            if(lookahead == '\r')
                ADVANCE(1557);
            if(lookahead == '\\')
                ADVANCE(1558);
            if(lookahead != 0)
                ADVANCE(1561);
            END_STATE();
        case 70:
            if(lookahead == '\n')
                ADVANCE(93);
            if(lookahead == '\r')
                ADVANCE(71);
            if(lookahead == '*')
                ADVANCE(1568);
            if(lookahead != 0)
                ADVANCE(94);
            END_STATE();
        case 71:
            if(lookahead == '\n')
                ADVANCE(93);
            if(lookahead == '*')
                ADVANCE(1568);
            if(lookahead != 0)
                ADVANCE(94);
            END_STATE();
        case 72:
            if(lookahead == '\n')
                SKIP(100);
            END_STATE();
        case 73:
            if(lookahead == '\n')
                SKIP(100);
            if(lookahead == '\r')
                SKIP(72);
            END_STATE();
        case 74:
            if(lookahead == '\r')
                ADVANCE(1562);
            if(lookahead == '\\')
                ADVANCE(1558);
            if(lookahead != 0)
                ADVANCE(1561);
            END_STATE();
        case 75:
            if(lookahead == ' ')
                ADVANCE(519);
            END_STATE();
        case 76:
            ADVANCE_MAP(
                '"', 895,
                '%', 885,
                '&', 875,
                ')', 887,
                '*', 882,
                '+', 878,
                ',', 868,
                '-', 880,
                '/', 884,
                ':', 978,
                ';', 979,
                '<', 126,
                '>', 865,
                'A', 174,
                'B', 157,
                'C', 206,
                'D', 150,
                'E', 201,
                'F', 178,
                'H', 129,
                'L', 893,
                'M', 232,
                'S', 158,
                '[', 1106,
            );
            if(lookahead == '\\')
                SKIP(30);
            if(lookahead == ']')
                ADVANCE(1107);
            if(lookahead == '^')
                ADVANCE(874);
            if(lookahead == 'a')
                ADVANCE(690);
            if(lookahead == 'b')
                ADVANCE(470);
            if(lookahead == 'c')
                ADVANCE(250);
            if(lookahead == 'd')
                ADVANCE(413);
            if(lookahead == 'e')
                ADVANCE(527);
            if(lookahead == 'g')
                ADVANCE(406);
            if(lookahead == 'i')
                ADVANCE(568);
            if(lookahead == 'l')
                ADVANCE(606);
            if(lookahead == 'm')
                ADVANCE(272);
            if(lookahead == 'o')
                ADVANCE(312);
            if(lookahead == 'p')
                ADVANCE(612);
            if(lookahead == 'r')
                ADVANCE(290);
            if(lookahead == 's')
                ADVANCE(416);
            if(lookahead == 'u')
                ADVANCE(446);
            if(lookahead == 'v')
                ADVANCE(275);
            if(lookahead == '{')
                ADVANCE(970);
            if(lookahead == '|')
                ADVANCE(873);
            if(lookahead == '}')
                ADVANCE(971);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(76);
            END_STATE();
        case 77:
            ADVANCE_MAP(
                '"', 895,
                '%', 885,
                '&', 875,
                ')', 887,
                '*', 882,
                '+', 878,
                ',', 868,
                '-', 880,
                '/', 884,
                ':', 977,
                ';', 979,
                '<', 126,
                '>', 865,
                'A', 173,
                'B', 157,
                'E', 201,
                'L', 893,
            );
            if(lookahead == '\\')
                SKIP(34);
            if(lookahead == ']')
                ADVANCE(1107);
            if(lookahead == '^')
                ADVANCE(874);
            if(lookahead == 'c')
                ADVANCE(1057);
            if(lookahead == 'i')
                ADVANCE(340);
            if(lookahead == 'j')
                ADVANCE(246);
            if(lookahead == 'm')
                ADVANCE(271);
            if(lookahead == 's')
                ADVANCE(756);
            if(lookahead == '{')
                ADVANCE(970);
            if(lookahead == '|')
                ADVANCE(873);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(77);
            END_STATE();
        case 78:
            ADVANCE_MAP(
                '"', 895,
                '&', 875,
                ')', 887,
                ',', 868,
                '/', 92,
                ':', 977,
                ';', 979,
                '<', 863,
                '>', 864,
                'L', 894,
            );
            if(lookahead == '\\')
                SKIP(40);
            if(lookahead == ']')
                ADVANCE(1107);
            if(lookahead == '^')
                ADVANCE(874);
            if(lookahead == '|')
                ADVANCE(873);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(78);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 79:
            ADVANCE_MAP(
                '"', 895,
                '\'', 899,
                '(', 886,
                '+', 879,
                '-', 881,
                '.', 794,
                '/', 92,
                '0', 917,
                ':', 125,
                'F', 1154,
                'L', 894,
                'T', 1159,
            );
            if(lookahead == '\\')
                SKIP(28);
            if(lookahead == '~')
                ADVANCE(888);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(79);
            if(('1' <= lookahead && lookahead <= '9'))
                ADVANCE(920);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 80:
            if(lookahead == '"')
                ADVANCE(895);
            if(lookahead == ',')
                ADVANCE(868);
            if(lookahead == '/')
                ADVANCE(92);
            if(lookahead == ':')
                ADVANCE(125);
            if(lookahead == '<')
                ADVANCE(863);
            if(lookahead == '>')
                ADVANCE(864);
            if(lookahead == 'L')
                ADVANCE(893);
            if(lookahead == '\\')
                SKIP(38);
            if(lookahead == 'm')
                ADVANCE(271);
            if(lookahead == 'p')
                ADVANCE(648);
            if(lookahead == 's')
                ADVANCE(756);
            if(lookahead == '{')
                ADVANCE(970);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(80);
            END_STATE();
        case 81:
            if(lookahead == '"')
                ADVANCE(895);
            if(lookahead == '/')
                ADVANCE(92);
            if(lookahead == ':')
                ADVANCE(125);
            if(lookahead == 'L')
                ADVANCE(894);
            if(lookahead == '\\')
                SKIP(46);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(81);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 82:
            if(lookahead == '"')
                ADVANCE(895);
            if(lookahead == '/')
                ADVANCE(92);
            if(lookahead == '\\')
                ADVANCE(57);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(82);
            END_STATE();
        case 83:
            ADVANCE_MAP(
                '%', 885,
                '&', 875,
                ')', 887,
                '*', 882,
                '+', 878,
                ',', 868,
                '-', 880,
                '/', 884,
                ':', 978,
                ';', 979,
                '<', 126,
                '=', 1011,
                '>', 865,
                'O', 1199,
                'V', 1164,
            );
            if(lookahead == '\\')
                SKIP(12);
            if(lookahead == ']')
                ADVANCE(1107);
            if(lookahead == '^')
                ADVANCE(874);
            if(lookahead == 'a')
                ADVANCE(1376);
            if(lookahead == 'b')
                ADVANCE(1408);
            if(lookahead == 'c')
                ADVANCE(1304);
            if(lookahead == 'd')
                ADVANCE(1404);
            if(lookahead == 'f')
                ADVANCE(1307);
            if(lookahead == 'i')
                ADVANCE(1380);
            if(lookahead == 'l')
                ADVANCE(1406);
            if(lookahead == 'm')
                ADVANCE(1169);
            if(lookahead == 'o')
                ADVANCE(1217);
            if(lookahead == 's')
                ADVANCE(1243);
            if(lookahead == 'u')
                ADVANCE(1316);
            if(lookahead == 'w')
                ADVANCE(1210);
            if(lookahead == '{')
                ADVANCE(970);
            if(lookahead == '|')
                ADVANCE(873);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(83);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('e' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 84:
            ADVANCE_MAP(
                '%', 885,
                '&', 875,
                ')', 887,
                '*', 882,
                '+', 878,
                ',', 868,
                '-', 880,
                '/', 884,
                ':', 978,
                ';', 979,
                '<', 126,
                '>', 865,
                '@', 347,
            );
            if(lookahead == '\\')
                SKIP(32);
            if(lookahead == ']')
                ADVANCE(1107);
            if(lookahead == '^')
                ADVANCE(874);
            if(lookahead == '{')
                ADVANCE(970);
            if(lookahead == '|')
                ADVANCE(873);
            if(lookahead == '}')
                ADVANCE(971);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(84);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 85:
            if(lookahead == '\'')
                ADVANCE(899);
            if(lookahead == '/')
                ADVANCE(92);
            if(lookahead == '\\')
                ADVANCE(57);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(85);
            END_STATE();
        case 86:
            if(lookahead == '(')
                ADVANCE(886);
            if(lookahead == '/')
                ADVANCE(91);
            if(lookahead == ':')
                ADVANCE(125);
            if(lookahead == '@')
                ADVANCE(1006);
            if(lookahead == 'O')
                ADVANCE(1199);
            if(lookahead == 'V')
                ADVANCE(1164);
            if(lookahead == '\\')
                SKIP(10);
            if(lookahead == 'a')
                ADVANCE(1376);
            if(lookahead == 'b')
                ADVANCE(1408);
            if(lookahead == 'c')
                ADVANCE(1304);
            if(lookahead == 'd')
                ADVANCE(1404);
            if(lookahead == 'f')
                ADVANCE(1307);
            if(lookahead == 'i')
                ADVANCE(1380);
            if(lookahead == 'l')
                ADVANCE(1406);
            if(lookahead == 'm')
                ADVANCE(1169);
            if(lookahead == 'o')
                ADVANCE(1217);
            if(lookahead == 's')
                ADVANCE(1244);
            if(lookahead == 'u')
                ADVANCE(1316);
            if(lookahead == 'w')
                ADVANCE(1210);
            if(lookahead == '}')
                ADVANCE(971);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(86);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('e' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 87:
            if(lookahead == '(')
                ADVANCE(886);
            if(lookahead == '/')
                ADVANCE(91);
            if(lookahead == ':')
                ADVANCE(125);
            if(lookahead == '@')
                ADVANCE(1006);
            if(lookahead == '\\')
                SKIP(36);
            if(lookahead == 'a')
                ADVANCE(295);
            if(lookahead == 'b')
                ADVANCE(471);
            if(lookahead == 'i')
                ADVANCE(577);
            if(lookahead == 'l')
                ADVANCE(587);
            if(lookahead == 's')
                ADVANCE(727);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(87);
            END_STATE();
        case 88:
            if(lookahead == '(')
                ADVANCE(886);
            if(lookahead == '/')
                ADVANCE(91);
            if(lookahead == ':')
                ADVANCE(125);
            if(lookahead == '@')
                ADVANCE(1006);
            if(lookahead == '\\')
                SKIP(44);
            if(lookahead == '}')
                ADVANCE(971);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(88);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 89:
            if(lookahead == ')')
                ADVANCE(887);
            if(lookahead == ',')
                ADVANCE(868);
            if(lookahead == '/')
                ADVANCE(92);
            if(lookahead == ':')
                ADVANCE(125);
            if(lookahead == ';')
                ADVANCE(979);
            if(lookahead == '<')
                ADVANCE(863);
            if(lookahead == '>')
                ADVANCE(864);
            if(lookahead == '\\')
                SKIP(42);
            if(lookahead == '{')
                ADVANCE(970);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(89);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 90:
            if(lookahead == ')')
                ADVANCE(887);
            if(lookahead == '/')
                ADVANCE(92);
            if(lookahead == ':')
                ADVANCE(125);
            if(lookahead == 'O')
                ADVANCE(1199);
            if(lookahead == 'V')
                ADVANCE(1164);
            if(lookahead == '\\')
                SKIP(14);
            if(lookahead == 'a')
                ADVANCE(1376);
            if(lookahead == 'b')
                ADVANCE(1408);
            if(lookahead == 'c')
                ADVANCE(1304);
            if(lookahead == 'd')
                ADVANCE(1404);
            if(lookahead == 'f')
                ADVANCE(1307);
            if(lookahead == 'i')
                ADVANCE(1372);
            if(lookahead == 'l')
                ADVANCE(1406);
            if(lookahead == 'm')
                ADVANCE(1169);
            if(lookahead == 'o')
                ADVANCE(1216);
            if(lookahead == 's')
                ADVANCE(1244);
            if(lookahead == 'u')
                ADVANCE(1316);
            if(lookahead == 'w')
                ADVANCE(1210);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(90);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('e' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 91:
            if(lookahead == '*')
                ADVANCE(1563);
            if(lookahead == '/')
                ADVANCE(1553);
            END_STATE();
        case 92:
            if(lookahead == '*')
                ADVANCE(1563);
            if(lookahead == '/')
                ADVANCE(1551);
            END_STATE();
        case 93:
            if(lookahead == '*')
                ADVANCE(1568);
            if(lookahead == '/')
                ADVANCE(95);
            if(lookahead == '\\')
                ADVANCE(70);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                ADVANCE(93);
            if(lookahead != 0)
                ADVANCE(94);
            END_STATE();
        case 94:
            if(lookahead == '*')
                ADVANCE(1568);
            if(lookahead != 0)
                ADVANCE(94);
            END_STATE();
        case 95:
            if(lookahead == '*')
                ADVANCE(1564);
            if(lookahead == '/')
                ADVANCE(1552);
            if(lookahead != 0)
                ADVANCE(94);
            END_STATE();
        case 96:
            if(lookahead == '+')
                ADVANCE(1059);
            END_STATE();
        case 97:
            if(lookahead == '.')
                ADVANCE(794);
            if(lookahead == '0')
                ADVANCE(911);
            if(('1' <= lookahead && lookahead <= '9'))
                ADVANCE(913);
            if(('A' <= lookahead && lookahead <= 'F') ||
               ('a' <= lookahead && lookahead <= 'f'))
                ADVANCE(926);
            END_STATE();
        case 98:
            if(lookahead == '/')
                ADVANCE(91);
            if(lookahead == ':')
                ADVANCE(125);
            if(lookahead == '@')
                ADVANCE(1008);
            if(lookahead == 'O')
                ADVANCE(1199);
            if(lookahead == 'V')
                ADVANCE(1164);
            if(lookahead == '\\')
                SKIP(2);
            if(lookahead == 'a')
                ADVANCE(1200);
            if(lookahead == 'b')
                ADVANCE(1310);
            if(lookahead == 'c')
                ADVANCE(1302);
            if(lookahead == 'd')
                ADVANCE(1404);
            if(lookahead == 'e')
                ADVANCE(1378);
            if(lookahead == 'f')
                ADVANCE(1167);
            if(lookahead == 'i')
                ADVANCE(1361);
            if(lookahead == 'l')
                ADVANCE(1406);
            if(lookahead == 'm')
                ADVANCE(1169);
            if(lookahead == 'n')
                ADVANCE(1175);
            if(lookahead == 'o')
                ADVANCE(1215);
            if(lookahead == 'p')
                ADVANCE(1436);
            if(lookahead == 'r')
                ADVANCE(1271);
            if(lookahead == 's')
                ADVANCE(1241);
            if(lookahead == 't')
                ADVANCE(1544);
            if(lookahead == 'u')
                ADVANCE(1315);
            if(lookahead == 'v')
                ADVANCE(1195);
            if(lookahead == 'w')
                ADVANCE(1210);
            if(lookahead == '}')
                ADVANCE(971);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(98);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('g' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 99:
            if(lookahead == '/')
                ADVANCE(91);
            if(lookahead == ':')
                ADVANCE(125);
            if(lookahead == '@')
                ADVANCE(1008);
            if(lookahead == 'O')
                ADVANCE(1199);
            if(lookahead == 'V')
                ADVANCE(1164);
            if(lookahead == '\\')
                SKIP(4);
            if(lookahead == 'a')
                ADVANCE(1200);
            if(lookahead == 'b')
                ADVANCE(1310);
            if(lookahead == 'c')
                ADVANCE(1302);
            if(lookahead == 'd')
                ADVANCE(1404);
            if(lookahead == 'e')
                ADVANCE(1378);
            if(lookahead == 'f')
                ADVANCE(1168);
            if(lookahead == 'i')
                ADVANCE(1361);
            if(lookahead == 'l')
                ADVANCE(1406);
            if(lookahead == 'm')
                ADVANCE(1169);
            if(lookahead == 'n')
                ADVANCE(1175);
            if(lookahead == 'o')
                ADVANCE(1215);
            if(lookahead == 'r')
                ADVANCE(1271);
            if(lookahead == 's')
                ADVANCE(1241);
            if(lookahead == 't')
                ADVANCE(1544);
            if(lookahead == 'u')
                ADVANCE(1315);
            if(lookahead == 'v')
                ADVANCE(1195);
            if(lookahead == 'w')
                ADVANCE(1210);
            if(lookahead == '}')
                ADVANCE(971);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(99);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('g' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 100:
            if(lookahead == '/')
                ADVANCE(91);
            if(lookahead == ':')
                ADVANCE(125);
            if(lookahead == '@')
                ADVANCE(1008);
            if(lookahead == 'O')
                ADVANCE(1199);
            if(lookahead == 'V')
                ADVANCE(1164);
            if(lookahead == '\\')
                SKIP(73);
            if(lookahead == 'a')
                ADVANCE(1200);
            if(lookahead == 'b')
                ADVANCE(1310);
            if(lookahead == 'c')
                ADVANCE(1302);
            if(lookahead == 'd')
                ADVANCE(1404);
            if(lookahead == 'e')
                ADVANCE(1378);
            if(lookahead == 'f')
                ADVANCE(1307);
            if(lookahead == 'i')
                ADVANCE(1361);
            if(lookahead == 'l')
                ADVANCE(1406);
            if(lookahead == 'm')
                ADVANCE(1169);
            if(lookahead == 'n')
                ADVANCE(1175);
            if(lookahead == 'o')
                ADVANCE(1215);
            if(lookahead == 'r')
                ADVANCE(1271);
            if(lookahead == 's')
                ADVANCE(1241);
            if(lookahead == 't')
                ADVANCE(1544);
            if(lookahead == 'u')
                ADVANCE(1315);
            if(lookahead == 'v')
                ADVANCE(1195);
            if(lookahead == 'w')
                ADVANCE(1210);
            if(lookahead == '}')
                ADVANCE(971);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(100);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('g' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 101:
            if(lookahead == '/')
                ADVANCE(91);
            if(lookahead == ':')
                ADVANCE(125);
            if(lookahead == '@')
                ADVANCE(1008);
            if(lookahead == 'O')
                ADVANCE(1199);
            if(lookahead == 'V')
                ADVANCE(1164);
            if(lookahead == '\\')
                SKIP(6);
            if(lookahead == 'a')
                ADVANCE(1376);
            if(lookahead == 'b')
                ADVANCE(1310);
            if(lookahead == 'c')
                ADVANCE(1188);
            if(lookahead == 'd')
                ADVANCE(1268);
            if(lookahead == 'e')
                ADVANCE(1379);
            if(lookahead == 'f')
                ADVANCE(1307);
            if(lookahead == 'i')
                ADVANCE(1380);
            if(lookahead == 'l')
                ADVANCE(1406);
            if(lookahead == 'm')
                ADVANCE(1169);
            if(lookahead == 'o')
                ADVANCE(1217);
            if(lookahead == 's')
                ADVANCE(1241);
            if(lookahead == 'u')
                ADVANCE(1315);
            if(lookahead == 'w')
                ADVANCE(1210);
            if(lookahead == '}')
                ADVANCE(971);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(101);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('g' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 102:
            if(lookahead == '/')
                ADVANCE(91);
            if(lookahead == ':')
                ADVANCE(125);
            if(lookahead == '@')
                ADVANCE(1008);
            if(lookahead == 'O')
                ADVANCE(1199);
            if(lookahead == 'V')
                ADVANCE(1164);
            if(lookahead == '\\')
                SKIP(8);
            if(lookahead == 'a')
                ADVANCE(1376);
            if(lookahead == 'b')
                ADVANCE(1310);
            if(lookahead == 'c')
                ADVANCE(1304);
            if(lookahead == 'd')
                ADVANCE(1404);
            if(lookahead == 'e')
                ADVANCE(1379);
            if(lookahead == 'f')
                ADVANCE(1307);
            if(lookahead == 'i')
                ADVANCE(1380);
            if(lookahead == 'l')
                ADVANCE(1406);
            if(lookahead == 'm')
                ADVANCE(1169);
            if(lookahead == 'o')
                ADVANCE(1217);
            if(lookahead == 's')
                ADVANCE(1241);
            if(lookahead == 'u')
                ADVANCE(1315);
            if(lookahead == 'w')
                ADVANCE(1210);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(102);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('g' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 103:
            if(lookahead == '/')
                ADVANCE(959);
            if(lookahead == '\\')
                ADVANCE(956);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(103);
            if(lookahead != 0)
                ADVANCE(960);
            END_STATE();
        case 104:
            if(lookahead == '/')
                ADVANCE(92);
            if(lookahead == ':')
                ADVANCE(125);
            if(lookahead == '@')
                ADVANCE(440);
            if(lookahead == '\\')
                SKIP(16);
            if(lookahead == 'a')
                ADVANCE(1376);
            if(lookahead == 'b')
                ADVANCE(1408);
            if(lookahead == 'c')
                ADVANCE(1303);
            if(lookahead == 'd')
                ADVANCE(1404);
            if(lookahead == 'e')
                ADVANCE(1379);
            if(lookahead == 'f')
                ADVANCE(1307);
            if(lookahead == 'i')
                ADVANCE(1380);
            if(lookahead == 'l')
                ADVANCE(1406);
            if(lookahead == 'o')
                ADVANCE(1217);
            if(lookahead == 's')
                ADVANCE(1244);
            if(lookahead == 't')
                ADVANCE(1546);
            if(lookahead == 'u')
                ADVANCE(1316);
            if(lookahead == 'w')
                ADVANCE(1210);
            if(lookahead == '}')
                ADVANCE(971);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(104);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('g' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 105:
            if(lookahead == '/')
                ADVANCE(92);
            if(lookahead == ':')
                ADVANCE(125);
            if(lookahead == 'O')
                ADVANCE(1199);
            if(lookahead == 'V')
                ADVANCE(1164);
            if(lookahead == '\\')
                SKIP(18);
            if(lookahead == 'a')
                ADVANCE(1376);
            if(lookahead == 'b')
                ADVANCE(1408);
            if(lookahead == 'c')
                ADVANCE(1303);
            if(lookahead == 'd')
                ADVANCE(1404);
            if(lookahead == 'e')
                ADVANCE(1377);
            if(lookahead == 'f')
                ADVANCE(1345);
            if(lookahead == 'i')
                ADVANCE(1393);
            if(lookahead == 'l')
                ADVANCE(1406);
            if(lookahead == 'o')
                ADVANCE(1217);
            if(lookahead == 's')
                ADVANCE(1242);
            if(lookahead == 't')
                ADVANCE(1547);
            if(lookahead == 'u')
                ADVANCE(1315);
            if(lookahead == 'v')
                ADVANCE(1196);
            if(lookahead == 'w')
                ADVANCE(1211);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(105);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('g' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 106:
            if(lookahead == '/')
                ADVANCE(92);
            if(lookahead == ':')
                ADVANCE(125);
            if(lookahead == 'O')
                ADVANCE(1199);
            if(lookahead == 'V')
                ADVANCE(1164);
            if(lookahead == '\\')
                SKIP(22);
            if(lookahead == 'a')
                ADVANCE(1376);
            if(lookahead == 'b')
                ADVANCE(1408);
            if(lookahead == 'c')
                ADVANCE(1304);
            if(lookahead == 'd')
                ADVANCE(1404);
            if(lookahead == 'f')
                ADVANCE(1307);
            if(lookahead == 'i')
                ADVANCE(1380);
            if(lookahead == 'l')
                ADVANCE(1406);
            if(lookahead == 'm')
                ADVANCE(1169);
            if(lookahead == 'o')
                ADVANCE(1217);
            if(lookahead == 's')
                ADVANCE(1244);
            if(lookahead == 'u')
                ADVANCE(1316);
            if(lookahead == 'w')
                ADVANCE(1210);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(106);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('e' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 107:
            if(lookahead == '/')
                ADVANCE(92);
            if(lookahead == ':')
                ADVANCE(125);
            if(lookahead == 'O')
                ADVANCE(1199);
            if(lookahead == '\\')
                SKIP(51);
            if(lookahead == 'm')
                ADVANCE(1529);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(107);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 108:
            if(lookahead == '/')
                ADVANCE(92);
            if(lookahead == ':')
                ADVANCE(125);
            if(lookahead == 'O')
                ADVANCE(1199);
            if(lookahead == '\\')
                SKIP(53);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(108);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 109:
            if(lookahead == '/')
                ADVANCE(92);
            if(lookahead == ':')
                ADVANCE(125);
            if(lookahead == '\\')
                SKIP(20);
            if(lookahead == 'a')
                ADVANCE(1366);
            if(lookahead == 'b')
                ADVANCE(1326);
            if(lookahead == 'd')
                ADVANCE(1290);
            if(lookahead == 'e')
                ADVANCE(1537);
            if(lookahead == 'f')
                ADVANCE(1325);
            if(lookahead == 'i')
                ADVANCE(1230);
            if(lookahead == 'k')
                ADVANCE(1273);
            if(lookahead == 'm')
                ADVANCE(1172);
            if(lookahead == 'n')
                ADVANCE(1289);
            if(lookahead == 'o')
                ADVANCE(1375);
            if(lookahead == 'p')
                ADVANCE(1411);
            if(lookahead == 'r')
                ADVANCE(1184);
            if(lookahead == 's')
                ADVANCE(1279);
            if(lookahead == 'u')
                ADVANCE(1399);
            if(lookahead == 'v')
                ADVANCE(1198);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(109);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('c' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 110:
            if(lookahead == '/')
                ADVANCE(92);
            if(lookahead == ':')
                ADVANCE(125);
            if(lookahead == '\\')
                SKIP(24);
            if(lookahead == 'b')
                ADVANCE(1408);
            if(lookahead == 'c')
                ADVANCE(1304);
            if(lookahead == 'd')
                ADVANCE(1404);
            if(lookahead == 'f')
                ADVANCE(1307);
            if(lookahead == 'i')
                ADVANCE(1380);
            if(lookahead == 'l')
                ADVANCE(1406);
            if(lookahead == 'o')
                ADVANCE(1217);
            if(lookahead == 's')
                ADVANCE(1244);
            if(lookahead == 'u')
                ADVANCE(1316);
            if(lookahead == 'w')
                ADVANCE(1210);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(110);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 111:
            if(lookahead == '/')
                ADVANCE(92);
            if(lookahead == ':')
                ADVANCE(125);
            if(lookahead == '\\')
                SKIP(26);
            if(lookahead == 'b')
                ADVANCE(1408);
            if(lookahead == 'c')
                ADVANCE(1304);
            if(lookahead == 'i')
                ADVANCE(1380);
            if(lookahead == 'l')
                ADVANCE(1416);
            if(lookahead == 's')
                ADVANCE(1305);
            if(lookahead == 'u')
                ADVANCE(1316);
            if(lookahead == 'w')
                ADVANCE(1211);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(111);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 112:
            if(lookahead == '/')
                ADVANCE(92);
            if(lookahead == ':')
                ADVANCE(125);
            if(lookahead == '\\')
                SKIP(55);
            if(lookahead == 't')
                ADVANCE(1453);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(112);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 113:
            if(lookahead == '/')
                ADVANCE(92);
            if(lookahead == ':')
                ADVANCE(977);
            if(lookahead == ';')
                ADVANCE(979);
            if(lookahead == '\\')
                SKIP(59);
            if(lookahead == '{')
                ADVANCE(970);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(113);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 114:
            if(lookahead == '/')
                ADVANCE(92);
            if(lookahead == ';')
                ADVANCE(979);
            if(lookahead == '\\')
                SKIP(62);
            if(lookahead == 's')
                ADVANCE(1534);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(114);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 115:
            if(lookahead == '/')
                ADVANCE(92);
            if(lookahead == '\\')
                SKIP(68);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(115);
            END_STATE();
        case 116:
            if(lookahead == '1')
                ADVANCE(123);
            if(lookahead == '3')
                ADVANCE(119);
            if(lookahead == '6')
                ADVANCE(121);
            if(lookahead == '8')
                ADVANCE(838);
            END_STATE();
        case 117:
            if(lookahead == '1')
                ADVANCE(123);
            if(lookahead == '3')
                ADVANCE(119);
            if(lookahead == '6')
                ADVANCE(121);
            if(lookahead == '8')
                ADVANCE(838);
            if(lookahead == 'e')
                ADVANCE(655);
            END_STATE();
        case 118:
            if(lookahead == '1')
                ADVANCE(124);
            if(lookahead == '3')
                ADVANCE(120);
            if(lookahead == '6')
                ADVANCE(122);
            if(lookahead == '8')
                ADVANCE(830);
            END_STATE();
        case 119:
            if(lookahead == '2')
                ADVANCE(825);
            END_STATE();
        case 120:
            if(lookahead == '2')
                ADVANCE(844);
            END_STATE();
        case 121:
            if(lookahead == '4')
                ADVANCE(828);
            END_STATE();
        case 122:
            if(lookahead == '4')
                ADVANCE(847);
            END_STATE();
        case 123:
            if(lookahead == '6')
                ADVANCE(819);
            END_STATE();
        case 124:
            if(lookahead == '6')
                ADVANCE(841);
            END_STATE();
        case 125:
            if(lookahead == ':')
                ADVANCE(858);
            END_STATE();
        case 126:
            if(lookahead == '<')
                ADVANCE(877);
            END_STATE();
        case 127:
            if(lookahead == 'A')
                ADVANCE(188);
            if(lookahead == 'I')
                ADVANCE(202);
            END_STATE();
        case 128:
            if(lookahead == 'A')
                ADVANCE(1070);
            END_STATE();
        case 129:
            if(lookahead == 'A')
                ADVANCE(223);
            END_STATE();
        case 130:
            if(lookahead == 'A')
                ADVANCE(186);
            END_STATE();
        case 131:
            if(lookahead == 'A')
                ADVANCE(142);
            END_STATE();
        case 132:
            if(lookahead == 'A')
                ADVANCE(217);
            END_STATE();
        case 133:
            if(lookahead == 'A')
                ADVANCE(187);
            END_STATE();
        case 134:
            if(lookahead == 'A')
                ADVANCE(228);
            END_STATE();
        case 135:
            if(lookahead == 'A')
                ADVANCE(229);
            END_STATE();
        case 136:
            if(lookahead == 'A')
                ADVANCE(230);
            END_STATE();
        case 137:
            if(lookahead == 'A')
                ADVANCE(231);
            END_STATE();
        case 138:
            if(lookahead == 'A')
                ADVANCE(145);
            END_STATE();
        case 139:
            if(lookahead == 'A')
                ADVANCE(219);
            END_STATE();
        case 140:
            if(lookahead == 'A')
                ADVANCE(220);
            END_STATE();
        case 141:
            if(lookahead == 'A')
                ADVANCE(221);
            END_STATE();
        case 142:
            if(lookahead == 'B')
                ADVANCE(190);
            END_STATE();
        case 143:
            if(lookahead == 'B')
                ADVANCE(128);
            END_STATE();
        case 144:
            if(lookahead == 'B')
                ADVANCE(286);
            END_STATE();
        case 145:
            if(lookahead == 'B')
                ADVANCE(192);
            END_STATE();
        case 146:
            if(lookahead == 'C')
                ADVANCE(189);
            END_STATE();
        case 147:
            if(lookahead == 'C')
                ADVANCE(194);
            END_STATE();
        case 148:
            if(lookahead == 'C')
                ADVANCE(195);
            END_STATE();
        case 149:
            if(lookahead == 'C')
                ADVANCE(196);
            END_STATE();
        case 150:
            if(lookahead == 'D')
                ADVANCE(222);
            END_STATE();
        case 151:
            if(lookahead == 'D')
                ADVANCE(235);
            END_STATE();
        case 152:
            if(lookahead == 'D')
                ADVANCE(161);
            if(lookahead == 'F')
                ADVANCE(182);
            END_STATE();
        case 153:
            if(lookahead == 'D')
                ADVANCE(138);
            END_STATE();
        case 154:
            if(lookahead == 'D')
                ADVANCE(169);
            END_STATE();
        case 155:
            if(lookahead == 'D')
                ADVANCE(170);
            if(lookahead == 'F')
                ADVANCE(185);
            END_STATE();
        case 156:
            if(lookahead == 'D')
                ADVANCE(171);
            END_STATE();
        case 157:
            if(lookahead == 'E')
                ADVANCE(175);
            END_STATE();
        case 158:
            if(lookahead == 'E')
                ADVANCE(213);
            END_STATE();
        case 159:
            if(lookahead == 'E')
                ADVANCE(904);
            END_STATE();
        case 160:
            if(lookahead == 'E')
                ADVANCE(906);
            END_STATE();
        case 161:
            if(lookahead == 'E')
                ADVANCE(146);
            END_STATE();
        case 162:
            if(lookahead == 'E')
                ADVANCE(1028);
            END_STATE();
        case 163:
            if(lookahead == 'E')
                ADVANCE(1067);
            END_STATE();
        case 164:
            if(lookahead == 'E')
                ADVANCE(1027);
            END_STATE();
        case 165:
            if(lookahead == 'E')
                ADVANCE(1062);
            END_STATE();
        case 166:
            if(lookahead == 'E')
                ADVANCE(216);
            END_STATE();
        case 167:
            if(lookahead == 'E')
                ADVANCE(204);
            END_STATE();
        case 168:
            if(lookahead == 'E')
                ADVANCE(203);
            END_STATE();
        case 169:
            if(lookahead == 'E')
                ADVANCE(147);
            END_STATE();
        case 170:
            if(lookahead == 'E')
                ADVANCE(148);
            END_STATE();
        case 171:
            if(lookahead == 'E')
                ADVANCE(149);
            END_STATE();
        case 172:
            if(lookahead == 'E')
                ADVANCE(243);
            END_STATE();
        case 173:
            if(lookahead == 'F')
                ADVANCE(225);
            END_STATE();
        case 174:
            if(lookahead == 'F')
                ADVANCE(225);
            if(lookahead == 'P')
                ADVANCE(212);
            END_STATE();
        case 175:
            if(lookahead == 'F')
                ADVANCE(207);
            if(lookahead == 'G')
                ADVANCE(179);
            END_STATE();
        case 176:
            if(lookahead == 'H')
                ADVANCE(1017);
            END_STATE();
        case 177:
            if(lookahead == 'I')
                ADVANCE(208);
            END_STATE();
        case 178:
            if(lookahead == 'I')
                ADVANCE(202);
            END_STATE();
        case 179:
            if(lookahead == 'I')
                ADVANCE(205);
            END_STATE();
        case 180:
            if(lookahead == 'I')
                ADVANCE(209);
            END_STATE();
        case 181:
            if(lookahead == 'I')
                ADVANCE(133);
            END_STATE();
        case 182:
            if(lookahead == 'I')
                ADVANCE(191);
            END_STATE();
        case 183:
            if(lookahead == 'I')
                ADVANCE(210);
            END_STATE();
        case 184:
            if(lookahead == 'I')
                ADVANCE(211);
            END_STATE();
        case 185:
            if(lookahead == 'I')
                ADVANCE(193);
            END_STATE();
        case 186:
            if(lookahead == 'L')
                ADVANCE(1026);
            END_STATE();
        case 187:
            if(lookahead == 'L')
                ADVANCE(1016);
            END_STATE();
        case 188:
            if(lookahead == 'L')
                ADVANCE(224);
            END_STATE();
        case 189:
            if(lookahead == 'L')
                ADVANCE(132);
            END_STATE();
        case 190:
            if(lookahead == 'L')
                ADVANCE(162);
            END_STATE();
        case 191:
            if(lookahead == 'L')
                ADVANCE(163);
            END_STATE();
        case 192:
            if(lookahead == 'L')
                ADVANCE(164);
            END_STATE();
        case 193:
            if(lookahead == 'L')
                ADVANCE(165);
            END_STATE();
        case 194:
            if(lookahead == 'L')
                ADVANCE(139);
            END_STATE();
        case 195:
            if(lookahead == 'L')
                ADVANCE(140);
            END_STATE();
        case 196:
            if(lookahead == 'L')
                ADVANCE(141);
            END_STATE();
        case 197:
            if(lookahead == 'N')
                ADVANCE(1065);
            END_STATE();
        case 198:
            if(lookahead == 'N')
                ADVANCE(1066);
            END_STATE();
        case 199:
            if(lookahead == 'N')
                ADVANCE(1064);
            END_STATE();
        case 200:
            if(lookahead == 'N')
                ADVANCE(1063);
            END_STATE();
        case 201:
            if(lookahead == 'N')
                ADVANCE(151);
            END_STATE();
        case 202:
            if(lookahead == 'N')
                ADVANCE(130);
            END_STATE();
        case 203:
            if(lookahead == 'N')
                ADVANCE(153);
            END_STATE();
        case 204:
            if(lookahead == 'N')
                ADVANCE(227);
            END_STATE();
        case 205:
            if(lookahead == 'N')
                ADVANCE(241);
            END_STATE();
        case 206:
            if(lookahead == 'O')
                ADVANCE(214);
            END_STATE();
        case 207:
            if(lookahead == 'O')
                ADVANCE(218);
            END_STATE();
        case 208:
            if(lookahead == 'O')
                ADVANCE(197);
            END_STATE();
        case 209:
            if(lookahead == 'O')
                ADVANCE(198);
            END_STATE();
        case 210:
            if(lookahead == 'O')
                ADVANCE(199);
            END_STATE();
        case 211:
            if(lookahead == 'O')
                ADVANCE(200);
            END_STATE();
        case 212:
            if(lookahead == 'P')
                ADVANCE(168);
            END_STATE();
        case 213:
            if(lookahead == 'Q')
                ADVANCE(234);
            END_STATE();
        case 214:
            if(lookahead == 'R')
                ADVANCE(143);
            END_STATE();
        case 215:
            if(lookahead == 'R')
                ADVANCE(233);
            END_STATE();
        case 216:
            if(lookahead == 'R')
                ADVANCE(236);
            END_STATE();
        case 217:
            if(lookahead == 'R')
                ADVANCE(134);
            END_STATE();
        case 218:
            if(lookahead == 'R')
                ADVANCE(172);
            END_STATE();
        case 219:
            if(lookahead == 'R')
                ADVANCE(135);
            END_STATE();
        case 220:
            if(lookahead == 'R')
                ADVANCE(136);
            END_STATE();
        case 221:
            if(lookahead == 'R')
                ADVANCE(137);
            END_STATE();
        case 222:
            if(lookahead == 'S')
                ADVANCE(1071);
            END_STATE();
        case 223:
            if(lookahead == 'S')
                ADVANCE(176);
            END_STATE();
        case 224:
            if(lookahead == 'S')
                ADVANCE(160);
            END_STATE();
        case 225:
            if(lookahead == 'T')
                ADVANCE(166);
            END_STATE();
        case 226:
            if(lookahead == 'T')
                ADVANCE(131);
            END_STATE();
        case 227:
            if(lookahead == 'T')
                ADVANCE(181);
            END_STATE();
        case 228:
            if(lookahead == 'T')
                ADVANCE(177);
            END_STATE();
        case 229:
            if(lookahead == 'T')
                ADVANCE(180);
            END_STATE();
        case 230:
            if(lookahead == 'T')
                ADVANCE(183);
            END_STATE();
        case 231:
            if(lookahead == 'T')
                ADVANCE(184);
            END_STATE();
        case 232:
            if(lookahead == 'U')
                ADVANCE(226);
            END_STATE();
        case 233:
            if(lookahead == 'U')
                ADVANCE(159);
            END_STATE();
        case 234:
            if(lookahead == 'U')
                ADVANCE(167);
            END_STATE();
        case 235:
            if(lookahead == '_')
                ADVANCE(152);
            END_STATE();
        case 236:
            if(lookahead == '_')
                ADVANCE(154);
            END_STATE();
        case 237:
            if(lookahead == '_')
                ADVANCE(299);
            if(lookahead == 'f')
                ADVANCE(467);
            if(lookahead == 'm')
                ADVANCE(259);
            if(lookahead == 's')
                ADVANCE(405);
            END_STATE();
        case 238:
            if(lookahead == '_')
                ADVANCE(579);
            END_STATE();
        case 239:
            if(lookahead == '_')
                ADVANCE(516);
            END_STATE();
        case 240:
            if(lookahead == '_')
                ADVANCE(765);
            END_STATE();
        case 241:
            if(lookahead == '_')
                ADVANCE(155);
            END_STATE();
        case 242:
            if(lookahead == '_')
                ADVANCE(522);
            END_STATE();
        case 243:
            if(lookahead == '_')
                ADVANCE(156);
            END_STATE();
        case 244:
            if(lookahead == 'a')
                ADVANCE(496);
            END_STATE();
        case 245:
            if(lookahead == 'a')
                ADVANCE(324);
            if(lookahead == 'i')
                ADVANCE(539);
            if(lookahead == 'l')
                ADVANCE(588);
            END_STATE();
        case 246:
            if(lookahead == 'a')
                ADVANCE(774);
            END_STATE();
        case 247:
            if(lookahead == 'a')
                ADVANCE(560);
            if(lookahead == 'i')
                ADVANCE(540);
            if(lookahead == 'o')
                ADVANCE(338);
            if(lookahead == 'u')
                ADVANCE(514);
            END_STATE();
        case 248:
            if(lookahead == 'a')
                ADVANCE(474);
            if(lookahead == 'e')
                ADVANCE(251);
            END_STATE();
        case 249:
            if(lookahead == 'a')
                ADVANCE(1060);
            END_STATE();
        case 250:
            if(lookahead == 'a')
                ADVANCE(680);
            if(lookahead == 'o')
                ADVANCE(546);
            END_STATE();
        case 251:
            if(lookahead == 'a')
                ADVANCE(345);
            END_STATE();
        case 252:
            if(lookahead == 'a')
                ADVANCE(783);
            END_STATE();
        case 253:
            if(lookahead == 'a')
                ADVANCE(490);
            if(lookahead == 'd')
                ADVANCE(395);
            END_STATE();
        case 254:
            if(lookahead == 'a')
                ADVANCE(665);
            END_STATE();
        case 255:
            if(lookahead == 'a')
                ADVANCE(719);
            END_STATE();
        case 256:
            if(lookahead == 'a')
                ADVANCE(719);
            if(lookahead == 'e')
                ADVANCE(681);
            END_STATE();
        case 257:
            if(lookahead == 'a')
                ADVANCE(631);
            END_STATE();
        case 258:
            if(lookahead == 'a')
                ADVANCE(491);
            END_STATE();
        case 259:
            if(lookahead == 'a')
                ADVANCE(667);
            END_STATE();
        case 260:
            if(lookahead == 'a')
                ADVANCE(758);
            END_STATE();
        case 261:
            if(lookahead == 'a')
                ADVANCE(632);
            END_STATE();
        case 262:
            if(lookahead == 'a')
                ADVANCE(492);
            END_STATE();
        case 263:
            if(lookahead == 'a')
                ADVANCE(493);
            END_STATE();
        case 264:
            if(lookahead == 'a')
                ADVANCE(497);
            END_STATE();
        case 265:
            if(lookahead == 'a')
                ADVANCE(494);
            END_STATE();
        case 266:
            if(lookahead == 'a')
                ADVANCE(638);
            END_STATE();
        case 267:
            if(lookahead == 'a')
                ADVANCE(542);
            END_STATE();
        case 268:
            if(lookahead == 'a')
                ADVANCE(495);
            END_STATE();
        case 269:
            if(lookahead == 'a')
                ADVANCE(696);
            END_STATE();
        case 270:
            if(lookahead == 'a')
                ADVANCE(476);
            END_STATE();
        case 271:
            if(lookahead == 'a')
                ADVANCE(559);
            END_STATE();
        case 272:
            if(lookahead == 'a')
                ADVANCE(559);
            if(lookahead == 'i')
                ADVANCE(639);
            END_STATE();
        case 273:
            if(lookahead == 'a')
                ADVANCE(752);
            END_STATE();
        case 274:
            if(lookahead == 'a')
                ADVANCE(499);
            END_STATE();
        case 275:
            if(lookahead == 'a')
                ADVANCE(499);
            if(lookahead == 'o')
                ADVANCE(450);
            END_STATE();
        case 276:
            if(lookahead == 'a')
                ADVANCE(433);
            END_STATE();
        case 277:
            if(lookahead == 'a')
                ADVANCE(766);
            END_STATE();
        case 278:
            if(lookahead == 'a')
                ADVANCE(732);
            END_STATE();
        case 279:
            if(lookahead == 'a')
                ADVANCE(533);
            END_STATE();
        case 280:
            if(lookahead == 'a')
                ADVANCE(770);
            END_STATE();
        case 281:
            if(lookahead == 'a')
                ADVANCE(318);
            END_STATE();
        case 282:
            if(lookahead == 'a')
                ADVANCE(534);
            END_STATE();
        case 283:
            if(lookahead == 'a')
                ADVANCE(729);
            END_STATE();
        case 284:
            if(lookahead == 'a')
                ADVANCE(321);
            END_STATE();
        case 285:
            if(lookahead == 'a')
                ADVANCE(564);
            END_STATE();
        case 286:
            if(lookahead == 'a')
                ADVANCE(688);
            END_STATE();
        case 287:
            if(lookahead == 'a')
                ADVANCE(515);
            if(lookahead == 'e')
                ADVANCE(635);
            if(lookahead == 'o')
                ADVANCE(450);
            END_STATE();
        case 288:
            if(lookahead == 'a')
                ADVANCE(477);
            END_STATE();
        case 289:
            if(lookahead == 'a')
                ADVANCE(305);
            END_STATE();
        case 290:
            if(lookahead == 'a')
                ADVANCE(473);
            if(lookahead == 'e')
                ADVANCE(251);
            END_STATE();
        case 291:
            if(lookahead == 'a')
                ADVANCE(306);
            END_STATE();
        case 292:
            if(lookahead == 'a')
                ADVANCE(751);
            END_STATE();
        case 293:
            if(lookahead == 'a')
                ADVANCE(308);
            END_STATE();
        case 294:
            if(lookahead == 'b')
                ADVANCE(486);
            END_STATE();
        case 295:
            if(lookahead == 'b')
                ADVANCE(689);
            END_STATE();
        case 296:
            if(lookahead == 'b')
                ADVANCE(689);
            if(lookahead == 'l')
                ADVANCE(454);
            END_STATE();
        case 297:
            if(lookahead == 'b')
                ADVANCE(689);
            if(lookahead == 'l')
                ADVANCE(454);
            if(lookahead == 'm')
                ADVANCE(441);
            if(lookahead == 'n')
                ADVANCE(781);
            if(lookahead == 'p')
                ADVANCE(616);
            if(lookahead == 't')
                ADVANCE(716);
            if(lookahead == 'u')
                ADVANCE(721);
            END_STATE();
        case 298:
            if(lookahead == 'b')
                ADVANCE(501);
            END_STATE();
        case 299:
            if(lookahead == 'b')
                ADVANCE(614);
            END_STATE();
        case 300:
            if(lookahead == 'b')
                ADVANCE(283);
            END_STATE();
        case 301:
            if(lookahead == 'b')
                ADVANCE(482);
            END_STATE();
        case 302:
            if(lookahead == 'b')
                ADVANCE(504);
            END_STATE();
        case 303:
            if(lookahead == 'b')
                ADVANCE(771);
            END_STATE();
        case 304:
            if(lookahead == 'b')
                ADVANCE(503);
            END_STATE();
        case 305:
            if(lookahead == 'b')
                ADVANCE(507);
            END_STATE();
        case 306:
            if(lookahead == 'b')
                ADVANCE(511);
            END_STATE();
        case 307:
            if(lookahead == 'b')
                ADVANCE(512);
            END_STATE();
        case 308:
            if(lookahead == 'b')
                ADVANCE(513);
            END_STATE();
        case 309:
            if(lookahead == 'c')
                ADVANCE(437);
            if(lookahead == 's')
                ADVANCE(739);
            END_STATE();
        case 310:
            if(lookahead == 'c')
                ADVANCE(1098);
            if(lookahead == 's')
                ADVANCE(436);
            END_STATE();
        case 311:
            if(lookahead == 'c')
                ADVANCE(435);
            END_STATE();
        case 312:
            if(lookahead == 'c')
                ADVANCE(736);
            END_STATE();
        case 313:
            if(lookahead == 'c')
                ADVANCE(736);
            if(lookahead == 'n')
                ADVANCE(350);
            if(lookahead == 'p')
                ADVANCE(722);
            if(lookahead == 'u')
                ADVANCE(692);
            END_STATE();
        case 314:
            if(lookahead == 'c')
                ADVANCE(382);
            END_STATE();
        case 315:
            if(lookahead == 'c')
                ADVANCE(382);
            if(lookahead == 't')
                ADVANCE(378);
            END_STATE();
        case 316:
            if(lookahead == 'c')
                ADVANCE(700);
            END_STATE();
        case 317:
            if(lookahead == 'c')
                ADVANCE(703);
            END_STATE();
        case 318:
            if(lookahead == 'c')
                ADVANCE(706);
            END_STATE();
        case 319:
            if(lookahead == 'c')
                ADVANCE(362);
            END_STATE();
        case 320:
            if(lookahead == 'c')
                ADVANCE(364);
            END_STATE();
        case 321:
            if(lookahead == 'c')
                ADVANCE(375);
            END_STATE();
        case 322:
            if(lookahead == 'c')
                ADVANCE(258);
            END_STATE();
        case 323:
            if(lookahead == 'c')
                ADVANCE(258);
            if(lookahead == 'n')
                ADVANCE(424);
            END_STATE();
        case 324:
            if(lookahead == 'c')
                ADVANCE(741);
            END_STATE();
        case 325:
            if(lookahead == 'c')
                ADVANCE(273);
            END_STATE();
        case 326:
            if(lookahead == 'c')
                ADVANCE(742);
            END_STATE();
        case 327:
            if(lookahead == 'd')
                ADVANCE(946);
            if(lookahead == 'i')
                ADVANCE(952);
            if(lookahead == '\t' ||
               lookahead == ' ')
                ADVANCE(439);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(955);
            END_STATE();
        case 328:
            if(lookahead == 'd')
                ADVANCE(1012);
            if(lookahead == 'm')
                ADVANCE(624);
            if(lookahead == 'n')
                ADVANCE(983);
            END_STATE();
        case 329:
            if(lookahead == 'd')
                ADVANCE(980);
            END_STATE();
        case 330:
            if(lookahead == 'd')
                ADVANCE(834);
            END_STATE();
        case 331:
            if(lookahead == 'd')
                ADVANCE(1014);
            END_STATE();
        case 332:
            if(lookahead == 'd')
                ADVANCE(1053);
            END_STATE();
        case 333:
            if(lookahead == 'd')
                ADVANCE(1114);
            END_STATE();
        case 334:
            if(lookahead == 'd')
                ADVANCE(998);
            END_STATE();
        case 335:
            if(lookahead == 'd')
                ADVANCE(75);
            END_STATE();
        case 336:
            if(lookahead == 'd')
                ADVANCE(1049);
            END_STATE();
        case 337:
            if(lookahead == 'd')
                ADVANCE(1037);
            END_STATE();
        case 338:
            if(lookahead == 'd')
                ADVANCE(768);
            END_STATE();
        case 339:
            if(lookahead == 'd')
                ADVANCE(615);
            if(lookahead == 'l')
                ADVANCE(599);
            END_STATE();
        case 340:
            if(lookahead == 'd')
                ADVANCE(489);
            if(lookahead == 'n')
                ADVANCE(982);
            END_STATE();
        case 341:
            if(lookahead == 'd')
                ADVANCE(377);
            if(lookahead == 'i')
                ADVANCE(333);
            if(lookahead == 'n')
                ADVANCE(279);
            if(lookahead == 'p')
                ADVANCE(654);
            END_STATE();
        case 342:
            if(lookahead == 'd')
                ADVANCE(377);
            if(lookahead == 'i')
                ADVANCE(333);
            if(lookahead == 'p')
                ADVANCE(654);
            END_STATE();
        case 343:
            if(lookahead == 'd')
                ADVANCE(393);
            END_STATE();
        case 344:
            if(lookahead == 'd')
                ADVANCE(399);
            END_STATE();
        case 345:
            if(lookahead == 'd')
                ADVANCE(595);
            END_STATE();
        case 346:
            if(lookahead == 'd')
                ADVANCE(291);
            END_STATE();
        case 347:
            if(lookahead == 'd')
                ADVANCE(415);
            END_STATE();
        case 348:
            if(lookahead == 'e')
                ADVANCE(418);
            if(lookahead == 'o')
                ADVANCE(764);
            END_STATE();
        case 349:
            if(lookahead == 'e')
                ADVANCE(629);
            if(lookahead == 'h')
                ADVANCE(591);
            if(lookahead == 't')
                ADVANCE(630);
            if(lookahead == 'u')
                ADVANCE(628);
            if(lookahead == 'w')
                ADVANCE(463);
            END_STATE();
        case 350:
            if(lookahead == 'e')
                ADVANCE(778);
            END_STATE();
        case 351:
            if(lookahead == 'e')
                ADVANCE(1112);
            END_STATE();
        case 352:
            if(lookahead == 'e')
                ADVANCE(1129);
            END_STATE();
        case 353:
            if(lookahead == 'e')
                ADVANCE(341);
            END_STATE();
        case 354:
            if(lookahead == 'e')
                ADVANCE(780);
            END_STATE();
        case 355:
            if(lookahead == 'e')
                ADVANCE(1041);
            END_STATE();
        case 356:
            if(lookahead == 'e')
                ADVANCE(1022);
            END_STATE();
        case 357:
            if(lookahead == 'e')
                ADVANCE(851);
            END_STATE();
        case 358:
            if(lookahead == 'e')
                ADVANCE(1076);
            END_STATE();
        case 359:
            if(lookahead == 'e')
                ADVANCE(1141);
            END_STATE();
        case 360:
            if(lookahead == 'e')
                ADVANCE(1033);
            END_STATE();
        case 361:
            if(lookahead == 'e')
                ADVANCE(1100);
            END_STATE();
        case 362:
            if(lookahead == 'e')
                ADVANCE(1068);
            END_STATE();
        case 363:
            if(lookahead == 'e')
                ADVANCE(1127);
            END_STATE();
        case 364:
            if(lookahead == 'e')
                ADVANCE(869);
            END_STATE();
        case 365:
            if(lookahead == 'e')
                ADVANCE(1077);
            END_STATE();
        case 366:
            if(lookahead == 'e')
                ADVANCE(1122);
            END_STATE();
        case 367:
            if(lookahead == 'e')
                ADVANCE(992);
            END_STATE();
        case 368:
            if(lookahead == 'e')
                ADVANCE(1081);
            END_STATE();
        case 369:
            if(lookahead == 'e')
                ADVANCE(1079);
            END_STATE();
        case 370:
            if(lookahead == 'e')
                ADVANCE(1031);
            END_STATE();
        case 371:
            if(lookahead == 'e')
                ADVANCE(853);
            END_STATE();
        case 372:
            if(lookahead == 'e')
                ADVANCE(1094);
            END_STATE();
        case 373:
            if(lookahead == 'e')
                ADVANCE(342);
            END_STATE();
        case 374:
            if(lookahead == 'e')
                ADVANCE(1137);
            END_STATE();
        case 375:
            if(lookahead == 'e')
                ADVANCE(975);
            END_STATE();
        case 376:
            if(lookahead == 'e')
                ADVANCE(782);
            END_STATE();
        case 377:
            if(lookahead == 'e')
                ADVANCE(417);
            END_STATE();
        case 378:
            if(lookahead == 'e')
                ADVANCE(556);
            END_STATE();
        case 379:
            if(lookahead == 'e')
                ADVANCE(664);
            END_STATE();
        case 380:
            if(lookahead == 'e')
                ADVANCE(421);
            END_STATE();
        case 381:
            if(lookahead == 'e')
                ADVANCE(144);
            END_STATE();
        case 382:
            if(lookahead == 'e')
                ADVANCE(626);
            END_STATE();
        case 383:
            if(lookahead == 'e')
                ADVANCE(330);
            END_STATE();
        case 384:
            if(lookahead == 'e')
                ADVANCE(239);
            END_STATE();
        case 385:
            if(lookahead == 'e')
                ADVANCE(552);
            END_STATE();
        case 386:
            if(lookahead == 'e')
                ADVANCE(500);
            END_STATE();
        case 387:
            if(lookahead == 'e')
                ADVANCE(332);
            END_STATE();
        case 388:
            if(lookahead == 'e')
                ADVANCE(668);
            END_STATE();
        case 389:
            if(lookahead == 'e')
                ADVANCE(786);
            END_STATE();
        case 390:
            if(lookahead == 'e')
                ADVANCE(669);
            END_STATE();
        case 391:
            if(lookahead == 'e')
                ADVANCE(670);
            END_STATE();
        case 392:
            if(lookahead == 'e')
                ADVANCE(569);
            END_STATE();
        case 393:
            if(lookahead == 'e')
                ADVANCE(671);
            END_STATE();
        case 394:
            if(lookahead == 'e')
                ADVANCE(335);
            END_STATE();
        case 395:
            if(lookahead == 'e')
                ADVANCE(633);
            END_STATE();
        case 396:
            if(lookahead == 'e')
                ADVANCE(673);
            END_STATE();
        case 397:
            if(lookahead == 'e')
                ADVANCE(674);
            END_STATE();
        case 398:
            if(lookahead == 'e')
                ADVANCE(675);
            END_STATE();
        case 399:
            if(lookahead == 'e')
                ADVANCE(656);
            END_STATE();
        case 400:
            if(lookahead == 'e')
                ADVANCE(267);
            END_STATE();
        case 401:
            if(lookahead == 'e')
                ADVANCE(676);
            END_STATE();
        case 402:
            if(lookahead == 'e')
                ADVANCE(658);
            END_STATE();
        case 403:
            if(lookahead == 'e')
                ADVANCE(698);
            END_STATE();
        case 404:
            if(lookahead == 'e')
                ADVANCE(655);
            END_STATE();
        case 405:
            if(lookahead == 'e')
                ADVANCE(701);
            END_STATE();
        case 406:
            if(lookahead == 'e')
                ADVANCE(720);
            END_STATE();
        case 407:
            if(lookahead == 'e')
                ADVANCE(316);
            END_STATE();
        case 408:
            if(lookahead == 'e')
                ADVANCE(565);
            END_STATE();
        case 409:
            if(lookahead == 'e')
                ADVANCE(566);
            END_STATE();
        case 410:
            if(lookahead == 'e')
                ADVANCE(659);
            END_STATE();
        case 411:
            if(lookahead == 'e')
                ADVANCE(660);
            END_STATE();
        case 412:
            if(lookahead == 'e')
                ADVANCE(743);
            END_STATE();
        case 413:
            if(lookahead == 'e')
                ADVANCE(422);
            END_STATE();
        case 414:
            if(lookahead == 'e')
                ADVANCE(326);
            END_STATE();
        case 415:
            if(lookahead == 'e')
                ADVANCE(423);
            END_STATE();
        case 416:
            if(lookahead == 'e')
                ADVANCE(753);
            if(lookahead == 'h')
                ADVANCE(591);
            if(lookahead == 'u')
                ADVANCE(628);
            END_STATE();
        case 417:
            if(lookahead == 'f')
                ADVANCE(1104);
            END_STATE();
        case 418:
            if(lookahead == 'f')
                ADVANCE(260);
            END_STATE();
        case 419:
            if(lookahead == 'f')
                ADVANCE(467);
            END_STATE();
        case 420:
            if(lookahead == 'f')
                ADVANCE(284);
            END_STATE();
        case 421:
            if(lookahead == 'f')
                ADVANCE(447);
            END_STATE();
        case 422:
            if(lookahead == 'f')
                ADVANCE(277);
            END_STATE();
        case 423:
            if(lookahead == 'f')
                ADVANCE(280);
            END_STATE();
        case 424:
            if(lookahead == 'g')
                ADVANCE(821);
            END_STATE();
        case 425:
            if(lookahead == 'g')
                ADVANCE(859);
            END_STATE();
        case 426:
            if(lookahead == 'g')
                ADVANCE(861);
            END_STATE();
        case 427:
            if(lookahead == 'g')
                ADVANCE(827);
            END_STATE();
        case 428:
            if(lookahead == 'g')
                ADVANCE(843);
            END_STATE();
        case 429:
            if(lookahead == 'g')
                ADVANCE(846);
            END_STATE();
        case 430:
            if(lookahead == 'g')
                ADVANCE(823);
            END_STATE();
        case 431:
            if(lookahead == 'g')
                ADVANCE(567);
            END_STATE();
        case 432:
            if(lookahead == 'g')
                ADVANCE(355);
            END_STATE();
        case 433:
            if(lookahead == 'g')
                ADVANCE(390);
            END_STATE();
        case 434:
            if(lookahead == 'g')
                ADVANCE(570);
            END_STATE();
        case 435:
            if(lookahead == 'h')
                ADVANCE(1110);
            END_STATE();
        case 436:
            if(lookahead == 'h')
                ADVANCE(397);
            END_STATE();
        case 437:
            if(lookahead == 'h')
                ADVANCE(261);
            END_STATE();
        case 438:
            if(lookahead == 'h')
                ADVANCE(610);
            END_STATE();
        case 439:
            if(lookahead == 'i')
                ADVANCE(952);
            if(lookahead == '\t' ||
               lookahead == ' ')
                ADVANCE(439);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(955);
            END_STATE();
        case 440:
            if(lookahead == 'i')
                ADVANCE(434);
            END_STATE();
        case 441:
            if(lookahead == 'i')
                ADVANCE(1074);
            END_STATE();
        case 442:
            if(lookahead == 'i')
                ADVANCE(538);
            if(lookahead == 'o')
                ADVANCE(775);
            END_STATE();
        case 443:
            if(lookahead == 'i')
                ADVANCE(590);
            if(lookahead == 's')
                ADVANCE(472);
            END_STATE();
        case 444:
            if(lookahead == 'i')
                ADVANCE(310);
            END_STATE();
        case 445:
            if(lookahead == 'i')
                ADVANCE(563);
            if(lookahead == 'n')
                ADVANCE(443);
            if(lookahead == 's')
                ADVANCE(379);
            END_STATE();
        case 446:
            if(lookahead == 'i')
                ADVANCE(563);
            if(lookahead == 'n')
                ADVANCE(678);
            if(lookahead == 's')
                ADVANCE(379);
            END_STATE();
        case 447:
            if(lookahead == 'i')
                ADVANCE(779);
            END_STATE();
        case 448:
            if(lookahead == 'i')
                ADVANCE(691);
            if(lookahead == 'o')
                ADVANCE(584);
            END_STATE();
        case 449:
            if(lookahead == 'i')
                ADVANCE(777);
            END_STATE();
        case 450:
            if(lookahead == 'i')
                ADVANCE(329);
            END_STATE();
        case 451:
            if(lookahead == 'i')
                ADVANCE(319);
            END_STATE();
        case 452:
            if(lookahead == 'i')
                ADVANCE(525);
            END_STATE();
        case 453:
            if(lookahead == 'i')
                ADVANCE(303);
            END_STATE();
        case 454:
            if(lookahead == 'i')
                ADVANCE(254);
            END_STATE();
        case 455:
            if(lookahead == 'i')
                ADVANCE(623);
            END_STATE();
        case 456:
            if(lookahead == 'i')
                ADVANCE(537);
            END_STATE();
        case 457:
            if(lookahead == 'i')
                ADVANCE(537);
            if(lookahead == 'o')
                ADVANCE(775);
            END_STATE();
        case 458:
            if(lookahead == 'i')
                ADVANCE(301);
            END_STATE();
        case 459:
            if(lookahead == 'i')
                ADVANCE(550);
            if(lookahead == 'u')
                ADVANCE(317);
            END_STATE();
        case 460:
            if(lookahead == 'i')
                ADVANCE(331);
            END_STATE();
        case 461:
            if(lookahead == 'i')
                ADVANCE(718);
            END_STATE();
        case 462:
            if(lookahead == 'i')
                ADVANCE(343);
            END_STATE();
        case 463:
            if(lookahead == 'i')
                ADVANCE(713);
            END_STATE();
        case 464:
            if(lookahead == 'i')
                ADVANCE(589);
            END_STATE();
        case 465:
            if(lookahead == 'i')
                ADVANCE(551);
            END_STATE();
        case 466:
            if(lookahead == 'i')
                ADVANCE(677);
            END_STATE();
        case 467:
            if(lookahead == 'i')
                ADVANCE(386);
            END_STATE();
        case 468:
            if(lookahead == 'i')
                ADVANCE(724);
            END_STATE();
        case 469:
            if(lookahead == 'i')
                ADVANCE(710);
            END_STATE();
        case 470:
            if(lookahead == 'i')
                ADVANCE(738);
            if(lookahead == 'o')
                ADVANCE(584);
            END_STATE();
        case 471:
            if(lookahead == 'i')
                ADVANCE(723);
            END_STATE();
        case 472:
            if(lookahead == 'i')
                ADVANCE(431);
            END_STATE();
        case 473:
            if(lookahead == 'i')
                ADVANCE(684);
            END_STATE();
        case 474:
            if(lookahead == 'i')
                ADVANCE(684);
            if(lookahead == 'n')
                ADVANCE(432);
            END_STATE();
        case 475:
            if(lookahead == 'i')
                ADVANCE(613);
            END_STATE();
        case 476:
            if(lookahead == 'i')
                ADVANCE(686);
            END_STATE();
        case 477:
            if(lookahead == 'i')
                ADVANCE(687);
            END_STATE();
        case 478:
            if(lookahead == 'i')
                ADVANCE(734);
            END_STATE();
        case 479:
            if(lookahead == 'i')
                ADVANCE(600);
            END_STATE();
        case 480:
            if(lookahead == 'i')
                ADVANCE(601);
            END_STATE();
        case 481:
            if(lookahead == 'i')
                ADVANCE(602);
            END_STATE();
        case 482:
            if(lookahead == 'i')
                ADVANCE(518);
            END_STATE();
        case 483:
            if(lookahead == 'i')
                ADVANCE(744);
            END_STATE();
        case 484:
            if(lookahead == 'i')
                ADVANCE(747);
            END_STATE();
        case 485:
            if(lookahead == 'i')
                ADVANCE(749);
            END_STATE();
        case 486:
            if(lookahead == 'j')
                ADVANCE(407);
            END_STATE();
        case 487:
            if(lookahead == 'k')
                ADVANCE(999);
            END_STATE();
        case 488:
            if(lookahead == 'k')
                ADVANCE(389);
            END_STATE();
        case 489:
            if(lookahead == 'l')
                ADVANCE(1061);
            END_STATE();
        case 490:
            if(lookahead == 'l')
                ADVANCE(1029);
            END_STATE();
        case 491:
            if(lookahead == 'l')
                ADVANCE(972);
            END_STATE();
        case 492:
            if(lookahead == 'l')
                ADVANCE(1051);
            END_STATE();
        case 493:
            if(lookahead == 'l')
                ADVANCE(1018);
            END_STATE();
        case 494:
            if(lookahead == 'l')
                ADVANCE(1039);
            END_STATE();
        case 495:
            if(lookahead == 'l')
                ADVANCE(1108);
            END_STATE();
        case 496:
            if(lookahead == 'l')
                ADVANCE(759);
            END_STATE();
        case 497:
            if(lookahead == 'l')
                ADVANCE(238);
            END_STATE();
        case 498:
            if(lookahead == 'l')
                ADVANCE(785);
            END_STATE();
        case 499:
            if(lookahead == 'l')
                ADVANCE(772);
            END_STATE();
        case 500:
            if(lookahead == 'l')
                ADVANCE(334);
            END_STATE();
        case 501:
            if(lookahead == 'l')
                ADVANCE(444);
            END_STATE();
        case 502:
            if(lookahead == 'l')
                ADVANCE(400);
            END_STATE();
        case 503:
            if(lookahead == 'l')
                ADVANCE(466);
            END_STATE();
        case 504:
            if(lookahead == 'l')
                ADVANCE(357);
            END_STATE();
        case 505:
            if(lookahead == 'l')
                ADVANCE(358);
            END_STATE();
        case 506:
            if(lookahead == 'l')
                ADVANCE(705);
            END_STATE();
        case 507:
            if(lookahead == 'l')
                ADVANCE(360);
            END_STATE();
        case 508:
            if(lookahead == 'l')
                ADVANCE(363);
            END_STATE();
        case 509:
            if(lookahead == 'l')
                ADVANCE(712);
            END_STATE();
        case 510:
            if(lookahead == 'l')
                ADVANCE(754);
            END_STATE();
        case 511:
            if(lookahead == 'l')
                ADVANCE(370);
            END_STATE();
        case 512:
            if(lookahead == 'l')
                ADVANCE(371);
            END_STATE();
        case 513:
            if(lookahead == 'l')
                ADVANCE(372);
            END_STATE();
        case 514:
            if(lookahead == 'l')
                ADVANCE(725);
            if(lookahead == 's')
                ADVANCE(714);
            if(lookahead == 't')
                ADVANCE(289);
            END_STATE();
        case 515:
            if(lookahead == 'l')
                ADVANCE(762);
            END_STATE();
        case 516:
            if(lookahead == 'l')
                ADVANCE(478);
            END_STATE();
        case 517:
            if(lookahead == 'l')
                ADVANCE(599);
            END_STATE();
        case 518:
            if(lookahead == 'l')
                ADVANCE(468);
            END_STATE();
        case 519:
            if(lookahead == 'l')
                ADVANCE(603);
            if(lookahead == 's')
                ADVANCE(438);
            END_STATE();
        case 520:
            if(lookahead == 'l')
                ADVANCE(605);
            END_STATE();
        case 521:
            if(lookahead == 'l')
                ADVANCE(484);
            END_STATE();
        case 522:
            if(lookahead == 'l')
                ADVANCE(485);
            END_STATE();
        case 523:
            if(lookahead == 'm')
                ADVANCE(1087);
            END_STATE();
        case 524:
            if(lookahead == 'm')
                ADVANCE(1092);
            END_STATE();
        case 525:
            if(lookahead == 'm')
                ADVANCE(1055);
            END_STATE();
        case 526:
            if(lookahead == 'm')
                ADVANCE(624);
            if(lookahead == 'n')
                ADVANCE(735);
            END_STATE();
        case 527:
            if(lookahead == 'm')
                ADVANCE(461);
            if(lookahead == 'n')
                ADVANCE(755);
            if(lookahead == 'v')
                ADVANCE(408);
            END_STATE();
        case 528:
            if(lookahead == 'm')
                ADVANCE(461);
            if(lookahead == 'n')
                ADVANCE(755);
            if(lookahead == 'v')
                ADVANCE(408);
            if(lookahead == 'x')
                ADVANCE(315);
            END_STATE();
        case 529:
            if(lookahead == 'm')
                ADVANCE(259);
            END_STATE();
        case 530:
            if(lookahead == 'm')
                ADVANCE(259);
            if(lookahead == 's')
                ADVANCE(405);
            END_STATE();
        case 531:
            if(lookahead == 'm')
                ADVANCE(352);
            END_STATE();
        case 532:
            if(lookahead == 'm')
                ADVANCE(391);
            END_STATE();
        case 533:
            if(lookahead == 'm')
                ADVANCE(365);
            END_STATE();
        case 534:
            if(lookahead == 'm')
                ADVANCE(401);
            END_STATE();
        case 535:
            if(lookahead == 'm')
                ADVANCE(617);
            if(lookahead == 'n')
                ADVANCE(571);
            END_STATE();
        case 536:
            if(lookahead == 'm')
                ADVANCE(617);
            if(lookahead == 'n')
                ADVANCE(572);
            END_STATE();
        case 537:
            if(lookahead == 'm')
                ADVANCE(266);
            END_STATE();
        case 538:
            if(lookahead == 'm')
                ADVANCE(266);
            if(lookahead == 'v')
                ADVANCE(278);
            END_STATE();
        case 539:
            if(lookahead == 'n')
                ADVANCE(253);
            if(lookahead == 'x')
                ADVANCE(383);
            END_STATE();
        case 540:
            if(lookahead == 'n')
                ADVANCE(1043);
            if(lookahead == 'r')
                ADVANCE(657);
            END_STATE();
        case 541:
            if(lookahead == 'n')
                ADVANCE(1085);
            END_STATE();
        case 542:
            if(lookahead == 'n')
                ADVANCE(832);
            END_STATE();
        case 543:
            if(lookahead == 'n')
                ADVANCE(1020);
            END_STATE();
        case 544:
            if(lookahead == 'n')
                ADVANCE(968);
            END_STATE();
        case 545:
            if(lookahead == 'n')
                ADVANCE(1001);
            END_STATE();
        case 546:
            if(lookahead == 'n')
                ADVANCE(682);
            END_STATE();
        case 547:
            if(lookahead == 'n')
                ADVANCE(755);
            if(lookahead == 'v')
                ADVANCE(408);
            if(lookahead == 'x')
                ADVANCE(314);
            END_STATE();
        case 548:
            if(lookahead == 'n')
                ADVANCE(554);
            END_STATE();
        case 549:
            if(lookahead == 'n')
                ADVANCE(325);
            END_STATE();
        case 550:
            if(lookahead == 'n')
                ADVANCE(425);
            END_STATE();
        case 551:
            if(lookahead == 'n')
                ADVANCE(426);
            END_STATE();
        case 552:
            if(lookahead == 'n')
                ADVANCE(346);
            END_STATE();
        case 553:
            if(lookahead == 'n')
                ADVANCE(427);
            END_STATE();
        case 554:
            if(lookahead == 'n')
                ADVANCE(604);
            END_STATE();
        case 555:
            if(lookahead == 'n')
                ADVANCE(428);
            END_STATE();
        case 556:
            if(lookahead == 'n')
                ADVANCE(683);
            if(lookahead == 'r')
                ADVANCE(575);
            END_STATE();
        case 557:
            if(lookahead == 'n')
                ADVANCE(429);
            END_STATE();
        case 558:
            if(lookahead == 'n')
                ADVANCE(498);
            END_STATE();
        case 559:
            if(lookahead == 'n')
                ADVANCE(276);
            END_STATE();
        case 560:
            if(lookahead == 'n')
                ADVANCE(276);
            if(lookahead == 'p')
                ADVANCE(871);
            if(lookahead == 'x')
                ADVANCE(1045);
            END_STATE();
        case 561:
            if(lookahead == 'n')
                ADVANCE(430);
            END_STATE();
        case 562:
            if(lookahead == 'n')
                ADVANCE(336);
            END_STATE();
        case 563:
            if(lookahead == 'n')
                ADVANCE(715);
            END_STATE();
        case 564:
            if(lookahead == 'n')
                ADVANCE(337);
            END_STATE();
        case 565:
            if(lookahead == 'n')
                ADVANCE(731);
            END_STATE();
        case 566:
            if(lookahead == 'n')
                ADVANCE(707);
            END_STATE();
        case 567:
            if(lookahead == 'n')
                ADVANCE(394);
            END_STATE();
        case 568:
            if(lookahead == 'n')
                ADVANCE(711);
            END_STATE();
        case 569:
            if(lookahead == 'n')
                ADVANCE(320);
            END_STATE();
        case 570:
            if(lookahead == 'n')
                ADVANCE(594);
            END_STATE();
        case 571:
            if(lookahead == 'n')
                ADVANCE(414);
            if(lookahead == 's')
                ADVANCE(695);
            if(lookahead == 't')
                ADVANCE(354);
            END_STATE();
        case 572:
            if(lookahead == 'n')
                ADVANCE(414);
            if(lookahead == 's')
                ADVANCE(694);
            END_STATE();
        case 573:
            if(lookahead == 'n')
                ADVANCE(464);
            END_STATE();
        case 574:
            if(lookahead == 'n')
                ADVANCE(344);
            END_STATE();
        case 575:
            if(lookahead == 'n')
                ADVANCE(262);
            END_STATE();
        case 576:
            if(lookahead == 'n')
                ADVANCE(263);
            END_STATE();
        case 577:
            if(lookahead == 'n')
                ADVANCE(735);
            END_STATE();
        case 578:
            if(lookahead == 'n')
                ADVANCE(409);
            END_STATE();
        case 579:
            if(lookahead == 'n')
                ADVANCE(282);
            END_STATE();
        case 580:
            if(lookahead == 'o')
                ADVANCE(531);
            END_STATE();
        case 581:
            if(lookahead == 'o')
                ADVANCE(323);
            END_STATE();
        case 582:
            if(lookahead == 'o')
                ADVANCE(338);
            END_STATE();
        case 583:
            if(lookahead == 'o')
                ADVANCE(643);
            if(lookahead == 'r')
                ADVANCE(442);
            if(lookahead == 'u')
                ADVANCE(298);
            END_STATE();
        case 584:
            if(lookahead == 'o')
                ADVANCE(502);
            END_STATE();
        case 585:
            if(lookahead == 'o')
                ADVANCE(536);
            if(lookahead == 'u')
                ADVANCE(679);
            END_STATE();
        case 586:
            if(lookahead == 'o')
                ADVANCE(524);
            END_STATE();
        case 587:
            if(lookahead == 'o')
                ADVANCE(322);
            END_STATE();
        case 588:
            if(lookahead == 'o')
                ADVANCE(269);
            END_STATE();
        case 589:
            if(lookahead == 'o')
                ADVANCE(541);
            END_STATE();
        case 590:
            if(lookahead == 'o')
                ADVANCE(541);
            if(lookahead == 't')
                ADVANCE(1047);
            END_STATE();
        case 591:
            if(lookahead == 'o')
                ADVANCE(647);
            END_STATE();
        case 592:
            if(lookahead == 'o')
                ADVANCE(578);
            END_STATE();
        case 593:
            if(lookahead == 'o')
                ADVANCE(460);
            END_STATE();
        case 594:
            if(lookahead == 'o')
                ADVANCE(651);
            END_STATE();
        case 595:
            if(lookahead == 'o')
                ADVANCE(558);
            END_STATE();
        case 596:
            if(lookahead == 'o')
                ADVANCE(637);
            END_STATE();
        case 597:
            if(lookahead == 'o')
                ADVANCE(663);
            END_STATE();
        case 598:
            if(lookahead == 'o')
                ADVANCE(634);
            END_STATE();
        case 599:
            if(lookahead == 'o')
                ADVANCE(553);
            END_STATE();
        case 600:
            if(lookahead == 'o')
                ADVANCE(543);
            END_STATE();
        case 601:
            if(lookahead == 'o')
                ADVANCE(544);
            END_STATE();
        case 602:
            if(lookahead == 'o')
                ADVANCE(545);
            END_STATE();
        case 603:
            if(lookahead == 'o')
                ADVANCE(555);
            END_STATE();
        case 604:
            if(lookahead == 'o')
                ADVANCE(745);
            END_STATE();
        case 605:
            if(lookahead == 'o')
                ADVANCE(557);
            END_STATE();
        case 606:
            if(lookahead == 'o')
                ADVANCE(561);
            END_STATE();
        case 607:
            if(lookahead == 'o')
                ADVANCE(649);
            END_STATE();
        case 608:
            if(lookahead == 'o')
                ADVANCE(650);
            END_STATE();
        case 609:
            if(lookahead == 'o')
                ADVANCE(652);
            END_STATE();
        case 610:
            if(lookahead == 'o')
                ADVANCE(653);
            END_STATE();
        case 611:
            if(lookahead == 'o')
                ADVANCE(662);
            END_STATE();
        case 612:
            if(lookahead == 'o')
                ADVANCE(642);
            if(lookahead == 'r')
                ADVANCE(457);
            if(lookahead == 'u')
                ADVANCE(304);
            END_STATE();
        case 613:
            if(lookahead == 'o')
                ADVANCE(576);
            END_STATE();
        case 614:
            if(lookahead == 'o')
                ADVANCE(769);
            END_STATE();
        case 615:
            if(lookahead == 'o')
                ADVANCE(773);
            END_STATE();
        case 616:
            if(lookahead == 'p')
                ADVANCE(385);
            END_STATE();
        case 617:
            if(lookahead == 'p')
                ADVANCE(592);
            END_STATE();
        case 618:
            if(lookahead == 'p')
                ADVANCE(353);
            END_STATE();
        case 619:
            if(lookahead == 'p')
                ADVANCE(368);
            END_STATE();
        case 620:
            if(lookahead == 'p')
                ADVANCE(369);
            END_STATE();
        case 621:
            if(lookahead == 'p')
                ADVANCE(373);
            END_STATE();
        case 622:
            if(lookahead == 'p')
                ADVANCE(374);
            END_STATE();
        case 623:
            if(lookahead == 'p')
                ADVANCE(508);
            END_STATE();
        case 624:
            if(lookahead == 'p')
                ADVANCE(607);
            END_STATE();
        case 625:
            if(lookahead == 'p')
                ADVANCE(608);
            END_STATE();
        case 626:
            if(lookahead == 'p')
                ADVANCE(748);
            END_STATE();
        case 627:
            if(lookahead == 'p')
                ADVANCE(609);
            END_STATE();
        case 628:
            if(lookahead == 'p')
                ADVANCE(625);
            END_STATE();
        case 629:
            if(lookahead == 'q')
                ADVANCE(761);
            if(lookahead == 'r')
                ADVANCE(776);
            if(lookahead == 't')
                ADVANCE(661);
            END_STATE();
        case 630:
            if(lookahead == 'r')
                ADVANCE(459);
            END_STATE();
        case 631:
            if(lookahead == 'r')
                ADVANCE(854);
            END_STATE();
        case 632:
            if(lookahead == 'r')
                ADVANCE(856);
            END_STATE();
        case 633:
            if(lookahead == 'r')
                ADVANCE(1135);
            END_STATE();
        case 634:
            if(lookahead == 'r')
                ADVANCE(1140);
            END_STATE();
        case 635:
            if(lookahead == 'r')
                ADVANCE(300);
            END_STATE();
        case 636:
            if(lookahead == 'r')
                ADVANCE(757);
            if(lookahead == 'y')
                ADVANCE(618);
            END_STATE();
        case 637:
            if(lookahead == 'r')
                ADVANCE(784);
            END_STATE();
        case 638:
            if(lookahead == 'r')
                ADVANCE(788);
            END_STATE();
        case 639:
            if(lookahead == 'r')
                ADVANCE(657);
            END_STATE();
        case 640:
            if(lookahead == 'r')
                ADVANCE(453);
            END_STATE();
        case 641:
            if(lookahead == 'r')
                ADVANCE(767);
            END_STATE();
        case 642:
            if(lookahead == 'r')
                ADVANCE(693);
            END_STATE();
        case 643:
            if(lookahead == 'r')
                ADVANCE(693);
            if(lookahead == 's')
                ADVANCE(483);
            END_STATE();
        case 644:
            if(lookahead == 'r')
                ADVANCE(270);
            END_STATE();
        case 645:
            if(lookahead == 'r')
                ADVANCE(281);
            END_STATE();
        case 646:
            if(lookahead == 'r')
                ADVANCE(465);
            END_STATE();
        case 647:
            if(lookahead == 'r')
                ADVANCE(699);
            END_STATE();
        case 648:
            if(lookahead == 'r')
                ADVANCE(456);
            END_STATE();
        case 649:
            if(lookahead == 'r')
                ADVANCE(702);
            END_STATE();
        case 650:
            if(lookahead == 'r')
                ADVANCE(726);
            END_STATE();
        case 651:
            if(lookahead == 'r')
                ADVANCE(384);
            END_STATE();
        case 652:
            if(lookahead == 'r')
                ADVANCE(708);
            END_STATE();
        case 653:
            if(lookahead == 'r')
                ADVANCE(709);
            END_STATE();
        case 654:
            if(lookahead == 'r')
                ADVANCE(380);
            END_STATE();
        case 655:
            if(lookahead == 'r')
                ADVANCE(420);
            END_STATE();
        case 656:
            if(lookahead == 'r')
                ADVANCE(685);
            END_STATE();
        case 657:
            if(lookahead == 'r')
                ADVANCE(597);
            END_STATE();
        case 658:
            if(lookahead == 'r')
                ADVANCE(264);
            END_STATE();
        case 659:
            if(lookahead == 'r')
                ADVANCE(265);
            END_STATE();
        case 660:
            if(lookahead == 'r')
                ADVANCE(268);
            END_STATE();
        case 661:
            if(lookahead == 'r')
                ADVANCE(288);
            END_STATE();
        case 662:
            if(lookahead == 'r')
                ADVANCE(746);
            END_STATE();
        case 663:
            if(lookahead == 'r')
                ADVANCE(627);
            END_STATE();
        case 664:
            if(lookahead == 's')
                ADVANCE(1126);
            END_STATE();
        case 665:
            if(lookahead == 's')
                ADVANCE(1091);
            END_STATE();
        case 666:
            if(lookahead == 's')
                ADVANCE(1131);
            END_STATE();
        case 667:
            if(lookahead == 's')
                ADVANCE(487);
            END_STATE();
        case 668:
            if(lookahead == 's')
                ADVANCE(989);
            END_STATE();
        case 669:
            if(lookahead == 's')
                ADVANCE(1130);
            END_STATE();
        case 670:
            if(lookahead == 's')
                ADVANCE(1133);
            END_STATE();
        case 671:
            if(lookahead == 's')
                ADVANCE(1125);
            END_STATE();
        case 672:
            if(lookahead == 's')
                ADVANCE(1096);
            END_STATE();
        case 673:
            if(lookahead == 's')
                ADVANCE(994);
            END_STATE();
        case 674:
            if(lookahead == 's')
                ADVANCE(1132);
            END_STATE();
        case 675:
            if(lookahead == 's')
                ADVANCE(995);
            END_STATE();
        case 676:
            if(lookahead == 's')
                ADVANCE(1109);
            END_STATE();
        case 677:
            if(lookahead == 's')
                ADVANCE(436);
            END_STATE();
        case 678:
            if(lookahead == 's')
                ADVANCE(472);
            END_STATE();
        case 679:
            if(lookahead == 's')
                ADVANCE(737);
            END_STATE();
        case 680:
            if(lookahead == 's')
                ADVANCE(351);
            END_STATE();
        case 681:
            if(lookahead == 's')
                ADVANCE(728);
            END_STATE();
        case 682:
            if(lookahead == 's')
                ADVANCE(763);
            if(lookahead == 't')
                ADVANCE(354);
            END_STATE();
        case 683:
            if(lookahead == 's')
                ADVANCE(458);
            END_STATE();
        case 684:
            if(lookahead == 's')
                ADVANCE(388);
            END_STATE();
        case 685:
            if(lookahead == 's')
                ADVANCE(730);
            END_STATE();
        case 686:
            if(lookahead == 's')
                ADVANCE(396);
            END_STATE();
        case 687:
            if(lookahead == 's')
                ADVANCE(398);
            END_STATE();
        case 688:
            if(lookahead == 's')
                ADVANCE(366);
            END_STATE();
        case 689:
            if(lookahead == 's')
                ADVANCE(740);
            END_STATE();
        case 690:
            if(lookahead == 't')
                ADVANCE(716);
            END_STATE();
        case 691:
            if(lookahead == 't')
                ADVANCE(237);
            END_STATE();
        case 692:
            if(lookahead == 't')
                ADVANCE(985);
            END_STATE();
        case 693:
            if(lookahead == 't')
                ADVANCE(1138);
            END_STATE();
        case 694:
            if(lookahead == 't')
                ADVANCE(1089);
            END_STATE();
        case 695:
            if(lookahead == 't')
                ADVANCE(1089);
            if(lookahead == 'u')
                ADVANCE(532);
            END_STATE();
        case 696:
            if(lookahead == 't')
                ADVANCE(849);
            END_STATE();
        case 697:
            if(lookahead == 't')
                ADVANCE(987);
            END_STATE();
        case 698:
            if(lookahead == 't')
                ADVANCE(836);
            END_STATE();
        case 699:
            if(lookahead == 't')
                ADVANCE(817);
            END_STATE();
        case 700:
            if(lookahead == 't')
                ADVANCE(1119);
            END_STATE();
        case 701:
            if(lookahead == 't')
                ADVANCE(996);
            END_STATE();
        case 702:
            if(lookahead == 't')
                ADVANCE(1117);
            END_STATE();
        case 703:
            if(lookahead == 't')
                ADVANCE(1083);
            END_STATE();
        case 704:
            if(lookahead == 't')
                ADVANCE(1121);
            END_STATE();
        case 705:
            if(lookahead == 't')
                ADVANCE(1004);
            END_STATE();
        case 706:
            if(lookahead == 't')
                ADVANCE(973);
            END_STATE();
        case 707:
            if(lookahead == 't')
                ADVANCE(1124);
            END_STATE();
        case 708:
            if(lookahead == 't')
                ADVANCE(1139);
            END_STATE();
        case 709:
            if(lookahead == 't')
                ADVANCE(840);
            END_STATE();
        case 710:
            if(lookahead == 't')
                ADVANCE(530);
            END_STATE();
        case 711:
            if(lookahead == 't')
                ADVANCE(117);
            END_STATE();
        case 712:
            if(lookahead == 't')
                ADVANCE(1002);
            END_STATE();
        case 713:
            if(lookahead == 't')
                ADVANCE(311);
            END_STATE();
        case 714:
            if(lookahead == 't')
                ADVANCE(240);
            END_STATE();
        case 715:
            if(lookahead == 't')
                ADVANCE(118);
            END_STATE();
        case 716:
            if(lookahead == 't')
                ADVANCE(640);
            END_STATE();
        case 717:
            if(lookahead == 't')
                ADVANCE(789);
            END_STATE();
        case 718:
            if(lookahead == 't')
                ADVANCE(666);
            END_STATE();
        case 719:
            if(lookahead == 't')
                ADVANCE(449);
            END_STATE();
        case 720:
            if(lookahead == 't')
                ADVANCE(644);
            END_STATE();
        case 721:
            if(lookahead == 't')
                ADVANCE(593);
            END_STATE();
        case 722:
            if(lookahead == 't')
                ADVANCE(475);
            END_STATE();
        case 723:
            if(lookahead == 't')
                ADVANCE(529);
            END_STATE();
        case 724:
            if(lookahead == 't')
                ADVANCE(787);
            END_STATE();
        case 725:
            if(lookahead == 't')
                ADVANCE(455);
            END_STATE();
        case 726:
            if(lookahead == 't')
                ADVANCE(672);
            END_STATE();
        case 727:
            if(lookahead == 't')
                ADVANCE(641);
            END_STATE();
        case 728:
            if(lookahead == 't')
                ADVANCE(387);
            END_STATE();
        case 729:
            if(lookahead == 't')
                ADVANCE(452);
            END_STATE();
        case 730:
            if(lookahead == 't')
                ADVANCE(285);
            END_STATE();
        case 731:
            if(lookahead == 't')
                ADVANCE(717);
            END_STATE();
        case 732:
            if(lookahead == 't')
                ADVANCE(361);
            END_STATE();
        case 733:
            if(lookahead == 't')
                ADVANCE(367);
            END_STATE();
        case 734:
            if(lookahead == 't')
                ADVANCE(402);
            END_STATE();
        case 735:
            if(lookahead == 't')
                ADVANCE(404);
            END_STATE();
        case 736:
            if(lookahead == 't')
                ADVANCE(403);
            END_STATE();
        case 737:
            if(lookahead == 't')
                ADVANCE(586);
            END_STATE();
        case 738:
            if(lookahead == 't')
                ADVANCE(419);
            END_STATE();
        case 739:
            if(lookahead == 't')
                ADVANCE(646);
            END_STATE();
        case 740:
            if(lookahead == 't')
                ADVANCE(645);
            END_STATE();
        case 741:
            if(lookahead == 't')
                ADVANCE(596);
            END_STATE();
        case 742:
            if(lookahead == 't')
                ADVANCE(598);
            END_STATE();
        case 743:
            if(lookahead == 't')
                ADVANCE(790);
            END_STATE();
        case 744:
            if(lookahead == 't')
                ADVANCE(479);
            END_STATE();
        case 745:
            if(lookahead == 't')
                ADVANCE(292);
            END_STATE();
        case 746:
            if(lookahead == 't')
                ADVANCE(750);
            END_STATE();
        case 747:
            if(lookahead == 't')
                ADVANCE(410);
            END_STATE();
        case 748:
            if(lookahead == 't')
                ADVANCE(480);
            END_STATE();
        case 749:
            if(lookahead == 't')
                ADVANCE(411);
            END_STATE();
        case 750:
            if(lookahead == 't')
                ADVANCE(792);
            END_STATE();
        case 751:
            if(lookahead == 't')
                ADVANCE(481);
            END_STATE();
        case 752:
            if(lookahead == 't')
                ADVANCE(293);
            END_STATE();
        case 753:
            if(lookahead == 't')
                ADVANCE(661);
            END_STATE();
        case 754:
            if(lookahead == 't')
                ADVANCE(242);
            END_STATE();
        case 755:
            if(lookahead == 'u')
                ADVANCE(523);
            END_STATE();
        case 756:
            if(lookahead == 'u')
                ADVANCE(628);
            END_STATE();
        case 757:
            if(lookahead == 'u')
                ADVANCE(549);
            END_STATE();
        case 758:
            if(lookahead == 'u')
                ADVANCE(506);
            END_STATE();
        case 759:
            if(lookahead == 'u')
                ADVANCE(381);
            END_STATE();
        case 760:
            if(lookahead == 'u')
                ADVANCE(697);
            END_STATE();
        case 761:
            if(lookahead == 'u')
                ADVANCE(392);
            END_STATE();
        case 762:
            if(lookahead == 'u')
                ADVANCE(356);
            END_STATE();
        case 763:
            if(lookahead == 'u')
                ADVANCE(532);
            END_STATE();
        case 764:
            if(lookahead == 'u')
                ADVANCE(302);
            END_STATE();
        case 765:
            if(lookahead == 'u')
                ADVANCE(574);
            END_STATE();
        case 766:
            if(lookahead == 'u')
                ADVANCE(509);
            END_STATE();
        case 767:
            if(lookahead == 'u')
                ADVANCE(317);
            END_STATE();
        case 768:
            if(lookahead == 'u')
                ADVANCE(505);
            END_STATE();
        case 769:
            if(lookahead == 'u')
                ADVANCE(562);
            END_STATE();
        case 770:
            if(lookahead == 'u')
                ADVANCE(510);
            END_STATE();
        case 771:
            if(lookahead == 'u')
                ADVANCE(733);
            END_STATE();
        case 772:
            if(lookahead == 'u')
                ADVANCE(412);
            END_STATE();
        case 773:
            if(lookahead == 'u')
                ADVANCE(307);
            END_STATE();
        case 774:
            if(lookahead == 'v')
                ADVANCE(249);
            END_STATE();
        case 775:
            if(lookahead == 'v')
                ADVANCE(462);
            END_STATE();
        case 776:
            if(lookahead == 'v')
                ADVANCE(451);
            END_STATE();
        case 777:
            if(lookahead == 'v')
                ADVANCE(359);
            END_STATE();
        case 778:
            if(lookahead == 'w')
                ADVANCE(252);
            END_STATE();
        case 779:
            if(lookahead == 'x')
                ADVANCE(1116);
            END_STATE();
        case 780:
            if(lookahead == 'x')
                ADVANCE(704);
            END_STATE();
        case 781:
            if(lookahead == 'y')
                ADVANCE(866);
            END_STATE();
        case 782:
            if(lookahead == 'y')
                ADVANCE(1035);
            END_STATE();
        case 783:
            if(lookahead == 'y')
                ADVANCE(1072);
            END_STATE();
        case 784:
            if(lookahead == 'y')
                ADVANCE(1102);
            END_STATE();
        case 785:
            if(lookahead == 'y')
                ADVANCE(990);
            END_STATE();
        case 786:
            if(lookahead == 'y')
                ADVANCE(1134);
            END_STATE();
        case 787:
            if(lookahead == 'y')
                ADVANCE(1024);
            END_STATE();
        case 788:
            if(lookahead == 'y')
                ADVANCE(488);
            END_STATE();
        case 789:
            if(lookahead == 'y')
                ADVANCE(619);
            END_STATE();
        case 790:
            if(lookahead == 'y')
                ADVANCE(620);
            END_STATE();
        case 791:
            if(lookahead == 'y')
                ADVANCE(621);
            END_STATE();
        case 792:
            if(lookahead == 'y')
                ADVANCE(622);
            END_STATE();
        case 793:
            if(('0' <= lookahead && lookahead <= '9'))
                ADVANCE(919);
            END_STATE();
        case 794:
            if(('0' <= lookahead && lookahead <= '9'))
                ADVANCE(908);
            END_STATE();
        case 795:
            if(('0' <= lookahead && lookahead <= '9'))
                ADVANCE(913);
            if(('A' <= lookahead && lookahead <= 'F') ||
               ('a' <= lookahead && lookahead <= 'f'))
                ADVANCE(926);
            END_STATE();
        case 796:
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'F') ||
               ('a' <= lookahead && lookahead <= 'f'))
                ADVANCE(922);
            END_STATE();
        case 797:
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'F') ||
               ('a' <= lookahead && lookahead <= 'f'))
                ADVANCE(926);
            END_STATE();
        case 798:
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'F') ||
               ('a' <= lookahead && lookahead <= 'f'))
                ADVANCE(909);
            END_STATE();
        case 799:
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'F') ||
               ('a' <= lookahead && lookahead <= 'f'))
                ADVANCE(889);
            END_STATE();
        case 800:
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'F') ||
               ('a' <= lookahead && lookahead <= 'f'))
                ADVANCE(799);
            END_STATE();
        case 801:
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'F') ||
               ('a' <= lookahead && lookahead <= 'f'))
                ADVANCE(800);
            END_STATE();
        case 802:
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'F') ||
               ('a' <= lookahead && lookahead <= 'f'))
                ADVANCE(801);
            END_STATE();
        case 803:
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'F') ||
               ('a' <= lookahead && lookahead <= 'f'))
                ADVANCE(802);
            END_STATE();
        case 804:
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'F') ||
               ('a' <= lookahead && lookahead <= 'f'))
                ADVANCE(803);
            END_STATE();
        case 805:
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'F') ||
               ('a' <= lookahead && lookahead <= 'f'))
                ADVANCE(804);
            END_STATE();
        case 806:
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'F') ||
               ('a' <= lookahead && lookahead <= 'f'))
                ADVANCE(805);
            END_STATE();
        case 807:
            if(lookahead != 0 &&
               lookahead != '*')
                ADVANCE(960);
            END_STATE();
        case 808:
            if(eof)
                ADVANCE(816);
            if(lookahead == '\n')
                SKIP(0);
            END_STATE();
        case 809:
            if(eof)
                ADVANCE(816);
            if(lookahead == '\n')
                SKIP(0);
            if(lookahead == '\r')
                SKIP(808);
            END_STATE();
        case 810:
            if(eof)
                ADVANCE(816);
            if(lookahead == '\n')
                SKIP(815);
            END_STATE();
        case 811:
            if(eof)
                ADVANCE(816);
            if(lookahead == '\n')
                SKIP(815);
            if(lookahead == '\r')
                SKIP(810);
            END_STATE();
        case 812:
            if(eof)
                ADVANCE(816);
            if(lookahead == '\n')
                SKIP(814);
            END_STATE();
        case 813:
            if(eof)
                ADVANCE(816);
            if(lookahead == '\n')
                SKIP(814);
            if(lookahead == '\r')
                SKIP(812);
            END_STATE();
        case 814:
            if(eof)
                ADVANCE(816);
            ADVANCE_MAP(
                '"', 895,
                '\'', 899,
                '(', 886,
                ')', 887,
                '+', 879,
                ',', 868,
                '-', 881,
                '.', 794,
                '/', 884,
                '0', 917,
                ':', 125,
                ';', 979,
                '<', 863,
                '=', 1011,
                '>', 864,
                'F', 1154,
                'L', 894,
                'O', 1199,
                'T', 1159,
                'V', 1164,
            );
            if(lookahead == '\\')
                SKIP(813);
            if(lookahead == ']')
                ADVANCE(1107);
            if(lookahead == 'a')
                ADVANCE(1376);
            if(lookahead == 'b')
                ADVANCE(1408);
            if(lookahead == 'c')
                ADVANCE(1304);
            if(lookahead == 'd')
                ADVANCE(1404);
            if(lookahead == 'f')
                ADVANCE(1307);
            if(lookahead == 'i')
                ADVANCE(1380);
            if(lookahead == 'l')
                ADVANCE(1406);
            if(lookahead == 'm')
                ADVANCE(1169);
            if(lookahead == 'o')
                ADVANCE(1217);
            if(lookahead == 's')
                ADVANCE(1244);
            if(lookahead == 'u')
                ADVANCE(1316);
            if(lookahead == 'w')
                ADVANCE(1210);
            if(lookahead == '{')
                ADVANCE(970);
            if(lookahead == '}')
                ADVANCE(971);
            if(lookahead == '~')
                ADVANCE(888);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(814);
            if(('1' <= lookahead && lookahead <= '9'))
                ADVANCE(920);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('e' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 815:
            if(eof)
                ADVANCE(816);
            if(lookahead == '#')
                ADVANCE(327);
            if(lookahead == '/')
                ADVANCE(91);
            if(lookahead == '@')
                ADVANCE(1007);
            if(lookahead == '\\')
                SKIP(811);
            if(lookahead == 'a')
                ADVANCE(296);
            if(lookahead == 'b')
                ADVANCE(469);
            if(lookahead == 'c')
                ADVANCE(585);
            if(lookahead == 'e')
                ADVANCE(547);
            if(lookahead == 'h')
                ADVANCE(580);
            if(lookahead == 'i')
                ADVANCE(526);
            if(lookahead == 'l')
                ADVANCE(587);
            if(lookahead == 'm')
                ADVANCE(582);
            if(lookahead == 'n')
                ADVANCE(255);
            if(lookahead == 'p')
                ADVANCE(611);
            if(lookahead == 's')
                ADVANCE(727);
            if(lookahead == 't')
                ADVANCE(791);
            if(lookahead == 'u')
                ADVANCE(573);
            if(lookahead == 'v')
                ADVANCE(274);
            if(lookahead == '}')
                ADVANCE(971);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(815);
            END_STATE();
        case 816:
            ACCEPT_TOKEN(ts_builtin_sym_end);
            END_STATE();
        case 817:
            ACCEPT_TOKEN(anon_sym_short);
            END_STATE();
        case 818:
            ACCEPT_TOKEN(anon_sym_short);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 819:
            ACCEPT_TOKEN(anon_sym_int16);
            END_STATE();
        case 820:
            ACCEPT_TOKEN(anon_sym_int16);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 821:
            ACCEPT_TOKEN(anon_sym_long);
            if(lookahead == ' ')
                ADVANCE(339);
            END_STATE();
        case 822:
            ACCEPT_TOKEN(anon_sym_long);
            if(lookahead == ' ')
                ADVANCE(339);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 823:
            ACCEPT_TOKEN(anon_sym_long);
            if(lookahead == ' ')
                ADVANCE(517);
            END_STATE();
        case 824:
            ACCEPT_TOKEN(anon_sym_long);
            if(lookahead == ' ')
                ADVANCE(517);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 825:
            ACCEPT_TOKEN(anon_sym_int32);
            END_STATE();
        case 826:
            ACCEPT_TOKEN(anon_sym_int32);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 827:
            ACCEPT_TOKEN(anon_sym_longlong);
            END_STATE();
        case 828:
            ACCEPT_TOKEN(anon_sym_int64);
            END_STATE();
        case 829:
            ACCEPT_TOKEN(anon_sym_int64);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 830:
            ACCEPT_TOKEN(sym_unsigned_tiny_int);
            END_STATE();
        case 831:
            ACCEPT_TOKEN(sym_unsigned_tiny_int);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 832:
            ACCEPT_TOKEN(sym_boolean_type);
            END_STATE();
        case 833:
            ACCEPT_TOKEN(sym_boolean_type);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 834:
            ACCEPT_TOKEN(anon_sym_fixed);
            END_STATE();
        case 835:
            ACCEPT_TOKEN(anon_sym_fixed);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 836:
            ACCEPT_TOKEN(sym_octet_type);
            END_STATE();
        case 837:
            ACCEPT_TOKEN(sym_octet_type);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 838:
            ACCEPT_TOKEN(sym_signed_tiny_int);
            END_STATE();
        case 839:
            ACCEPT_TOKEN(sym_signed_tiny_int);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 840:
            ACCEPT_TOKEN(anon_sym_unsignedshort);
            END_STATE();
        case 841:
            ACCEPT_TOKEN(anon_sym_uint16);
            END_STATE();
        case 842:
            ACCEPT_TOKEN(anon_sym_uint16);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 843:
            ACCEPT_TOKEN(anon_sym_unsignedlong);
            if(lookahead == ' ')
                ADVANCE(520);
            END_STATE();
        case 844:
            ACCEPT_TOKEN(anon_sym_uint32);
            END_STATE();
        case 845:
            ACCEPT_TOKEN(anon_sym_uint32);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 846:
            ACCEPT_TOKEN(anon_sym_unsignedlonglong);
            END_STATE();
        case 847:
            ACCEPT_TOKEN(anon_sym_uint64);
            END_STATE();
        case 848:
            ACCEPT_TOKEN(anon_sym_uint64);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 849:
            ACCEPT_TOKEN(anon_sym_float);
            END_STATE();
        case 850:
            ACCEPT_TOKEN(anon_sym_float);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 851:
            ACCEPT_TOKEN(anon_sym_double);
            END_STATE();
        case 852:
            ACCEPT_TOKEN(anon_sym_double);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 853:
            ACCEPT_TOKEN(anon_sym_longdouble);
            END_STATE();
        case 854:
            ACCEPT_TOKEN(anon_sym_char);
            END_STATE();
        case 855:
            ACCEPT_TOKEN(anon_sym_char);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 856:
            ACCEPT_TOKEN(anon_sym_wchar);
            END_STATE();
        case 857:
            ACCEPT_TOKEN(anon_sym_wchar);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 858:
            ACCEPT_TOKEN(anon_sym_COLON_COLON);
            END_STATE();
        case 859:
            ACCEPT_TOKEN(anon_sym_string);
            END_STATE();
        case 860:
            ACCEPT_TOKEN(anon_sym_string);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 861:
            ACCEPT_TOKEN(anon_sym_wstring);
            END_STATE();
        case 862:
            ACCEPT_TOKEN(anon_sym_wstring);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 863:
            ACCEPT_TOKEN(anon_sym_LT);
            END_STATE();
        case 864:
            ACCEPT_TOKEN(anon_sym_GT);
            END_STATE();
        case 865:
            ACCEPT_TOKEN(anon_sym_GT);
            if(lookahead == '>')
                ADVANCE(876);
            END_STATE();
        case 866:
            ACCEPT_TOKEN(anon_sym_any);
            END_STATE();
        case 867:
            ACCEPT_TOKEN(anon_sym_any);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 868:
            ACCEPT_TOKEN(anon_sym_COMMA);
            END_STATE();
        case 869:
            ACCEPT_TOKEN(anon_sym_sequence);
            END_STATE();
        case 870:
            ACCEPT_TOKEN(anon_sym_sequence);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 871:
            ACCEPT_TOKEN(anon_sym_map);
            END_STATE();
        case 872:
            ACCEPT_TOKEN(anon_sym_map);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 873:
            ACCEPT_TOKEN(anon_sym_PIPE);
            END_STATE();
        case 874:
            ACCEPT_TOKEN(anon_sym_CARET);
            END_STATE();
        case 875:
            ACCEPT_TOKEN(anon_sym_AMP);
            END_STATE();
        case 876:
            ACCEPT_TOKEN(anon_sym_GT_GT);
            END_STATE();
        case 877:
            ACCEPT_TOKEN(anon_sym_LT_LT);
            END_STATE();
        case 878:
            ACCEPT_TOKEN(anon_sym_PLUS);
            END_STATE();
        case 879:
            ACCEPT_TOKEN(anon_sym_PLUS);
            if(lookahead == '.')
                ADVANCE(794);
            if(lookahead == '0')
                ADVANCE(915);
            if(('1' <= lookahead && lookahead <= '9'))
                ADVANCE(919);
            END_STATE();
        case 880:
            ACCEPT_TOKEN(anon_sym_DASH);
            END_STATE();
        case 881:
            ACCEPT_TOKEN(anon_sym_DASH);
            if(lookahead == '.')
                ADVANCE(794);
            if(lookahead == '0')
                ADVANCE(915);
            if(('1' <= lookahead && lookahead <= '9'))
                ADVANCE(919);
            END_STATE();
        case 882:
            ACCEPT_TOKEN(anon_sym_STAR);
            END_STATE();
        case 883:
            ACCEPT_TOKEN(anon_sym_SLASH);
            if(lookahead == '*')
                ADVANCE(1563);
            if(lookahead == '/')
                ADVANCE(1553);
            END_STATE();
        case 884:
            ACCEPT_TOKEN(anon_sym_SLASH);
            if(lookahead == '*')
                ADVANCE(1563);
            if(lookahead == '/')
                ADVANCE(1551);
            END_STATE();
        case 885:
            ACCEPT_TOKEN(anon_sym_PERCENT);
            END_STATE();
        case 886:
            ACCEPT_TOKEN(anon_sym_LPAREN);
            END_STATE();
        case 887:
            ACCEPT_TOKEN(anon_sym_RPAREN);
            END_STATE();
        case 888:
            ACCEPT_TOKEN(anon_sym_TILDE);
            END_STATE();
        case 889:
            ACCEPT_TOKEN(sym_escape_sequence);
            END_STATE();
        case 890:
            ACCEPT_TOKEN(sym_escape_sequence);
            if(lookahead == '\\')
                ADVANCE(57);
            END_STATE();
        case 891:
            ACCEPT_TOKEN(sym_escape_sequence);
            if(('0' <= lookahead && lookahead <= '9'))
                ADVANCE(889);
            END_STATE();
        case 892:
            ACCEPT_TOKEN(sym_escape_sequence);
            if(('0' <= lookahead && lookahead <= '9'))
                ADVANCE(891);
            END_STATE();
        case 893:
            ACCEPT_TOKEN(anon_sym_L);
            END_STATE();
        case 894:
            ACCEPT_TOKEN(anon_sym_L);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 895:
            ACCEPT_TOKEN(anon_sym_DQUOTE);
            END_STATE();
        case 896:
            ACCEPT_TOKEN(aux_sym_string_literal_token1);
            if(lookahead == '*')
                ADVANCE(898);
            if(lookahead == '/')
                ADVANCE(898);
            if(lookahead != 0 &&
               lookahead != '\n' &&
               lookahead != '"' &&
               lookahead != '\\')
                ADVANCE(898);
            END_STATE();
        case 897:
            ACCEPT_TOKEN(aux_sym_string_literal_token1);
            if(lookahead == '/')
                ADVANCE(896);
            if(lookahead == '\t' ||
               (0x0b <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                ADVANCE(897);
            if(lookahead != 0 &&
               (lookahead < '\t' || '\r' < lookahead) &&
               lookahead != '"' &&
               lookahead != '\\')
                ADVANCE(898);
            END_STATE();
        case 898:
            ACCEPT_TOKEN(aux_sym_string_literal_token1);
            if(lookahead != 0 &&
               lookahead != '\n' &&
               lookahead != '"' &&
               lookahead != '\\')
                ADVANCE(898);
            END_STATE();
        case 899:
            ACCEPT_TOKEN(anon_sym_SQUOTE);
            END_STATE();
        case 900:
            ACCEPT_TOKEN(aux_sym_char_literal_token1);
            END_STATE();
        case 901:
            ACCEPT_TOKEN(aux_sym_char_literal_token1);
            if(lookahead == '\n')
                ADVANCE(890);
            if(lookahead == '\r')
                ADVANCE(889);
            if(lookahead == 'U')
                ADVANCE(806);
            if(lookahead == 'u')
                ADVANCE(802);
            if(lookahead == 'x')
                ADVANCE(800);
            if(('0' <= lookahead && lookahead <= '9'))
                ADVANCE(892);
            if(lookahead != 0)
                ADVANCE(889);
            END_STATE();
        case 902:
            ACCEPT_TOKEN(aux_sym_char_literal_token1);
            if(lookahead == '*')
                ADVANCE(1563);
            if(lookahead == '/')
                ADVANCE(1551);
            END_STATE();
        case 903:
            ACCEPT_TOKEN(aux_sym_char_literal_token1);
            if(lookahead == '\\')
                ADVANCE(57);
            END_STATE();
        case 904:
            ACCEPT_TOKEN(anon_sym_TRUE);
            END_STATE();
        case 905:
            ACCEPT_TOKEN(anon_sym_TRUE);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 906:
            ACCEPT_TOKEN(anon_sym_FALSE);
            END_STATE();
        case 907:
            ACCEPT_TOKEN(anon_sym_FALSE);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 908:
            ACCEPT_TOKEN(sym_number_literal);
            if(lookahead == '\'')
                ADVANCE(794);
            if(lookahead == 'E' ||
               lookahead == 'P' ||
               lookahead == 'e' ||
               lookahead == 'p')
                ADVANCE(931);
            if(('0' <= lookahead && lookahead <= '9'))
                ADVANCE(908);
            if(set_contains(sym_number_literal_character_set_13, 13, lookahead))
                ADVANCE(936);
            END_STATE();
        case 909:
            ACCEPT_TOKEN(sym_number_literal);
            ADVANCE_MAP(
                '\'', 798,
                'B', 909,
                'D', 909,
                'F', 909,
                'b', 909,
                'd', 909,
                'f', 909,
                'L', 936,
                'U', 936,
                'W', 936,
                'l', 936,
                'u', 936,
                'w', 936,
            );
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'E') ||
               ('a' <= lookahead && lookahead <= 'e'))
                ADVANCE(909);
            END_STATE();
        case 910:
            ACCEPT_TOKEN(sym_number_literal);
            ADVANCE_MAP(
                '\'', 798,
                'B', 910,
                'D', 910,
                'F', 910,
                'b', 910,
                'd', 910,
                'f', 910,
                'L', 937,
                'U', 937,
                'W', 937,
                'l', 937,
                'u', 937,
                'w', 937,
            );
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'E') ||
               ('a' <= lookahead && lookahead <= 'e'))
                ADVANCE(910);
            if(('G' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('g' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 911:
            ACCEPT_TOKEN(sym_number_literal);
            ADVANCE_MAP(
                '\'', 795,
                '.', 933,
                'B', 925,
                'b', 925,
                'E', 923,
                'e', 923,
                'P', 931,
                'p', 931,
                'X', 797,
                'x', 797,
                'A', 926,
                'C', 926,
                'a', 926,
                'c', 926,
                'D', 926,
                'F', 926,
                'd', 926,
                'f', 926,
                'L', 936,
                'U', 936,
                'W', 936,
                'l', 936,
                'u', 936,
                'w', 936,
            );
            if(('0' <= lookahead && lookahead <= '9'))
                ADVANCE(913);
            END_STATE();
        case 912:
            ACCEPT_TOKEN(sym_number_literal);
            ADVANCE_MAP(
                '\'', 795,
                '.', 933,
                'B', 927,
                'b', 927,
                'E', 924,
                'e', 924,
                'P', 932,
                'p', 932,
                'X', 1549,
                'x', 1549,
                'A', 928,
                'C', 928,
                'a', 928,
                'c', 928,
                'D', 928,
                'F', 928,
                'd', 928,
                'f', 928,
                'L', 937,
                'U', 937,
                'W', 937,
                'l', 937,
                'u', 937,
                'w', 937,
            );
            if(('0' <= lookahead && lookahead <= '9'))
                ADVANCE(914);
            if(('G' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('g' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 913:
            ACCEPT_TOKEN(sym_number_literal);
            ADVANCE_MAP(
                '\'', 795,
                '.', 933,
                'E', 923,
                'e', 923,
                'P', 931,
                'p', 931,
                'A', 926,
                'C', 926,
                'a', 926,
                'c', 926,
                'B', 926,
                'D', 926,
                'F', 926,
                'b', 926,
                'd', 926,
                'f', 926,
                'L', 936,
                'U', 936,
                'W', 936,
                'l', 936,
                'u', 936,
                'w', 936,
            );
            if(('0' <= lookahead && lookahead <= '9'))
                ADVANCE(913);
            END_STATE();
        case 914:
            ACCEPT_TOKEN(sym_number_literal);
            ADVANCE_MAP(
                '\'', 795,
                '.', 933,
                'E', 924,
                'e', 924,
                'P', 932,
                'p', 932,
                'A', 928,
                'C', 928,
                'a', 928,
                'c', 928,
                'B', 928,
                'D', 928,
                'F', 928,
                'b', 928,
                'd', 928,
                'f', 928,
                'L', 937,
                'U', 937,
                'W', 937,
                'l', 937,
                'u', 937,
                'w', 937,
            );
            if(('0' <= lookahead && lookahead <= '9'))
                ADVANCE(914);
            if(('G' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('g' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 915:
            ACCEPT_TOKEN(sym_number_literal);
            ADVANCE_MAP(
                '\'', 793,
                '.', 933,
                'B', 929,
                'b', 929,
                'X', 97,
                'x', 97,
                'E', 931,
                'P', 931,
                'e', 931,
                'p', 931,
                'D', 936,
                'F', 936,
                'L', 936,
                'U', 936,
                'W', 936,
                'd', 936,
                'f', 936,
                'l', 936,
                'u', 936,
                'w', 936,
            );
            if(('0' <= lookahead && lookahead <= '9'))
                ADVANCE(919);
            END_STATE();
        case 916:
            ACCEPT_TOKEN(sym_number_literal);
            ADVANCE_MAP(
                '\'', 793,
                '.', 933,
                'B', 934,
                'b', 934,
                'X', 797,
                'x', 797,
                'E', 931,
                'P', 931,
                'e', 931,
                'p', 931,
                'D', 936,
                'F', 936,
                'L', 936,
                'U', 936,
                'W', 936,
                'd', 936,
                'f', 936,
                'l', 936,
                'u', 936,
                'w', 936,
            );
            if(('0' <= lookahead && lookahead <= '9'))
                ADVANCE(919);
            END_STATE();
        case 917:
            ACCEPT_TOKEN(sym_number_literal);
            ADVANCE_MAP(
                '\'', 793,
                '.', 933,
                'B', 930,
                'b', 930,
                'X', 1144,
                'x', 1144,
                'E', 932,
                'P', 932,
                'e', 932,
                'p', 932,
                'D', 937,
                'F', 937,
                'L', 937,
                'U', 937,
                'W', 937,
                'd', 937,
                'f', 937,
                'l', 937,
                'u', 937,
                'w', 937,
            );
            if(('0' <= lookahead && lookahead <= '9'))
                ADVANCE(920);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 918:
            ACCEPT_TOKEN(sym_number_literal);
            ADVANCE_MAP(
                '\'', 793,
                '.', 933,
                'B', 935,
                'b', 935,
                'X', 1549,
                'x', 1549,
                'E', 932,
                'P', 932,
                'e', 932,
                'p', 932,
                'D', 937,
                'F', 937,
                'L', 937,
                'U', 937,
                'W', 937,
                'd', 937,
                'f', 937,
                'l', 937,
                'u', 937,
                'w', 937,
            );
            if(('0' <= lookahead && lookahead <= '9'))
                ADVANCE(920);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 919:
            ACCEPT_TOKEN(sym_number_literal);
            if(lookahead == '\'')
                ADVANCE(793);
            if(lookahead == '.')
                ADVANCE(933);
            if(lookahead == 'E' ||
               lookahead == 'P' ||
               lookahead == 'e' ||
               lookahead == 'p')
                ADVANCE(931);
            if(('0' <= lookahead && lookahead <= '9'))
                ADVANCE(919);
            if(set_contains(sym_number_literal_character_set_13, 13, lookahead))
                ADVANCE(936);
            END_STATE();
        case 920:
            ACCEPT_TOKEN(sym_number_literal);
            if(lookahead == '\'')
                ADVANCE(793);
            if(lookahead == '.')
                ADVANCE(933);
            if(lookahead == 'E' ||
               lookahead == 'P' ||
               lookahead == 'e' ||
               lookahead == 'p')
                ADVANCE(932);
            if(('0' <= lookahead && lookahead <= '9'))
                ADVANCE(920);
            if(set_contains(sym_number_literal_character_set_13, 13, lookahead))
                ADVANCE(937);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 921:
            ACCEPT_TOKEN(sym_number_literal);
            ADVANCE_MAP(
                '\'', 796,
                '+', 798,
                '-', 798,
                'E', 921,
                'e', 921,
                'P', 931,
                'p', 931,
                'B', 922,
                'D', 922,
                'F', 922,
                'b', 922,
                'd', 922,
                'f', 922,
                'L', 936,
                'U', 936,
                'W', 936,
                'l', 936,
                'u', 936,
                'w', 936,
            );
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'C') ||
               ('a' <= lookahead && lookahead <= 'c'))
                ADVANCE(922);
            END_STATE();
        case 922:
            ACCEPT_TOKEN(sym_number_literal);
            ADVANCE_MAP(
                '\'', 796,
                'E', 921,
                'e', 921,
                'P', 931,
                'p', 931,
                'B', 922,
                'D', 922,
                'F', 922,
                'b', 922,
                'd', 922,
                'f', 922,
                'L', 936,
                'U', 936,
                'W', 936,
                'l', 936,
                'u', 936,
                'w', 936,
            );
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'C') ||
               ('a' <= lookahead && lookahead <= 'c'))
                ADVANCE(922);
            END_STATE();
        case 923:
            ACCEPT_TOKEN(sym_number_literal);
            ADVANCE_MAP(
                '\'', 797,
                '.', 933,
                '+', 798,
                '-', 798,
                'E', 923,
                'e', 923,
                'P', 931,
                'p', 931,
                'B', 926,
                'D', 926,
                'F', 926,
                'b', 926,
                'd', 926,
                'f', 926,
                'L', 936,
                'U', 936,
                'W', 936,
                'l', 936,
                'u', 936,
                'w', 936,
            );
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'C') ||
               ('a' <= lookahead && lookahead <= 'c'))
                ADVANCE(926);
            END_STATE();
        case 924:
            ACCEPT_TOKEN(sym_number_literal);
            ADVANCE_MAP(
                '\'', 797,
                '.', 933,
                '+', 798,
                '-', 798,
                'E', 924,
                'e', 924,
                'P', 932,
                'p', 932,
                'B', 928,
                'D', 928,
                'F', 928,
                'b', 928,
                'd', 928,
                'f', 928,
                'L', 937,
                'U', 937,
                'W', 937,
                'l', 937,
                'u', 937,
                'w', 937,
            );
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'C') ||
               ('a' <= lookahead && lookahead <= 'c'))
                ADVANCE(928);
            if(('G' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('g' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 925:
            ACCEPT_TOKEN(sym_number_literal);
            ADVANCE_MAP(
                '\'', 797,
                '.', 933,
                'E', 923,
                'e', 923,
                'P', 931,
                'p', 931,
                'A', 926,
                'C', 926,
                'a', 926,
                'c', 926,
                'B', 926,
                'D', 926,
                'F', 926,
                'b', 926,
                'd', 926,
                'f', 926,
                'L', 936,
                'U', 936,
                'W', 936,
                'l', 936,
                'u', 936,
                'w', 936,
            );
            if(('0' <= lookahead && lookahead <= '9'))
                ADVANCE(913);
            END_STATE();
        case 926:
            ACCEPT_TOKEN(sym_number_literal);
            ADVANCE_MAP(
                '\'', 797,
                '.', 933,
                'E', 923,
                'e', 923,
                'P', 931,
                'p', 931,
                'B', 926,
                'D', 926,
                'F', 926,
                'b', 926,
                'd', 926,
                'f', 926,
                'L', 936,
                'U', 936,
                'W', 936,
                'l', 936,
                'u', 936,
                'w', 936,
            );
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'C') ||
               ('a' <= lookahead && lookahead <= 'c'))
                ADVANCE(926);
            END_STATE();
        case 927:
            ACCEPT_TOKEN(sym_number_literal);
            ADVANCE_MAP(
                '\'', 797,
                '.', 933,
                'E', 924,
                'e', 924,
                'P', 932,
                'p', 932,
                'A', 928,
                'C', 928,
                'a', 928,
                'c', 928,
                'B', 928,
                'D', 928,
                'F', 928,
                'b', 928,
                'd', 928,
                'f', 928,
                'L', 937,
                'U', 937,
                'W', 937,
                'l', 937,
                'u', 937,
                'w', 937,
            );
            if(('0' <= lookahead && lookahead <= '9'))
                ADVANCE(914);
            if(('G' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('g' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 928:
            ACCEPT_TOKEN(sym_number_literal);
            ADVANCE_MAP(
                '\'', 797,
                '.', 933,
                'E', 924,
                'e', 924,
                'P', 932,
                'p', 932,
                'B', 928,
                'D', 928,
                'F', 928,
                'b', 928,
                'd', 928,
                'f', 928,
                'L', 937,
                'U', 937,
                'W', 937,
                'l', 937,
                'u', 937,
                'w', 937,
            );
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'C') ||
               ('a' <= lookahead && lookahead <= 'c'))
                ADVANCE(928);
            if(('G' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('g' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 929:
            ACCEPT_TOKEN(sym_number_literal);
            if(lookahead == '.')
                ADVANCE(794);
            if(lookahead == '0')
                ADVANCE(916);
            if(('1' <= lookahead && lookahead <= '9'))
                ADVANCE(919);
            if(set_contains(sym_number_literal_character_set_13, 13, lookahead))
                ADVANCE(936);
            END_STATE();
        case 930:
            ACCEPT_TOKEN(sym_number_literal);
            if(lookahead == '.')
                ADVANCE(794);
            if(lookahead == '0')
                ADVANCE(918);
            if(('1' <= lookahead && lookahead <= '9'))
                ADVANCE(920);
            if(set_contains(sym_number_literal_character_set_13, 13, lookahead))
                ADVANCE(937);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 931:
            ACCEPT_TOKEN(sym_number_literal);
            ADVANCE_MAP(
                '+', 798,
                '-', 798,
                'B', 909,
                'D', 909,
                'F', 909,
                'b', 909,
                'd', 909,
                'f', 909,
                'L', 936,
                'U', 936,
                'W', 936,
                'l', 936,
                'u', 936,
                'w', 936,
            );
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'E') ||
               ('a' <= lookahead && lookahead <= 'e'))
                ADVANCE(909);
            END_STATE();
        case 932:
            ACCEPT_TOKEN(sym_number_literal);
            ADVANCE_MAP(
                '+', 798,
                '-', 798,
                'B', 910,
                'D', 910,
                'F', 910,
                'b', 910,
                'd', 910,
                'f', 910,
                'L', 937,
                'U', 937,
                'W', 937,
                'l', 937,
                'u', 937,
                'w', 937,
            );
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'E') ||
               ('a' <= lookahead && lookahead <= 'e'))
                ADVANCE(910);
            if(('G' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('g' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 933:
            ACCEPT_TOKEN(sym_number_literal);
            ADVANCE_MAP(
                'E', 921,
                'e', 921,
                'P', 931,
                'p', 931,
                'B', 922,
                'D', 922,
                'F', 922,
                'b', 922,
                'd', 922,
                'f', 922,
                'L', 936,
                'U', 936,
                'W', 936,
                'l', 936,
                'u', 936,
                'w', 936,
            );
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'C') ||
               ('a' <= lookahead && lookahead <= 'c'))
                ADVANCE(922);
            END_STATE();
        case 934:
            ACCEPT_TOKEN(sym_number_literal);
            if(('0' <= lookahead && lookahead <= '9'))
                ADVANCE(919);
            if(set_contains(sym_number_literal_character_set_13, 13, lookahead))
                ADVANCE(936);
            END_STATE();
        case 935:
            ACCEPT_TOKEN(sym_number_literal);
            if(('0' <= lookahead && lookahead <= '9'))
                ADVANCE(920);
            if(set_contains(sym_number_literal_character_set_13, 13, lookahead))
                ADVANCE(937);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 936:
            ACCEPT_TOKEN(sym_number_literal);
            ADVANCE_MAP(
                'B', 936,
                'D', 936,
                'F', 936,
                'L', 936,
                'U', 936,
                'W', 936,
                'b', 936,
                'd', 936,
                'f', 936,
                'l', 936,
                'u', 936,
                'w', 936,
            );
            END_STATE();
        case 937:
            ACCEPT_TOKEN(sym_number_literal);
            ADVANCE_MAP(
                'B', 937,
                'D', 937,
                'F', 937,
                'L', 937,
                'U', 937,
                'W', 937,
                'b', 937,
                'd', 937,
                'f', 937,
                'l', 937,
                'u', 937,
                'w', 937,
            );
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 938:
            ACCEPT_TOKEN(anon_sym_POUNDdefine);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(955);
            END_STATE();
        case 939:
            ACCEPT_TOKEN(aux_sym_preproc_define_token1);
            if(lookahead == '\r')
                ADVANCE(942);
            if(lookahead != 0 &&
               lookahead != '\n')
                ADVANCE(942);
            END_STATE();
        case 940:
            ACCEPT_TOKEN(aux_sym_preproc_define_token1);
            if(lookahead == '*')
                ADVANCE(1567);
            if(lookahead == '/')
                ADVANCE(1556);
            if(lookahead != 0 &&
               lookahead != '\n')
                ADVANCE(942);
            END_STATE();
        case 941:
            ACCEPT_TOKEN(aux_sym_preproc_define_token1);
            if(lookahead == '/')
                ADVANCE(940);
            if(lookahead == '\\')
                ADVANCE(939);
            if(lookahead == '\t' ||
               (0x0b <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                ADVANCE(941);
            if(lookahead != 0 &&
               (lookahead < '\t' || '\r' < lookahead))
                ADVANCE(942);
            END_STATE();
        case 942:
            ACCEPT_TOKEN(aux_sym_preproc_define_token1);
            if(lookahead != 0 &&
               lookahead != '\n')
                ADVANCE(942);
            END_STATE();
        case 943:
            ACCEPT_TOKEN(aux_sym_preproc_call_token1);
            END_STATE();
        case 944:
            ACCEPT_TOKEN(sym_preproc_directive);
            if(lookahead == 'c')
                ADVANCE(951);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(955);
            END_STATE();
        case 945:
            ACCEPT_TOKEN(sym_preproc_directive);
            if(lookahead == 'd')
                ADVANCE(948);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(955);
            END_STATE();
        case 946:
            ACCEPT_TOKEN(sym_preproc_directive);
            if(lookahead == 'e')
                ADVANCE(949);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(955);
            END_STATE();
        case 947:
            ACCEPT_TOKEN(sym_preproc_directive);
            if(lookahead == 'e')
                ADVANCE(938);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(955);
            END_STATE();
        case 948:
            ACCEPT_TOKEN(sym_preproc_directive);
            if(lookahead == 'e')
                ADVANCE(962);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(955);
            END_STATE();
        case 949:
            ACCEPT_TOKEN(sym_preproc_directive);
            if(lookahead == 'f')
                ADVANCE(950);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(955);
            END_STATE();
        case 950:
            ACCEPT_TOKEN(sym_preproc_directive);
            if(lookahead == 'i')
                ADVANCE(953);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(955);
            END_STATE();
        case 951:
            ACCEPT_TOKEN(sym_preproc_directive);
            if(lookahead == 'l')
                ADVANCE(954);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(955);
            END_STATE();
        case 952:
            ACCEPT_TOKEN(sym_preproc_directive);
            if(lookahead == 'n')
                ADVANCE(944);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(955);
            END_STATE();
        case 953:
            ACCEPT_TOKEN(sym_preproc_directive);
            if(lookahead == 'n')
                ADVANCE(947);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(955);
            END_STATE();
        case 954:
            ACCEPT_TOKEN(sym_preproc_directive);
            if(lookahead == 'u')
                ADVANCE(945);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(955);
            END_STATE();
        case 955:
            ACCEPT_TOKEN(sym_preproc_directive);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(955);
            END_STATE();
        case 956:
            ACCEPT_TOKEN(sym_preproc_arg);
            if(lookahead == '\n')
                SKIP(103);
            if(lookahead == '\r')
                ADVANCE(957);
            if(lookahead == '/')
                ADVANCE(807);
            if(lookahead == '\\')
                ADVANCE(958);
            if(lookahead != 0)
                ADVANCE(960);
            END_STATE();
        case 957:
            ACCEPT_TOKEN(sym_preproc_arg);
            if(lookahead == '\n')
                SKIP(103);
            if(lookahead == '/')
                ADVANCE(807);
            if(lookahead == '\\')
                ADVANCE(958);
            if(lookahead != 0)
                ADVANCE(960);
            END_STATE();
        case 958:
            ACCEPT_TOKEN(sym_preproc_arg);
            if(lookahead == '\r')
                ADVANCE(961);
            if(lookahead == '/')
                ADVANCE(807);
            if(lookahead == '\\')
                ADVANCE(958);
            if(lookahead != 0)
                ADVANCE(960);
            END_STATE();
        case 959:
            ACCEPT_TOKEN(sym_preproc_arg);
            if(lookahead == '*')
                ADVANCE(1563);
            if(lookahead == '/')
                ADVANCE(1551);
            if(lookahead == '\\')
                ADVANCE(958);
            if(lookahead != 0 &&
               lookahead != '\n')
                ADVANCE(960);
            END_STATE();
        case 960:
            ACCEPT_TOKEN(sym_preproc_arg);
            if(lookahead == '/')
                ADVANCE(807);
            if(lookahead == '\\')
                ADVANCE(958);
            if(lookahead != 0 &&
               lookahead != '\n')
                ADVANCE(960);
            END_STATE();
        case 961:
            ACCEPT_TOKEN(sym_preproc_arg);
            if(lookahead == '/')
                ADVANCE(807);
            if(lookahead == '\\')
                ADVANCE(958);
            if(lookahead != 0)
                ADVANCE(960);
            END_STATE();
        case 962:
            ACCEPT_TOKEN(aux_sym_preproc_include_token1);
            END_STATE();
        case 963:
            ACCEPT_TOKEN(sym_system_lib_path);
            if(lookahead == '\r')
                ADVANCE(966);
            if(lookahead == '\\')
                ADVANCE(967);
            if(lookahead != 0 &&
               lookahead != '\n')
                ADVANCE(966);
            END_STATE();
        case 964:
            ACCEPT_TOKEN(sym_system_lib_path);
            if(lookahead == '*')
                ADVANCE(1565);
            if(lookahead == '/')
                ADVANCE(1554);
            if(lookahead == '\\')
                ADVANCE(967);
            if(lookahead != 0 &&
               lookahead != '\n' &&
               lookahead != '>')
                ADVANCE(966);
            END_STATE();
        case 965:
            ACCEPT_TOKEN(sym_system_lib_path);
            if(lookahead == '/')
                ADVANCE(964);
            if(lookahead == '\\')
                ADVANCE(963);
            if(lookahead == '\t' ||
               (0x0b <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                ADVANCE(965);
            if(lookahead != 0 &&
               (lookahead < '\t' || '\r' < lookahead) &&
               lookahead != '>')
                ADVANCE(966);
            END_STATE();
        case 966:
            ACCEPT_TOKEN(sym_system_lib_path);
            if(lookahead == '\\')
                ADVANCE(967);
            if(lookahead != 0 &&
               lookahead != '\n' &&
               lookahead != '>')
                ADVANCE(966);
            END_STATE();
        case 967:
            ACCEPT_TOKEN(sym_system_lib_path);
            if(lookahead == '\\')
                ADVANCE(967);
            if(lookahead != 0 &&
               lookahead != '\n')
                ADVANCE(966);
            END_STATE();
        case 968:
            ACCEPT_TOKEN(anon_sym_exception);
            END_STATE();
        case 969:
            ACCEPT_TOKEN(anon_sym_exception);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 970:
            ACCEPT_TOKEN(anon_sym_LBRACE);
            END_STATE();
        case 971:
            ACCEPT_TOKEN(anon_sym_RBRACE);
            END_STATE();
        case 972:
            ACCEPT_TOKEN(anon_sym_local);
            END_STATE();
        case 973:
            ACCEPT_TOKEN(anon_sym_abstract);
            END_STATE();
        case 974:
            ACCEPT_TOKEN(anon_sym_abstract);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 975:
            ACCEPT_TOKEN(anon_sym_interface);
            END_STATE();
        case 976:
            ACCEPT_TOKEN(anon_sym_interface);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 977:
            ACCEPT_TOKEN(anon_sym_COLON);
            END_STATE();
        case 978:
            ACCEPT_TOKEN(anon_sym_COLON);
            if(lookahead == ':')
                ADVANCE(858);
            END_STATE();
        case 979:
            ACCEPT_TOKEN(anon_sym_SEMI);
            END_STATE();
        case 980:
            ACCEPT_TOKEN(anon_sym_void);
            END_STATE();
        case 981:
            ACCEPT_TOKEN(anon_sym_void);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 982:
            ACCEPT_TOKEN(anon_sym_in);
            END_STATE();
        case 983:
            ACCEPT_TOKEN(anon_sym_in);
            if(lookahead == 'o')
                ADVANCE(760);
            if(lookahead == 't')
                ADVANCE(116);
            END_STATE();
        case 984:
            ACCEPT_TOKEN(anon_sym_in);
            if(lookahead == 'o')
                ADVANCE(1520);
            if(lookahead == 't')
                ADVANCE(1146);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 985:
            ACCEPT_TOKEN(anon_sym_out);
            END_STATE();
        case 986:
            ACCEPT_TOKEN(anon_sym_out);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 987:
            ACCEPT_TOKEN(anon_sym_inout);
            END_STATE();
        case 988:
            ACCEPT_TOKEN(anon_sym_inout);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 989:
            ACCEPT_TOKEN(anon_sym_raises);
            END_STATE();
        case 990:
            ACCEPT_TOKEN(anon_sym_readonly);
            END_STATE();
        case 991:
            ACCEPT_TOKEN(anon_sym_readonly);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 992:
            ACCEPT_TOKEN(anon_sym_attribute);
            END_STATE();
        case 993:
            ACCEPT_TOKEN(anon_sym_attribute);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 994:
            ACCEPT_TOKEN(anon_sym_getraises);
            END_STATE();
        case 995:
            ACCEPT_TOKEN(anon_sym_setraises);
            END_STATE();
        case 996:
            ACCEPT_TOKEN(anon_sym_bitset);
            END_STATE();
        case 997:
            ACCEPT_TOKEN(anon_sym_bitset);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 998:
            ACCEPT_TOKEN(anon_sym_bitfield);
            END_STATE();
        case 999:
            ACCEPT_TOKEN(anon_sym_bitmask);
            END_STATE();
        case 1000:
            ACCEPT_TOKEN(anon_sym_bitmask);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1001:
            ACCEPT_TOKEN(anon_sym_ATannotation);
            END_STATE();
        case 1002:
            ACCEPT_TOKEN(anon_sym_default);
            END_STATE();
        case 1003:
            ACCEPT_TOKEN(anon_sym_default);
            if(lookahead == '_')
                ADVANCE(1349);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1004:
            ACCEPT_TOKEN(anon_sym_default);
            if(lookahead == '_')
                ADVANCE(521);
            END_STATE();
        case 1005:
            ACCEPT_TOKEN(anon_sym_default);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1006:
            ACCEPT_TOKEN(anon_sym_AT);
            END_STATE();
        case 1007:
            ACCEPT_TOKEN(anon_sym_AT);
            if(lookahead == 'a')
                ADVANCE(548);
            if(lookahead == 'i')
                ADVANCE(434);
            END_STATE();
        case 1008:
            ACCEPT_TOKEN(anon_sym_AT);
            if(lookahead == 'i')
                ADVANCE(434);
            END_STATE();
        case 1009:
            ACCEPT_TOKEN(anon_sym_SLASH_SLASH_AT);
            END_STATE();
        case 1010:
            ACCEPT_TOKEN(aux_sym_extend_annotation_appl_token1);
            if(lookahead == '\n')
                ADVANCE(1010);
            if(lookahead == '\r')
                ADVANCE(49);
            if(lookahead == '/')
                ADVANCE(91);
            END_STATE();
        case 1011:
            ACCEPT_TOKEN(anon_sym_EQ);
            END_STATE();
        case 1012:
            ACCEPT_TOKEN(anon_sym_id);
            if(lookahead == 'l')
                ADVANCE(1061);
            END_STATE();
        case 1013:
            ACCEPT_TOKEN(anon_sym_id);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1014:
            ACCEPT_TOKEN(anon_sym_autoid);
            END_STATE();
        case 1015:
            ACCEPT_TOKEN(anon_sym_autoid);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1016:
            ACCEPT_TOKEN(anon_sym_SEQUENTIAL);
            END_STATE();
        case 1017:
            ACCEPT_TOKEN(anon_sym_HASH);
            END_STATE();
        case 1018:
            ACCEPT_TOKEN(anon_sym_optional);
            END_STATE();
        case 1019:
            ACCEPT_TOKEN(anon_sym_optional);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1020:
            ACCEPT_TOKEN(anon_sym_position);
            END_STATE();
        case 1021:
            ACCEPT_TOKEN(anon_sym_position);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1022:
            ACCEPT_TOKEN(anon_sym_value);
            if(lookahead == 't')
                ADVANCE(790);
            END_STATE();
        case 1023:
            ACCEPT_TOKEN(anon_sym_value);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1024:
            ACCEPT_TOKEN(anon_sym_extensibility);
            END_STATE();
        case 1025:
            ACCEPT_TOKEN(anon_sym_extensibility);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1026:
            ACCEPT_TOKEN(anon_sym_FINAL);
            END_STATE();
        case 1027:
            ACCEPT_TOKEN(anon_sym_APPENDABLE);
            END_STATE();
        case 1028:
            ACCEPT_TOKEN(anon_sym_MUTABLE);
            END_STATE();
        case 1029:
            ACCEPT_TOKEN(anon_sym_final);
            END_STATE();
        case 1030:
            ACCEPT_TOKEN(anon_sym_final);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1031:
            ACCEPT_TOKEN(anon_sym_appendable);
            END_STATE();
        case 1032:
            ACCEPT_TOKEN(anon_sym_appendable);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1033:
            ACCEPT_TOKEN(anon_sym_mutable);
            END_STATE();
        case 1034:
            ACCEPT_TOKEN(anon_sym_mutable);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1035:
            ACCEPT_TOKEN(anon_sym_key);
            END_STATE();
        case 1036:
            ACCEPT_TOKEN(anon_sym_key);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1037:
            ACCEPT_TOKEN(anon_sym_must_understand);
            END_STATE();
        case 1038:
            ACCEPT_TOKEN(anon_sym_must_understand);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1039:
            ACCEPT_TOKEN(anon_sym_default_literal);
            END_STATE();
        case 1040:
            ACCEPT_TOKEN(anon_sym_default_literal);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1041:
            ACCEPT_TOKEN(anon_sym_range);
            END_STATE();
        case 1042:
            ACCEPT_TOKEN(anon_sym_range);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1043:
            ACCEPT_TOKEN(anon_sym_min);
            END_STATE();
        case 1044:
            ACCEPT_TOKEN(anon_sym_min);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1045:
            ACCEPT_TOKEN(anon_sym_max);
            END_STATE();
        case 1046:
            ACCEPT_TOKEN(anon_sym_max);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1047:
            ACCEPT_TOKEN(anon_sym_unit);
            END_STATE();
        case 1048:
            ACCEPT_TOKEN(anon_sym_unit);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1049:
            ACCEPT_TOKEN(anon_sym_bit_bound);
            END_STATE();
        case 1050:
            ACCEPT_TOKEN(anon_sym_bit_bound);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1051:
            ACCEPT_TOKEN(anon_sym_external);
            END_STATE();
        case 1052:
            ACCEPT_TOKEN(anon_sym_external);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1053:
            ACCEPT_TOKEN(anon_sym_nested);
            END_STATE();
        case 1054:
            ACCEPT_TOKEN(anon_sym_nested);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1055:
            ACCEPT_TOKEN(anon_sym_verbatim);
            END_STATE();
        case 1056:
            ACCEPT_TOKEN(anon_sym_verbatim);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1057:
            ACCEPT_TOKEN(anon_sym_c);
            if(lookahead == '+')
                ADVANCE(96);
            END_STATE();
        case 1058:
            ACCEPT_TOKEN(anon_sym_c);
            if(lookahead == '+')
                ADVANCE(96);
            if(lookahead == 'a')
                ADVANCE(680);
            if(lookahead == 'h')
                ADVANCE(257);
            if(lookahead == 'o')
                ADVANCE(535);
            if(lookahead == 'u')
                ADVANCE(679);
            END_STATE();
        case 1059:
            ACCEPT_TOKEN(anon_sym_c_PLUS_PLUS);
            END_STATE();
        case 1060:
            ACCEPT_TOKEN(anon_sym_java);
            END_STATE();
        case 1061:
            ACCEPT_TOKEN(anon_sym_idl);
            END_STATE();
        case 1062:
            ACCEPT_TOKEN(anon_sym_BEGIN_FILE);
            END_STATE();
        case 1063:
            ACCEPT_TOKEN(anon_sym_BEFORE_DECLARATION);
            END_STATE();
        case 1064:
            ACCEPT_TOKEN(anon_sym_BEGIN_DECLARATION);
            END_STATE();
        case 1065:
            ACCEPT_TOKEN(anon_sym_END_DECLARATION);
            END_STATE();
        case 1066:
            ACCEPT_TOKEN(anon_sym_AFTER_DECLARATION);
            END_STATE();
        case 1067:
            ACCEPT_TOKEN(anon_sym_END_FILE);
            END_STATE();
        case 1068:
            ACCEPT_TOKEN(anon_sym_service);
            END_STATE();
        case 1069:
            ACCEPT_TOKEN(anon_sym_service);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1070:
            ACCEPT_TOKEN(anon_sym_CORBA);
            END_STATE();
        case 1071:
            ACCEPT_TOKEN(anon_sym_DDS);
            END_STATE();
        case 1072:
            ACCEPT_TOKEN(anon_sym_oneway);
            END_STATE();
        case 1073:
            ACCEPT_TOKEN(anon_sym_oneway);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1074:
            ACCEPT_TOKEN(anon_sym_ami);
            END_STATE();
        case 1075:
            ACCEPT_TOKEN(anon_sym_ami);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1076:
            ACCEPT_TOKEN(anon_sym_module);
            END_STATE();
        case 1077:
            ACCEPT_TOKEN(anon_sym_typename);
            END_STATE();
        case 1078:
            ACCEPT_TOKEN(anon_sym_typename);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1079:
            ACCEPT_TOKEN(anon_sym_valuetype);
            END_STATE();
        case 1080:
            ACCEPT_TOKEN(anon_sym_valuetype);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1081:
            ACCEPT_TOKEN(anon_sym_eventtype);
            END_STATE();
        case 1082:
            ACCEPT_TOKEN(anon_sym_eventtype);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1083:
            ACCEPT_TOKEN(anon_sym_struct);
            END_STATE();
        case 1084:
            ACCEPT_TOKEN(anon_sym_struct);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1085:
            ACCEPT_TOKEN(anon_sym_union);
            END_STATE();
        case 1086:
            ACCEPT_TOKEN(anon_sym_union);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1087:
            ACCEPT_TOKEN(anon_sym_enum);
            END_STATE();
        case 1088:
            ACCEPT_TOKEN(anon_sym_enum);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1089:
            ACCEPT_TOKEN(anon_sym_const);
            END_STATE();
        case 1090:
            ACCEPT_TOKEN(anon_sym_const);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1091:
            ACCEPT_TOKEN(anon_sym_alias);
            END_STATE();
        case 1092:
            ACCEPT_TOKEN(anon_sym_custom);
            END_STATE();
        case 1093:
            ACCEPT_TOKEN(anon_sym_custom);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1094:
            ACCEPT_TOKEN(anon_sym_truncatable);
            END_STATE();
        case 1095:
            ACCEPT_TOKEN(anon_sym_truncatable);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1096:
            ACCEPT_TOKEN(anon_sym_supports);
            END_STATE();
        case 1097:
            ACCEPT_TOKEN(anon_sym_supports);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1098:
            ACCEPT_TOKEN(anon_sym_public);
            END_STATE();
        case 1099:
            ACCEPT_TOKEN(anon_sym_public);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1100:
            ACCEPT_TOKEN(anon_sym_private);
            END_STATE();
        case 1101:
            ACCEPT_TOKEN(anon_sym_private);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1102:
            ACCEPT_TOKEN(anon_sym_factory);
            END_STATE();
        case 1103:
            ACCEPT_TOKEN(anon_sym_factory);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1104:
            ACCEPT_TOKEN(anon_sym_typedef);
            END_STATE();
        case 1105:
            ACCEPT_TOKEN(anon_sym_typedef);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1106:
            ACCEPT_TOKEN(anon_sym_LBRACK);
            END_STATE();
        case 1107:
            ACCEPT_TOKEN(anon_sym_RBRACK);
            END_STATE();
        case 1108:
            ACCEPT_TOKEN(anon_sym_ATdefault_literal);
            END_STATE();
        case 1109:
            ACCEPT_TOKEN(anon_sym_ATignore_literal_names);
            END_STATE();
        case 1110:
            ACCEPT_TOKEN(anon_sym_switch);
            END_STATE();
        case 1111:
            ACCEPT_TOKEN(anon_sym_switch);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1112:
            ACCEPT_TOKEN(anon_sym_case);
            END_STATE();
        case 1113:
            ACCEPT_TOKEN(anon_sym_case);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1114:
            ACCEPT_TOKEN(anon_sym_typeid);
            END_STATE();
        case 1115:
            ACCEPT_TOKEN(anon_sym_typeid);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1116:
            ACCEPT_TOKEN(anon_sym_typeprefix);
            END_STATE();
        case 1117:
            ACCEPT_TOKEN(anon_sym_import);
            END_STATE();
        case 1118:
            ACCEPT_TOKEN(anon_sym_import);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1119:
            ACCEPT_TOKEN(anon_sym_Object);
            END_STATE();
        case 1120:
            ACCEPT_TOKEN(anon_sym_Object);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1121:
            ACCEPT_TOKEN(anon_sym_context);
            END_STATE();
        case 1122:
            ACCEPT_TOKEN(sym_value_base_type);
            END_STATE();
        case 1123:
            ACCEPT_TOKEN(sym_value_base_type);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1124:
            ACCEPT_TOKEN(anon_sym_component);
            END_STATE();
        case 1125:
            ACCEPT_TOKEN(anon_sym_provides);
            END_STATE();
        case 1126:
            ACCEPT_TOKEN(anon_sym_uses);
            END_STATE();
        case 1127:
            ACCEPT_TOKEN(anon_sym_multiple);
            END_STATE();
        case 1128:
            ACCEPT_TOKEN(anon_sym_multiple);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1129:
            ACCEPT_TOKEN(anon_sym_home);
            END_STATE();
        case 1130:
            ACCEPT_TOKEN(anon_sym_manages);
            END_STATE();
        case 1131:
            ACCEPT_TOKEN(anon_sym_emits);
            END_STATE();
        case 1132:
            ACCEPT_TOKEN(anon_sym_publishes);
            END_STATE();
        case 1133:
            ACCEPT_TOKEN(anon_sym_consumes);
            END_STATE();
        case 1134:
            ACCEPT_TOKEN(anon_sym_primarykey);
            END_STATE();
        case 1135:
            ACCEPT_TOKEN(anon_sym_finder);
            END_STATE();
        case 1136:
            ACCEPT_TOKEN(anon_sym_finder);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1137:
            ACCEPT_TOKEN(anon_sym_porttype);
            END_STATE();
        case 1138:
            ACCEPT_TOKEN(anon_sym_port);
            END_STATE();
        case 1139:
            ACCEPT_TOKEN(anon_sym_mirrorport);
            END_STATE();
        case 1140:
            ACCEPT_TOKEN(anon_sym_connector);
            END_STATE();
        case 1141:
            ACCEPT_TOKEN(anon_sym_native);
            END_STATE();
        case 1142:
            ACCEPT_TOKEN(anon_sym_native);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1143:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == ' ')
                ADVANCE(519);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1144:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '.')
                ADVANCE(794);
            if(lookahead == '0')
                ADVANCE(912);
            if(('1' <= lookahead && lookahead <= '9'))
                ADVANCE(914);
            if(('A' <= lookahead && lookahead <= 'F') ||
               ('a' <= lookahead && lookahead <= 'f'))
                ADVANCE(928);
            if(('G' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('g' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1145:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '1')
                ADVANCE(1152);
            if(lookahead == '3')
                ADVANCE(1148);
            if(lookahead == '6')
                ADVANCE(1150);
            if(lookahead == '8')
                ADVANCE(839);
            if(lookahead == 'e')
                ADVANCE(1452);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1146:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '1')
                ADVANCE(1152);
            if(lookahead == '3')
                ADVANCE(1148);
            if(lookahead == '6')
                ADVANCE(1150);
            if(lookahead == '8')
                ADVANCE(839);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1147:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '1')
                ADVANCE(1153);
            if(lookahead == '3')
                ADVANCE(1149);
            if(lookahead == '6')
                ADVANCE(1151);
            if(lookahead == '8')
                ADVANCE(831);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1148:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '2')
                ADVANCE(826);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1149:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '2')
                ADVANCE(845);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1150:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '4')
                ADVANCE(829);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1151:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '4')
                ADVANCE(848);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1152:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '6')
                ADVANCE(820);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1153:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '6')
                ADVANCE(842);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1154:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A')
                ADVANCE(1158);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1155:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'B')
                ADVANCE(1171);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1156:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E')
                ADVANCE(905);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1157:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E')
                ADVANCE(907);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1158:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'L')
                ADVANCE(1160);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1159:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'R')
                ADVANCE(1161);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1160:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'S')
                ADVANCE(1157);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1161:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'U')
                ADVANCE(1156);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1162:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '_')
                ADVANCE(1205);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1163:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '_')
                ADVANCE(1519);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1164:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1344);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1165:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1239);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1166:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1456);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1167:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1218);
            if(lookahead == 'i')
                ADVANCE(1536);
            if(lookahead == 'l')
                ADVANCE(1418);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1168:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1218);
            if(lookahead == 'i')
                ADVANCE(1386);
            if(lookahead == 'l')
                ADVANCE(1418);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1169:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1423);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1170:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1539);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1171:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1462);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1172:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1535);
            if(lookahead == 'i')
                ADVANCE(1373);
            if(lookahead == 'u')
                ADVANCE(1464);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1173:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1438);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1174:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1367);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1175:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1506);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1176:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1516);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1177:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1439);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1178:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1340);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1179:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1341);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1180:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1342);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1181:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1472);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1182:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1370);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1183:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1343);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1184:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1385);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1185:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1390);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1186:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1500);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1187:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1512);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1188:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1463);
            if(lookahead == 'h')
                ADVANCE(1173);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1189:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1499);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1190:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1223);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1191:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1206);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1192:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1207);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1193:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1222);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1194:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1209);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1195:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1358);
            if(lookahead == 'o')
                ADVANCE(1313);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1196:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1358);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1197:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1525);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1198:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1359);
            if(lookahead == 'e')
                ADVANCE(1442);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1199:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'b')
                ADVANCE(1338);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1200:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'b')
                ADVANCE(1466);
            if(lookahead == 'n')
                ADVANCE(1538);
            if(lookahead == 't')
                ADVANCE(1487);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1201:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'b')
                ADVANCE(1347);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1202:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'b')
                ADVANCE(1348);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1203:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'b')
                ADVANCE(1527);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1204:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'b')
                ADVANCE(1331);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1205:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'b')
                ADVANCE(1420);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1206:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'b')
                ADVANCE(1353);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1207:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'b')
                ADVANCE(1354);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1208:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'b')
                ADVANCE(1186);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1209:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'b')
                ADVANCE(1356);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1210:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1306);
            if(lookahead == 's')
                ADVANCE(1507);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1211:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1306);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1212:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1099);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1213:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1301);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1214:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1270);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1215:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1493);
            if(lookahead == 'n')
                ADVANCE(1245);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1216:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1493);
            if(lookahead == 'u')
                ADVANCE(1481);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1217:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1493);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1218:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1495);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1219:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1475);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1220:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1252);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1221:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1478);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1222:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1479);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1223:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1259);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1224:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1264);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1225:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1187);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1226:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'd')
                ADVANCE(981);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1227:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'd')
                ADVANCE(835);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1228:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'd')
                ADVANCE(1115);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1229:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'd')
                ADVANCE(1143);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1230:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'd')
                ADVANCE(1013);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1231:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'd')
                ADVANCE(1015);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1232:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'd')
                ADVANCE(1054);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1233:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'd')
                ADVANCE(1050);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1234:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'd')
                ADVANCE(1038);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1235:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'd')
                ADVANCE(1250);
            if(lookahead == 'i')
                ADVANCE(1228);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1236:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'd')
                ADVANCE(1250);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1237:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'd')
                ADVANCE(1275);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1238:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'd')
                ADVANCE(1280);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1239:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'd')
                ADVANCE(1412);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1240:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'd')
                ADVANCE(1192);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1241:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1435);
            if(lookahead == 'h')
                ADVANCE(1409);
            if(lookahead == 't')
                ADVANCE(1437);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1242:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1435);
            if(lookahead == 'h')
                ADVANCE(1409);
            if(lookahead == 't')
                ADVANCE(1445);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1243:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1435);
            if(lookahead == 'h')
                ADVANCE(1409);
            if(lookahead == 't')
                ADVANCE(1447);
            if(lookahead == 'u')
                ADVANCE(1434);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1244:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1435);
            if(lookahead == 'h')
                ADVANCE(1409);
            if(lookahead == 't')
                ADVANCE(1447);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1245:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1533);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1246:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1235);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1247:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1155);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1248:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(852);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1249:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1142);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1250:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1291);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1251:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1101);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1252:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(870);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1253:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1123);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1254:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(993);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1255:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1080);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1256:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1113);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1257:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1078);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1258:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1082);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1259:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(976);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1260:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1398);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1261:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1042);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1262:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1023);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1263:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1034);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1264:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1069);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1265:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1032);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1266:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1128);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1267:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1095);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1268:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1292);
            if(lookahead == 'o')
                ADVANCE(1524);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1269:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1227);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1270:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1425);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1271:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1165);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1272:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1229);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1273:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1542);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1274:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1396);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1275:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1440);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1276:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1182);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1277:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1232);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1278:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1473);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1279:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1441);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1280:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1455);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1281:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1476);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1282:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1454);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1283:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1391);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1284:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1509);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1285:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1388);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1286:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1219);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1287:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1236);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1288:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1394);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1289:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1468);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1290:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1294);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1291:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'f')
                ADVANCE(1105);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1292:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'f')
                ADVANCE(1176);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1293:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'f')
                ADVANCE(1190);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1294:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'f')
                ADVANCE(1197);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1295:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'g')
                ADVANCE(822);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1296:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'g')
                ADVANCE(860);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1297:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'g')
                ADVANCE(862);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1298:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'g')
                ADVANCE(824);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1299:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'g')
                ADVANCE(1392);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1300:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'g')
                ADVANCE(1261);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1301:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'h')
                ADVANCE(1111);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1302:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'h')
                ADVANCE(1173);
            if(lookahead == 'o')
                ADVANCE(1401);
            if(lookahead == 'u')
                ADVANCE(1459);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1303:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'h')
                ADVANCE(1173);
            if(lookahead == 'o')
                ADVANCE(1401);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1304:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'h')
                ADVANCE(1173);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1305:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'h')
                ADVANCE(1409);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1306:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'h')
                ADVANCE(1177);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1307:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1536);
            if(lookahead == 'l')
                ADVANCE(1418);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1308:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1532);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1309:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1075);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1310:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1469);
            if(lookahead == 'o')
                ADVANCE(1405);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1311:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1299);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1312:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1530);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1313:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1226);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1314:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1203);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1315:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1387);
            if(lookahead == 'n')
                ADVANCE(1330);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1316:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1387);
            if(lookahead == 'n')
                ADVANCE(1458);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1317:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1212);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1318:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1381);
            if(lookahead == 'u')
                ADVANCE(1221);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1319:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1381);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1320:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1364);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1321:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1204);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1322:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1433);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1323:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1382);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1324:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1231);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1325:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1395);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1326:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1484);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1327:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1485);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1328:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1496);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1329:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1494);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1330:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1410);
            if(lookahead == 's')
                ADVANCE(1311);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1331:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1360);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1332:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1224);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1333:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1414);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1334:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1422);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1335:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1415);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1336:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1505);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1337:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1511);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1338:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'j')
                ADVANCE(1286);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1339:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'k')
                ADVANCE(1000);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1340:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1030);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1341:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1052);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1342:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1019);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1343:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1040);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1344:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1517);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1345:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1418);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1346:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1541);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1347:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1317);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1348:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1248);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1349:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1336);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1350:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1480);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1351:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1486);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1352:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1501);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1353:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1263);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1354:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1265);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1355:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1266);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1356:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1267);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1357:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1276);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1358:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1528);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1359:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1523);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1360:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1328);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1361:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'm')
                ADVANCE(1431);
            if(lookahead == 'n')
                ADVANCE(1470);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1362:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'm')
                ADVANCE(1088);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1363:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'm')
                ADVANCE(1093);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1364:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'm')
                ADVANCE(1056);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1365:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'm')
                ADVANCE(1166);
            if(lookahead == 's')
                ADVANCE(1281);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1366:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'm')
                ADVANCE(1309);
            if(lookahead == 'p')
                ADVANCE(1430);
            if(lookahead == 'u')
                ADVANCE(1498);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1367:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'm')
                ADVANCE(1257);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1368:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1295);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1369:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1086);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1370:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(833);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1371:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(969);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1372:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(984);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1373:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1044);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1374:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1021);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1375:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1245);
            if(lookahead == 'p')
                ADVANCE(1510);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1376:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1538);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1377:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1515);
            if(lookahead == 'v')
                ADVANCE(1288);
            if(lookahead == 'x')
                ADVANCE(1214);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1378:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1515);
            if(lookahead == 'x')
                ADVANCE(1214);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1379:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1515);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1380:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1470);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1381:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1296);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1382:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1297);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1383:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1346);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1384:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1225);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1385:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1300);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1386:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1237);
            if(lookahead == 'x')
                ADVANCE(1269);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1387:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1488);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1388:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1240);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1389:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1233);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1390:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1234);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1391:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1174);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1392:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1272);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1393:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1483);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1394:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1514);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1395:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1178);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1396:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1220);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1397:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1298);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1398:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1461);
            if(lookahead == 'r')
                ADVANCE(1400);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1399:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1327);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1400:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1179);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1401:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1460);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1402:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1238);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1403:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1180);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1404:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1524);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1405:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1357);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1406:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1368);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1407:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1363);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1408:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1405);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1409:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1449);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1410:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1369);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1411:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1467);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1412:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1383);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1413:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1443);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1414:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1371);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1415:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1374);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1416:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1397);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1417:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1324);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1418:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1181);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1419:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1450);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1420:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1521);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1421:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1451);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1422:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1403);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1423:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'p')
                ADVANCE(872);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1424:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'p')
                ADVANCE(1246);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1425:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'p')
                ADVANCE(1497);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1426:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'p')
                ADVANCE(1255);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1427:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'p')
                ADVANCE(1287);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1428:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'p')
                ADVANCE(1283);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1429:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'p')
                ADVANCE(1258);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1430:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'p')
                ADVANCE(1285);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1431:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'p')
                ADVANCE(1419);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1432:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'p')
                ADVANCE(1421);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1433:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'p')
                ADVANCE(1355);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1434:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'p')
                ADVANCE(1432);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1435:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'q')
                ADVANCE(1518);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1436:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1308);
            if(lookahead == 'u')
                ADVANCE(1201);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1437:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1318);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1438:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(855);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1439:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(857);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1440:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1136);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1441:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1531);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1442:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1208);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1443:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1540);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1444:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1314);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1445:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1526);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1446:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1323);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1447:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1319);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1448:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1193);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1449:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1474);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1450:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1477);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1451:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1490);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1452:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1293);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1453:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1522);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1454:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1183);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1455:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1465);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1456:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 's')
                ADVANCE(1339);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1457:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 's')
                ADVANCE(1097);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1458:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 's')
                ADVANCE(1311);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1459:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 's')
                ADVANCE(1492);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1460:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 's')
                ADVANCE(1471);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1461:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 's')
                ADVANCE(1321);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1462:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 's')
                ADVANCE(1253);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1463:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 's')
                ADVANCE(1256);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1464:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 's')
                ADVANCE(1489);
            if(lookahead == 't')
                ADVANCE(1191);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1465:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 's')
                ADVANCE(1508);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1466:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 's')
                ADVANCE(1491);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1467:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 's')
                ADVANCE(1337);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1468:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 's')
                ADVANCE(1504);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1469:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1365);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1470:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1146);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1471:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1090);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1472:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(850);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1473:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(837);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1474:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(818);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1475:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1120);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1476:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(997);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1477:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1118);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1478:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1084);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1479:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(974);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1480:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1005);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1481:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(986);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1482:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(988);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1483:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1145);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1484:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1162);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1485:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1048);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1486:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1003);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1487:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1444);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1488:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1147);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1489:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1163);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1490:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1457);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1491:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1448);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1492:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1407);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1493:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1278);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1494:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1213);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1495:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1413);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1496:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1543);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1497:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1333);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1498:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1417);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1499:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1251);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1500:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1320);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1501:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1322);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1502:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1254);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1503:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1260);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1504:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1277);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1505:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1282);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1506:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1312);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1507:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1446);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1508:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1185);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1509:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1545);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1510:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1334);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1511:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1335);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1512:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1194);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1513:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1548);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1514:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1513);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1515:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'u')
                ADVANCE(1362);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1516:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'u')
                ADVANCE(1350);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1517:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'u')
                ADVANCE(1247);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1518:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'u')
                ADVANCE(1274);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1519:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'u')
                ADVANCE(1402);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1520:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'u')
                ADVANCE(1482);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1521:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'u')
                ADVANCE(1389);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1522:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'u')
                ADVANCE(1384);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1523:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'u')
                ADVANCE(1262);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1524:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'u')
                ADVANCE(1202);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1525:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'u')
                ADVANCE(1351);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1526:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'u')
                ADVANCE(1221);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1527:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'u')
                ADVANCE(1502);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1528:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'u')
                ADVANCE(1284);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1529:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'u')
                ADVANCE(1352);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1530:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'v')
                ADVANCE(1249);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1531:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'v')
                ADVANCE(1332);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1532:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'v')
                ADVANCE(1189);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1533:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'w')
                ADVANCE(1170);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1534:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'w')
                ADVANCE(1329);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1535:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'x')
                ADVANCE(1046);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1536:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'x')
                ADVANCE(1269);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1537:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'x')
                ADVANCE(1503);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1538:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'y')
                ADVANCE(867);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1539:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'y')
                ADVANCE(1073);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1540:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'y')
                ADVANCE(1103);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1541:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'y')
                ADVANCE(991);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1542:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'y')
                ADVANCE(1036);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1543:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'y')
                ADVANCE(1025);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1544:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'y')
                ADVANCE(1424);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1545:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'y')
                ADVANCE(1426);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1546:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'y')
                ADVANCE(1427);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1547:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'y')
                ADVANCE(1428);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1548:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'y')
                ADVANCE(1429);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1549:
            ACCEPT_TOKEN(sym_identifier);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'F') ||
               ('a' <= lookahead && lookahead <= 'f'))
                ADVANCE(928);
            if(('G' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('g' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1550:
            ACCEPT_TOKEN(sym_identifier);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1550);
            END_STATE();
        case 1551:
            ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
            END_STATE();
        case 1552:
            ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
            if(lookahead == '*')
                ADVANCE(1568);
            if(lookahead != 0)
                ADVANCE(94);
            END_STATE();
        case 1553:
            ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
            if(lookahead == '@')
                ADVANCE(1009);
            END_STATE();
        case 1554:
            ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
            if(lookahead == '\\')
                ADVANCE(967);
            if(lookahead != 0 &&
               lookahead != '\n' &&
               lookahead != '>')
                ADVANCE(966);
            END_STATE();
        case 1555:
            ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
            if(lookahead == '\\')
                ADVANCE(74);
            if(lookahead != 0 &&
               lookahead != '\n')
                ADVANCE(1561);
            END_STATE();
        case 1556:
            ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
            if(lookahead != 0 &&
               lookahead != '\n')
                ADVANCE(942);
            END_STATE();
        case 1557:
            ACCEPT_TOKEN(aux_sym_comment_token1);
            if(lookahead == '\n')
                ADVANCE(1560);
            if(lookahead == '\\')
                ADVANCE(74);
            if(lookahead != 0)
                ADVANCE(1561);
            END_STATE();
        case 1558:
            ACCEPT_TOKEN(aux_sym_comment_token1);
            if(lookahead == '\r')
                ADVANCE(1562);
            if(lookahead == '\\')
                ADVANCE(1558);
            if(lookahead != 0)
                ADVANCE(1561);
            END_STATE();
        case 1559:
            ACCEPT_TOKEN(aux_sym_comment_token1);
            if(lookahead == '*')
                ADVANCE(1566);
            if(lookahead == '/')
                ADVANCE(1555);
            if(lookahead == '\\')
                ADVANCE(74);
            if(lookahead != 0 &&
               lookahead != '\n')
                ADVANCE(1561);
            END_STATE();
        case 1560:
            ACCEPT_TOKEN(aux_sym_comment_token1);
            if(lookahead == '/')
                ADVANCE(1559);
            if(lookahead == '\\')
                ADVANCE(69);
            if(lookahead == '\t' ||
               (0x0b <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                ADVANCE(1560);
            if(lookahead != 0 &&
               (lookahead < '\t' || '\r' < lookahead))
                ADVANCE(1561);
            END_STATE();
        case 1561:
            ACCEPT_TOKEN(aux_sym_comment_token1);
            if(lookahead == '\\')
                ADVANCE(74);
            if(lookahead != 0 &&
               lookahead != '\n')
                ADVANCE(1561);
            END_STATE();
        case 1562:
            ACCEPT_TOKEN(aux_sym_comment_token1);
            if(lookahead == '\\')
                ADVANCE(74);
            if(lookahead != 0)
                ADVANCE(1561);
            END_STATE();
        case 1563:
            ACCEPT_TOKEN(anon_sym_SLASH_STAR);
            END_STATE();
        case 1564:
            ACCEPT_TOKEN(anon_sym_SLASH_STAR);
            if(lookahead == '*')
                ADVANCE(1568);
            if(lookahead != 0 &&
               lookahead != '/')
                ADVANCE(94);
            END_STATE();
        case 1565:
            ACCEPT_TOKEN(anon_sym_SLASH_STAR);
            if(lookahead == '\\')
                ADVANCE(967);
            if(lookahead != 0 &&
               lookahead != '\n' &&
               lookahead != '>')
                ADVANCE(966);
            END_STATE();
        case 1566:
            ACCEPT_TOKEN(anon_sym_SLASH_STAR);
            if(lookahead == '\\')
                ADVANCE(74);
            if(lookahead != 0 &&
               lookahead != '\n')
                ADVANCE(1561);
            END_STATE();
        case 1567:
            ACCEPT_TOKEN(anon_sym_SLASH_STAR);
            if(lookahead != 0 &&
               lookahead != '\n')
                ADVANCE(942);
            END_STATE();
        case 1568:
            ACCEPT_TOKEN(aux_sym_comment_token2);
            if(lookahead == '*')
                ADVANCE(1568);
            if(lookahead != 0 &&
               lookahead != '/')
                ADVANCE(94);
            END_STATE();
        default:
            return false;
    }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
    [0] = { .lex_state = 0 },
    [1] = { .lex_state = 815 },
    [2] = { .lex_state = 98 },
    [3] = { .lex_state = 98 },
    [4] = { .lex_state = 99 },
    [5] = { .lex_state = 98 },
    [6] = { .lex_state = 98 },
    [7] = { .lex_state = 98 },
    [8] = { .lex_state = 99 },
    [9] = { .lex_state = 99 },
    [10] = { .lex_state = 100 },
    [11] = { .lex_state = 100 },
    [12] = { .lex_state = 100 },
    [13] = { .lex_state = 100 },
    [14] = { .lex_state = 100 },
    [15] = { .lex_state = 100 },
    [16] = { .lex_state = 100 },
    [17] = { .lex_state = 100 },
    [18] = { .lex_state = 100 },
    [19] = { .lex_state = 100 },
    [20] = { .lex_state = 100 },
    [21] = { .lex_state = 100 },
    [22] = { .lex_state = 815 },
    [23] = { .lex_state = 815 },
    [24] = { .lex_state = 815 },
    [25] = { .lex_state = 815 },
    [26] = { .lex_state = 815 },
    [27] = { .lex_state = 815 },
    [28] = { .lex_state = 815 },
    [29] = { .lex_state = 815 },
    [30] = { .lex_state = 101 },
    [31] = { .lex_state = 814 },
    [32] = { .lex_state = 814 },
    [33] = { .lex_state = 102 },
    [34] = { .lex_state = 86 },
    [35] = { .lex_state = 86 },
    [36] = { .lex_state = 86 },
    [37] = { .lex_state = 86 },
    [38] = { .lex_state = 86 },
    [39] = { .lex_state = 86 },
    [40] = { .lex_state = 86 },
    [41] = { .lex_state = 86 },
    [42] = { .lex_state = 86 },
    [43] = { .lex_state = 86 },
    [44] = { .lex_state = 86 },
    [45] = { .lex_state = 83 },
    [46] = { .lex_state = 90 },
    [47] = { .lex_state = 90 },
    [48] = { .lex_state = 86 },
    [49] = { .lex_state = 104 },
    [50] = { .lex_state = 104 },
    [51] = { .lex_state = 104 },
    [52] = { .lex_state = 98 },
    [53] = { .lex_state = 98 },
    [54] = { .lex_state = 98 },
    [55] = { .lex_state = 98 },
    [56] = { .lex_state = 98 },
    [57] = { .lex_state = 105 },
    [58] = { .lex_state = 98 },
    [59] = { .lex_state = 98 },
    [60] = { .lex_state = 99 },
    [61] = { .lex_state = 99 },
    [62] = { .lex_state = 105 },
    [63] = { .lex_state = 99 },
    [64] = { .lex_state = 99 },
    [65] = { .lex_state = 109 },
    [66] = { .lex_state = 100 },
    [67] = { .lex_state = 109 },
    [68] = { .lex_state = 106 },
    [69] = { .lex_state = 106 },
    [70] = { .lex_state = 109 },
    [71] = { .lex_state = 100 },
    [72] = { .lex_state = 109 },
    [73] = { .lex_state = 106 },
    [74] = { .lex_state = 109 },
    [75] = { .lex_state = 109 },
    [76] = { .lex_state = 106 },
    [77] = { .lex_state = 109 },
    [78] = { .lex_state = 106 },
    [79] = { .lex_state = 106 },
    [80] = { .lex_state = 106 },
    [81] = { .lex_state = 106 },
    [82] = { .lex_state = 106 },
    [83] = { .lex_state = 109 },
    [84] = { .lex_state = 106 },
    [85] = { .lex_state = 110 },
    [86] = { .lex_state = 110 },
    [87] = { .lex_state = 101 },
    [88] = { .lex_state = 101 },
    [89] = { .lex_state = 86 },
    [90] = { .lex_state = 86 },
    [91] = { .lex_state = 86 },
    [92] = { .lex_state = 86 },
    [93] = { .lex_state = 86 },
    [94] = { .lex_state = 86 },
    [95] = { .lex_state = 86 },
    [96] = { .lex_state = 86 },
    [97] = { .lex_state = 86 },
    [98] = { .lex_state = 86 },
    [99] = { .lex_state = 86 },
    [100] = { .lex_state = 86 },
    [101] = { .lex_state = 86 },
    [102] = { .lex_state = 86 },
    [103] = { .lex_state = 86 },
    [104] = { .lex_state = 86 },
    [105] = { .lex_state = 86 },
    [106] = { .lex_state = 86 },
    [107] = { .lex_state = 86 },
    [108] = { .lex_state = 104 },
    [109] = { .lex_state = 104 },
    [110] = { .lex_state = 86 },
    [111] = { .lex_state = 86 },
    [112] = { .lex_state = 86 },
    [113] = { .lex_state = 86 },
    [114] = { .lex_state = 86 },
    [115] = { .lex_state = 86 },
    [116] = { .lex_state = 104 },
    [117] = { .lex_state = 104 },
    [118] = { .lex_state = 86 },
    [119] = { .lex_state = 86 },
    [120] = { .lex_state = 86 },
    [121] = { .lex_state = 86 },
    [122] = { .lex_state = 86 },
    [123] = { .lex_state = 86 },
    [124] = { .lex_state = 86 },
    [125] = { .lex_state = 86 },
    [126] = { .lex_state = 86 },
    [127] = { .lex_state = 86 },
    [128] = { .lex_state = 86 },
    [129] = { .lex_state = 86 },
    [130] = { .lex_state = 86 },
    [131] = { .lex_state = 86 },
    [132] = { .lex_state = 86 },
    [133] = { .lex_state = 86 },
    [134] = { .lex_state = 86 },
    [135] = { .lex_state = 815 },
    [136] = { .lex_state = 86 },
    [137] = { .lex_state = 104 },
    [138] = { .lex_state = 86 },
    [139] = { .lex_state = 86 },
    [140] = { .lex_state = 86 },
    [141] = { .lex_state = 86 },
    [142] = { .lex_state = 86 },
    [143] = { .lex_state = 86 },
    [144] = { .lex_state = 86 },
    [145] = { .lex_state = 86 },
    [146] = { .lex_state = 86 },
    [147] = { .lex_state = 86 },
    [148] = { .lex_state = 86 },
    [149] = { .lex_state = 86 },
    [150] = { .lex_state = 815 },
    [151] = { .lex_state = 815 },
    [152] = { .lex_state = 111 },
    [153] = { .lex_state = 815 },
    [154] = { .lex_state = 815 },
    [155] = { .lex_state = 815 },
    [156] = { .lex_state = 106 },
    [157] = { .lex_state = 79 },
    [158] = { .lex_state = 815 },
    [159] = { .lex_state = 815 },
    [160] = { .lex_state = 815 },
    [161] = { .lex_state = 79 },
    [162] = { .lex_state = 79 },
    [163] = { .lex_state = 79 },
    [164] = { .lex_state = 79 },
    [165] = { .lex_state = 79 },
    [166] = { .lex_state = 79 },
    [167] = { .lex_state = 79 },
    [168] = { .lex_state = 815 },
    [169] = { .lex_state = 79 },
    [170] = { .lex_state = 79 },
    [171] = { .lex_state = 79 },
    [172] = { .lex_state = 79 },
    [173] = { .lex_state = 79 },
    [174] = { .lex_state = 79 },
    [175] = { .lex_state = 79 },
    [176] = { .lex_state = 79 },
    [177] = { .lex_state = 79 },
    [178] = { .lex_state = 76 },
    [179] = { .lex_state = 79 },
    [180] = { .lex_state = 79 },
    [181] = { .lex_state = 76 },
    [182] = { .lex_state = 76 },
    [183] = { .lex_state = 79 },
    [184] = { .lex_state = 76 },
    [185] = { .lex_state = 79 },
    [186] = { .lex_state = 76 },
    [187] = { .lex_state = 76 },
    [188] = { .lex_state = 79 },
    [189] = { .lex_state = 79 },
    [190] = { .lex_state = 84 },
    [191] = { .lex_state = 83 },
    [192] = { .lex_state = 76 },
    [193] = { .lex_state = 76 },
    [194] = { .lex_state = 77 },
    [195] = { .lex_state = 77 },
    [196] = { .lex_state = 77 },
    [197] = { .lex_state = 77 },
    [198] = { .lex_state = 77 },
    [199] = { .lex_state = 77 },
    [200] = { .lex_state = 77 },
    [201] = { .lex_state = 76 },
    [202] = { .lex_state = 77 },
    [203] = { .lex_state = 76 },
    [204] = { .lex_state = 77 },
    [205] = { .lex_state = 76 },
    [206] = { .lex_state = 77 },
    [207] = { .lex_state = 77 },
    [208] = { .lex_state = 77 },
    [209] = { .lex_state = 77 },
    [210] = { .lex_state = 77 },
    [211] = { .lex_state = 77 },
    [212] = { .lex_state = 77 },
    [213] = { .lex_state = 77 },
    [214] = { .lex_state = 77 },
    [215] = { .lex_state = 77 },
    [216] = { .lex_state = 79 },
    [217] = { .lex_state = 76 },
    [218] = { .lex_state = 77 },
    [219] = { .lex_state = 83 },
    [220] = { .lex_state = 77 },
    [221] = { .lex_state = 83 },
    [222] = { .lex_state = 87 },
    [223] = { .lex_state = 77 },
    [224] = { .lex_state = 77 },
    [225] = { .lex_state = 76 },
    [226] = { .lex_state = 814 },
    [227] = { .lex_state = 76 },
    [228] = { .lex_state = 87 },
    [229] = { .lex_state = 76 },
    [230] = { .lex_state = 80 },
    [231] = { .lex_state = 814 },
    [232] = { .lex_state = 814 },
    [233] = { .lex_state = 814 },
    [234] = { .lex_state = 814 },
    [235] = { .lex_state = 76 },
    [236] = { .lex_state = 76 },
    [237] = { .lex_state = 814 },
    [238] = { .lex_state = 814 },
    [239] = { .lex_state = 814 },
    [240] = { .lex_state = 814 },
    [241] = { .lex_state = 814 },
    [242] = { .lex_state = 814 },
    [243] = { .lex_state = 814 },
    [244] = { .lex_state = 814 },
    [245] = { .lex_state = 76 },
    [246] = { .lex_state = 814 },
    [247] = { .lex_state = 814 },
    [248] = { .lex_state = 76 },
    [249] = { .lex_state = 814 },
    [250] = { .lex_state = 814 },
    [251] = { .lex_state = 814 },
    [252] = { .lex_state = 87 },
    [253] = { .lex_state = 78 },
    [254] = { .lex_state = 87 },
    [255] = { .lex_state = 87 },
    [256] = { .lex_state = 78 },
    [257] = { .lex_state = 79 },
    [258] = { .lex_state = 87 },
    [259] = { .lex_state = 87 },
    [260] = { .lex_state = 89 },
    [261] = { .lex_state = 88 },
    [262] = { .lex_state = 87 },
    [263] = { .lex_state = 87 },
    [264] = { .lex_state = 87 },
    [265] = { .lex_state = 78 },
    [266] = { .lex_state = 87 },
    [267] = { .lex_state = 87 },
    [268] = { .lex_state = 87 },
    [269] = { .lex_state = 87 },
    [270] = { .lex_state = 87 },
    [271] = { .lex_state = 76 },
    [272] = { .lex_state = 78 },
    [273] = { .lex_state = 88 },
    [274] = { .lex_state = 89 },
    [275] = { .lex_state = 87 },
    [276] = { .lex_state = 87 },
    [277] = { .lex_state = 87 },
    [278] = { .lex_state = 87 },
    [279] = { .lex_state = 81 },
    [280] = { .lex_state = 87 },
    [281] = { .lex_state = 77 },
    [282] = { .lex_state = 87 },
    [283] = { .lex_state = 88 },
    [284] = { .lex_state = 76 },
    [285] = { .lex_state = 87 },
    [286] = { .lex_state = 87 },
    [287] = { .lex_state = 87 },
    [288] = { .lex_state = 87 },
    [289] = { .lex_state = 87 },
    [290] = { .lex_state = 87 },
    [291] = { .lex_state = 87 },
    [292] = { .lex_state = 78 },
    [293] = { .lex_state = 76 },
    [294] = { .lex_state = 76 },
    [295] = { .lex_state = 87 },
    [296] = { .lex_state = 87 },
    [297] = { .lex_state = 87 },
    [298] = { .lex_state = 88 },
    [299] = { .lex_state = 77 },
    [300] = { .lex_state = 87 },
    [301] = { .lex_state = 87 },
    [302] = { .lex_state = 87 },
    [303] = { .lex_state = 87 },
    [304] = { .lex_state = 76 },
    [305] = { .lex_state = 87 },
    [306] = { .lex_state = 87 },
    [307] = { .lex_state = 87 },
    [308] = { .lex_state = 87 },
    [309] = { .lex_state = 76 },
    [310] = { .lex_state = 76 },
    [311] = { .lex_state = 87 },
    [312] = { .lex_state = 76 },
    [313] = { .lex_state = 87 },
    [314] = { .lex_state = 87 },
    [315] = { .lex_state = 87 },
    [316] = { .lex_state = 76 },
    [317] = { .lex_state = 87 },
    [318] = { .lex_state = 87 },
    [319] = { .lex_state = 87 },
    [320] = { .lex_state = 87 },
    [321] = { .lex_state = 87 },
    [322] = { .lex_state = 88 },
    [323] = { .lex_state = 87 },
    [324] = { .lex_state = 88 },
    [325] = { .lex_state = 87 },
    [326] = { .lex_state = 87 },
    [327] = { .lex_state = 87 },
    [328] = { .lex_state = 76 },
    [329] = { .lex_state = 76 },
    [330] = { .lex_state = 77 },
    [331] = { .lex_state = 49 },
    [332] = { .lex_state = 107 },
    [333] = { .lex_state = 76 },
    [334] = { .lex_state = 49 },
    [335] = { .lex_state = 76 },
    [336] = { .lex_state = 49 },
    [337] = { .lex_state = 49 },
    [338] = { .lex_state = 49 },
    [339] = { .lex_state = 88 },
    [340] = { .lex_state = 49 },
    [341] = { .lex_state = 49 },
    [342] = { .lex_state = 84 },
    [343] = { .lex_state = 76 },
    [344] = { .lex_state = 77 },
    [345] = { .lex_state = 49 },
    [346] = { .lex_state = 76 },
    [347] = { .lex_state = 77 },
    [348] = { .lex_state = 49 },
    [349] = { .lex_state = 84 },
    [350] = { .lex_state = 78 },
    [351] = { .lex_state = 89 },
    [352] = { .lex_state = 49 },
    [353] = { .lex_state = 84 },
    [354] = { .lex_state = 76 },
    [355] = { .lex_state = 76 },
    [356] = { .lex_state = 88 },
    [357] = { .lex_state = 88 },
    [358] = { .lex_state = 88 },
    [359] = { .lex_state = 88 },
    [360] = { .lex_state = 76 },
    [361] = { .lex_state = 108 },
    [362] = { .lex_state = 89 },
    [363] = { .lex_state = 76 },
    [364] = { .lex_state = 89 },
    [365] = { .lex_state = 89 },
    [366] = { .lex_state = 89 },
    [367] = { .lex_state = 76 },
    [368] = { .lex_state = 84 },
    [369] = { .lex_state = 84 },
    [370] = { .lex_state = 89 },
    [371] = { .lex_state = 89 },
    [372] = { .lex_state = 89 },
    [373] = { .lex_state = 89 },
    [374] = { .lex_state = 89 },
    [375] = { .lex_state = 89 },
    [376] = { .lex_state = 89 },
    [377] = { .lex_state = 84 },
    [378] = { .lex_state = 108 },
    [379] = { .lex_state = 77 },
    [380] = { .lex_state = 76 },
    [381] = { .lex_state = 49 },
    [382] = { .lex_state = 49 },
    [383] = { .lex_state = 84 },
    [384] = { .lex_state = 112 },
    [385] = { .lex_state = 49 },
    [386] = { .lex_state = 814 },
    [387] = { .lex_state = 89 },
    [388] = { .lex_state = 89 },
    [389] = { .lex_state = 814 },
    [390] = { .lex_state = 49 },
    [391] = { .lex_state = 77 },
    [392] = { .lex_state = 77 },
    [393] = { .lex_state = 49 },
    [394] = { .lex_state = 77 },
    [395] = { .lex_state = 49 },
    [396] = { .lex_state = 814 },
    [397] = { .lex_state = 49 },
    [398] = { .lex_state = 84 },
    [399] = { .lex_state = 49 },
    [400] = { .lex_state = 49 },
    [401] = { .lex_state = 84 },
    [402] = { .lex_state = 49 },
    [403] = { .lex_state = 49 },
    [404] = { .lex_state = 84 },
    [405] = { .lex_state = 76 },
    [406] = { .lex_state = 76 },
    [407] = { .lex_state = 49 },
    [408] = { .lex_state = 76 },
    [409] = { .lex_state = 84 },
    [410] = { .lex_state = 89 },
    [411] = { .lex_state = 89 },
    [412] = { .lex_state = 84 },
    [413] = { .lex_state = 84 },
    [414] = { .lex_state = 76 },
    [415] = { .lex_state = 76 },
    [416] = { .lex_state = 84 },
    [417] = { .lex_state = 76 },
    [418] = { .lex_state = 84 },
    [419] = { .lex_state = 76 },
    [420] = { .lex_state = 814 },
    [421] = { .lex_state = 76 },
    [422] = { .lex_state = 76 },
    [423] = { .lex_state = 814 },
    [424] = { .lex_state = 84 },
    [425] = { .lex_state = 56 },
    [426] = { .lex_state = 56 },
    [427] = { .lex_state = 814 },
    [428] = { .lex_state = 77 },
    [429] = { .lex_state = 84 },
    [430] = { .lex_state = 76 },
    [431] = { .lex_state = 814 },
    [432] = { .lex_state = 814 },
    [433] = { .lex_state = 89 },
    [434] = { .lex_state = 89 },
    [435] = { .lex_state = 89 },
    [436] = { .lex_state = 76 },
    [437] = { .lex_state = 89 },
    [438] = { .lex_state = 76 },
    [439] = { .lex_state = 89 },
    [440] = { .lex_state = 89 },
    [441] = { .lex_state = 89 },
    [442] = { .lex_state = 89 },
    [443] = { .lex_state = 89 },
    [444] = { .lex_state = 84 },
    [445] = { .lex_state = 56 },
    [446] = { .lex_state = 84 },
    [447] = { .lex_state = 56 },
    [448] = { .lex_state = 76 },
    [449] = { .lex_state = 76 },
    [450] = { .lex_state = 76 },
    [451] = { .lex_state = 77 },
    [452] = { .lex_state = 113 },
    [453] = { .lex_state = 88 },
    [454] = { .lex_state = 88 },
    [455] = { .lex_state = 76 },
    [456] = { .lex_state = 88 },
    [457] = { .lex_state = 88 },
    [458] = { .lex_state = 88 },
    [459] = { .lex_state = 88 },
    [460] = { .lex_state = 88 },
    [461] = { .lex_state = 88 },
    [462] = { .lex_state = 88 },
    [463] = { .lex_state = 814 },
    [464] = { .lex_state = 60 },
    [465] = { .lex_state = 56 },
    [466] = { .lex_state = 60 },
    [467] = { .lex_state = 84 },
    [468] = { .lex_state = 56 },
    [469] = { .lex_state = 56 },
    [470] = { .lex_state = 56 },
    [471] = { .lex_state = 76 },
    [472] = { .lex_state = 814 },
    [473] = { .lex_state = 56 },
    [474] = { .lex_state = 76 },
    [475] = { .lex_state = 814 },
    [476] = { .lex_state = 76 },
    [477] = { .lex_state = 76 },
    [478] = { .lex_state = 76 },
    [479] = { .lex_state = 814 },
    [480] = { .lex_state = 76 },
    [481] = { .lex_state = 76 },
    [482] = { .lex_state = 60 },
    [483] = { .lex_state = 76 },
    [484] = { .lex_state = 76 },
    [485] = { .lex_state = 76 },
    [486] = { .lex_state = 76 },
    [487] = { .lex_state = 76 },
    [488] = { .lex_state = 76 },
    [489] = { .lex_state = 814 },
    [490] = { .lex_state = 814 },
    [491] = { .lex_state = 814 },
    [492] = { .lex_state = 814 },
    [493] = { .lex_state = 814 },
    [494] = { .lex_state = 814 },
    [495] = { .lex_state = 84 },
    [496] = { .lex_state = 814 },
    [497] = { .lex_state = 814 },
    [498] = { .lex_state = 76 },
    [499] = { .lex_state = 76 },
    [500] = { .lex_state = 814 },
    [501] = { .lex_state = 76 },
    [502] = { .lex_state = 814 },
    [503] = { .lex_state = 814 },
    [504] = { .lex_state = 814 },
    [505] = { .lex_state = 84 },
    [506] = { .lex_state = 814 },
    [507] = { .lex_state = 84 },
    [508] = { .lex_state = 814 },
    [509] = { .lex_state = 814 },
    [510] = { .lex_state = 814 },
    [511] = { .lex_state = 814 },
    [512] = { .lex_state = 60 },
    [513] = { .lex_state = 60 },
    [514] = { .lex_state = 814 },
    [515] = { .lex_state = 814 },
    [516] = { .lex_state = 814 },
    [517] = { .lex_state = 814 },
    [518] = { .lex_state = 814 },
    [519] = { .lex_state = 84 },
    [520] = { .lex_state = 84 },
    [521] = { .lex_state = 814 },
    [522] = { .lex_state = 76 },
    [523] = { .lex_state = 814 },
    [524] = { .lex_state = 814 },
    [525] = { .lex_state = 814 },
    [526] = { .lex_state = 814 },
    [527] = { .lex_state = 814 },
    [528] = { .lex_state = 814 },
    [529] = { .lex_state = 814 },
    [530] = { .lex_state = 814 },
    [531] = { .lex_state = 814 },
    [532] = { .lex_state = 76 },
    [533] = { .lex_state = 76 },
    [534] = { .lex_state = 84 },
    [535] = { .lex_state = 814 },
    [536] = { .lex_state = 76 },
    [537] = { .lex_state = 84 },
    [538] = { .lex_state = 76 },
    [539] = { .lex_state = 84 },
    [540] = { .lex_state = 84 },
    [541] = { .lex_state = 76 },
    [542] = { .lex_state = 88 },
    [543] = { .lex_state = 814 },
    [544] = { .lex_state = 88 },
    [545] = { .lex_state = 88 },
    [546] = { .lex_state = 88 },
    [547] = { .lex_state = 814 },
    [548] = { .lex_state = 88 },
    [549] = { .lex_state = 88 },
    [550] = { .lex_state = 76 },
    [551] = { .lex_state = 88 },
    [552] = { .lex_state = 814 },
    [553] = { .lex_state = 814 },
    [554] = { .lex_state = 88 },
    [555] = { .lex_state = 88 },
    [556] = { .lex_state = 88 },
    [557] = { .lex_state = 88 },
    [558] = { .lex_state = 88 },
    [559] = { .lex_state = 814 },
    [560] = { .lex_state = 88 },
    [561] = { .lex_state = 88 },
    [562] = { .lex_state = 88 },
    [563] = { .lex_state = 88 },
    [564] = { .lex_state = 88 },
    [565] = { .lex_state = 814 },
    [566] = { .lex_state = 88 },
    [567] = { .lex_state = 88 },
    [568] = { .lex_state = 814 },
    [569] = { .lex_state = 88 },
    [570] = { .lex_state = 88 },
    [571] = { .lex_state = 88 },
    [572] = { .lex_state = 88 },
    [573] = { .lex_state = 88 },
    [574] = { .lex_state = 88 },
    [575] = { .lex_state = 88 },
    [576] = { .lex_state = 88 },
    [577] = { .lex_state = 814 },
    [578] = { .lex_state = 84 },
    [579] = { .lex_state = 814 },
    [580] = { .lex_state = 84 },
    [581] = { .lex_state = 88 },
    [582] = { .lex_state = 88 },
    [583] = { .lex_state = 84 },
    [584] = { .lex_state = 88 },
    [585] = { .lex_state = 88 },
    [586] = { .lex_state = 88 },
    [587] = { .lex_state = 814 },
    [588] = { .lex_state = 814 },
    [589] = { .lex_state = 88 },
    [590] = { .lex_state = 814 },
    [591] = { .lex_state = 84 },
    [592] = { .lex_state = 88 },
    [593] = { .lex_state = 88 },
    [594] = { .lex_state = 88 },
    [595] = { .lex_state = 814 },
    [596] = { .lex_state = 114 },
    [597] = { .lex_state = 77 },
    [598] = { .lex_state = 814 },
    [599] = { .lex_state = 814 },
    [600] = { .lex_state = 56 },
    [601] = { .lex_state = 84 },
    [602] = { .lex_state = 814 },
    [603] = { .lex_state = 814 },
    [604] = { .lex_state = 814 },
    [605] = { .lex_state = 814 },
    [606] = { .lex_state = 814 },
    [607] = { .lex_state = 814 },
    [608] = { .lex_state = 814 },
    [609] = { .lex_state = 76 },
    [610] = { .lex_state = 814 },
    [611] = { .lex_state = 84 },
    [612] = { .lex_state = 814 },
    [613] = { .lex_state = 49 },
    [614] = { .lex_state = 49 },
    [615] = { .lex_state = 49 },
    [616] = { .lex_state = 49 },
    [617] = { .lex_state = 49 },
    [618] = { .lex_state = 76 },
    [619] = { .lex_state = 49 },
    [620] = { .lex_state = 49 },
    [621] = { .lex_state = 49 },
    [622] = { .lex_state = 49 },
    [623] = { .lex_state = 49 },
    [624] = { .lex_state = 49 },
    [625] = { .lex_state = 84 },
    [626] = { .lex_state = 49 },
    [627] = { .lex_state = 49 },
    [628] = { .lex_state = 49 },
    [629] = { .lex_state = 49 },
    [630] = { .lex_state = 49 },
    [631] = { .lex_state = 49 },
    [632] = { .lex_state = 814 },
    [633] = { .lex_state = 49 },
    [634] = { .lex_state = 49 },
    [635] = { .lex_state = 49 },
    [636] = { .lex_state = 49 },
    [637] = { .lex_state = 49 },
    [638] = { .lex_state = 49 },
    [639] = { .lex_state = 49 },
    [640] = { .lex_state = 49 },
    [641] = { .lex_state = 49 },
    [642] = { .lex_state = 49 },
    [643] = { .lex_state = 84 },
    [644] = { .lex_state = 49 },
    [645] = { .lex_state = 84 },
    [646] = { .lex_state = 76 },
    [647] = { .lex_state = 49 },
    [648] = { .lex_state = 49 },
    [649] = { .lex_state = 84 },
    [650] = { .lex_state = 84 },
    [651] = { .lex_state = 76 },
    [652] = { .lex_state = 84 },
    [653] = { .lex_state = 49 },
    [654] = { .lex_state = 814 },
    [655] = { .lex_state = 49 },
    [656] = { .lex_state = 49 },
    [657] = { .lex_state = 814 },
    [658] = { .lex_state = 49 },
    [659] = { .lex_state = 49 },
    [660] = { .lex_state = 814 },
    [661] = { .lex_state = 49 },
    [662] = { .lex_state = 814 },
    [663] = { .lex_state = 76 },
    [664] = { .lex_state = 814 },
    [665] = { .lex_state = 814 },
    [666] = { .lex_state = 814 },
    [667] = { .lex_state = 76 },
    [668] = { .lex_state = 814 },
    [669] = { .lex_state = 814 },
    [670] = { .lex_state = 814 },
    [671] = { .lex_state = 814 },
    [672] = { .lex_state = 76 },
    [673] = { .lex_state = 814 },
    [674] = { .lex_state = 814 },
    [675] = { .lex_state = 814 },
    [676] = { .lex_state = 814 },
    [677] = { .lex_state = 814 },
    [678] = { .lex_state = 814 },
    [679] = { .lex_state = 84 },
    [680] = { .lex_state = 76 },
    [681] = { .lex_state = 60 },
    [682] = { .lex_state = 814 },
    [683] = { .lex_state = 814 },
    [684] = { .lex_state = 814 },
    [685] = { .lex_state = 84 },
    [686] = { .lex_state = 84 },
    [687] = { .lex_state = 84 },
    [688] = { .lex_state = 84 },
    [689] = { .lex_state = 814 },
    [690] = { .lex_state = 76 },
    [691] = { .lex_state = 76 },
    [692] = { .lex_state = 814 },
    [693] = { .lex_state = 814 },
    [694] = { .lex_state = 76 },
    [695] = { .lex_state = 814 },
    [696] = { .lex_state = 814 },
    [697] = { .lex_state = 76 },
    [698] = { .lex_state = 814 },
    [699] = { .lex_state = 814 },
    [700] = { .lex_state = 814 },
    [701] = { .lex_state = 814 },
    [702] = { .lex_state = 814 },
    [703] = { .lex_state = 814 },
    [704] = { .lex_state = 76 },
    [705] = { .lex_state = 814 },
    [706] = { .lex_state = 84 },
    [707] = { .lex_state = 814 },
    [708] = { .lex_state = 814 },
    [709] = { .lex_state = 814 },
    [710] = { .lex_state = 76 },
    [711] = { .lex_state = 814 },
    [712] = { .lex_state = 77 },
    [713] = { .lex_state = 814 },
    [714] = { .lex_state = 76 },
    [715] = { .lex_state = 84 },
    [716] = { .lex_state = 814 },
    [717] = { .lex_state = 814 },
    [718] = { .lex_state = 84 },
    [719] = { .lex_state = 76 },
    [720] = { .lex_state = 814 },
    [721] = { .lex_state = 84 },
    [722] = { .lex_state = 109 },
    [723] = { .lex_state = 84 },
    [724] = { .lex_state = 84 },
    [725] = { .lex_state = 814 },
    [726] = { .lex_state = 109 },
    [727] = { .lex_state = 76 },
    [728] = { .lex_state = 109 },
    [729] = { .lex_state = 109 },
    [730] = { .lex_state = 63 },
    [731] = { .lex_state = 84 },
    [732] = { .lex_state = 76 },
    [733] = { .lex_state = 84 },
    [734] = { .lex_state = 814 },
    [735] = { .lex_state = 84 },
    [736] = { .lex_state = 84 },
    [737] = { .lex_state = 84 },
    [738] = { .lex_state = 84 },
    [739] = { .lex_state = 84 },
    [740] = { .lex_state = 76 },
    [741] = { .lex_state = 109 },
    [742] = { .lex_state = 84 },
    [743] = { .lex_state = 84 },
    [744] = { .lex_state = 84 },
    [745] = { .lex_state = 77 },
    [746] = { .lex_state = 84 },
    [747] = { .lex_state = 109 },
    [748] = { .lex_state = 84 },
    [749] = { .lex_state = 76 },
    [750] = { .lex_state = 84 },
    [751] = { .lex_state = 84 },
    [752] = { .lex_state = 109 },
    [753] = { .lex_state = 84 },
    [754] = { .lex_state = 84 },
    [755] = { .lex_state = 84 },
    [756] = { .lex_state = 814 },
    [757] = { .lex_state = 814 },
    [758] = { .lex_state = 814 },
    [759] = { .lex_state = 84 },
    [760] = { .lex_state = 76 },
    [761] = { .lex_state = 84 },
    [762] = { .lex_state = 814 },
    [763] = { .lex_state = 814 },
    [764] = { .lex_state = 76 },
    [765] = { .lex_state = 84 },
    [766] = { .lex_state = 814 },
    [767] = { .lex_state = 84 },
    [768] = { .lex_state = 814 },
    [769] = { .lex_state = 84 },
    [770] = { .lex_state = 814 },
    [771] = { .lex_state = 76 },
    [772] = { .lex_state = 814 },
    [773] = { .lex_state = 84 },
    [774] = { .lex_state = 814 },
    [775] = { .lex_state = 84 },
    [776] = { .lex_state = 84 },
    [777] = { .lex_state = 84 },
    [778] = { .lex_state = 77 },
    [779] = { .lex_state = 84 },
    [780] = { .lex_state = 814 },
    [781] = { .lex_state = 77 },
    [782] = { .lex_state = 84 },
    [783] = { .lex_state = 84 },
    [784] = { .lex_state = 814 },
    [785] = { .lex_state = 84 },
    [786] = { .lex_state = 814 },
    [787] = { .lex_state = 77 },
    [788] = { .lex_state = 84 },
    [789] = { .lex_state = 814 },
    [790] = { .lex_state = 814 },
    [791] = { .lex_state = 109 },
    [792] = { .lex_state = 84 },
    [793] = { .lex_state = 84 },
    [794] = { .lex_state = 814 },
    [795] = { .lex_state = 89 },
    [796] = { .lex_state = 814 },
    [797] = { .lex_state = 814 },
    [798] = { .lex_state = 814 },
    [799] = { .lex_state = 76 },
    [800] = { .lex_state = 814 },
    [801] = { .lex_state = 84 },
    [802] = { .lex_state = 84 },
    [803] = { .lex_state = 814 },
    [804] = { .lex_state = 84 },
    [805] = { .lex_state = 814 },
    [806] = { .lex_state = 84 },
    [807] = { .lex_state = 814 },
    [808] = { .lex_state = 814 },
    [809] = { .lex_state = 814 },
    [810] = { .lex_state = 814 },
    [811] = { .lex_state = 814 },
    [812] = { .lex_state = 814 },
    [813] = { .lex_state = 76 },
    [814] = { .lex_state = 84 },
    [815] = { .lex_state = 84 },
    [816] = { .lex_state = 76 },
    [817] = { .lex_state = 77 },
    [818] = { .lex_state = 76 },
    [819] = { .lex_state = 814 },
    [820] = { .lex_state = 76 },
    [821] = { .lex_state = 814 },
    [822] = { .lex_state = 76 },
    [823] = { .lex_state = 814 },
    [824] = { .lex_state = 814 },
    [825] = { .lex_state = 814 },
    [826] = { .lex_state = 84 },
    [827] = { .lex_state = 814 },
    [828] = { .lex_state = 814 },
    [829] = { .lex_state = 814 },
    [830] = { .lex_state = 814 },
    [831] = { .lex_state = 814 },
    [832] = { .lex_state = 76 },
    [833] = { .lex_state = 814 },
    [834] = { .lex_state = 84 },
    [835] = { .lex_state = 814 },
    [836] = { .lex_state = 84 },
    [837] = { .lex_state = 84 },
    [838] = { .lex_state = 84 },
    [839] = { .lex_state = 814 },
    [840] = { .lex_state = 814 },
    [841] = { .lex_state = 814 },
    [842] = { .lex_state = 814 },
    [843] = { .lex_state = 814 },
    [844] = { .lex_state = 77 },
    [845] = { .lex_state = 84 },
    [846] = { .lex_state = 814 },
    [847] = { .lex_state = 814 },
    [848] = { .lex_state = 814 },
    [849] = { .lex_state = 814 },
    [850] = { .lex_state = 814 },
    [851] = { .lex_state = 814 },
    [852] = { .lex_state = 814 },
    [853] = { .lex_state = 814 },
    [854] = { .lex_state = 814 },
    [855] = { .lex_state = 76 },
    [856] = { .lex_state = 84 },
    [857] = { .lex_state = 814 },
    [858] = { .lex_state = 76 },
    [859] = { .lex_state = 814 },
    [860] = { .lex_state = 814 },
    [861] = { .lex_state = 814 },
    [862] = { .lex_state = 814 },
    [863] = { .lex_state = 814 },
    [864] = { .lex_state = 84 },
    [865] = { .lex_state = 814 },
    [866] = { .lex_state = 84 },
    [867] = { .lex_state = 814 },
    [868] = { .lex_state = 814 },
    [869] = { .lex_state = 814 },
    [870] = { .lex_state = 814 },
    [871] = { .lex_state = 814 },
    [872] = { .lex_state = 814 },
    [873] = { .lex_state = 76 },
    [874] = { .lex_state = 84 },
    [875] = { .lex_state = 814 },
    [876] = { .lex_state = 814 },
    [877] = { .lex_state = 84 },
    [878] = { .lex_state = 76 },
    [879] = { .lex_state = 814 },
    [880] = { .lex_state = 814 },
    [881] = { .lex_state = 814 },
    [882] = { .lex_state = 814 },
    [883] = { .lex_state = 814 },
    [884] = { .lex_state = 76 },
    [885] = { .lex_state = 814 },
    [886] = { .lex_state = 814 },
    [887] = { .lex_state = 814 },
    [888] = { .lex_state = 814 },
    [889] = { .lex_state = 814 },
    [890] = { .lex_state = 814 },
    [891] = { .lex_state = 814 },
    [892] = { .lex_state = 814 },
    [893] = { .lex_state = 814 },
    [894] = { .lex_state = 814 },
    [895] = { .lex_state = 814 },
    [896] = { .lex_state = 814 },
    [897] = { .lex_state = 814 },
    [898] = { .lex_state = 814 },
    [899] = { .lex_state = 814 },
    [900] = { .lex_state = 814 },
    [901] = { .lex_state = 814 },
    [902] = { .lex_state = 814 },
    [903] = { .lex_state = 814 },
    [904] = { .lex_state = 814 },
    [905] = { .lex_state = 814 },
    [906] = { .lex_state = 814 },
    [907] = { .lex_state = 814 },
    [908] = { .lex_state = 814 },
    [909] = { .lex_state = 814 },
    [910] = { .lex_state = 77 },
    [911] = { .lex_state = 814 },
    [912] = { .lex_state = 814 },
    [913] = { .lex_state = 814 },
    [914] = { .lex_state = 814 },
    [915] = { .lex_state = 814 },
    [916] = { .lex_state = 814 },
    [917] = { .lex_state = 814 },
    [918] = { .lex_state = 814 },
    [919] = { .lex_state = 814 },
    [920] = { .lex_state = 814 },
    [921] = { .lex_state = 814 },
    [922] = { .lex_state = 814 },
    [923] = { .lex_state = 814 },
    [924] = { .lex_state = 814 },
    [925] = { .lex_state = 814 },
    [926] = { .lex_state = 814 },
    [927] = { .lex_state = 814 },
    [928] = { .lex_state = 814 },
    [929] = { .lex_state = 814 },
    [930] = { .lex_state = 814 },
    [931] = { .lex_state = 814 },
    [932] = { .lex_state = 814 },
    [933] = { .lex_state = 84 },
    [934] = { .lex_state = 814 },
    [935] = { .lex_state = 814 },
    [936] = { .lex_state = 814 },
    [937] = { .lex_state = 814 },
    [938] = { .lex_state = 814 },
    [939] = { .lex_state = 814 },
    [940] = { .lex_state = 814 },
    [941] = { .lex_state = 814 },
    [942] = { .lex_state = 814 },
    [943] = { .lex_state = 814 },
    [944] = { .lex_state = 814 },
    [945] = { .lex_state = 814 },
    [946] = { .lex_state = 64 },
    [947] = { .lex_state = 84 },
    [948] = { .lex_state = 814 },
    [949] = { .lex_state = 814 },
    [950] = { .lex_state = 814 },
    [951] = { .lex_state = 84 },
    [952] = { .lex_state = 84 },
    [953] = { .lex_state = 84 },
    [954] = { .lex_state = 84 },
    [955] = { .lex_state = 814 },
    [956] = { .lex_state = 814 },
    [957] = { .lex_state = 814 },
    [958] = { .lex_state = 814 },
    [959] = { .lex_state = 814 },
    [960] = { .lex_state = 814 },
    [961] = { .lex_state = 814 },
    [962] = { .lex_state = 814 },
    [963] = { .lex_state = 814 },
    [964] = { .lex_state = 76 },
    [965] = { .lex_state = 84 },
    [966] = { .lex_state = 84 },
    [967] = { .lex_state = 814 },
    [968] = { .lex_state = 814 },
    [969] = { .lex_state = 84 },
    [970] = { .lex_state = 84 },
    [971] = { .lex_state = 814 },
    [972] = { .lex_state = 814 },
    [973] = { .lex_state = 84 },
    [974] = { .lex_state = 84 },
    [975] = { .lex_state = 814 },
    [976] = { .lex_state = 814 },
    [977] = { .lex_state = 814 },
    [978] = { .lex_state = 814 },
    [979] = { .lex_state = 814 },
    [980] = { .lex_state = 814 },
    [981] = { .lex_state = 814 },
    [982] = { .lex_state = 814 },
    [983] = { .lex_state = 814 },
    [984] = { .lex_state = 814 },
    [985] = { .lex_state = 814 },
    [986] = { .lex_state = 814 },
    [987] = { .lex_state = 814 },
    [988] = { .lex_state = 814 },
    [989] = { .lex_state = 814 },
    [990] = { .lex_state = 814 },
    [991] = { .lex_state = 814 },
    [992] = { .lex_state = 84 },
    [993] = { .lex_state = 814 },
    [994] = { .lex_state = 814 },
    [995] = { .lex_state = 814 },
    [996] = { .lex_state = 814 },
    [997] = { .lex_state = 814 },
    [998] = { .lex_state = 814 },
    [999] = { .lex_state = 814 },
    [1000] = { .lex_state = 814 },
    [1001] = { .lex_state = 814 },
    [1002] = { .lex_state = 814 },
    [1003] = { .lex_state = 814 },
    [1004] = { .lex_state = 814 },
    [1005] = { .lex_state = 814 },
    [1006] = { .lex_state = 84 },
    [1007] = { .lex_state = 84 },
    [1008] = { .lex_state = 814 },
    [1009] = { .lex_state = 814 },
    [1010] = { .lex_state = 814 },
    [1011] = { .lex_state = 814 },
    [1012] = { .lex_state = 814 },
    [1013] = { .lex_state = 84 },
    [1014] = { .lex_state = 814 },
    [1015] = { .lex_state = 814 },
    [1016] = { .lex_state = 84 },
    [1017] = { .lex_state = 814 },
    [1018] = { .lex_state = 814 },
    [1019] = { .lex_state = 814 },
    [1020] = { .lex_state = 84 },
    [1021] = { .lex_state = 814 },
    [1022] = { .lex_state = 814 },
    [1023] = { .lex_state = 814 },
    [1024] = { .lex_state = 814 },
    [1025] = { .lex_state = 84 },
    [1026] = { .lex_state = 84 },
    [1027] = { .lex_state = 84 },
    [1028] = { .lex_state = 84 },
    [1029] = { .lex_state = 814 },
    [1030] = { .lex_state = 64 },
    [1031] = { .lex_state = 814 },
    [1032] = { .lex_state = 965 },
    [1033] = { .lex_state = 64 },
    [1034] = { .lex_state = 84 },
    [1035] = { .lex_state = 814 },
    [1036] = { .lex_state = 814 },
    [1037] = { .lex_state = 814 },
    [1038] = { .lex_state = 814 },
    [1039] = { .lex_state = 814 },
    [1040] = { .lex_state = 84 },
    [1041] = { .lex_state = 814 },
    [1042] = { .lex_state = 814 },
    [1043] = { .lex_state = 814 },
    [1044] = { .lex_state = 76 },
    [1045] = { .lex_state = 814 },
    [1046] = { .lex_state = 814 },
    [1047] = { .lex_state = 814 },
    [1048] = { .lex_state = 814 },
    [1049] = { .lex_state = 814 },
    [1050] = { .lex_state = 814 },
    [1051] = { .lex_state = 814 },
    [1052] = { .lex_state = 814 },
    [1053] = { .lex_state = 814 },
    [1054] = { .lex_state = 814 },
    [1055] = { .lex_state = 814 },
    [1056] = { .lex_state = 814 },
    [1057] = { .lex_state = 814 },
    [1058] = { .lex_state = 814 },
    [1059] = { .lex_state = 814 },
    [1060] = { .lex_state = 814 },
    [1061] = { .lex_state = 814 },
    [1062] = { .lex_state = 814 },
    [1063] = { .lex_state = 814 },
    [1064] = { .lex_state = 814 },
    [1065] = { .lex_state = 814 },
    [1066] = { .lex_state = 814 },
    [1067] = { .lex_state = 814 },
    [1068] = { .lex_state = 814 },
    [1069] = { .lex_state = 814 },
    [1070] = { .lex_state = 814 },
    [1071] = { .lex_state = 814 },
    [1072] = { .lex_state = 814 },
    [1073] = { .lex_state = 814 },
    [1074] = { .lex_state = 84 },
    [1075] = { .lex_state = 814 },
    [1076] = { .lex_state = 814 },
    [1077] = { .lex_state = 814 },
    [1078] = { .lex_state = 84 },
    [1079] = { .lex_state = 814 },
    [1080] = { .lex_state = 814 },
    [1081] = { .lex_state = 84 },
    [1082] = { .lex_state = 814 },
    [1083] = { .lex_state = 814 },
    [1084] = { .lex_state = 814 },
    [1085] = { .lex_state = 814 },
    [1086] = { .lex_state = 814 },
    [1087] = { .lex_state = 814 },
    [1088] = { .lex_state = 814 },
    [1089] = { .lex_state = 814 },
    [1090] = { .lex_state = 814 },
    [1091] = { .lex_state = 814 },
    [1092] = { .lex_state = 814 },
    [1093] = { .lex_state = 814 },
    [1094] = { .lex_state = 814 },
    [1095] = { .lex_state = 814 },
    [1096] = { .lex_state = 814 },
    [1097] = { .lex_state = 814 },
    [1098] = { .lex_state = 814 },
    [1099] = { .lex_state = 814 },
    [1100] = { .lex_state = 814 },
    [1101] = { .lex_state = 814 },
    [1102] = { .lex_state = 814 },
    [1103] = { .lex_state = 814 },
    [1104] = { .lex_state = 814 },
    [1105] = { .lex_state = 814 },
    [1106] = { .lex_state = 1560 },
    [1107] = { .lex_state = 84 },
    [1108] = { .lex_state = 814 },
    [1109] = { .lex_state = 814 },
    [1110] = { .lex_state = 84 },
    [1111] = { .lex_state = 84 },
    [1112] = { .lex_state = 814 },
    [1113] = { .lex_state = 814 },
    [1114] = { .lex_state = 814 },
    [1115] = { .lex_state = 814 },
    [1116] = { .lex_state = 814 },
    [1117] = { .lex_state = 814 },
    [1118] = { .lex_state = 814 },
    [1119] = { .lex_state = 814 },
    [1120] = { .lex_state = 814 },
    [1121] = { .lex_state = 814 },
    [1122] = { .lex_state = 814 },
    [1123] = { .lex_state = 814 },
    [1124] = { .lex_state = 814 },
    [1125] = { .lex_state = 814 },
    [1126] = { .lex_state = 814 },
    [1127] = { .lex_state = 814 },
    [1128] = { .lex_state = 814 },
    [1129] = { .lex_state = 814 },
    [1130] = { .lex_state = 814 },
    [1131] = { .lex_state = 814 },
    [1132] = { .lex_state = 814 },
    [1133] = { .lex_state = 814 },
    [1134] = { .lex_state = 814 },
    [1135] = { .lex_state = 814 },
    [1136] = { .lex_state = 814 },
    [1137] = { .lex_state = 84 },
    [1138] = { .lex_state = 84 },
    [1139] = { .lex_state = 84 },
    [1140] = { .lex_state = 814 },
    [1141] = { .lex_state = 814 },
    [1142] = { .lex_state = 814 },
    [1143] = { .lex_state = 814 },
    [1144] = { .lex_state = 814 },
    [1145] = { .lex_state = 814 },
    [1146] = { .lex_state = 84 },
    [1147] = { .lex_state = 814 },
    [1148] = { .lex_state = 814 },
    [1149] = { .lex_state = 814 },
    [1150] = { .lex_state = 814 },
    [1151] = { .lex_state = 814 },
    [1152] = { .lex_state = 814 },
    [1153] = { .lex_state = 814 },
    [1154] = { .lex_state = 814 },
    [1155] = { .lex_state = 814 },
    [1156] = { .lex_state = 84 },
    [1157] = { .lex_state = 814 },
    [1158] = { .lex_state = 814 },
    [1159] = { .lex_state = 84 },
    [1160] = { .lex_state = 84 },
    [1161] = { .lex_state = 814 },
    [1162] = { .lex_state = 84 },
    [1163] = { .lex_state = 84 },
    [1164] = { .lex_state = 814 },
    [1165] = { .lex_state = 84 },
    [1166] = { .lex_state = 84 },
    [1167] = { .lex_state = 814 },
    [1168] = { .lex_state = 814 },
    [1169] = { .lex_state = 814 },
    [1170] = { .lex_state = 76 },
    [1171] = { .lex_state = 814 },
    [1172] = { .lex_state = 814 },
    [1173] = { .lex_state = 814 },
    [1174] = { .lex_state = 84 },
    [1175] = { .lex_state = 84 },
    [1176] = { .lex_state = 814 },
    [1177] = { .lex_state = 814 },
    [1178] = { .lex_state = 814 },
    [1179] = { .lex_state = 814 },
    [1180] = { .lex_state = 84 },
    [1181] = { .lex_state = 84 },
    [1182] = { .lex_state = 64 },
    [1183] = { .lex_state = 814 },
    [1184] = { .lex_state = 84 },
    [1185] = { .lex_state = 814 },
    [1186] = { .lex_state = 64 },
    [1187] = { .lex_state = 814 },
    [1188] = { .lex_state = 814 },
    [1189] = { .lex_state = 84 },
    [1190] = { .lex_state = 84 },
    [1191] = { .lex_state = 814 },
    [1192] = { .lex_state = 814 },
    [1193] = { .lex_state = 84 },
    [1194] = { .lex_state = 84 },
    [1195] = { .lex_state = 814 },
    [1196] = { .lex_state = 814 },
    [1197] = { .lex_state = 814 },
    [1198] = { .lex_state = 76 },
    [1199] = { .lex_state = 814 },
    [1200] = { .lex_state = 814 },
    [1201] = { .lex_state = 814 },
    [1202] = { .lex_state = 64 },
    [1203] = { .lex_state = 84 },
    [1204] = { .lex_state = 814 },
    [1205] = { .lex_state = 814 },
    [1206] = { .lex_state = 814 },
    [1207] = { .lex_state = 941 },
    [1208] = { .lex_state = 814 },
    [1209] = { .lex_state = 93 },
    [1210] = { .lex_state = 814 },
    [1211] = { .lex_state = 814 },
    [1212] = { .lex_state = 814 },
    [1213] = { .lex_state = 814 },
    [1214] = { .lex_state = 814 },
    [1215] = { .lex_state = 814 },
    [1216] = { .lex_state = 814 },
    [1217] = { .lex_state = 814 },
    [1218] = { .lex_state = 814 },
    [1219] = { .lex_state = 814 },
    [1220] = { .lex_state = 814 },
    [1221] = { .lex_state = 814 },
    [1222] = { .lex_state = 814 },
    [1223] = { .lex_state = 814 },
    [1224] = { .lex_state = 814 },
    [1225] = { .lex_state = 814 },
    [1226] = { .lex_state = 814 },
    [1227] = { .lex_state = 814 },
    [1228] = { .lex_state = 814 },
    [1229] = { .lex_state = 814 },
    [1230] = { .lex_state = 814 },
    [1231] = { .lex_state = 814 },
    [1232] = { .lex_state = 814 },
    [1233] = { .lex_state = 814 },
    [1234] = { .lex_state = 814 },
    [1235] = { .lex_state = 814 },
    [1236] = { .lex_state = 814 },
    [1237] = { .lex_state = 814 },
    [1238] = { .lex_state = 814 },
    [1239] = { .lex_state = 814 },
    [1240] = { .lex_state = 814 },
    [1241] = { .lex_state = 814 },
    [1242] = { .lex_state = 814 },
    [1243] = { .lex_state = 814 },
    [1244] = { .lex_state = 814 },
    [1245] = { .lex_state = 814 },
    [1246] = { .lex_state = 814 },
    [1247] = { .lex_state = 814 },
    [1248] = { .lex_state = 814 },
    [1249] = { .lex_state = 814 },
    [1250] = { .lex_state = 814 },
    [1251] = { .lex_state = 814 },
    [1252] = { .lex_state = 814 },
    [1253] = { .lex_state = 814 },
    [1254] = { .lex_state = 814 },
    [1255] = { .lex_state = 814 },
    [1256] = { .lex_state = 814 },
    [1257] = { .lex_state = 814 },
    [1258] = { (TSStateId)(-1) },
    [1259] = { (TSStateId)(-1) },
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
    [0] = {
        [sym_comment] = STATE(0),
        [ts_builtin_sym_end] = ACTIONS(1),
        [anon_sym_short] = ACTIONS(1),
        [anon_sym_int16] = ACTIONS(1),
        [anon_sym_long] = ACTIONS(1),
        [anon_sym_int32] = ACTIONS(1),
        [anon_sym_longlong] = ACTIONS(1),
        [anon_sym_int64] = ACTIONS(1),
        [sym_unsigned_tiny_int] = ACTIONS(1),
        [sym_boolean_type] = ACTIONS(1),
        [anon_sym_fixed] = ACTIONS(1),
        [sym_octet_type] = ACTIONS(1),
        [sym_signed_tiny_int] = ACTIONS(1),
        [anon_sym_unsignedshort] = ACTIONS(1),
        [anon_sym_uint16] = ACTIONS(1),
        [anon_sym_unsignedlong] = ACTIONS(1),
        [anon_sym_uint32] = ACTIONS(1),
        [anon_sym_unsignedlonglong] = ACTIONS(1),
        [anon_sym_uint64] = ACTIONS(1),
        [anon_sym_float] = ACTIONS(1),
        [anon_sym_double] = ACTIONS(1),
        [anon_sym_longdouble] = ACTIONS(1),
        [anon_sym_char] = ACTIONS(1),
        [anon_sym_wchar] = ACTIONS(1),
        [anon_sym_COLON_COLON] = ACTIONS(1),
        [anon_sym_string] = ACTIONS(1),
        [anon_sym_wstring] = ACTIONS(1),
        [anon_sym_LT] = ACTIONS(1),
        [anon_sym_GT] = ACTIONS(1),
        [anon_sym_any] = ACTIONS(1),
        [anon_sym_COMMA] = ACTIONS(1),
        [anon_sym_sequence] = ACTIONS(1),
        [anon_sym_map] = ACTIONS(1),
        [anon_sym_PIPE] = ACTIONS(1),
        [anon_sym_CARET] = ACTIONS(1),
        [anon_sym_AMP] = ACTIONS(1),
        [anon_sym_GT_GT] = ACTIONS(1),
        [anon_sym_PLUS] = ACTIONS(1),
        [anon_sym_DASH] = ACTIONS(1),
        [anon_sym_STAR] = ACTIONS(1),
        [anon_sym_SLASH] = ACTIONS(1),
        [anon_sym_PERCENT] = ACTIONS(1),
        [anon_sym_LPAREN] = ACTIONS(1),
        [anon_sym_RPAREN] = ACTIONS(1),
        [anon_sym_TILDE] = ACTIONS(1),
        [anon_sym_L] = ACTIONS(1),
        [anon_sym_DQUOTE] = ACTIONS(1),
        [anon_sym_SQUOTE] = ACTIONS(1),
        [anon_sym_TRUE] = ACTIONS(1),
        [anon_sym_FALSE] = ACTIONS(1),
        [sym_number_literal] = ACTIONS(1),
        [anon_sym_POUNDdefine] = ACTIONS(1),
        [sym_preproc_directive] = ACTIONS(1),
        [aux_sym_preproc_include_token1] = ACTIONS(1),
        [anon_sym_exception] = ACTIONS(1),
        [anon_sym_LBRACE] = ACTIONS(1),
        [anon_sym_RBRACE] = ACTIONS(1),
        [anon_sym_local] = ACTIONS(1),
        [anon_sym_abstract] = ACTIONS(1),
        [anon_sym_COLON] = ACTIONS(1),
        [anon_sym_SEMI] = ACTIONS(1),
        [anon_sym_void] = ACTIONS(1),
        [anon_sym_in] = ACTIONS(1),
        [anon_sym_out] = ACTIONS(1),
        [anon_sym_inout] = ACTIONS(1),
        [anon_sym_raises] = ACTIONS(1),
        [anon_sym_readonly] = ACTIONS(1),
        [anon_sym_attribute] = ACTIONS(1),
        [anon_sym_getraises] = ACTIONS(1),
        [anon_sym_setraises] = ACTIONS(1),
        [anon_sym_bitset] = ACTIONS(1),
        [anon_sym_bitfield] = ACTIONS(1),
        [anon_sym_bitmask] = ACTIONS(1),
        [anon_sym_ATannotation] = ACTIONS(1),
        [anon_sym_default] = ACTIONS(1),
        [anon_sym_AT] = ACTIONS(1),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(1),
        [anon_sym_EQ] = ACTIONS(1),
        [anon_sym_id] = ACTIONS(1),
        [anon_sym_autoid] = ACTIONS(1),
        [anon_sym_SEQUENTIAL] = ACTIONS(1),
        [anon_sym_HASH] = ACTIONS(1),
        [anon_sym_optional] = ACTIONS(1),
        [anon_sym_position] = ACTIONS(1),
        [anon_sym_value] = ACTIONS(1),
        [anon_sym_extensibility] = ACTIONS(1),
        [anon_sym_FINAL] = ACTIONS(1),
        [anon_sym_APPENDABLE] = ACTIONS(1),
        [anon_sym_MUTABLE] = ACTIONS(1),
        [anon_sym_final] = ACTIONS(1),
        [anon_sym_appendable] = ACTIONS(1),
        [anon_sym_mutable] = ACTIONS(1),
        [anon_sym_key] = ACTIONS(1),
        [anon_sym_must_understand] = ACTIONS(1),
        [anon_sym_default_literal] = ACTIONS(1),
        [anon_sym_range] = ACTIONS(1),
        [anon_sym_min] = ACTIONS(1),
        [anon_sym_max] = ACTIONS(1),
        [anon_sym_unit] = ACTIONS(1),
        [anon_sym_bit_bound] = ACTIONS(1),
        [anon_sym_external] = ACTIONS(1),
        [anon_sym_nested] = ACTIONS(1),
        [anon_sym_verbatim] = ACTIONS(1),
        [anon_sym_c] = ACTIONS(1),
        [anon_sym_c_PLUS_PLUS] = ACTIONS(1),
        [anon_sym_java] = ACTIONS(1),
        [anon_sym_idl] = ACTIONS(1),
        [anon_sym_BEGIN_FILE] = ACTIONS(1),
        [anon_sym_BEFORE_DECLARATION] = ACTIONS(1),
        [anon_sym_BEGIN_DECLARATION] = ACTIONS(1),
        [anon_sym_END_DECLARATION] = ACTIONS(1),
        [anon_sym_AFTER_DECLARATION] = ACTIONS(1),
        [anon_sym_END_FILE] = ACTIONS(1),
        [anon_sym_service] = ACTIONS(1),
        [anon_sym_CORBA] = ACTIONS(1),
        [anon_sym_DDS] = ACTIONS(1),
        [anon_sym_oneway] = ACTIONS(1),
        [anon_sym_ami] = ACTIONS(1),
        [anon_sym_module] = ACTIONS(1),
        [anon_sym_typename] = ACTIONS(1),
        [anon_sym_valuetype] = ACTIONS(1),
        [anon_sym_eventtype] = ACTIONS(1),
        [anon_sym_struct] = ACTIONS(1),
        [anon_sym_union] = ACTIONS(1),
        [anon_sym_enum] = ACTIONS(1),
        [anon_sym_const] = ACTIONS(1),
        [anon_sym_alias] = ACTIONS(1),
        [anon_sym_custom] = ACTIONS(1),
        [anon_sym_truncatable] = ACTIONS(1),
        [anon_sym_supports] = ACTIONS(1),
        [anon_sym_public] = ACTIONS(1),
        [anon_sym_private] = ACTIONS(1),
        [anon_sym_factory] = ACTIONS(1),
        [anon_sym_typedef] = ACTIONS(1),
        [anon_sym_LBRACK] = ACTIONS(1),
        [anon_sym_RBRACK] = ACTIONS(1),
        [anon_sym_ATignore_literal_names] = ACTIONS(1),
        [anon_sym_switch] = ACTIONS(1),
        [anon_sym_case] = ACTIONS(1),
        [anon_sym_typeid] = ACTIONS(1),
        [anon_sym_typeprefix] = ACTIONS(1),
        [anon_sym_import] = ACTIONS(1),
        [anon_sym_Object] = ACTIONS(1),
        [anon_sym_context] = ACTIONS(1),
        [sym_value_base_type] = ACTIONS(1),
        [anon_sym_component] = ACTIONS(1),
        [anon_sym_provides] = ACTIONS(1),
        [anon_sym_uses] = ACTIONS(1),
        [anon_sym_multiple] = ACTIONS(1),
        [anon_sym_home] = ACTIONS(1),
        [anon_sym_manages] = ACTIONS(1),
        [anon_sym_emits] = ACTIONS(1),
        [anon_sym_publishes] = ACTIONS(1),
        [anon_sym_consumes] = ACTIONS(1),
        [anon_sym_primarykey] = ACTIONS(1),
        [anon_sym_finder] = ACTIONS(1),
        [anon_sym_port] = ACTIONS(1),
        [anon_sym_mirrorport] = ACTIONS(1),
        [anon_sym_connector] = ACTIONS(1),
        [anon_sym_native] = ACTIONS(1),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [1] = {
        [sym_specification] = STATE(1150),
        [sym_preproc_define] = STATE(153),
        [sym_preproc_call] = STATE(153),
        [sym_preproc_include] = STATE(153),
        [sym_except_dcl] = STATE(1149),
        [sym_interface_dcl] = STATE(1149),
        [sym_interface_kind] = STATE(1146),
        [sym_interface_forward_dcl] = STATE(1145),
        [sym_interface_def] = STATE(1145),
        [sym_interface_header] = STATE(1142),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_dcl] = STATE(1149),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_template_module_dcl] = STATE(1149),
        [sym_template_module_inst] = STATE(1149),
        [sym_value_dcl] = STATE(1149),
        [sym_value_def] = STATE(1112),
        [sym_value_kind] = STATE(1110),
        [sym_value_header] = STATE(1109),
        [sym_value_forward_dcl] = STATE(1112),
        [sym_typedef_dcl] = STATE(1108),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_type_id_dcl] = STATE(1149),
        [sym_type_prefix_dcl] = STATE(1149),
        [sym_import_dcl] = STATE(1149),
        [sym_value_box_def] = STATE(1112),
        [sym_value_abs_def] = STATE(1112),
        [sym_component_dcl] = STATE(1149),
        [sym_component_forward_dcl] = STATE(1077),
        [sym_component_def] = STATE(1077),
        [sym_component_header] = STATE(1076),
        [sym_home_dcl] = STATE(1149),
        [sym_home_header] = STATE(1075),
        [sym_event_dcl] = STATE(1149),
        [sym_event_forward_dcl] = STATE(1073),
        [sym_event_abs_def] = STATE(1073),
        [sym_event_def] = STATE(1073),
        [sym_event_header] = STATE(1045),
        [sym_porttype_dcl] = STATE(1149),
        [sym_porttype_forward_dcl] = STATE(1041),
        [sym_porttype_def] = STATE(1041),
        [sym_connector_dcl] = STATE(1149),
        [sym_connector_header] = STATE(1039),
        [sym_definition] = STATE(153),
        [sym_type_dcl] = STATE(1149),
        [sym_constr_type_dcl] = STATE(1038),
        [sym_native_dcl] = STATE(1038),
        [sym_module_dcl] = STATE(1149),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_const_dcl] = STATE(1149),
        [sym_comment] = STATE(1),
        [aux_sym_specification_repeat1] = STATE(23),
        [aux_sym_interface_def_repeat1] = STATE(222),
        [ts_builtin_sym_end] = ACTIONS(7),
        [anon_sym_POUNDdefine] = ACTIONS(9),
        [sym_preproc_directive] = ACTIONS(11),
        [aux_sym_preproc_include_token1] = ACTIONS(13),
        [anon_sym_exception] = ACTIONS(15),
        [anon_sym_local] = ACTIONS(17),
        [anon_sym_abstract] = ACTIONS(19),
        [anon_sym_interface] = ACTIONS(21),
        [anon_sym_bitset] = ACTIONS(23),
        [anon_sym_bitmask] = ACTIONS(25),
        [anon_sym_ATannotation] = ACTIONS(27),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_module] = ACTIONS(33),
        [anon_sym_valuetype] = ACTIONS(35),
        [anon_sym_eventtype] = ACTIONS(37),
        [anon_sym_struct] = ACTIONS(39),
        [anon_sym_union] = ACTIONS(41),
        [anon_sym_enum] = ACTIONS(43),
        [anon_sym_const] = ACTIONS(45),
        [anon_sym_custom] = ACTIONS(47),
        [anon_sym_typedef] = ACTIONS(49),
        [anon_sym_ATignore_literal_names] = ACTIONS(51),
        [anon_sym_typeid] = ACTIONS(53),
        [anon_sym_typeprefix] = ACTIONS(55),
        [anon_sym_import] = ACTIONS(57),
        [anon_sym_component] = ACTIONS(59),
        [anon_sym_home] = ACTIONS(61),
        [anon_sym_porttype] = ACTIONS(63),
        [anon_sym_connector] = ACTIONS(65),
        [anon_sym_native] = ACTIONS(67),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [2] = {
        [sym_signed_short_int] = STATE(370),
        [sym_signed_long_int] = STATE(370),
        [sym_signed_longlong_int] = STATE(370),
        [sym_unsigned_int] = STATE(375),
        [sym_integer_type] = STATE(439),
        [sym_signed_int] = STATE(375),
        [sym_unsigned_short_int] = STATE(366),
        [sym_unsigned_long_int] = STATE(366),
        [sym_unsigned_longlong_int] = STATE(366),
        [sym_floating_pt_type] = STATE(439),
        [sym_char_type] = STATE(439),
        [sym_scoped_name] = STATE(376),
        [sym_string_type] = STATE(435),
        [sym_type_spec] = STATE(874),
        [sym_simple_type_spec] = STATE(388),
        [sym_base_type_spec] = STATE(433),
        [sym_any_type] = STATE(439),
        [sym_fixed_pt_type] = STATE(435),
        [sym_template_type_spec] = STATE(388),
        [sym_sequence_type] = STATE(435),
        [sym_map_type] = STATE(435),
        [sym_except_dcl] = STATE(1043),
        [sym_export] = STATE(53),
        [sym_op_dcl] = STATE(538),
        [sym_op_type_spec] = STATE(856),
        [sym_attr_dcl] = STATE(1043),
        [sym_readonly_attr_spec] = STATE(843),
        [sym_attr_spec] = STATE(843),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_value_dcl] = STATE(1043),
        [sym_value_def] = STATE(1112),
        [sym_value_kind] = STATE(1110),
        [sym_value_header] = STATE(1109),
        [sym_value_element] = STATE(56),
        [sym_state_member] = STATE(53),
        [sym_init_dcl] = STATE(53),
        [sym_value_forward_dcl] = STATE(1112),
        [sym_typedef_dcl] = STATE(1038),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_type_id_dcl] = STATE(1043),
        [sym_import_dcl] = STATE(1043),
        [sym_object_type] = STATE(439),
        [sym_op_oneway_dcl] = STATE(538),
        [sym_op_with_context] = STATE(1043),
        [sym_value_box_def] = STATE(1112),
        [sym_value_abs_def] = STATE(1112),
        [sym_type_dcl] = STATE(1043),
        [sym_constr_type_dcl] = STATE(1038),
        [sym_native_dcl] = STATE(1038),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_const_dcl] = STATE(1043),
        [sym_comment] = STATE(2),
        [aux_sym_interface_def_repeat1] = STATE(277),
        [aux_sym_value_def_repeat1] = STATE(7),
        [anon_sym_short] = ACTIONS(69),
        [anon_sym_int16] = ACTIONS(69),
        [anon_sym_long] = ACTIONS(71),
        [anon_sym_int32] = ACTIONS(71),
        [anon_sym_longlong] = ACTIONS(73),
        [anon_sym_int64] = ACTIONS(75),
        [sym_unsigned_tiny_int] = ACTIONS(77),
        [sym_boolean_type] = ACTIONS(79),
        [anon_sym_fixed] = ACTIONS(81),
        [sym_octet_type] = ACTIONS(79),
        [sym_signed_tiny_int] = ACTIONS(83),
        [anon_sym_unsignedshort] = ACTIONS(85),
        [anon_sym_uint16] = ACTIONS(87),
        [anon_sym_unsignedlong] = ACTIONS(89),
        [anon_sym_uint32] = ACTIONS(89),
        [anon_sym_unsignedlonglong] = ACTIONS(91),
        [anon_sym_uint64] = ACTIONS(93),
        [anon_sym_float] = ACTIONS(95),
        [anon_sym_double] = ACTIONS(95),
        [anon_sym_longdouble] = ACTIONS(97),
        [anon_sym_char] = ACTIONS(99),
        [anon_sym_wchar] = ACTIONS(99),
        [anon_sym_COLON_COLON] = ACTIONS(101),
        [anon_sym_string] = ACTIONS(103),
        [anon_sym_wstring] = ACTIONS(103),
        [anon_sym_any] = ACTIONS(105),
        [anon_sym_sequence] = ACTIONS(107),
        [anon_sym_map] = ACTIONS(109),
        [anon_sym_exception] = ACTIONS(111),
        [anon_sym_RBRACE] = ACTIONS(113),
        [anon_sym_abstract] = ACTIONS(115),
        [anon_sym_void] = ACTIONS(117),
        [anon_sym_readonly] = ACTIONS(119),
        [anon_sym_attribute] = ACTIONS(121),
        [anon_sym_bitset] = ACTIONS(123),
        [anon_sym_bitmask] = ACTIONS(125),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_oneway] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_public] = ACTIONS(141),
        [anon_sym_private] = ACTIONS(141),
        [anon_sym_factory] = ACTIONS(143),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_ATignore_literal_names] = ACTIONS(51),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [sym_value_base_type] = ACTIONS(79),
        [anon_sym_native] = ACTIONS(153),
        [sym_identifier] = ACTIONS(155),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [3] = {
        [sym_signed_short_int] = STATE(370),
        [sym_signed_long_int] = STATE(370),
        [sym_signed_longlong_int] = STATE(370),
        [sym_unsigned_int] = STATE(375),
        [sym_integer_type] = STATE(439),
        [sym_signed_int] = STATE(375),
        [sym_unsigned_short_int] = STATE(366),
        [sym_unsigned_long_int] = STATE(366),
        [sym_unsigned_longlong_int] = STATE(366),
        [sym_floating_pt_type] = STATE(439),
        [sym_char_type] = STATE(439),
        [sym_scoped_name] = STATE(376),
        [sym_string_type] = STATE(435),
        [sym_type_spec] = STATE(874),
        [sym_simple_type_spec] = STATE(388),
        [sym_base_type_spec] = STATE(433),
        [sym_any_type] = STATE(439),
        [sym_fixed_pt_type] = STATE(435),
        [sym_template_type_spec] = STATE(388),
        [sym_sequence_type] = STATE(435),
        [sym_map_type] = STATE(435),
        [sym_except_dcl] = STATE(1043),
        [sym_export] = STATE(53),
        [sym_op_dcl] = STATE(538),
        [sym_op_type_spec] = STATE(856),
        [sym_attr_dcl] = STATE(1043),
        [sym_readonly_attr_spec] = STATE(843),
        [sym_attr_spec] = STATE(843),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_value_dcl] = STATE(1043),
        [sym_value_def] = STATE(1112),
        [sym_value_kind] = STATE(1110),
        [sym_value_header] = STATE(1109),
        [sym_value_element] = STATE(56),
        [sym_state_member] = STATE(53),
        [sym_init_dcl] = STATE(53),
        [sym_value_forward_dcl] = STATE(1112),
        [sym_typedef_dcl] = STATE(1038),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_type_id_dcl] = STATE(1043),
        [sym_import_dcl] = STATE(1043),
        [sym_object_type] = STATE(439),
        [sym_op_oneway_dcl] = STATE(538),
        [sym_op_with_context] = STATE(1043),
        [sym_value_box_def] = STATE(1112),
        [sym_value_abs_def] = STATE(1112),
        [sym_type_dcl] = STATE(1043),
        [sym_constr_type_dcl] = STATE(1038),
        [sym_native_dcl] = STATE(1038),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_const_dcl] = STATE(1043),
        [sym_comment] = STATE(3),
        [aux_sym_interface_def_repeat1] = STATE(277),
        [aux_sym_value_def_repeat1] = STATE(6),
        [anon_sym_short] = ACTIONS(69),
        [anon_sym_int16] = ACTIONS(69),
        [anon_sym_long] = ACTIONS(71),
        [anon_sym_int32] = ACTIONS(71),
        [anon_sym_longlong] = ACTIONS(73),
        [anon_sym_int64] = ACTIONS(75),
        [sym_unsigned_tiny_int] = ACTIONS(77),
        [sym_boolean_type] = ACTIONS(79),
        [anon_sym_fixed] = ACTIONS(81),
        [sym_octet_type] = ACTIONS(79),
        [sym_signed_tiny_int] = ACTIONS(83),
        [anon_sym_unsignedshort] = ACTIONS(85),
        [anon_sym_uint16] = ACTIONS(87),
        [anon_sym_unsignedlong] = ACTIONS(89),
        [anon_sym_uint32] = ACTIONS(89),
        [anon_sym_unsignedlonglong] = ACTIONS(91),
        [anon_sym_uint64] = ACTIONS(93),
        [anon_sym_float] = ACTIONS(95),
        [anon_sym_double] = ACTIONS(95),
        [anon_sym_longdouble] = ACTIONS(97),
        [anon_sym_char] = ACTIONS(99),
        [anon_sym_wchar] = ACTIONS(99),
        [anon_sym_COLON_COLON] = ACTIONS(101),
        [anon_sym_string] = ACTIONS(103),
        [anon_sym_wstring] = ACTIONS(103),
        [anon_sym_any] = ACTIONS(105),
        [anon_sym_sequence] = ACTIONS(107),
        [anon_sym_map] = ACTIONS(109),
        [anon_sym_exception] = ACTIONS(111),
        [anon_sym_RBRACE] = ACTIONS(157),
        [anon_sym_abstract] = ACTIONS(115),
        [anon_sym_void] = ACTIONS(117),
        [anon_sym_readonly] = ACTIONS(119),
        [anon_sym_attribute] = ACTIONS(121),
        [anon_sym_bitset] = ACTIONS(123),
        [anon_sym_bitmask] = ACTIONS(125),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_oneway] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_public] = ACTIONS(141),
        [anon_sym_private] = ACTIONS(141),
        [anon_sym_factory] = ACTIONS(143),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_ATignore_literal_names] = ACTIONS(51),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [sym_value_base_type] = ACTIONS(79),
        [anon_sym_native] = ACTIONS(153),
        [sym_identifier] = ACTIONS(155),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [4] = {
        [sym_signed_short_int] = STATE(370),
        [sym_signed_long_int] = STATE(370),
        [sym_signed_longlong_int] = STATE(370),
        [sym_unsigned_int] = STATE(375),
        [sym_integer_type] = STATE(439),
        [sym_signed_int] = STATE(375),
        [sym_unsigned_short_int] = STATE(366),
        [sym_unsigned_long_int] = STATE(366),
        [sym_unsigned_longlong_int] = STATE(366),
        [sym_floating_pt_type] = STATE(439),
        [sym_char_type] = STATE(439),
        [sym_scoped_name] = STATE(376),
        [sym_string_type] = STATE(435),
        [sym_type_spec] = STATE(874),
        [sym_simple_type_spec] = STATE(388),
        [sym_base_type_spec] = STATE(433),
        [sym_any_type] = STATE(439),
        [sym_fixed_pt_type] = STATE(435),
        [sym_template_type_spec] = STATE(388),
        [sym_sequence_type] = STATE(435),
        [sym_map_type] = STATE(435),
        [sym_except_dcl] = STATE(1080),
        [sym_export] = STATE(63),
        [sym_op_dcl] = STATE(532),
        [sym_op_type_spec] = STATE(856),
        [sym_attr_dcl] = STATE(1080),
        [sym_readonly_attr_spec] = STATE(843),
        [sym_attr_spec] = STATE(843),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_value_dcl] = STATE(1080),
        [sym_value_def] = STATE(1112),
        [sym_value_kind] = STATE(1110),
        [sym_value_header] = STATE(1109),
        [sym_value_forward_dcl] = STATE(1112),
        [sym_typedef_dcl] = STATE(1038),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_type_id_dcl] = STATE(1080),
        [sym_import_dcl] = STATE(1080),
        [sym_object_type] = STATE(439),
        [sym_op_oneway_dcl] = STATE(532),
        [sym_op_with_context] = STATE(1080),
        [sym_value_box_def] = STATE(1112),
        [sym_value_abs_def] = STATE(1112),
        [sym_home_body] = STATE(1161),
        [sym_home_export] = STATE(64),
        [sym_factory_dcl] = STATE(1164),
        [sym_finder_dcl] = STATE(1164),
        [sym_type_dcl] = STATE(1080),
        [sym_constr_type_dcl] = STATE(1038),
        [sym_native_dcl] = STATE(1038),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_const_dcl] = STATE(1080),
        [sym_comment] = STATE(4),
        [aux_sym_interface_def_repeat1] = STATE(277),
        [aux_sym_home_body_repeat1] = STATE(9),
        [anon_sym_short] = ACTIONS(69),
        [anon_sym_int16] = ACTIONS(69),
        [anon_sym_long] = ACTIONS(71),
        [anon_sym_int32] = ACTIONS(71),
        [anon_sym_longlong] = ACTIONS(73),
        [anon_sym_int64] = ACTIONS(75),
        [sym_unsigned_tiny_int] = ACTIONS(77),
        [sym_boolean_type] = ACTIONS(79),
        [anon_sym_fixed] = ACTIONS(81),
        [sym_octet_type] = ACTIONS(79),
        [sym_signed_tiny_int] = ACTIONS(83),
        [anon_sym_unsignedshort] = ACTIONS(85),
        [anon_sym_uint16] = ACTIONS(87),
        [anon_sym_unsignedlong] = ACTIONS(89),
        [anon_sym_uint32] = ACTIONS(89),
        [anon_sym_unsignedlonglong] = ACTIONS(91),
        [anon_sym_uint64] = ACTIONS(93),
        [anon_sym_float] = ACTIONS(95),
        [anon_sym_double] = ACTIONS(95),
        [anon_sym_longdouble] = ACTIONS(97),
        [anon_sym_char] = ACTIONS(99),
        [anon_sym_wchar] = ACTIONS(99),
        [anon_sym_COLON_COLON] = ACTIONS(101),
        [anon_sym_string] = ACTIONS(103),
        [anon_sym_wstring] = ACTIONS(103),
        [anon_sym_any] = ACTIONS(105),
        [anon_sym_sequence] = ACTIONS(107),
        [anon_sym_map] = ACTIONS(109),
        [anon_sym_exception] = ACTIONS(111),
        [anon_sym_RBRACE] = ACTIONS(159),
        [anon_sym_abstract] = ACTIONS(115),
        [anon_sym_void] = ACTIONS(117),
        [anon_sym_readonly] = ACTIONS(119),
        [anon_sym_attribute] = ACTIONS(121),
        [anon_sym_bitset] = ACTIONS(123),
        [anon_sym_bitmask] = ACTIONS(125),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_oneway] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_factory] = ACTIONS(161),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_ATignore_literal_names] = ACTIONS(51),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [sym_value_base_type] = ACTIONS(79),
        [anon_sym_finder] = ACTIONS(163),
        [anon_sym_native] = ACTIONS(153),
        [sym_identifier] = ACTIONS(155),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [5] = {
        [sym_signed_short_int] = STATE(370),
        [sym_signed_long_int] = STATE(370),
        [sym_signed_longlong_int] = STATE(370),
        [sym_unsigned_int] = STATE(375),
        [sym_integer_type] = STATE(439),
        [sym_signed_int] = STATE(375),
        [sym_unsigned_short_int] = STATE(366),
        [sym_unsigned_long_int] = STATE(366),
        [sym_unsigned_longlong_int] = STATE(366),
        [sym_floating_pt_type] = STATE(439),
        [sym_char_type] = STATE(439),
        [sym_scoped_name] = STATE(376),
        [sym_string_type] = STATE(435),
        [sym_type_spec] = STATE(874),
        [sym_simple_type_spec] = STATE(388),
        [sym_base_type_spec] = STATE(433),
        [sym_any_type] = STATE(439),
        [sym_fixed_pt_type] = STATE(435),
        [sym_template_type_spec] = STATE(388),
        [sym_sequence_type] = STATE(435),
        [sym_map_type] = STATE(435),
        [sym_except_dcl] = STATE(1043),
        [sym_export] = STATE(53),
        [sym_op_dcl] = STATE(538),
        [sym_op_type_spec] = STATE(856),
        [sym_attr_dcl] = STATE(1043),
        [sym_readonly_attr_spec] = STATE(843),
        [sym_attr_spec] = STATE(843),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_value_dcl] = STATE(1043),
        [sym_value_def] = STATE(1112),
        [sym_value_kind] = STATE(1110),
        [sym_value_header] = STATE(1109),
        [sym_value_element] = STATE(56),
        [sym_state_member] = STATE(53),
        [sym_init_dcl] = STATE(53),
        [sym_value_forward_dcl] = STATE(1112),
        [sym_typedef_dcl] = STATE(1038),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_type_id_dcl] = STATE(1043),
        [sym_import_dcl] = STATE(1043),
        [sym_object_type] = STATE(439),
        [sym_op_oneway_dcl] = STATE(538),
        [sym_op_with_context] = STATE(1043),
        [sym_value_box_def] = STATE(1112),
        [sym_value_abs_def] = STATE(1112),
        [sym_type_dcl] = STATE(1043),
        [sym_constr_type_dcl] = STATE(1038),
        [sym_native_dcl] = STATE(1038),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_const_dcl] = STATE(1043),
        [sym_comment] = STATE(5),
        [aux_sym_interface_def_repeat1] = STATE(277),
        [aux_sym_value_def_repeat1] = STATE(2),
        [anon_sym_short] = ACTIONS(69),
        [anon_sym_int16] = ACTIONS(69),
        [anon_sym_long] = ACTIONS(71),
        [anon_sym_int32] = ACTIONS(71),
        [anon_sym_longlong] = ACTIONS(73),
        [anon_sym_int64] = ACTIONS(75),
        [sym_unsigned_tiny_int] = ACTIONS(77),
        [sym_boolean_type] = ACTIONS(79),
        [anon_sym_fixed] = ACTIONS(81),
        [sym_octet_type] = ACTIONS(79),
        [sym_signed_tiny_int] = ACTIONS(83),
        [anon_sym_unsignedshort] = ACTIONS(85),
        [anon_sym_uint16] = ACTIONS(87),
        [anon_sym_unsignedlong] = ACTIONS(89),
        [anon_sym_uint32] = ACTIONS(89),
        [anon_sym_unsignedlonglong] = ACTIONS(91),
        [anon_sym_uint64] = ACTIONS(93),
        [anon_sym_float] = ACTIONS(95),
        [anon_sym_double] = ACTIONS(95),
        [anon_sym_longdouble] = ACTIONS(97),
        [anon_sym_char] = ACTIONS(99),
        [anon_sym_wchar] = ACTIONS(99),
        [anon_sym_COLON_COLON] = ACTIONS(101),
        [anon_sym_string] = ACTIONS(103),
        [anon_sym_wstring] = ACTIONS(103),
        [anon_sym_any] = ACTIONS(105),
        [anon_sym_sequence] = ACTIONS(107),
        [anon_sym_map] = ACTIONS(109),
        [anon_sym_exception] = ACTIONS(111),
        [anon_sym_RBRACE] = ACTIONS(165),
        [anon_sym_abstract] = ACTIONS(115),
        [anon_sym_void] = ACTIONS(117),
        [anon_sym_readonly] = ACTIONS(119),
        [anon_sym_attribute] = ACTIONS(121),
        [anon_sym_bitset] = ACTIONS(123),
        [anon_sym_bitmask] = ACTIONS(125),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_oneway] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_public] = ACTIONS(141),
        [anon_sym_private] = ACTIONS(141),
        [anon_sym_factory] = ACTIONS(143),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_ATignore_literal_names] = ACTIONS(51),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [sym_value_base_type] = ACTIONS(79),
        [anon_sym_native] = ACTIONS(153),
        [sym_identifier] = ACTIONS(155),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [6] = {
        [sym_signed_short_int] = STATE(370),
        [sym_signed_long_int] = STATE(370),
        [sym_signed_longlong_int] = STATE(370),
        [sym_unsigned_int] = STATE(375),
        [sym_integer_type] = STATE(439),
        [sym_signed_int] = STATE(375),
        [sym_unsigned_short_int] = STATE(366),
        [sym_unsigned_long_int] = STATE(366),
        [sym_unsigned_longlong_int] = STATE(366),
        [sym_floating_pt_type] = STATE(439),
        [sym_char_type] = STATE(439),
        [sym_scoped_name] = STATE(376),
        [sym_string_type] = STATE(435),
        [sym_type_spec] = STATE(874),
        [sym_simple_type_spec] = STATE(388),
        [sym_base_type_spec] = STATE(433),
        [sym_any_type] = STATE(439),
        [sym_fixed_pt_type] = STATE(435),
        [sym_template_type_spec] = STATE(388),
        [sym_sequence_type] = STATE(435),
        [sym_map_type] = STATE(435),
        [sym_except_dcl] = STATE(1043),
        [sym_export] = STATE(53),
        [sym_op_dcl] = STATE(538),
        [sym_op_type_spec] = STATE(856),
        [sym_attr_dcl] = STATE(1043),
        [sym_readonly_attr_spec] = STATE(843),
        [sym_attr_spec] = STATE(843),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_value_dcl] = STATE(1043),
        [sym_value_def] = STATE(1112),
        [sym_value_kind] = STATE(1110),
        [sym_value_header] = STATE(1109),
        [sym_value_element] = STATE(56),
        [sym_state_member] = STATE(53),
        [sym_init_dcl] = STATE(53),
        [sym_value_forward_dcl] = STATE(1112),
        [sym_typedef_dcl] = STATE(1038),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_type_id_dcl] = STATE(1043),
        [sym_import_dcl] = STATE(1043),
        [sym_object_type] = STATE(439),
        [sym_op_oneway_dcl] = STATE(538),
        [sym_op_with_context] = STATE(1043),
        [sym_value_box_def] = STATE(1112),
        [sym_value_abs_def] = STATE(1112),
        [sym_type_dcl] = STATE(1043),
        [sym_constr_type_dcl] = STATE(1038),
        [sym_native_dcl] = STATE(1038),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_const_dcl] = STATE(1043),
        [sym_comment] = STATE(6),
        [aux_sym_interface_def_repeat1] = STATE(277),
        [aux_sym_value_def_repeat1] = STATE(7),
        [anon_sym_short] = ACTIONS(69),
        [anon_sym_int16] = ACTIONS(69),
        [anon_sym_long] = ACTIONS(71),
        [anon_sym_int32] = ACTIONS(71),
        [anon_sym_longlong] = ACTIONS(73),
        [anon_sym_int64] = ACTIONS(75),
        [sym_unsigned_tiny_int] = ACTIONS(77),
        [sym_boolean_type] = ACTIONS(79),
        [anon_sym_fixed] = ACTIONS(81),
        [sym_octet_type] = ACTIONS(79),
        [sym_signed_tiny_int] = ACTIONS(83),
        [anon_sym_unsignedshort] = ACTIONS(85),
        [anon_sym_uint16] = ACTIONS(87),
        [anon_sym_unsignedlong] = ACTIONS(89),
        [anon_sym_uint32] = ACTIONS(89),
        [anon_sym_unsignedlonglong] = ACTIONS(91),
        [anon_sym_uint64] = ACTIONS(93),
        [anon_sym_float] = ACTIONS(95),
        [anon_sym_double] = ACTIONS(95),
        [anon_sym_longdouble] = ACTIONS(97),
        [anon_sym_char] = ACTIONS(99),
        [anon_sym_wchar] = ACTIONS(99),
        [anon_sym_COLON_COLON] = ACTIONS(101),
        [anon_sym_string] = ACTIONS(103),
        [anon_sym_wstring] = ACTIONS(103),
        [anon_sym_any] = ACTIONS(105),
        [anon_sym_sequence] = ACTIONS(107),
        [anon_sym_map] = ACTIONS(109),
        [anon_sym_exception] = ACTIONS(111),
        [anon_sym_RBRACE] = ACTIONS(167),
        [anon_sym_abstract] = ACTIONS(115),
        [anon_sym_void] = ACTIONS(117),
        [anon_sym_readonly] = ACTIONS(119),
        [anon_sym_attribute] = ACTIONS(121),
        [anon_sym_bitset] = ACTIONS(123),
        [anon_sym_bitmask] = ACTIONS(125),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_oneway] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_public] = ACTIONS(141),
        [anon_sym_private] = ACTIONS(141),
        [anon_sym_factory] = ACTIONS(143),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_ATignore_literal_names] = ACTIONS(51),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [sym_value_base_type] = ACTIONS(79),
        [anon_sym_native] = ACTIONS(153),
        [sym_identifier] = ACTIONS(155),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [7] = {
        [sym_signed_short_int] = STATE(370),
        [sym_signed_long_int] = STATE(370),
        [sym_signed_longlong_int] = STATE(370),
        [sym_unsigned_int] = STATE(375),
        [sym_integer_type] = STATE(439),
        [sym_signed_int] = STATE(375),
        [sym_unsigned_short_int] = STATE(366),
        [sym_unsigned_long_int] = STATE(366),
        [sym_unsigned_longlong_int] = STATE(366),
        [sym_floating_pt_type] = STATE(439),
        [sym_char_type] = STATE(439),
        [sym_scoped_name] = STATE(376),
        [sym_string_type] = STATE(435),
        [sym_type_spec] = STATE(874),
        [sym_simple_type_spec] = STATE(388),
        [sym_base_type_spec] = STATE(433),
        [sym_any_type] = STATE(439),
        [sym_fixed_pt_type] = STATE(435),
        [sym_template_type_spec] = STATE(388),
        [sym_sequence_type] = STATE(435),
        [sym_map_type] = STATE(435),
        [sym_except_dcl] = STATE(1043),
        [sym_export] = STATE(53),
        [sym_op_dcl] = STATE(538),
        [sym_op_type_spec] = STATE(856),
        [sym_attr_dcl] = STATE(1043),
        [sym_readonly_attr_spec] = STATE(843),
        [sym_attr_spec] = STATE(843),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_value_dcl] = STATE(1043),
        [sym_value_def] = STATE(1112),
        [sym_value_kind] = STATE(1110),
        [sym_value_header] = STATE(1109),
        [sym_value_element] = STATE(56),
        [sym_state_member] = STATE(53),
        [sym_init_dcl] = STATE(53),
        [sym_value_forward_dcl] = STATE(1112),
        [sym_typedef_dcl] = STATE(1038),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_type_id_dcl] = STATE(1043),
        [sym_import_dcl] = STATE(1043),
        [sym_object_type] = STATE(439),
        [sym_op_oneway_dcl] = STATE(538),
        [sym_op_with_context] = STATE(1043),
        [sym_value_box_def] = STATE(1112),
        [sym_value_abs_def] = STATE(1112),
        [sym_type_dcl] = STATE(1043),
        [sym_constr_type_dcl] = STATE(1038),
        [sym_native_dcl] = STATE(1038),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_const_dcl] = STATE(1043),
        [sym_comment] = STATE(7),
        [aux_sym_interface_def_repeat1] = STATE(277),
        [aux_sym_value_def_repeat1] = STATE(7),
        [anon_sym_short] = ACTIONS(169),
        [anon_sym_int16] = ACTIONS(169),
        [anon_sym_long] = ACTIONS(172),
        [anon_sym_int32] = ACTIONS(172),
        [anon_sym_longlong] = ACTIONS(175),
        [anon_sym_int64] = ACTIONS(178),
        [sym_unsigned_tiny_int] = ACTIONS(181),
        [sym_boolean_type] = ACTIONS(184),
        [anon_sym_fixed] = ACTIONS(187),
        [sym_octet_type] = ACTIONS(184),
        [sym_signed_tiny_int] = ACTIONS(190),
        [anon_sym_unsignedshort] = ACTIONS(193),
        [anon_sym_uint16] = ACTIONS(196),
        [anon_sym_unsignedlong] = ACTIONS(199),
        [anon_sym_uint32] = ACTIONS(199),
        [anon_sym_unsignedlonglong] = ACTIONS(202),
        [anon_sym_uint64] = ACTIONS(205),
        [anon_sym_float] = ACTIONS(208),
        [anon_sym_double] = ACTIONS(208),
        [anon_sym_longdouble] = ACTIONS(211),
        [anon_sym_char] = ACTIONS(214),
        [anon_sym_wchar] = ACTIONS(214),
        [anon_sym_COLON_COLON] = ACTIONS(217),
        [anon_sym_string] = ACTIONS(220),
        [anon_sym_wstring] = ACTIONS(220),
        [anon_sym_any] = ACTIONS(223),
        [anon_sym_sequence] = ACTIONS(226),
        [anon_sym_map] = ACTIONS(229),
        [anon_sym_exception] = ACTIONS(232),
        [anon_sym_RBRACE] = ACTIONS(235),
        [anon_sym_abstract] = ACTIONS(237),
        [anon_sym_void] = ACTIONS(240),
        [anon_sym_readonly] = ACTIONS(243),
        [anon_sym_attribute] = ACTIONS(246),
        [anon_sym_bitset] = ACTIONS(249),
        [anon_sym_bitmask] = ACTIONS(252),
        [anon_sym_AT] = ACTIONS(255),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(258),
        [anon_sym_oneway] = ACTIONS(261),
        [anon_sym_valuetype] = ACTIONS(264),
        [anon_sym_struct] = ACTIONS(267),
        [anon_sym_union] = ACTIONS(270),
        [anon_sym_enum] = ACTIONS(273),
        [anon_sym_const] = ACTIONS(276),
        [anon_sym_custom] = ACTIONS(279),
        [anon_sym_public] = ACTIONS(282),
        [anon_sym_private] = ACTIONS(282),
        [anon_sym_factory] = ACTIONS(285),
        [anon_sym_typedef] = ACTIONS(288),
        [anon_sym_ATignore_literal_names] = ACTIONS(291),
        [anon_sym_typeid] = ACTIONS(294),
        [anon_sym_import] = ACTIONS(297),
        [anon_sym_Object] = ACTIONS(300),
        [sym_value_base_type] = ACTIONS(184),
        [anon_sym_native] = ACTIONS(303),
        [sym_identifier] = ACTIONS(306),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [8] = {
        [sym_signed_short_int] = STATE(370),
        [sym_signed_long_int] = STATE(370),
        [sym_signed_longlong_int] = STATE(370),
        [sym_unsigned_int] = STATE(375),
        [sym_integer_type] = STATE(439),
        [sym_signed_int] = STATE(375),
        [sym_unsigned_short_int] = STATE(366),
        [sym_unsigned_long_int] = STATE(366),
        [sym_unsigned_longlong_int] = STATE(366),
        [sym_floating_pt_type] = STATE(439),
        [sym_char_type] = STATE(439),
        [sym_scoped_name] = STATE(376),
        [sym_string_type] = STATE(435),
        [sym_type_spec] = STATE(874),
        [sym_simple_type_spec] = STATE(388),
        [sym_base_type_spec] = STATE(433),
        [sym_any_type] = STATE(439),
        [sym_fixed_pt_type] = STATE(435),
        [sym_template_type_spec] = STATE(388),
        [sym_sequence_type] = STATE(435),
        [sym_map_type] = STATE(435),
        [sym_except_dcl] = STATE(1080),
        [sym_export] = STATE(63),
        [sym_op_dcl] = STATE(532),
        [sym_op_type_spec] = STATE(856),
        [sym_attr_dcl] = STATE(1080),
        [sym_readonly_attr_spec] = STATE(843),
        [sym_attr_spec] = STATE(843),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_value_dcl] = STATE(1080),
        [sym_value_def] = STATE(1112),
        [sym_value_kind] = STATE(1110),
        [sym_value_header] = STATE(1109),
        [sym_value_forward_dcl] = STATE(1112),
        [sym_typedef_dcl] = STATE(1038),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_type_id_dcl] = STATE(1080),
        [sym_import_dcl] = STATE(1080),
        [sym_object_type] = STATE(439),
        [sym_op_oneway_dcl] = STATE(532),
        [sym_op_with_context] = STATE(1080),
        [sym_value_box_def] = STATE(1112),
        [sym_value_abs_def] = STATE(1112),
        [sym_home_export] = STATE(64),
        [sym_factory_dcl] = STATE(1164),
        [sym_finder_dcl] = STATE(1164),
        [sym_type_dcl] = STATE(1080),
        [sym_constr_type_dcl] = STATE(1038),
        [sym_native_dcl] = STATE(1038),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_const_dcl] = STATE(1080),
        [sym_comment] = STATE(8),
        [aux_sym_interface_def_repeat1] = STATE(277),
        [aux_sym_home_body_repeat1] = STATE(8),
        [anon_sym_short] = ACTIONS(309),
        [anon_sym_int16] = ACTIONS(309),
        [anon_sym_long] = ACTIONS(312),
        [anon_sym_int32] = ACTIONS(312),
        [anon_sym_longlong] = ACTIONS(315),
        [anon_sym_int64] = ACTIONS(318),
        [sym_unsigned_tiny_int] = ACTIONS(321),
        [sym_boolean_type] = ACTIONS(324),
        [anon_sym_fixed] = ACTIONS(327),
        [sym_octet_type] = ACTIONS(324),
        [sym_signed_tiny_int] = ACTIONS(330),
        [anon_sym_unsignedshort] = ACTIONS(333),
        [anon_sym_uint16] = ACTIONS(336),
        [anon_sym_unsignedlong] = ACTIONS(339),
        [anon_sym_uint32] = ACTIONS(339),
        [anon_sym_unsignedlonglong] = ACTIONS(342),
        [anon_sym_uint64] = ACTIONS(345),
        [anon_sym_float] = ACTIONS(348),
        [anon_sym_double] = ACTIONS(348),
        [anon_sym_longdouble] = ACTIONS(351),
        [anon_sym_char] = ACTIONS(354),
        [anon_sym_wchar] = ACTIONS(354),
        [anon_sym_COLON_COLON] = ACTIONS(357),
        [anon_sym_string] = ACTIONS(360),
        [anon_sym_wstring] = ACTIONS(360),
        [anon_sym_any] = ACTIONS(363),
        [anon_sym_sequence] = ACTIONS(366),
        [anon_sym_map] = ACTIONS(369),
        [anon_sym_exception] = ACTIONS(372),
        [anon_sym_RBRACE] = ACTIONS(375),
        [anon_sym_abstract] = ACTIONS(377),
        [anon_sym_void] = ACTIONS(380),
        [anon_sym_readonly] = ACTIONS(383),
        [anon_sym_attribute] = ACTIONS(386),
        [anon_sym_bitset] = ACTIONS(389),
        [anon_sym_bitmask] = ACTIONS(392),
        [anon_sym_AT] = ACTIONS(395),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(398),
        [anon_sym_oneway] = ACTIONS(401),
        [anon_sym_valuetype] = ACTIONS(404),
        [anon_sym_struct] = ACTIONS(407),
        [anon_sym_union] = ACTIONS(410),
        [anon_sym_enum] = ACTIONS(413),
        [anon_sym_const] = ACTIONS(416),
        [anon_sym_custom] = ACTIONS(419),
        [anon_sym_factory] = ACTIONS(422),
        [anon_sym_typedef] = ACTIONS(425),
        [anon_sym_ATignore_literal_names] = ACTIONS(428),
        [anon_sym_typeid] = ACTIONS(431),
        [anon_sym_import] = ACTIONS(434),
        [anon_sym_Object] = ACTIONS(437),
        [sym_value_base_type] = ACTIONS(324),
        [anon_sym_finder] = ACTIONS(440),
        [anon_sym_native] = ACTIONS(443),
        [sym_identifier] = ACTIONS(446),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [9] = {
        [sym_signed_short_int] = STATE(370),
        [sym_signed_long_int] = STATE(370),
        [sym_signed_longlong_int] = STATE(370),
        [sym_unsigned_int] = STATE(375),
        [sym_integer_type] = STATE(439),
        [sym_signed_int] = STATE(375),
        [sym_unsigned_short_int] = STATE(366),
        [sym_unsigned_long_int] = STATE(366),
        [sym_unsigned_longlong_int] = STATE(366),
        [sym_floating_pt_type] = STATE(439),
        [sym_char_type] = STATE(439),
        [sym_scoped_name] = STATE(376),
        [sym_string_type] = STATE(435),
        [sym_type_spec] = STATE(874),
        [sym_simple_type_spec] = STATE(388),
        [sym_base_type_spec] = STATE(433),
        [sym_any_type] = STATE(439),
        [sym_fixed_pt_type] = STATE(435),
        [sym_template_type_spec] = STATE(388),
        [sym_sequence_type] = STATE(435),
        [sym_map_type] = STATE(435),
        [sym_except_dcl] = STATE(1080),
        [sym_export] = STATE(63),
        [sym_op_dcl] = STATE(532),
        [sym_op_type_spec] = STATE(856),
        [sym_attr_dcl] = STATE(1080),
        [sym_readonly_attr_spec] = STATE(843),
        [sym_attr_spec] = STATE(843),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_value_dcl] = STATE(1080),
        [sym_value_def] = STATE(1112),
        [sym_value_kind] = STATE(1110),
        [sym_value_header] = STATE(1109),
        [sym_value_forward_dcl] = STATE(1112),
        [sym_typedef_dcl] = STATE(1038),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_type_id_dcl] = STATE(1080),
        [sym_import_dcl] = STATE(1080),
        [sym_object_type] = STATE(439),
        [sym_op_oneway_dcl] = STATE(532),
        [sym_op_with_context] = STATE(1080),
        [sym_value_box_def] = STATE(1112),
        [sym_value_abs_def] = STATE(1112),
        [sym_home_export] = STATE(64),
        [sym_factory_dcl] = STATE(1164),
        [sym_finder_dcl] = STATE(1164),
        [sym_type_dcl] = STATE(1080),
        [sym_constr_type_dcl] = STATE(1038),
        [sym_native_dcl] = STATE(1038),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_const_dcl] = STATE(1080),
        [sym_comment] = STATE(9),
        [aux_sym_interface_def_repeat1] = STATE(277),
        [aux_sym_home_body_repeat1] = STATE(8),
        [anon_sym_short] = ACTIONS(69),
        [anon_sym_int16] = ACTIONS(69),
        [anon_sym_long] = ACTIONS(71),
        [anon_sym_int32] = ACTIONS(71),
        [anon_sym_longlong] = ACTIONS(73),
        [anon_sym_int64] = ACTIONS(75),
        [sym_unsigned_tiny_int] = ACTIONS(77),
        [sym_boolean_type] = ACTIONS(79),
        [anon_sym_fixed] = ACTIONS(81),
        [sym_octet_type] = ACTIONS(79),
        [sym_signed_tiny_int] = ACTIONS(83),
        [anon_sym_unsignedshort] = ACTIONS(85),
        [anon_sym_uint16] = ACTIONS(87),
        [anon_sym_unsignedlong] = ACTIONS(89),
        [anon_sym_uint32] = ACTIONS(89),
        [anon_sym_unsignedlonglong] = ACTIONS(91),
        [anon_sym_uint64] = ACTIONS(93),
        [anon_sym_float] = ACTIONS(95),
        [anon_sym_double] = ACTIONS(95),
        [anon_sym_longdouble] = ACTIONS(97),
        [anon_sym_char] = ACTIONS(99),
        [anon_sym_wchar] = ACTIONS(99),
        [anon_sym_COLON_COLON] = ACTIONS(101),
        [anon_sym_string] = ACTIONS(103),
        [anon_sym_wstring] = ACTIONS(103),
        [anon_sym_any] = ACTIONS(105),
        [anon_sym_sequence] = ACTIONS(107),
        [anon_sym_map] = ACTIONS(109),
        [anon_sym_exception] = ACTIONS(111),
        [anon_sym_RBRACE] = ACTIONS(449),
        [anon_sym_abstract] = ACTIONS(115),
        [anon_sym_void] = ACTIONS(117),
        [anon_sym_readonly] = ACTIONS(119),
        [anon_sym_attribute] = ACTIONS(121),
        [anon_sym_bitset] = ACTIONS(123),
        [anon_sym_bitmask] = ACTIONS(125),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_oneway] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_factory] = ACTIONS(161),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_ATignore_literal_names] = ACTIONS(51),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [sym_value_base_type] = ACTIONS(79),
        [anon_sym_finder] = ACTIONS(163),
        [anon_sym_native] = ACTIONS(153),
        [sym_identifier] = ACTIONS(155),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [10] = {
        [sym_signed_short_int] = STATE(370),
        [sym_signed_long_int] = STATE(370),
        [sym_signed_longlong_int] = STATE(370),
        [sym_unsigned_int] = STATE(375),
        [sym_integer_type] = STATE(439),
        [sym_signed_int] = STATE(375),
        [sym_unsigned_short_int] = STATE(366),
        [sym_unsigned_long_int] = STATE(366),
        [sym_unsigned_longlong_int] = STATE(366),
        [sym_floating_pt_type] = STATE(439),
        [sym_char_type] = STATE(439),
        [sym_scoped_name] = STATE(376),
        [sym_string_type] = STATE(435),
        [sym_type_spec] = STATE(874),
        [sym_simple_type_spec] = STATE(388),
        [sym_base_type_spec] = STATE(433),
        [sym_any_type] = STATE(439),
        [sym_fixed_pt_type] = STATE(435),
        [sym_template_type_spec] = STATE(388),
        [sym_sequence_type] = STATE(435),
        [sym_map_type] = STATE(435),
        [sym_except_dcl] = STATE(849),
        [sym_interface_body] = STATE(1205),
        [sym_export] = STATE(71),
        [sym_op_dcl] = STATE(672),
        [sym_op_type_spec] = STATE(856),
        [sym_attr_dcl] = STATE(849),
        [sym_readonly_attr_spec] = STATE(843),
        [sym_attr_spec] = STATE(843),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_value_dcl] = STATE(849),
        [sym_value_def] = STATE(1112),
        [sym_value_kind] = STATE(1110),
        [sym_value_header] = STATE(1109),
        [sym_value_forward_dcl] = STATE(1112),
        [sym_typedef_dcl] = STATE(1038),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_type_id_dcl] = STATE(849),
        [sym_import_dcl] = STATE(849),
        [sym_object_type] = STATE(439),
        [sym_op_oneway_dcl] = STATE(672),
        [sym_op_with_context] = STATE(849),
        [sym_value_box_def] = STATE(1112),
        [sym_value_abs_def] = STATE(1112),
        [sym_type_dcl] = STATE(849),
        [sym_constr_type_dcl] = STATE(1038),
        [sym_native_dcl] = STATE(1038),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_const_dcl] = STATE(849),
        [sym_comment] = STATE(10),
        [aux_sym_interface_def_repeat1] = STATE(277),
        [aux_sym_interface_body_repeat1] = STATE(14),
        [anon_sym_short] = ACTIONS(69),
        [anon_sym_int16] = ACTIONS(69),
        [anon_sym_long] = ACTIONS(71),
        [anon_sym_int32] = ACTIONS(71),
        [anon_sym_longlong] = ACTIONS(73),
        [anon_sym_int64] = ACTIONS(75),
        [sym_unsigned_tiny_int] = ACTIONS(77),
        [sym_boolean_type] = ACTIONS(79),
        [anon_sym_fixed] = ACTIONS(81),
        [sym_octet_type] = ACTIONS(79),
        [sym_signed_tiny_int] = ACTIONS(83),
        [anon_sym_unsignedshort] = ACTIONS(85),
        [anon_sym_uint16] = ACTIONS(87),
        [anon_sym_unsignedlong] = ACTIONS(89),
        [anon_sym_uint32] = ACTIONS(89),
        [anon_sym_unsignedlonglong] = ACTIONS(91),
        [anon_sym_uint64] = ACTIONS(93),
        [anon_sym_float] = ACTIONS(95),
        [anon_sym_double] = ACTIONS(95),
        [anon_sym_longdouble] = ACTIONS(97),
        [anon_sym_char] = ACTIONS(99),
        [anon_sym_wchar] = ACTIONS(99),
        [anon_sym_COLON_COLON] = ACTIONS(101),
        [anon_sym_string] = ACTIONS(103),
        [anon_sym_wstring] = ACTIONS(103),
        [anon_sym_any] = ACTIONS(105),
        [anon_sym_sequence] = ACTIONS(107),
        [anon_sym_map] = ACTIONS(109),
        [anon_sym_exception] = ACTIONS(111),
        [anon_sym_RBRACE] = ACTIONS(451),
        [anon_sym_abstract] = ACTIONS(115),
        [anon_sym_void] = ACTIONS(117),
        [anon_sym_readonly] = ACTIONS(119),
        [anon_sym_attribute] = ACTIONS(121),
        [anon_sym_bitset] = ACTIONS(123),
        [anon_sym_bitmask] = ACTIONS(125),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_oneway] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_ATignore_literal_names] = ACTIONS(51),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [sym_value_base_type] = ACTIONS(79),
        [anon_sym_native] = ACTIONS(153),
        [sym_identifier] = ACTIONS(155),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [11] = {
        [sym_signed_short_int] = STATE(370),
        [sym_signed_long_int] = STATE(370),
        [sym_signed_longlong_int] = STATE(370),
        [sym_unsigned_int] = STATE(375),
        [sym_integer_type] = STATE(439),
        [sym_signed_int] = STATE(375),
        [sym_unsigned_short_int] = STATE(366),
        [sym_unsigned_long_int] = STATE(366),
        [sym_unsigned_longlong_int] = STATE(366),
        [sym_floating_pt_type] = STATE(439),
        [sym_char_type] = STATE(439),
        [sym_scoped_name] = STATE(376),
        [sym_string_type] = STATE(435),
        [sym_type_spec] = STATE(874),
        [sym_simple_type_spec] = STATE(388),
        [sym_base_type_spec] = STATE(433),
        [sym_any_type] = STATE(439),
        [sym_fixed_pt_type] = STATE(435),
        [sym_template_type_spec] = STATE(388),
        [sym_sequence_type] = STATE(435),
        [sym_map_type] = STATE(435),
        [sym_except_dcl] = STATE(849),
        [sym_interface_body] = STATE(848),
        [sym_export] = STATE(71),
        [sym_op_dcl] = STATE(672),
        [sym_op_type_spec] = STATE(856),
        [sym_attr_dcl] = STATE(849),
        [sym_readonly_attr_spec] = STATE(843),
        [sym_attr_spec] = STATE(843),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_value_dcl] = STATE(849),
        [sym_value_def] = STATE(1112),
        [sym_value_kind] = STATE(1110),
        [sym_value_header] = STATE(1109),
        [sym_value_forward_dcl] = STATE(1112),
        [sym_typedef_dcl] = STATE(1038),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_type_id_dcl] = STATE(849),
        [sym_import_dcl] = STATE(849),
        [sym_object_type] = STATE(439),
        [sym_op_oneway_dcl] = STATE(672),
        [sym_op_with_context] = STATE(849),
        [sym_value_box_def] = STATE(1112),
        [sym_value_abs_def] = STATE(1112),
        [sym_type_dcl] = STATE(849),
        [sym_constr_type_dcl] = STATE(1038),
        [sym_native_dcl] = STATE(1038),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_const_dcl] = STATE(849),
        [sym_comment] = STATE(11),
        [aux_sym_interface_def_repeat1] = STATE(277),
        [aux_sym_interface_body_repeat1] = STATE(14),
        [anon_sym_short] = ACTIONS(69),
        [anon_sym_int16] = ACTIONS(69),
        [anon_sym_long] = ACTIONS(71),
        [anon_sym_int32] = ACTIONS(71),
        [anon_sym_longlong] = ACTIONS(73),
        [anon_sym_int64] = ACTIONS(75),
        [sym_unsigned_tiny_int] = ACTIONS(77),
        [sym_boolean_type] = ACTIONS(79),
        [anon_sym_fixed] = ACTIONS(81),
        [sym_octet_type] = ACTIONS(79),
        [sym_signed_tiny_int] = ACTIONS(83),
        [anon_sym_unsignedshort] = ACTIONS(85),
        [anon_sym_uint16] = ACTIONS(87),
        [anon_sym_unsignedlong] = ACTIONS(89),
        [anon_sym_uint32] = ACTIONS(89),
        [anon_sym_unsignedlonglong] = ACTIONS(91),
        [anon_sym_uint64] = ACTIONS(93),
        [anon_sym_float] = ACTIONS(95),
        [anon_sym_double] = ACTIONS(95),
        [anon_sym_longdouble] = ACTIONS(97),
        [anon_sym_char] = ACTIONS(99),
        [anon_sym_wchar] = ACTIONS(99),
        [anon_sym_COLON_COLON] = ACTIONS(101),
        [anon_sym_string] = ACTIONS(103),
        [anon_sym_wstring] = ACTIONS(103),
        [anon_sym_any] = ACTIONS(105),
        [anon_sym_sequence] = ACTIONS(107),
        [anon_sym_map] = ACTIONS(109),
        [anon_sym_exception] = ACTIONS(111),
        [anon_sym_RBRACE] = ACTIONS(453),
        [anon_sym_abstract] = ACTIONS(115),
        [anon_sym_void] = ACTIONS(117),
        [anon_sym_readonly] = ACTIONS(119),
        [anon_sym_attribute] = ACTIONS(121),
        [anon_sym_bitset] = ACTIONS(123),
        [anon_sym_bitmask] = ACTIONS(125),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_oneway] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_ATignore_literal_names] = ACTIONS(51),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [sym_value_base_type] = ACTIONS(79),
        [anon_sym_native] = ACTIONS(153),
        [sym_identifier] = ACTIONS(155),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [12] = {
        [sym_signed_short_int] = STATE(370),
        [sym_signed_long_int] = STATE(370),
        [sym_signed_longlong_int] = STATE(370),
        [sym_unsigned_int] = STATE(375),
        [sym_integer_type] = STATE(439),
        [sym_signed_int] = STATE(375),
        [sym_unsigned_short_int] = STATE(366),
        [sym_unsigned_long_int] = STATE(366),
        [sym_unsigned_longlong_int] = STATE(366),
        [sym_floating_pt_type] = STATE(439),
        [sym_char_type] = STATE(439),
        [sym_scoped_name] = STATE(376),
        [sym_string_type] = STATE(435),
        [sym_type_spec] = STATE(874),
        [sym_simple_type_spec] = STATE(388),
        [sym_base_type_spec] = STATE(433),
        [sym_any_type] = STATE(439),
        [sym_fixed_pt_type] = STATE(435),
        [sym_template_type_spec] = STATE(388),
        [sym_sequence_type] = STATE(435),
        [sym_map_type] = STATE(435),
        [sym_except_dcl] = STATE(849),
        [sym_export] = STATE(71),
        [sym_op_dcl] = STATE(672),
        [sym_op_type_spec] = STATE(856),
        [sym_attr_dcl] = STATE(849),
        [sym_readonly_attr_spec] = STATE(843),
        [sym_attr_spec] = STATE(843),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_value_dcl] = STATE(849),
        [sym_value_def] = STATE(1112),
        [sym_value_kind] = STATE(1110),
        [sym_value_header] = STATE(1109),
        [sym_value_forward_dcl] = STATE(1112),
        [sym_typedef_dcl] = STATE(1038),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_type_id_dcl] = STATE(849),
        [sym_import_dcl] = STATE(849),
        [sym_object_type] = STATE(439),
        [sym_op_oneway_dcl] = STATE(672),
        [sym_op_with_context] = STATE(849),
        [sym_value_box_def] = STATE(1112),
        [sym_value_abs_def] = STATE(1112),
        [sym_type_dcl] = STATE(849),
        [sym_constr_type_dcl] = STATE(1038),
        [sym_native_dcl] = STATE(1038),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_const_dcl] = STATE(849),
        [sym_comment] = STATE(12),
        [aux_sym_interface_def_repeat1] = STATE(277),
        [aux_sym_interface_body_repeat1] = STATE(16),
        [anon_sym_short] = ACTIONS(69),
        [anon_sym_int16] = ACTIONS(69),
        [anon_sym_long] = ACTIONS(71),
        [anon_sym_int32] = ACTIONS(71),
        [anon_sym_longlong] = ACTIONS(73),
        [anon_sym_int64] = ACTIONS(75),
        [sym_unsigned_tiny_int] = ACTIONS(77),
        [sym_boolean_type] = ACTIONS(79),
        [anon_sym_fixed] = ACTIONS(81),
        [sym_octet_type] = ACTIONS(79),
        [sym_signed_tiny_int] = ACTIONS(83),
        [anon_sym_unsignedshort] = ACTIONS(85),
        [anon_sym_uint16] = ACTIONS(87),
        [anon_sym_unsignedlong] = ACTIONS(89),
        [anon_sym_uint32] = ACTIONS(89),
        [anon_sym_unsignedlonglong] = ACTIONS(91),
        [anon_sym_uint64] = ACTIONS(93),
        [anon_sym_float] = ACTIONS(95),
        [anon_sym_double] = ACTIONS(95),
        [anon_sym_longdouble] = ACTIONS(97),
        [anon_sym_char] = ACTIONS(99),
        [anon_sym_wchar] = ACTIONS(99),
        [anon_sym_COLON_COLON] = ACTIONS(101),
        [anon_sym_string] = ACTIONS(103),
        [anon_sym_wstring] = ACTIONS(103),
        [anon_sym_any] = ACTIONS(105),
        [anon_sym_sequence] = ACTIONS(107),
        [anon_sym_map] = ACTIONS(109),
        [anon_sym_exception] = ACTIONS(111),
        [anon_sym_RBRACE] = ACTIONS(455),
        [anon_sym_abstract] = ACTIONS(115),
        [anon_sym_void] = ACTIONS(117),
        [anon_sym_readonly] = ACTIONS(119),
        [anon_sym_attribute] = ACTIONS(121),
        [anon_sym_bitset] = ACTIONS(123),
        [anon_sym_bitmask] = ACTIONS(125),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_oneway] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_ATignore_literal_names] = ACTIONS(51),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [sym_value_base_type] = ACTIONS(79),
        [anon_sym_native] = ACTIONS(153),
        [sym_identifier] = ACTIONS(155),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [13] = {
        [sym_signed_short_int] = STATE(370),
        [sym_signed_long_int] = STATE(370),
        [sym_signed_longlong_int] = STATE(370),
        [sym_unsigned_int] = STATE(375),
        [sym_integer_type] = STATE(439),
        [sym_signed_int] = STATE(375),
        [sym_unsigned_short_int] = STATE(366),
        [sym_unsigned_long_int] = STATE(366),
        [sym_unsigned_longlong_int] = STATE(366),
        [sym_floating_pt_type] = STATE(439),
        [sym_char_type] = STATE(439),
        [sym_scoped_name] = STATE(376),
        [sym_string_type] = STATE(435),
        [sym_type_spec] = STATE(874),
        [sym_simple_type_spec] = STATE(388),
        [sym_base_type_spec] = STATE(433),
        [sym_any_type] = STATE(439),
        [sym_fixed_pt_type] = STATE(435),
        [sym_template_type_spec] = STATE(388),
        [sym_sequence_type] = STATE(435),
        [sym_map_type] = STATE(435),
        [sym_except_dcl] = STATE(849),
        [sym_export] = STATE(71),
        [sym_op_dcl] = STATE(672),
        [sym_op_type_spec] = STATE(856),
        [sym_attr_dcl] = STATE(849),
        [sym_readonly_attr_spec] = STATE(843),
        [sym_attr_spec] = STATE(843),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_value_dcl] = STATE(849),
        [sym_value_def] = STATE(1112),
        [sym_value_kind] = STATE(1110),
        [sym_value_header] = STATE(1109),
        [sym_value_forward_dcl] = STATE(1112),
        [sym_typedef_dcl] = STATE(1038),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_type_id_dcl] = STATE(849),
        [sym_import_dcl] = STATE(849),
        [sym_object_type] = STATE(439),
        [sym_op_oneway_dcl] = STATE(672),
        [sym_op_with_context] = STATE(849),
        [sym_value_box_def] = STATE(1112),
        [sym_value_abs_def] = STATE(1112),
        [sym_type_dcl] = STATE(849),
        [sym_constr_type_dcl] = STATE(1038),
        [sym_native_dcl] = STATE(1038),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_const_dcl] = STATE(849),
        [sym_comment] = STATE(13),
        [aux_sym_interface_def_repeat1] = STATE(277),
        [aux_sym_interface_body_repeat1] = STATE(17),
        [anon_sym_short] = ACTIONS(69),
        [anon_sym_int16] = ACTIONS(69),
        [anon_sym_long] = ACTIONS(71),
        [anon_sym_int32] = ACTIONS(71),
        [anon_sym_longlong] = ACTIONS(73),
        [anon_sym_int64] = ACTIONS(75),
        [sym_unsigned_tiny_int] = ACTIONS(77),
        [sym_boolean_type] = ACTIONS(79),
        [anon_sym_fixed] = ACTIONS(81),
        [sym_octet_type] = ACTIONS(79),
        [sym_signed_tiny_int] = ACTIONS(83),
        [anon_sym_unsignedshort] = ACTIONS(85),
        [anon_sym_uint16] = ACTIONS(87),
        [anon_sym_unsignedlong] = ACTIONS(89),
        [anon_sym_uint32] = ACTIONS(89),
        [anon_sym_unsignedlonglong] = ACTIONS(91),
        [anon_sym_uint64] = ACTIONS(93),
        [anon_sym_float] = ACTIONS(95),
        [anon_sym_double] = ACTIONS(95),
        [anon_sym_longdouble] = ACTIONS(97),
        [anon_sym_char] = ACTIONS(99),
        [anon_sym_wchar] = ACTIONS(99),
        [anon_sym_COLON_COLON] = ACTIONS(101),
        [anon_sym_string] = ACTIONS(103),
        [anon_sym_wstring] = ACTIONS(103),
        [anon_sym_any] = ACTIONS(105),
        [anon_sym_sequence] = ACTIONS(107),
        [anon_sym_map] = ACTIONS(109),
        [anon_sym_exception] = ACTIONS(111),
        [anon_sym_RBRACE] = ACTIONS(457),
        [anon_sym_abstract] = ACTIONS(115),
        [anon_sym_void] = ACTIONS(117),
        [anon_sym_readonly] = ACTIONS(119),
        [anon_sym_attribute] = ACTIONS(121),
        [anon_sym_bitset] = ACTIONS(123),
        [anon_sym_bitmask] = ACTIONS(125),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_oneway] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_ATignore_literal_names] = ACTIONS(51),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [sym_value_base_type] = ACTIONS(79),
        [anon_sym_native] = ACTIONS(153),
        [sym_identifier] = ACTIONS(155),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [14] = {
        [sym_signed_short_int] = STATE(370),
        [sym_signed_long_int] = STATE(370),
        [sym_signed_longlong_int] = STATE(370),
        [sym_unsigned_int] = STATE(375),
        [sym_integer_type] = STATE(439),
        [sym_signed_int] = STATE(375),
        [sym_unsigned_short_int] = STATE(366),
        [sym_unsigned_long_int] = STATE(366),
        [sym_unsigned_longlong_int] = STATE(366),
        [sym_floating_pt_type] = STATE(439),
        [sym_char_type] = STATE(439),
        [sym_scoped_name] = STATE(376),
        [sym_string_type] = STATE(435),
        [sym_type_spec] = STATE(874),
        [sym_simple_type_spec] = STATE(388),
        [sym_base_type_spec] = STATE(433),
        [sym_any_type] = STATE(439),
        [sym_fixed_pt_type] = STATE(435),
        [sym_template_type_spec] = STATE(388),
        [sym_sequence_type] = STATE(435),
        [sym_map_type] = STATE(435),
        [sym_except_dcl] = STATE(849),
        [sym_export] = STATE(71),
        [sym_op_dcl] = STATE(672),
        [sym_op_type_spec] = STATE(856),
        [sym_attr_dcl] = STATE(849),
        [sym_readonly_attr_spec] = STATE(843),
        [sym_attr_spec] = STATE(843),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_value_dcl] = STATE(849),
        [sym_value_def] = STATE(1112),
        [sym_value_kind] = STATE(1110),
        [sym_value_header] = STATE(1109),
        [sym_value_forward_dcl] = STATE(1112),
        [sym_typedef_dcl] = STATE(1038),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_type_id_dcl] = STATE(849),
        [sym_import_dcl] = STATE(849),
        [sym_object_type] = STATE(439),
        [sym_op_oneway_dcl] = STATE(672),
        [sym_op_with_context] = STATE(849),
        [sym_value_box_def] = STATE(1112),
        [sym_value_abs_def] = STATE(1112),
        [sym_type_dcl] = STATE(849),
        [sym_constr_type_dcl] = STATE(1038),
        [sym_native_dcl] = STATE(1038),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_const_dcl] = STATE(849),
        [sym_comment] = STATE(14),
        [aux_sym_interface_def_repeat1] = STATE(277),
        [aux_sym_interface_body_repeat1] = STATE(17),
        [anon_sym_short] = ACTIONS(69),
        [anon_sym_int16] = ACTIONS(69),
        [anon_sym_long] = ACTIONS(71),
        [anon_sym_int32] = ACTIONS(71),
        [anon_sym_longlong] = ACTIONS(73),
        [anon_sym_int64] = ACTIONS(75),
        [sym_unsigned_tiny_int] = ACTIONS(77),
        [sym_boolean_type] = ACTIONS(79),
        [anon_sym_fixed] = ACTIONS(81),
        [sym_octet_type] = ACTIONS(79),
        [sym_signed_tiny_int] = ACTIONS(83),
        [anon_sym_unsignedshort] = ACTIONS(85),
        [anon_sym_uint16] = ACTIONS(87),
        [anon_sym_unsignedlong] = ACTIONS(89),
        [anon_sym_uint32] = ACTIONS(89),
        [anon_sym_unsignedlonglong] = ACTIONS(91),
        [anon_sym_uint64] = ACTIONS(93),
        [anon_sym_float] = ACTIONS(95),
        [anon_sym_double] = ACTIONS(95),
        [anon_sym_longdouble] = ACTIONS(97),
        [anon_sym_char] = ACTIONS(99),
        [anon_sym_wchar] = ACTIONS(99),
        [anon_sym_COLON_COLON] = ACTIONS(101),
        [anon_sym_string] = ACTIONS(103),
        [anon_sym_wstring] = ACTIONS(103),
        [anon_sym_any] = ACTIONS(105),
        [anon_sym_sequence] = ACTIONS(107),
        [anon_sym_map] = ACTIONS(109),
        [anon_sym_exception] = ACTIONS(111),
        [anon_sym_RBRACE] = ACTIONS(459),
        [anon_sym_abstract] = ACTIONS(115),
        [anon_sym_void] = ACTIONS(117),
        [anon_sym_readonly] = ACTIONS(119),
        [anon_sym_attribute] = ACTIONS(121),
        [anon_sym_bitset] = ACTIONS(123),
        [anon_sym_bitmask] = ACTIONS(125),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_oneway] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_ATignore_literal_names] = ACTIONS(51),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [sym_value_base_type] = ACTIONS(79),
        [anon_sym_native] = ACTIONS(153),
        [sym_identifier] = ACTIONS(155),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [15] = {
        [sym_signed_short_int] = STATE(370),
        [sym_signed_long_int] = STATE(370),
        [sym_signed_longlong_int] = STATE(370),
        [sym_unsigned_int] = STATE(375),
        [sym_integer_type] = STATE(439),
        [sym_signed_int] = STATE(375),
        [sym_unsigned_short_int] = STATE(366),
        [sym_unsigned_long_int] = STATE(366),
        [sym_unsigned_longlong_int] = STATE(366),
        [sym_floating_pt_type] = STATE(439),
        [sym_char_type] = STATE(439),
        [sym_scoped_name] = STATE(376),
        [sym_string_type] = STATE(435),
        [sym_type_spec] = STATE(874),
        [sym_simple_type_spec] = STATE(388),
        [sym_base_type_spec] = STATE(433),
        [sym_any_type] = STATE(439),
        [sym_fixed_pt_type] = STATE(435),
        [sym_template_type_spec] = STATE(388),
        [sym_sequence_type] = STATE(435),
        [sym_map_type] = STATE(435),
        [sym_except_dcl] = STATE(849),
        [sym_export] = STATE(71),
        [sym_op_dcl] = STATE(672),
        [sym_op_type_spec] = STATE(856),
        [sym_attr_dcl] = STATE(849),
        [sym_readonly_attr_spec] = STATE(843),
        [sym_attr_spec] = STATE(843),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_value_dcl] = STATE(849),
        [sym_value_def] = STATE(1112),
        [sym_value_kind] = STATE(1110),
        [sym_value_header] = STATE(1109),
        [sym_value_forward_dcl] = STATE(1112),
        [sym_typedef_dcl] = STATE(1038),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_type_id_dcl] = STATE(849),
        [sym_import_dcl] = STATE(849),
        [sym_object_type] = STATE(439),
        [sym_op_oneway_dcl] = STATE(672),
        [sym_op_with_context] = STATE(849),
        [sym_value_box_def] = STATE(1112),
        [sym_value_abs_def] = STATE(1112),
        [sym_type_dcl] = STATE(849),
        [sym_constr_type_dcl] = STATE(1038),
        [sym_native_dcl] = STATE(1038),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_const_dcl] = STATE(849),
        [sym_comment] = STATE(15),
        [aux_sym_interface_def_repeat1] = STATE(277),
        [aux_sym_interface_body_repeat1] = STATE(17),
        [anon_sym_short] = ACTIONS(69),
        [anon_sym_int16] = ACTIONS(69),
        [anon_sym_long] = ACTIONS(71),
        [anon_sym_int32] = ACTIONS(71),
        [anon_sym_longlong] = ACTIONS(73),
        [anon_sym_int64] = ACTIONS(75),
        [sym_unsigned_tiny_int] = ACTIONS(77),
        [sym_boolean_type] = ACTIONS(79),
        [anon_sym_fixed] = ACTIONS(81),
        [sym_octet_type] = ACTIONS(79),
        [sym_signed_tiny_int] = ACTIONS(83),
        [anon_sym_unsignedshort] = ACTIONS(85),
        [anon_sym_uint16] = ACTIONS(87),
        [anon_sym_unsignedlong] = ACTIONS(89),
        [anon_sym_uint32] = ACTIONS(89),
        [anon_sym_unsignedlonglong] = ACTIONS(91),
        [anon_sym_uint64] = ACTIONS(93),
        [anon_sym_float] = ACTIONS(95),
        [anon_sym_double] = ACTIONS(95),
        [anon_sym_longdouble] = ACTIONS(97),
        [anon_sym_char] = ACTIONS(99),
        [anon_sym_wchar] = ACTIONS(99),
        [anon_sym_COLON_COLON] = ACTIONS(101),
        [anon_sym_string] = ACTIONS(103),
        [anon_sym_wstring] = ACTIONS(103),
        [anon_sym_any] = ACTIONS(105),
        [anon_sym_sequence] = ACTIONS(107),
        [anon_sym_map] = ACTIONS(109),
        [anon_sym_exception] = ACTIONS(111),
        [anon_sym_RBRACE] = ACTIONS(461),
        [anon_sym_abstract] = ACTIONS(115),
        [anon_sym_void] = ACTIONS(117),
        [anon_sym_readonly] = ACTIONS(119),
        [anon_sym_attribute] = ACTIONS(121),
        [anon_sym_bitset] = ACTIONS(123),
        [anon_sym_bitmask] = ACTIONS(125),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_oneway] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_ATignore_literal_names] = ACTIONS(51),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [sym_value_base_type] = ACTIONS(79),
        [anon_sym_native] = ACTIONS(153),
        [sym_identifier] = ACTIONS(155),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [16] = {
        [sym_signed_short_int] = STATE(370),
        [sym_signed_long_int] = STATE(370),
        [sym_signed_longlong_int] = STATE(370),
        [sym_unsigned_int] = STATE(375),
        [sym_integer_type] = STATE(439),
        [sym_signed_int] = STATE(375),
        [sym_unsigned_short_int] = STATE(366),
        [sym_unsigned_long_int] = STATE(366),
        [sym_unsigned_longlong_int] = STATE(366),
        [sym_floating_pt_type] = STATE(439),
        [sym_char_type] = STATE(439),
        [sym_scoped_name] = STATE(376),
        [sym_string_type] = STATE(435),
        [sym_type_spec] = STATE(874),
        [sym_simple_type_spec] = STATE(388),
        [sym_base_type_spec] = STATE(433),
        [sym_any_type] = STATE(439),
        [sym_fixed_pt_type] = STATE(435),
        [sym_template_type_spec] = STATE(388),
        [sym_sequence_type] = STATE(435),
        [sym_map_type] = STATE(435),
        [sym_except_dcl] = STATE(849),
        [sym_export] = STATE(71),
        [sym_op_dcl] = STATE(672),
        [sym_op_type_spec] = STATE(856),
        [sym_attr_dcl] = STATE(849),
        [sym_readonly_attr_spec] = STATE(843),
        [sym_attr_spec] = STATE(843),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_value_dcl] = STATE(849),
        [sym_value_def] = STATE(1112),
        [sym_value_kind] = STATE(1110),
        [sym_value_header] = STATE(1109),
        [sym_value_forward_dcl] = STATE(1112),
        [sym_typedef_dcl] = STATE(1038),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_type_id_dcl] = STATE(849),
        [sym_import_dcl] = STATE(849),
        [sym_object_type] = STATE(439),
        [sym_op_oneway_dcl] = STATE(672),
        [sym_op_with_context] = STATE(849),
        [sym_value_box_def] = STATE(1112),
        [sym_value_abs_def] = STATE(1112),
        [sym_type_dcl] = STATE(849),
        [sym_constr_type_dcl] = STATE(1038),
        [sym_native_dcl] = STATE(1038),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_const_dcl] = STATE(849),
        [sym_comment] = STATE(16),
        [aux_sym_interface_def_repeat1] = STATE(277),
        [aux_sym_interface_body_repeat1] = STATE(17),
        [anon_sym_short] = ACTIONS(69),
        [anon_sym_int16] = ACTIONS(69),
        [anon_sym_long] = ACTIONS(71),
        [anon_sym_int32] = ACTIONS(71),
        [anon_sym_longlong] = ACTIONS(73),
        [anon_sym_int64] = ACTIONS(75),
        [sym_unsigned_tiny_int] = ACTIONS(77),
        [sym_boolean_type] = ACTIONS(79),
        [anon_sym_fixed] = ACTIONS(81),
        [sym_octet_type] = ACTIONS(79),
        [sym_signed_tiny_int] = ACTIONS(83),
        [anon_sym_unsignedshort] = ACTIONS(85),
        [anon_sym_uint16] = ACTIONS(87),
        [anon_sym_unsignedlong] = ACTIONS(89),
        [anon_sym_uint32] = ACTIONS(89),
        [anon_sym_unsignedlonglong] = ACTIONS(91),
        [anon_sym_uint64] = ACTIONS(93),
        [anon_sym_float] = ACTIONS(95),
        [anon_sym_double] = ACTIONS(95),
        [anon_sym_longdouble] = ACTIONS(97),
        [anon_sym_char] = ACTIONS(99),
        [anon_sym_wchar] = ACTIONS(99),
        [anon_sym_COLON_COLON] = ACTIONS(101),
        [anon_sym_string] = ACTIONS(103),
        [anon_sym_wstring] = ACTIONS(103),
        [anon_sym_any] = ACTIONS(105),
        [anon_sym_sequence] = ACTIONS(107),
        [anon_sym_map] = ACTIONS(109),
        [anon_sym_exception] = ACTIONS(111),
        [anon_sym_RBRACE] = ACTIONS(463),
        [anon_sym_abstract] = ACTIONS(115),
        [anon_sym_void] = ACTIONS(117),
        [anon_sym_readonly] = ACTIONS(119),
        [anon_sym_attribute] = ACTIONS(121),
        [anon_sym_bitset] = ACTIONS(123),
        [anon_sym_bitmask] = ACTIONS(125),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_oneway] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_ATignore_literal_names] = ACTIONS(51),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [sym_value_base_type] = ACTIONS(79),
        [anon_sym_native] = ACTIONS(153),
        [sym_identifier] = ACTIONS(155),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [17] = {
        [sym_signed_short_int] = STATE(370),
        [sym_signed_long_int] = STATE(370),
        [sym_signed_longlong_int] = STATE(370),
        [sym_unsigned_int] = STATE(375),
        [sym_integer_type] = STATE(439),
        [sym_signed_int] = STATE(375),
        [sym_unsigned_short_int] = STATE(366),
        [sym_unsigned_long_int] = STATE(366),
        [sym_unsigned_longlong_int] = STATE(366),
        [sym_floating_pt_type] = STATE(439),
        [sym_char_type] = STATE(439),
        [sym_scoped_name] = STATE(376),
        [sym_string_type] = STATE(435),
        [sym_type_spec] = STATE(874),
        [sym_simple_type_spec] = STATE(388),
        [sym_base_type_spec] = STATE(433),
        [sym_any_type] = STATE(439),
        [sym_fixed_pt_type] = STATE(435),
        [sym_template_type_spec] = STATE(388),
        [sym_sequence_type] = STATE(435),
        [sym_map_type] = STATE(435),
        [sym_except_dcl] = STATE(849),
        [sym_export] = STATE(71),
        [sym_op_dcl] = STATE(672),
        [sym_op_type_spec] = STATE(856),
        [sym_attr_dcl] = STATE(849),
        [sym_readonly_attr_spec] = STATE(843),
        [sym_attr_spec] = STATE(843),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_value_dcl] = STATE(849),
        [sym_value_def] = STATE(1112),
        [sym_value_kind] = STATE(1110),
        [sym_value_header] = STATE(1109),
        [sym_value_forward_dcl] = STATE(1112),
        [sym_typedef_dcl] = STATE(1038),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_type_id_dcl] = STATE(849),
        [sym_import_dcl] = STATE(849),
        [sym_object_type] = STATE(439),
        [sym_op_oneway_dcl] = STATE(672),
        [sym_op_with_context] = STATE(849),
        [sym_value_box_def] = STATE(1112),
        [sym_value_abs_def] = STATE(1112),
        [sym_type_dcl] = STATE(849),
        [sym_constr_type_dcl] = STATE(1038),
        [sym_native_dcl] = STATE(1038),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_const_dcl] = STATE(849),
        [sym_comment] = STATE(17),
        [aux_sym_interface_def_repeat1] = STATE(277),
        [aux_sym_interface_body_repeat1] = STATE(17),
        [anon_sym_short] = ACTIONS(465),
        [anon_sym_int16] = ACTIONS(465),
        [anon_sym_long] = ACTIONS(468),
        [anon_sym_int32] = ACTIONS(468),
        [anon_sym_longlong] = ACTIONS(471),
        [anon_sym_int64] = ACTIONS(474),
        [sym_unsigned_tiny_int] = ACTIONS(477),
        [sym_boolean_type] = ACTIONS(480),
        [anon_sym_fixed] = ACTIONS(483),
        [sym_octet_type] = ACTIONS(480),
        [sym_signed_tiny_int] = ACTIONS(486),
        [anon_sym_unsignedshort] = ACTIONS(489),
        [anon_sym_uint16] = ACTIONS(492),
        [anon_sym_unsignedlong] = ACTIONS(495),
        [anon_sym_uint32] = ACTIONS(495),
        [anon_sym_unsignedlonglong] = ACTIONS(498),
        [anon_sym_uint64] = ACTIONS(501),
        [anon_sym_float] = ACTIONS(504),
        [anon_sym_double] = ACTIONS(504),
        [anon_sym_longdouble] = ACTIONS(507),
        [anon_sym_char] = ACTIONS(510),
        [anon_sym_wchar] = ACTIONS(510),
        [anon_sym_COLON_COLON] = ACTIONS(513),
        [anon_sym_string] = ACTIONS(516),
        [anon_sym_wstring] = ACTIONS(516),
        [anon_sym_any] = ACTIONS(519),
        [anon_sym_sequence] = ACTIONS(522),
        [anon_sym_map] = ACTIONS(525),
        [anon_sym_exception] = ACTIONS(528),
        [anon_sym_RBRACE] = ACTIONS(531),
        [anon_sym_abstract] = ACTIONS(533),
        [anon_sym_void] = ACTIONS(536),
        [anon_sym_readonly] = ACTIONS(539),
        [anon_sym_attribute] = ACTIONS(542),
        [anon_sym_bitset] = ACTIONS(545),
        [anon_sym_bitmask] = ACTIONS(548),
        [anon_sym_AT] = ACTIONS(551),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(554),
        [anon_sym_oneway] = ACTIONS(557),
        [anon_sym_valuetype] = ACTIONS(560),
        [anon_sym_struct] = ACTIONS(563),
        [anon_sym_union] = ACTIONS(566),
        [anon_sym_enum] = ACTIONS(569),
        [anon_sym_const] = ACTIONS(572),
        [anon_sym_custom] = ACTIONS(575),
        [anon_sym_typedef] = ACTIONS(578),
        [anon_sym_ATignore_literal_names] = ACTIONS(581),
        [anon_sym_typeid] = ACTIONS(584),
        [anon_sym_import] = ACTIONS(587),
        [anon_sym_Object] = ACTIONS(590),
        [sym_value_base_type] = ACTIONS(480),
        [anon_sym_native] = ACTIONS(593),
        [sym_identifier] = ACTIONS(596),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [18] = {
        [sym_signed_short_int] = STATE(370),
        [sym_signed_long_int] = STATE(370),
        [sym_signed_longlong_int] = STATE(370),
        [sym_unsigned_int] = STATE(375),
        [sym_integer_type] = STATE(439),
        [sym_signed_int] = STATE(375),
        [sym_unsigned_short_int] = STATE(366),
        [sym_unsigned_long_int] = STATE(366),
        [sym_unsigned_longlong_int] = STATE(366),
        [sym_floating_pt_type] = STATE(439),
        [sym_char_type] = STATE(439),
        [sym_scoped_name] = STATE(376),
        [sym_string_type] = STATE(435),
        [sym_type_spec] = STATE(874),
        [sym_simple_type_spec] = STATE(388),
        [sym_base_type_spec] = STATE(433),
        [sym_any_type] = STATE(439),
        [sym_fixed_pt_type] = STATE(435),
        [sym_template_type_spec] = STATE(388),
        [sym_sequence_type] = STATE(435),
        [sym_map_type] = STATE(435),
        [sym_except_dcl] = STATE(849),
        [sym_export] = STATE(71),
        [sym_op_dcl] = STATE(672),
        [sym_op_type_spec] = STATE(856),
        [sym_attr_dcl] = STATE(849),
        [sym_readonly_attr_spec] = STATE(843),
        [sym_attr_spec] = STATE(843),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_value_dcl] = STATE(849),
        [sym_value_def] = STATE(1112),
        [sym_value_kind] = STATE(1110),
        [sym_value_header] = STATE(1109),
        [sym_value_forward_dcl] = STATE(1112),
        [sym_typedef_dcl] = STATE(1038),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_type_id_dcl] = STATE(849),
        [sym_import_dcl] = STATE(849),
        [sym_object_type] = STATE(439),
        [sym_op_oneway_dcl] = STATE(672),
        [sym_op_with_context] = STATE(849),
        [sym_value_box_def] = STATE(1112),
        [sym_value_abs_def] = STATE(1112),
        [sym_type_dcl] = STATE(849),
        [sym_constr_type_dcl] = STATE(1038),
        [sym_native_dcl] = STATE(1038),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_const_dcl] = STATE(849),
        [sym_comment] = STATE(18),
        [aux_sym_interface_def_repeat1] = STATE(277),
        [aux_sym_interface_body_repeat1] = STATE(17),
        [anon_sym_short] = ACTIONS(69),
        [anon_sym_int16] = ACTIONS(69),
        [anon_sym_long] = ACTIONS(71),
        [anon_sym_int32] = ACTIONS(71),
        [anon_sym_longlong] = ACTIONS(73),
        [anon_sym_int64] = ACTIONS(75),
        [sym_unsigned_tiny_int] = ACTIONS(77),
        [sym_boolean_type] = ACTIONS(79),
        [anon_sym_fixed] = ACTIONS(81),
        [sym_octet_type] = ACTIONS(79),
        [sym_signed_tiny_int] = ACTIONS(83),
        [anon_sym_unsignedshort] = ACTIONS(85),
        [anon_sym_uint16] = ACTIONS(87),
        [anon_sym_unsignedlong] = ACTIONS(89),
        [anon_sym_uint32] = ACTIONS(89),
        [anon_sym_unsignedlonglong] = ACTIONS(91),
        [anon_sym_uint64] = ACTIONS(93),
        [anon_sym_float] = ACTIONS(95),
        [anon_sym_double] = ACTIONS(95),
        [anon_sym_longdouble] = ACTIONS(97),
        [anon_sym_char] = ACTIONS(99),
        [anon_sym_wchar] = ACTIONS(99),
        [anon_sym_COLON_COLON] = ACTIONS(101),
        [anon_sym_string] = ACTIONS(103),
        [anon_sym_wstring] = ACTIONS(103),
        [anon_sym_any] = ACTIONS(105),
        [anon_sym_sequence] = ACTIONS(107),
        [anon_sym_map] = ACTIONS(109),
        [anon_sym_exception] = ACTIONS(111),
        [anon_sym_RBRACE] = ACTIONS(599),
        [anon_sym_abstract] = ACTIONS(115),
        [anon_sym_void] = ACTIONS(117),
        [anon_sym_readonly] = ACTIONS(119),
        [anon_sym_attribute] = ACTIONS(121),
        [anon_sym_bitset] = ACTIONS(123),
        [anon_sym_bitmask] = ACTIONS(125),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_oneway] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_ATignore_literal_names] = ACTIONS(51),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [sym_value_base_type] = ACTIONS(79),
        [anon_sym_native] = ACTIONS(153),
        [sym_identifier] = ACTIONS(155),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [19] = {
        [sym_signed_short_int] = STATE(370),
        [sym_signed_long_int] = STATE(370),
        [sym_signed_longlong_int] = STATE(370),
        [sym_unsigned_int] = STATE(375),
        [sym_integer_type] = STATE(439),
        [sym_signed_int] = STATE(375),
        [sym_unsigned_short_int] = STATE(366),
        [sym_unsigned_long_int] = STATE(366),
        [sym_unsigned_longlong_int] = STATE(366),
        [sym_floating_pt_type] = STATE(439),
        [sym_char_type] = STATE(439),
        [sym_scoped_name] = STATE(376),
        [sym_string_type] = STATE(435),
        [sym_type_spec] = STATE(874),
        [sym_simple_type_spec] = STATE(388),
        [sym_base_type_spec] = STATE(433),
        [sym_any_type] = STATE(439),
        [sym_fixed_pt_type] = STATE(435),
        [sym_template_type_spec] = STATE(388),
        [sym_sequence_type] = STATE(435),
        [sym_map_type] = STATE(435),
        [sym_except_dcl] = STATE(849),
        [sym_export] = STATE(71),
        [sym_op_dcl] = STATE(672),
        [sym_op_type_spec] = STATE(856),
        [sym_attr_dcl] = STATE(849),
        [sym_readonly_attr_spec] = STATE(843),
        [sym_attr_spec] = STATE(843),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_value_dcl] = STATE(849),
        [sym_value_def] = STATE(1112),
        [sym_value_kind] = STATE(1110),
        [sym_value_header] = STATE(1109),
        [sym_value_forward_dcl] = STATE(1112),
        [sym_typedef_dcl] = STATE(1038),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_type_id_dcl] = STATE(849),
        [sym_import_dcl] = STATE(849),
        [sym_object_type] = STATE(439),
        [sym_op_oneway_dcl] = STATE(672),
        [sym_op_with_context] = STATE(849),
        [sym_value_box_def] = STATE(1112),
        [sym_value_abs_def] = STATE(1112),
        [sym_type_dcl] = STATE(849),
        [sym_constr_type_dcl] = STATE(1038),
        [sym_native_dcl] = STATE(1038),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_const_dcl] = STATE(849),
        [sym_comment] = STATE(19),
        [aux_sym_interface_def_repeat1] = STATE(277),
        [aux_sym_interface_body_repeat1] = STATE(15),
        [anon_sym_short] = ACTIONS(69),
        [anon_sym_int16] = ACTIONS(69),
        [anon_sym_long] = ACTIONS(71),
        [anon_sym_int32] = ACTIONS(71),
        [anon_sym_longlong] = ACTIONS(73),
        [anon_sym_int64] = ACTIONS(75),
        [sym_unsigned_tiny_int] = ACTIONS(77),
        [sym_boolean_type] = ACTIONS(79),
        [anon_sym_fixed] = ACTIONS(81),
        [sym_octet_type] = ACTIONS(79),
        [sym_signed_tiny_int] = ACTIONS(83),
        [anon_sym_unsignedshort] = ACTIONS(85),
        [anon_sym_uint16] = ACTIONS(87),
        [anon_sym_unsignedlong] = ACTIONS(89),
        [anon_sym_uint32] = ACTIONS(89),
        [anon_sym_unsignedlonglong] = ACTIONS(91),
        [anon_sym_uint64] = ACTIONS(93),
        [anon_sym_float] = ACTIONS(95),
        [anon_sym_double] = ACTIONS(95),
        [anon_sym_longdouble] = ACTIONS(97),
        [anon_sym_char] = ACTIONS(99),
        [anon_sym_wchar] = ACTIONS(99),
        [anon_sym_COLON_COLON] = ACTIONS(101),
        [anon_sym_string] = ACTIONS(103),
        [anon_sym_wstring] = ACTIONS(103),
        [anon_sym_any] = ACTIONS(105),
        [anon_sym_sequence] = ACTIONS(107),
        [anon_sym_map] = ACTIONS(109),
        [anon_sym_exception] = ACTIONS(111),
        [anon_sym_RBRACE] = ACTIONS(463),
        [anon_sym_abstract] = ACTIONS(115),
        [anon_sym_void] = ACTIONS(117),
        [anon_sym_readonly] = ACTIONS(119),
        [anon_sym_attribute] = ACTIONS(121),
        [anon_sym_bitset] = ACTIONS(123),
        [anon_sym_bitmask] = ACTIONS(125),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_oneway] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_ATignore_literal_names] = ACTIONS(51),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [sym_value_base_type] = ACTIONS(79),
        [anon_sym_native] = ACTIONS(153),
        [sym_identifier] = ACTIONS(155),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [20] = {
        [sym_signed_short_int] = STATE(370),
        [sym_signed_long_int] = STATE(370),
        [sym_signed_longlong_int] = STATE(370),
        [sym_unsigned_int] = STATE(375),
        [sym_integer_type] = STATE(439),
        [sym_signed_int] = STATE(375),
        [sym_unsigned_short_int] = STATE(366),
        [sym_unsigned_long_int] = STATE(366),
        [sym_unsigned_longlong_int] = STATE(366),
        [sym_floating_pt_type] = STATE(439),
        [sym_char_type] = STATE(439),
        [sym_scoped_name] = STATE(376),
        [sym_string_type] = STATE(435),
        [sym_type_spec] = STATE(874),
        [sym_simple_type_spec] = STATE(388),
        [sym_base_type_spec] = STATE(433),
        [sym_any_type] = STATE(439),
        [sym_fixed_pt_type] = STATE(435),
        [sym_template_type_spec] = STATE(388),
        [sym_sequence_type] = STATE(435),
        [sym_map_type] = STATE(435),
        [sym_except_dcl] = STATE(849),
        [sym_export] = STATE(71),
        [sym_op_dcl] = STATE(672),
        [sym_op_type_spec] = STATE(856),
        [sym_attr_dcl] = STATE(849),
        [sym_readonly_attr_spec] = STATE(843),
        [sym_attr_spec] = STATE(843),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_value_dcl] = STATE(849),
        [sym_value_def] = STATE(1112),
        [sym_value_kind] = STATE(1110),
        [sym_value_header] = STATE(1109),
        [sym_value_forward_dcl] = STATE(1112),
        [sym_typedef_dcl] = STATE(1038),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_type_id_dcl] = STATE(849),
        [sym_import_dcl] = STATE(849),
        [sym_object_type] = STATE(439),
        [sym_op_oneway_dcl] = STATE(672),
        [sym_op_with_context] = STATE(849),
        [sym_value_box_def] = STATE(1112),
        [sym_value_abs_def] = STATE(1112),
        [sym_type_dcl] = STATE(849),
        [sym_constr_type_dcl] = STATE(1038),
        [sym_native_dcl] = STATE(1038),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_const_dcl] = STATE(849),
        [sym_comment] = STATE(20),
        [aux_sym_interface_def_repeat1] = STATE(277),
        [aux_sym_interface_body_repeat1] = STATE(13),
        [anon_sym_short] = ACTIONS(69),
        [anon_sym_int16] = ACTIONS(69),
        [anon_sym_long] = ACTIONS(71),
        [anon_sym_int32] = ACTIONS(71),
        [anon_sym_longlong] = ACTIONS(73),
        [anon_sym_int64] = ACTIONS(75),
        [sym_unsigned_tiny_int] = ACTIONS(77),
        [sym_boolean_type] = ACTIONS(79),
        [anon_sym_fixed] = ACTIONS(81),
        [sym_octet_type] = ACTIONS(79),
        [sym_signed_tiny_int] = ACTIONS(83),
        [anon_sym_unsignedshort] = ACTIONS(85),
        [anon_sym_uint16] = ACTIONS(87),
        [anon_sym_unsignedlong] = ACTIONS(89),
        [anon_sym_uint32] = ACTIONS(89),
        [anon_sym_unsignedlonglong] = ACTIONS(91),
        [anon_sym_uint64] = ACTIONS(93),
        [anon_sym_float] = ACTIONS(95),
        [anon_sym_double] = ACTIONS(95),
        [anon_sym_longdouble] = ACTIONS(97),
        [anon_sym_char] = ACTIONS(99),
        [anon_sym_wchar] = ACTIONS(99),
        [anon_sym_COLON_COLON] = ACTIONS(101),
        [anon_sym_string] = ACTIONS(103),
        [anon_sym_wstring] = ACTIONS(103),
        [anon_sym_any] = ACTIONS(105),
        [anon_sym_sequence] = ACTIONS(107),
        [anon_sym_map] = ACTIONS(109),
        [anon_sym_exception] = ACTIONS(111),
        [anon_sym_RBRACE] = ACTIONS(599),
        [anon_sym_abstract] = ACTIONS(115),
        [anon_sym_void] = ACTIONS(117),
        [anon_sym_readonly] = ACTIONS(119),
        [anon_sym_attribute] = ACTIONS(121),
        [anon_sym_bitset] = ACTIONS(123),
        [anon_sym_bitmask] = ACTIONS(125),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_oneway] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_ATignore_literal_names] = ACTIONS(51),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [sym_value_base_type] = ACTIONS(79),
        [anon_sym_native] = ACTIONS(153),
        [sym_identifier] = ACTIONS(155),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [21] = {
        [sym_signed_short_int] = STATE(370),
        [sym_signed_long_int] = STATE(370),
        [sym_signed_longlong_int] = STATE(370),
        [sym_unsigned_int] = STATE(375),
        [sym_integer_type] = STATE(439),
        [sym_signed_int] = STATE(375),
        [sym_unsigned_short_int] = STATE(366),
        [sym_unsigned_long_int] = STATE(366),
        [sym_unsigned_longlong_int] = STATE(366),
        [sym_floating_pt_type] = STATE(439),
        [sym_char_type] = STATE(439),
        [sym_scoped_name] = STATE(376),
        [sym_string_type] = STATE(435),
        [sym_type_spec] = STATE(874),
        [sym_simple_type_spec] = STATE(388),
        [sym_base_type_spec] = STATE(433),
        [sym_any_type] = STATE(439),
        [sym_fixed_pt_type] = STATE(435),
        [sym_template_type_spec] = STATE(388),
        [sym_sequence_type] = STATE(435),
        [sym_map_type] = STATE(435),
        [sym_except_dcl] = STATE(849),
        [sym_export] = STATE(71),
        [sym_op_dcl] = STATE(672),
        [sym_op_type_spec] = STATE(856),
        [sym_attr_dcl] = STATE(849),
        [sym_readonly_attr_spec] = STATE(843),
        [sym_attr_spec] = STATE(843),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_value_dcl] = STATE(849),
        [sym_value_def] = STATE(1112),
        [sym_value_kind] = STATE(1110),
        [sym_value_header] = STATE(1109),
        [sym_value_forward_dcl] = STATE(1112),
        [sym_typedef_dcl] = STATE(1038),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_type_id_dcl] = STATE(849),
        [sym_import_dcl] = STATE(849),
        [sym_object_type] = STATE(439),
        [sym_op_oneway_dcl] = STATE(672),
        [sym_op_with_context] = STATE(849),
        [sym_value_box_def] = STATE(1112),
        [sym_value_abs_def] = STATE(1112),
        [sym_type_dcl] = STATE(849),
        [sym_constr_type_dcl] = STATE(1038),
        [sym_native_dcl] = STATE(1038),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_const_dcl] = STATE(849),
        [sym_comment] = STATE(21),
        [aux_sym_interface_def_repeat1] = STATE(277),
        [aux_sym_interface_body_repeat1] = STATE(18),
        [anon_sym_short] = ACTIONS(69),
        [anon_sym_int16] = ACTIONS(69),
        [anon_sym_long] = ACTIONS(71),
        [anon_sym_int32] = ACTIONS(71),
        [anon_sym_longlong] = ACTIONS(73),
        [anon_sym_int64] = ACTIONS(75),
        [sym_unsigned_tiny_int] = ACTIONS(77),
        [sym_boolean_type] = ACTIONS(79),
        [anon_sym_fixed] = ACTIONS(81),
        [sym_octet_type] = ACTIONS(79),
        [sym_signed_tiny_int] = ACTIONS(83),
        [anon_sym_unsignedshort] = ACTIONS(85),
        [anon_sym_uint16] = ACTIONS(87),
        [anon_sym_unsignedlong] = ACTIONS(89),
        [anon_sym_uint32] = ACTIONS(89),
        [anon_sym_unsignedlonglong] = ACTIONS(91),
        [anon_sym_uint64] = ACTIONS(93),
        [anon_sym_float] = ACTIONS(95),
        [anon_sym_double] = ACTIONS(95),
        [anon_sym_longdouble] = ACTIONS(97),
        [anon_sym_char] = ACTIONS(99),
        [anon_sym_wchar] = ACTIONS(99),
        [anon_sym_COLON_COLON] = ACTIONS(101),
        [anon_sym_string] = ACTIONS(103),
        [anon_sym_wstring] = ACTIONS(103),
        [anon_sym_any] = ACTIONS(105),
        [anon_sym_sequence] = ACTIONS(107),
        [anon_sym_map] = ACTIONS(109),
        [anon_sym_exception] = ACTIONS(111),
        [anon_sym_RBRACE] = ACTIONS(601),
        [anon_sym_abstract] = ACTIONS(115),
        [anon_sym_void] = ACTIONS(117),
        [anon_sym_readonly] = ACTIONS(119),
        [anon_sym_attribute] = ACTIONS(121),
        [anon_sym_bitset] = ACTIONS(123),
        [anon_sym_bitmask] = ACTIONS(125),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_oneway] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_ATignore_literal_names] = ACTIONS(51),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [sym_value_base_type] = ACTIONS(79),
        [anon_sym_native] = ACTIONS(153),
        [sym_identifier] = ACTIONS(155),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [22] = {
        [sym_preproc_define] = STATE(153),
        [sym_preproc_call] = STATE(153),
        [sym_preproc_include] = STATE(153),
        [sym_except_dcl] = STATE(1149),
        [sym_interface_dcl] = STATE(1149),
        [sym_interface_kind] = STATE(1146),
        [sym_interface_forward_dcl] = STATE(1145),
        [sym_interface_def] = STATE(1145),
        [sym_interface_header] = STATE(1142),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_dcl] = STATE(1149),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_template_module_dcl] = STATE(1149),
        [sym_template_module_inst] = STATE(1149),
        [sym_value_dcl] = STATE(1149),
        [sym_value_def] = STATE(1112),
        [sym_value_kind] = STATE(1110),
        [sym_value_header] = STATE(1109),
        [sym_value_forward_dcl] = STATE(1112),
        [sym_typedef_dcl] = STATE(1108),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_type_id_dcl] = STATE(1149),
        [sym_type_prefix_dcl] = STATE(1149),
        [sym_import_dcl] = STATE(1149),
        [sym_value_box_def] = STATE(1112),
        [sym_value_abs_def] = STATE(1112),
        [sym_component_dcl] = STATE(1149),
        [sym_component_forward_dcl] = STATE(1077),
        [sym_component_def] = STATE(1077),
        [sym_component_header] = STATE(1076),
        [sym_home_dcl] = STATE(1149),
        [sym_home_header] = STATE(1075),
        [sym_event_dcl] = STATE(1149),
        [sym_event_forward_dcl] = STATE(1073),
        [sym_event_abs_def] = STATE(1073),
        [sym_event_def] = STATE(1073),
        [sym_event_header] = STATE(1045),
        [sym_porttype_dcl] = STATE(1149),
        [sym_porttype_forward_dcl] = STATE(1041),
        [sym_porttype_def] = STATE(1041),
        [sym_connector_dcl] = STATE(1149),
        [sym_connector_header] = STATE(1039),
        [sym_definition] = STATE(153),
        [sym_type_dcl] = STATE(1149),
        [sym_constr_type_dcl] = STATE(1038),
        [sym_native_dcl] = STATE(1038),
        [sym_module_dcl] = STATE(1149),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_const_dcl] = STATE(1149),
        [sym_comment] = STATE(22),
        [aux_sym_specification_repeat1] = STATE(22),
        [aux_sym_interface_def_repeat1] = STATE(222),
        [ts_builtin_sym_end] = ACTIONS(603),
        [anon_sym_POUNDdefine] = ACTIONS(605),
        [sym_preproc_directive] = ACTIONS(608),
        [aux_sym_preproc_include_token1] = ACTIONS(611),
        [anon_sym_exception] = ACTIONS(614),
        [anon_sym_local] = ACTIONS(617),
        [anon_sym_abstract] = ACTIONS(620),
        [anon_sym_interface] = ACTIONS(623),
        [anon_sym_bitset] = ACTIONS(626),
        [anon_sym_bitmask] = ACTIONS(629),
        [anon_sym_ATannotation] = ACTIONS(632),
        [anon_sym_AT] = ACTIONS(635),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(638),
        [anon_sym_module] = ACTIONS(641),
        [anon_sym_valuetype] = ACTIONS(644),
        [anon_sym_eventtype] = ACTIONS(647),
        [anon_sym_struct] = ACTIONS(650),
        [anon_sym_union] = ACTIONS(653),
        [anon_sym_enum] = ACTIONS(656),
        [anon_sym_const] = ACTIONS(659),
        [anon_sym_custom] = ACTIONS(662),
        [anon_sym_typedef] = ACTIONS(665),
        [anon_sym_ATignore_literal_names] = ACTIONS(668),
        [anon_sym_typeid] = ACTIONS(671),
        [anon_sym_typeprefix] = ACTIONS(674),
        [anon_sym_import] = ACTIONS(677),
        [anon_sym_component] = ACTIONS(680),
        [anon_sym_home] = ACTIONS(683),
        [anon_sym_porttype] = ACTIONS(686),
        [anon_sym_connector] = ACTIONS(689),
        [anon_sym_native] = ACTIONS(692),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [23] = {
        [sym_preproc_define] = STATE(153),
        [sym_preproc_call] = STATE(153),
        [sym_preproc_include] = STATE(153),
        [sym_except_dcl] = STATE(1149),
        [sym_interface_dcl] = STATE(1149),
        [sym_interface_kind] = STATE(1146),
        [sym_interface_forward_dcl] = STATE(1145),
        [sym_interface_def] = STATE(1145),
        [sym_interface_header] = STATE(1142),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_dcl] = STATE(1149),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_template_module_dcl] = STATE(1149),
        [sym_template_module_inst] = STATE(1149),
        [sym_value_dcl] = STATE(1149),
        [sym_value_def] = STATE(1112),
        [sym_value_kind] = STATE(1110),
        [sym_value_header] = STATE(1109),
        [sym_value_forward_dcl] = STATE(1112),
        [sym_typedef_dcl] = STATE(1108),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_type_id_dcl] = STATE(1149),
        [sym_type_prefix_dcl] = STATE(1149),
        [sym_import_dcl] = STATE(1149),
        [sym_value_box_def] = STATE(1112),
        [sym_value_abs_def] = STATE(1112),
        [sym_component_dcl] = STATE(1149),
        [sym_component_forward_dcl] = STATE(1077),
        [sym_component_def] = STATE(1077),
        [sym_component_header] = STATE(1076),
        [sym_home_dcl] = STATE(1149),
        [sym_home_header] = STATE(1075),
        [sym_event_dcl] = STATE(1149),
        [sym_event_forward_dcl] = STATE(1073),
        [sym_event_abs_def] = STATE(1073),
        [sym_event_def] = STATE(1073),
        [sym_event_header] = STATE(1045),
        [sym_porttype_dcl] = STATE(1149),
        [sym_porttype_forward_dcl] = STATE(1041),
        [sym_porttype_def] = STATE(1041),
        [sym_connector_dcl] = STATE(1149),
        [sym_connector_header] = STATE(1039),
        [sym_definition] = STATE(153),
        [sym_type_dcl] = STATE(1149),
        [sym_constr_type_dcl] = STATE(1038),
        [sym_native_dcl] = STATE(1038),
        [sym_module_dcl] = STATE(1149),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_const_dcl] = STATE(1149),
        [sym_comment] = STATE(23),
        [aux_sym_specification_repeat1] = STATE(22),
        [aux_sym_interface_def_repeat1] = STATE(222),
        [ts_builtin_sym_end] = ACTIONS(695),
        [anon_sym_POUNDdefine] = ACTIONS(9),
        [sym_preproc_directive] = ACTIONS(11),
        [aux_sym_preproc_include_token1] = ACTIONS(13),
        [anon_sym_exception] = ACTIONS(15),
        [anon_sym_local] = ACTIONS(17),
        [anon_sym_abstract] = ACTIONS(19),
        [anon_sym_interface] = ACTIONS(21),
        [anon_sym_bitset] = ACTIONS(23),
        [anon_sym_bitmask] = ACTIONS(25),
        [anon_sym_ATannotation] = ACTIONS(27),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_module] = ACTIONS(33),
        [anon_sym_valuetype] = ACTIONS(35),
        [anon_sym_eventtype] = ACTIONS(37),
        [anon_sym_struct] = ACTIONS(39),
        [anon_sym_union] = ACTIONS(41),
        [anon_sym_enum] = ACTIONS(43),
        [anon_sym_const] = ACTIONS(45),
        [anon_sym_custom] = ACTIONS(47),
        [anon_sym_typedef] = ACTIONS(49),
        [anon_sym_ATignore_literal_names] = ACTIONS(51),
        [anon_sym_typeid] = ACTIONS(53),
        [anon_sym_typeprefix] = ACTIONS(55),
        [anon_sym_import] = ACTIONS(57),
        [anon_sym_component] = ACTIONS(59),
        [anon_sym_home] = ACTIONS(61),
        [anon_sym_porttype] = ACTIONS(63),
        [anon_sym_connector] = ACTIONS(65),
        [anon_sym_native] = ACTIONS(67),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [24] = {
        [sym_except_dcl] = STATE(1149),
        [sym_interface_dcl] = STATE(1149),
        [sym_interface_kind] = STATE(1146),
        [sym_interface_forward_dcl] = STATE(1145),
        [sym_interface_def] = STATE(1145),
        [sym_interface_header] = STATE(1142),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_dcl] = STATE(1149),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_template_module_dcl] = STATE(1149),
        [sym_tpl_definition] = STATE(160),
        [sym_template_module_inst] = STATE(1149),
        [sym_template_module_ref] = STATE(1178),
        [sym_value_dcl] = STATE(1149),
        [sym_value_def] = STATE(1112),
        [sym_value_kind] = STATE(1110),
        [sym_value_header] = STATE(1109),
        [sym_value_forward_dcl] = STATE(1112),
        [sym_typedef_dcl] = STATE(1108),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_type_id_dcl] = STATE(1149),
        [sym_type_prefix_dcl] = STATE(1149),
        [sym_import_dcl] = STATE(1149),
        [sym_value_box_def] = STATE(1112),
        [sym_value_abs_def] = STATE(1112),
        [sym_component_dcl] = STATE(1149),
        [sym_component_forward_dcl] = STATE(1077),
        [sym_component_def] = STATE(1077),
        [sym_component_header] = STATE(1076),
        [sym_home_dcl] = STATE(1149),
        [sym_home_header] = STATE(1075),
        [sym_event_dcl] = STATE(1149),
        [sym_event_forward_dcl] = STATE(1073),
        [sym_event_abs_def] = STATE(1073),
        [sym_event_def] = STATE(1073),
        [sym_event_header] = STATE(1045),
        [sym_porttype_dcl] = STATE(1149),
        [sym_porttype_forward_dcl] = STATE(1041),
        [sym_porttype_def] = STATE(1041),
        [sym_connector_dcl] = STATE(1149),
        [sym_connector_header] = STATE(1039),
        [sym_definition] = STATE(159),
        [sym_type_dcl] = STATE(1149),
        [sym_constr_type_dcl] = STATE(1038),
        [sym_native_dcl] = STATE(1038),
        [sym_module_dcl] = STATE(1149),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_const_dcl] = STATE(1149),
        [sym_comment] = STATE(24),
        [aux_sym_interface_def_repeat1] = STATE(222),
        [aux_sym_template_module_dcl_repeat1] = STATE(25),
        [anon_sym_exception] = ACTIONS(15),
        [anon_sym_RBRACE] = ACTIONS(697),
        [anon_sym_local] = ACTIONS(17),
        [anon_sym_abstract] = ACTIONS(19),
        [anon_sym_interface] = ACTIONS(21),
        [anon_sym_bitset] = ACTIONS(23),
        [anon_sym_bitmask] = ACTIONS(25),
        [anon_sym_ATannotation] = ACTIONS(27),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_module] = ACTIONS(33),
        [anon_sym_valuetype] = ACTIONS(35),
        [anon_sym_eventtype] = ACTIONS(37),
        [anon_sym_struct] = ACTIONS(39),
        [anon_sym_union] = ACTIONS(41),
        [anon_sym_enum] = ACTIONS(43),
        [anon_sym_const] = ACTIONS(45),
        [anon_sym_alias] = ACTIONS(699),
        [anon_sym_custom] = ACTIONS(47),
        [anon_sym_typedef] = ACTIONS(49),
        [anon_sym_ATignore_literal_names] = ACTIONS(51),
        [anon_sym_typeid] = ACTIONS(53),
        [anon_sym_typeprefix] = ACTIONS(55),
        [anon_sym_import] = ACTIONS(57),
        [anon_sym_component] = ACTIONS(59),
        [anon_sym_home] = ACTIONS(61),
        [anon_sym_porttype] = ACTIONS(63),
        [anon_sym_connector] = ACTIONS(65),
        [anon_sym_native] = ACTIONS(67),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [25] = {
        [sym_except_dcl] = STATE(1149),
        [sym_interface_dcl] = STATE(1149),
        [sym_interface_kind] = STATE(1146),
        [sym_interface_forward_dcl] = STATE(1145),
        [sym_interface_def] = STATE(1145),
        [sym_interface_header] = STATE(1142),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_dcl] = STATE(1149),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_template_module_dcl] = STATE(1149),
        [sym_tpl_definition] = STATE(160),
        [sym_template_module_inst] = STATE(1149),
        [sym_template_module_ref] = STATE(1178),
        [sym_value_dcl] = STATE(1149),
        [sym_value_def] = STATE(1112),
        [sym_value_kind] = STATE(1110),
        [sym_value_header] = STATE(1109),
        [sym_value_forward_dcl] = STATE(1112),
        [sym_typedef_dcl] = STATE(1108),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_type_id_dcl] = STATE(1149),
        [sym_type_prefix_dcl] = STATE(1149),
        [sym_import_dcl] = STATE(1149),
        [sym_value_box_def] = STATE(1112),
        [sym_value_abs_def] = STATE(1112),
        [sym_component_dcl] = STATE(1149),
        [sym_component_forward_dcl] = STATE(1077),
        [sym_component_def] = STATE(1077),
        [sym_component_header] = STATE(1076),
        [sym_home_dcl] = STATE(1149),
        [sym_home_header] = STATE(1075),
        [sym_event_dcl] = STATE(1149),
        [sym_event_forward_dcl] = STATE(1073),
        [sym_event_abs_def] = STATE(1073),
        [sym_event_def] = STATE(1073),
        [sym_event_header] = STATE(1045),
        [sym_porttype_dcl] = STATE(1149),
        [sym_porttype_forward_dcl] = STATE(1041),
        [sym_porttype_def] = STATE(1041),
        [sym_connector_dcl] = STATE(1149),
        [sym_connector_header] = STATE(1039),
        [sym_definition] = STATE(159),
        [sym_type_dcl] = STATE(1149),
        [sym_constr_type_dcl] = STATE(1038),
        [sym_native_dcl] = STATE(1038),
        [sym_module_dcl] = STATE(1149),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_const_dcl] = STATE(1149),
        [sym_comment] = STATE(25),
        [aux_sym_interface_def_repeat1] = STATE(222),
        [aux_sym_template_module_dcl_repeat1] = STATE(26),
        [anon_sym_exception] = ACTIONS(15),
        [anon_sym_RBRACE] = ACTIONS(701),
        [anon_sym_local] = ACTIONS(17),
        [anon_sym_abstract] = ACTIONS(19),
        [anon_sym_interface] = ACTIONS(21),
        [anon_sym_bitset] = ACTIONS(23),
        [anon_sym_bitmask] = ACTIONS(25),
        [anon_sym_ATannotation] = ACTIONS(27),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_module] = ACTIONS(33),
        [anon_sym_valuetype] = ACTIONS(35),
        [anon_sym_eventtype] = ACTIONS(37),
        [anon_sym_struct] = ACTIONS(39),
        [anon_sym_union] = ACTIONS(41),
        [anon_sym_enum] = ACTIONS(43),
        [anon_sym_const] = ACTIONS(45),
        [anon_sym_alias] = ACTIONS(699),
        [anon_sym_custom] = ACTIONS(47),
        [anon_sym_typedef] = ACTIONS(49),
        [anon_sym_ATignore_literal_names] = ACTIONS(51),
        [anon_sym_typeid] = ACTIONS(53),
        [anon_sym_typeprefix] = ACTIONS(55),
        [anon_sym_import] = ACTIONS(57),
        [anon_sym_component] = ACTIONS(59),
        [anon_sym_home] = ACTIONS(61),
        [anon_sym_porttype] = ACTIONS(63),
        [anon_sym_connector] = ACTIONS(65),
        [anon_sym_native] = ACTIONS(67),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [26] = {
        [sym_except_dcl] = STATE(1149),
        [sym_interface_dcl] = STATE(1149),
        [sym_interface_kind] = STATE(1146),
        [sym_interface_forward_dcl] = STATE(1145),
        [sym_interface_def] = STATE(1145),
        [sym_interface_header] = STATE(1142),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_dcl] = STATE(1149),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_template_module_dcl] = STATE(1149),
        [sym_tpl_definition] = STATE(160),
        [sym_template_module_inst] = STATE(1149),
        [sym_template_module_ref] = STATE(1178),
        [sym_value_dcl] = STATE(1149),
        [sym_value_def] = STATE(1112),
        [sym_value_kind] = STATE(1110),
        [sym_value_header] = STATE(1109),
        [sym_value_forward_dcl] = STATE(1112),
        [sym_typedef_dcl] = STATE(1108),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_type_id_dcl] = STATE(1149),
        [sym_type_prefix_dcl] = STATE(1149),
        [sym_import_dcl] = STATE(1149),
        [sym_value_box_def] = STATE(1112),
        [sym_value_abs_def] = STATE(1112),
        [sym_component_dcl] = STATE(1149),
        [sym_component_forward_dcl] = STATE(1077),
        [sym_component_def] = STATE(1077),
        [sym_component_header] = STATE(1076),
        [sym_home_dcl] = STATE(1149),
        [sym_home_header] = STATE(1075),
        [sym_event_dcl] = STATE(1149),
        [sym_event_forward_dcl] = STATE(1073),
        [sym_event_abs_def] = STATE(1073),
        [sym_event_def] = STATE(1073),
        [sym_event_header] = STATE(1045),
        [sym_porttype_dcl] = STATE(1149),
        [sym_porttype_forward_dcl] = STATE(1041),
        [sym_porttype_def] = STATE(1041),
        [sym_connector_dcl] = STATE(1149),
        [sym_connector_header] = STATE(1039),
        [sym_definition] = STATE(159),
        [sym_type_dcl] = STATE(1149),
        [sym_constr_type_dcl] = STATE(1038),
        [sym_native_dcl] = STATE(1038),
        [sym_module_dcl] = STATE(1149),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_const_dcl] = STATE(1149),
        [sym_comment] = STATE(26),
        [aux_sym_interface_def_repeat1] = STATE(222),
        [aux_sym_template_module_dcl_repeat1] = STATE(26),
        [anon_sym_exception] = ACTIONS(703),
        [anon_sym_RBRACE] = ACTIONS(706),
        [anon_sym_local] = ACTIONS(708),
        [anon_sym_abstract] = ACTIONS(711),
        [anon_sym_interface] = ACTIONS(714),
        [anon_sym_bitset] = ACTIONS(717),
        [anon_sym_bitmask] = ACTIONS(720),
        [anon_sym_ATannotation] = ACTIONS(723),
        [anon_sym_AT] = ACTIONS(726),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(729),
        [anon_sym_module] = ACTIONS(732),
        [anon_sym_valuetype] = ACTIONS(735),
        [anon_sym_eventtype] = ACTIONS(738),
        [anon_sym_struct] = ACTIONS(741),
        [anon_sym_union] = ACTIONS(744),
        [anon_sym_enum] = ACTIONS(747),
        [anon_sym_const] = ACTIONS(750),
        [anon_sym_alias] = ACTIONS(753),
        [anon_sym_custom] = ACTIONS(756),
        [anon_sym_typedef] = ACTIONS(759),
        [anon_sym_ATignore_literal_names] = ACTIONS(762),
        [anon_sym_typeid] = ACTIONS(765),
        [anon_sym_typeprefix] = ACTIONS(768),
        [anon_sym_import] = ACTIONS(771),
        [anon_sym_component] = ACTIONS(774),
        [anon_sym_home] = ACTIONS(777),
        [anon_sym_porttype] = ACTIONS(780),
        [anon_sym_connector] = ACTIONS(783),
        [anon_sym_native] = ACTIONS(786),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [27] = {
        [sym_except_dcl] = STATE(1149),
        [sym_interface_dcl] = STATE(1149),
        [sym_interface_kind] = STATE(1146),
        [sym_interface_forward_dcl] = STATE(1145),
        [sym_interface_def] = STATE(1145),
        [sym_interface_header] = STATE(1142),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_dcl] = STATE(1149),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_template_module_dcl] = STATE(1149),
        [sym_template_module_inst] = STATE(1149),
        [sym_value_dcl] = STATE(1149),
        [sym_value_def] = STATE(1112),
        [sym_value_kind] = STATE(1110),
        [sym_value_header] = STATE(1109),
        [sym_value_forward_dcl] = STATE(1112),
        [sym_typedef_dcl] = STATE(1108),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_type_id_dcl] = STATE(1149),
        [sym_type_prefix_dcl] = STATE(1149),
        [sym_import_dcl] = STATE(1149),
        [sym_value_box_def] = STATE(1112),
        [sym_value_abs_def] = STATE(1112),
        [sym_component_dcl] = STATE(1149),
        [sym_component_forward_dcl] = STATE(1077),
        [sym_component_def] = STATE(1077),
        [sym_component_header] = STATE(1076),
        [sym_home_dcl] = STATE(1149),
        [sym_home_header] = STATE(1075),
        [sym_event_dcl] = STATE(1149),
        [sym_event_forward_dcl] = STATE(1073),
        [sym_event_abs_def] = STATE(1073),
        [sym_event_def] = STATE(1073),
        [sym_event_header] = STATE(1045),
        [sym_porttype_dcl] = STATE(1149),
        [sym_porttype_forward_dcl] = STATE(1041),
        [sym_porttype_def] = STATE(1041),
        [sym_connector_dcl] = STATE(1149),
        [sym_connector_header] = STATE(1039),
        [sym_definition] = STATE(168),
        [sym_type_dcl] = STATE(1149),
        [sym_constr_type_dcl] = STATE(1038),
        [sym_native_dcl] = STATE(1038),
        [sym_module_dcl] = STATE(1149),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_const_dcl] = STATE(1149),
        [sym_comment] = STATE(27),
        [aux_sym_interface_def_repeat1] = STATE(222),
        [aux_sym_module_dcl_repeat1] = STATE(28),
        [anon_sym_exception] = ACTIONS(15),
        [anon_sym_RBRACE] = ACTIONS(789),
        [anon_sym_local] = ACTIONS(17),
        [anon_sym_abstract] = ACTIONS(19),
        [anon_sym_interface] = ACTIONS(21),
        [anon_sym_bitset] = ACTIONS(23),
        [anon_sym_bitmask] = ACTIONS(25),
        [anon_sym_ATannotation] = ACTIONS(27),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_module] = ACTIONS(33),
        [anon_sym_valuetype] = ACTIONS(35),
        [anon_sym_eventtype] = ACTIONS(37),
        [anon_sym_struct] = ACTIONS(39),
        [anon_sym_union] = ACTIONS(41),
        [anon_sym_enum] = ACTIONS(43),
        [anon_sym_const] = ACTIONS(45),
        [anon_sym_custom] = ACTIONS(47),
        [anon_sym_typedef] = ACTIONS(49),
        [anon_sym_ATignore_literal_names] = ACTIONS(51),
        [anon_sym_typeid] = ACTIONS(53),
        [anon_sym_typeprefix] = ACTIONS(55),
        [anon_sym_import] = ACTIONS(57),
        [anon_sym_component] = ACTIONS(59),
        [anon_sym_home] = ACTIONS(61),
        [anon_sym_porttype] = ACTIONS(63),
        [anon_sym_connector] = ACTIONS(65),
        [anon_sym_native] = ACTIONS(67),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [28] = {
        [sym_except_dcl] = STATE(1149),
        [sym_interface_dcl] = STATE(1149),
        [sym_interface_kind] = STATE(1146),
        [sym_interface_forward_dcl] = STATE(1145),
        [sym_interface_def] = STATE(1145),
        [sym_interface_header] = STATE(1142),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_dcl] = STATE(1149),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_template_module_dcl] = STATE(1149),
        [sym_template_module_inst] = STATE(1149),
        [sym_value_dcl] = STATE(1149),
        [sym_value_def] = STATE(1112),
        [sym_value_kind] = STATE(1110),
        [sym_value_header] = STATE(1109),
        [sym_value_forward_dcl] = STATE(1112),
        [sym_typedef_dcl] = STATE(1108),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_type_id_dcl] = STATE(1149),
        [sym_type_prefix_dcl] = STATE(1149),
        [sym_import_dcl] = STATE(1149),
        [sym_value_box_def] = STATE(1112),
        [sym_value_abs_def] = STATE(1112),
        [sym_component_dcl] = STATE(1149),
        [sym_component_forward_dcl] = STATE(1077),
        [sym_component_def] = STATE(1077),
        [sym_component_header] = STATE(1076),
        [sym_home_dcl] = STATE(1149),
        [sym_home_header] = STATE(1075),
        [sym_event_dcl] = STATE(1149),
        [sym_event_forward_dcl] = STATE(1073),
        [sym_event_abs_def] = STATE(1073),
        [sym_event_def] = STATE(1073),
        [sym_event_header] = STATE(1045),
        [sym_porttype_dcl] = STATE(1149),
        [sym_porttype_forward_dcl] = STATE(1041),
        [sym_porttype_def] = STATE(1041),
        [sym_connector_dcl] = STATE(1149),
        [sym_connector_header] = STATE(1039),
        [sym_definition] = STATE(168),
        [sym_type_dcl] = STATE(1149),
        [sym_constr_type_dcl] = STATE(1038),
        [sym_native_dcl] = STATE(1038),
        [sym_module_dcl] = STATE(1149),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_const_dcl] = STATE(1149),
        [sym_comment] = STATE(28),
        [aux_sym_interface_def_repeat1] = STATE(222),
        [aux_sym_module_dcl_repeat1] = STATE(28),
        [anon_sym_exception] = ACTIONS(791),
        [anon_sym_RBRACE] = ACTIONS(794),
        [anon_sym_local] = ACTIONS(796),
        [anon_sym_abstract] = ACTIONS(799),
        [anon_sym_interface] = ACTIONS(802),
        [anon_sym_bitset] = ACTIONS(805),
        [anon_sym_bitmask] = ACTIONS(808),
        [anon_sym_ATannotation] = ACTIONS(811),
        [anon_sym_AT] = ACTIONS(814),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(817),
        [anon_sym_module] = ACTIONS(820),
        [anon_sym_valuetype] = ACTIONS(823),
        [anon_sym_eventtype] = ACTIONS(826),
        [anon_sym_struct] = ACTIONS(829),
        [anon_sym_union] = ACTIONS(832),
        [anon_sym_enum] = ACTIONS(835),
        [anon_sym_const] = ACTIONS(838),
        [anon_sym_custom] = ACTIONS(841),
        [anon_sym_typedef] = ACTIONS(844),
        [anon_sym_ATignore_literal_names] = ACTIONS(847),
        [anon_sym_typeid] = ACTIONS(850),
        [anon_sym_typeprefix] = ACTIONS(853),
        [anon_sym_import] = ACTIONS(856),
        [anon_sym_component] = ACTIONS(859),
        [anon_sym_home] = ACTIONS(862),
        [anon_sym_porttype] = ACTIONS(865),
        [anon_sym_connector] = ACTIONS(868),
        [anon_sym_native] = ACTIONS(871),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [29] = {
        [sym_except_dcl] = STATE(1149),
        [sym_interface_dcl] = STATE(1149),
        [sym_interface_kind] = STATE(1146),
        [sym_interface_forward_dcl] = STATE(1145),
        [sym_interface_def] = STATE(1145),
        [sym_interface_header] = STATE(1142),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_dcl] = STATE(1149),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_template_module_dcl] = STATE(1149),
        [sym_template_module_inst] = STATE(1149),
        [sym_value_dcl] = STATE(1149),
        [sym_value_def] = STATE(1112),
        [sym_value_kind] = STATE(1110),
        [sym_value_header] = STATE(1109),
        [sym_value_forward_dcl] = STATE(1112),
        [sym_typedef_dcl] = STATE(1108),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_type_id_dcl] = STATE(1149),
        [sym_type_prefix_dcl] = STATE(1149),
        [sym_import_dcl] = STATE(1149),
        [sym_value_box_def] = STATE(1112),
        [sym_value_abs_def] = STATE(1112),
        [sym_component_dcl] = STATE(1149),
        [sym_component_forward_dcl] = STATE(1077),
        [sym_component_def] = STATE(1077),
        [sym_component_header] = STATE(1076),
        [sym_home_dcl] = STATE(1149),
        [sym_home_header] = STATE(1075),
        [sym_event_dcl] = STATE(1149),
        [sym_event_forward_dcl] = STATE(1073),
        [sym_event_abs_def] = STATE(1073),
        [sym_event_def] = STATE(1073),
        [sym_event_header] = STATE(1045),
        [sym_porttype_dcl] = STATE(1149),
        [sym_porttype_forward_dcl] = STATE(1041),
        [sym_porttype_def] = STATE(1041),
        [sym_connector_dcl] = STATE(1149),
        [sym_connector_header] = STATE(1039),
        [sym_definition] = STATE(168),
        [sym_type_dcl] = STATE(1149),
        [sym_constr_type_dcl] = STATE(1038),
        [sym_native_dcl] = STATE(1038),
        [sym_module_dcl] = STATE(1149),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_const_dcl] = STATE(1149),
        [sym_comment] = STATE(29),
        [aux_sym_interface_def_repeat1] = STATE(222),
        [aux_sym_module_dcl_repeat1] = STATE(27),
        [anon_sym_exception] = ACTIONS(15),
        [anon_sym_RBRACE] = ACTIONS(874),
        [anon_sym_local] = ACTIONS(17),
        [anon_sym_abstract] = ACTIONS(19),
        [anon_sym_interface] = ACTIONS(21),
        [anon_sym_bitset] = ACTIONS(23),
        [anon_sym_bitmask] = ACTIONS(25),
        [anon_sym_ATannotation] = ACTIONS(27),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_module] = ACTIONS(33),
        [anon_sym_valuetype] = ACTIONS(35),
        [anon_sym_eventtype] = ACTIONS(37),
        [anon_sym_struct] = ACTIONS(39),
        [anon_sym_union] = ACTIONS(41),
        [anon_sym_enum] = ACTIONS(43),
        [anon_sym_const] = ACTIONS(45),
        [anon_sym_custom] = ACTIONS(47),
        [anon_sym_typedef] = ACTIONS(49),
        [anon_sym_ATignore_literal_names] = ACTIONS(51),
        [anon_sym_typeid] = ACTIONS(53),
        [anon_sym_typeprefix] = ACTIONS(55),
        [anon_sym_import] = ACTIONS(57),
        [anon_sym_component] = ACTIONS(59),
        [anon_sym_home] = ACTIONS(61),
        [anon_sym_porttype] = ACTIONS(63),
        [anon_sym_connector] = ACTIONS(65),
        [anon_sym_native] = ACTIONS(67),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [30] = {
        [sym_signed_short_int] = STATE(370),
        [sym_signed_long_int] = STATE(370),
        [sym_signed_longlong_int] = STATE(370),
        [sym_unsigned_int] = STATE(375),
        [sym_integer_type] = STATE(439),
        [sym_signed_int] = STATE(375),
        [sym_unsigned_short_int] = STATE(366),
        [sym_unsigned_long_int] = STATE(366),
        [sym_unsigned_longlong_int] = STATE(366),
        [sym_floating_pt_type] = STATE(439),
        [sym_char_type] = STATE(439),
        [sym_scoped_name] = STATE(376),
        [sym_string_type] = STATE(435),
        [sym_type_spec] = STATE(429),
        [sym_simple_type_spec] = STATE(388),
        [sym_base_type_spec] = STATE(433),
        [sym_any_type] = STATE(439),
        [sym_fixed_pt_type] = STATE(435),
        [sym_template_type_spec] = STATE(388),
        [sym_sequence_type] = STATE(435),
        [sym_map_type] = STATE(435),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_element_spec] = STATE(846),
        [sym_object_type] = STATE(439),
        [sym_constr_type_dcl] = STATE(429),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_comment] = STATE(30),
        [aux_sym_interface_def_repeat1] = STATE(277),
        [anon_sym_short] = ACTIONS(69),
        [anon_sym_int16] = ACTIONS(69),
        [anon_sym_long] = ACTIONS(71),
        [anon_sym_int32] = ACTIONS(71),
        [anon_sym_longlong] = ACTIONS(73),
        [anon_sym_int64] = ACTIONS(75),
        [sym_unsigned_tiny_int] = ACTIONS(77),
        [sym_boolean_type] = ACTIONS(79),
        [anon_sym_fixed] = ACTIONS(81),
        [sym_octet_type] = ACTIONS(79),
        [sym_signed_tiny_int] = ACTIONS(83),
        [anon_sym_unsignedshort] = ACTIONS(85),
        [anon_sym_uint16] = ACTIONS(87),
        [anon_sym_unsignedlong] = ACTIONS(89),
        [anon_sym_uint32] = ACTIONS(89),
        [anon_sym_unsignedlonglong] = ACTIONS(91),
        [anon_sym_uint64] = ACTIONS(93),
        [anon_sym_float] = ACTIONS(95),
        [anon_sym_double] = ACTIONS(95),
        [anon_sym_longdouble] = ACTIONS(97),
        [anon_sym_char] = ACTIONS(99),
        [anon_sym_wchar] = ACTIONS(99),
        [anon_sym_COLON_COLON] = ACTIONS(101),
        [anon_sym_string] = ACTIONS(103),
        [anon_sym_wstring] = ACTIONS(103),
        [anon_sym_any] = ACTIONS(105),
        [anon_sym_sequence] = ACTIONS(107),
        [anon_sym_map] = ACTIONS(109),
        [anon_sym_RBRACE] = ACTIONS(876),
        [anon_sym_bitset] = ACTIONS(123),
        [anon_sym_bitmask] = ACTIONS(125),
        [anon_sym_default] = ACTIONS(878),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_ATignore_literal_names] = ACTIONS(51),
        [anon_sym_case] = ACTIONS(878),
        [anon_sym_Object] = ACTIONS(151),
        [sym_value_base_type] = ACTIONS(79),
        [sym_identifier] = ACTIONS(155),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [31] = {
        [sym_signed_short_int] = STATE(370),
        [sym_signed_long_int] = STATE(370),
        [sym_signed_longlong_int] = STATE(370),
        [sym_unsigned_int] = STATE(375),
        [sym_integer_type] = STATE(439),
        [sym_signed_int] = STATE(375),
        [sym_unsigned_short_int] = STATE(366),
        [sym_unsigned_long_int] = STATE(366),
        [sym_unsigned_longlong_int] = STATE(366),
        [sym_floating_pt_type] = STATE(439),
        [sym_char_type] = STATE(439),
        [sym_scoped_name] = STATE(221),
        [sym_string_type] = STATE(435),
        [sym_type_spec] = STATE(784),
        [sym_simple_type_spec] = STATE(388),
        [sym_base_type_spec] = STATE(433),
        [sym_any_type] = STATE(439),
        [sym_fixed_pt_type] = STATE(435),
        [sym_template_type_spec] = STATE(388),
        [sym_sequence_type] = STATE(435),
        [sym_map_type] = STATE(435),
        [sym_const_expr] = STATE(784),
        [sym_or_expr] = STATE(292),
        [sym_xor_expr] = STATE(272),
        [sym_and_expr] = STATE(253),
        [sym_shift_expr] = STATE(223),
        [sym_add_expr] = STATE(218),
        [sym_mult_expr] = STATE(197),
        [sym_unary_expr] = STATE(195),
        [sym_primary_expr] = STATE(196),
        [sym_unary_operator] = STATE(216),
        [sym_literal] = STATE(198),
        [sym_string_literal] = STATE(208),
        [sym_char_literal] = STATE(208),
        [sym_boolean_literal] = STATE(208),
        [sym_actual_parameters] = STATE(982),
        [sym_actual_parameter] = STATE(588),
        [sym_object_type] = STATE(439),
        [sym_comment] = STATE(31),
        [anon_sym_short] = ACTIONS(69),
        [anon_sym_int16] = ACTIONS(69),
        [anon_sym_long] = ACTIONS(71),
        [anon_sym_int32] = ACTIONS(71),
        [anon_sym_longlong] = ACTIONS(73),
        [anon_sym_int64] = ACTIONS(75),
        [sym_unsigned_tiny_int] = ACTIONS(77),
        [sym_boolean_type] = ACTIONS(79),
        [anon_sym_fixed] = ACTIONS(81),
        [sym_octet_type] = ACTIONS(79),
        [sym_signed_tiny_int] = ACTIONS(83),
        [anon_sym_unsignedshort] = ACTIONS(85),
        [anon_sym_uint16] = ACTIONS(87),
        [anon_sym_unsignedlong] = ACTIONS(89),
        [anon_sym_uint32] = ACTIONS(89),
        [anon_sym_unsignedlonglong] = ACTIONS(91),
        [anon_sym_uint64] = ACTIONS(93),
        [anon_sym_float] = ACTIONS(95),
        [anon_sym_double] = ACTIONS(95),
        [anon_sym_longdouble] = ACTIONS(97),
        [anon_sym_char] = ACTIONS(99),
        [anon_sym_wchar] = ACTIONS(99),
        [anon_sym_COLON_COLON] = ACTIONS(880),
        [anon_sym_string] = ACTIONS(103),
        [anon_sym_wstring] = ACTIONS(103),
        [anon_sym_any] = ACTIONS(105),
        [anon_sym_sequence] = ACTIONS(107),
        [anon_sym_map] = ACTIONS(109),
        [anon_sym_PLUS] = ACTIONS(882),
        [anon_sym_DASH] = ACTIONS(882),
        [anon_sym_LPAREN] = ACTIONS(884),
        [anon_sym_TILDE] = ACTIONS(886),
        [anon_sym_L] = ACTIONS(888),
        [anon_sym_DQUOTE] = ACTIONS(890),
        [anon_sym_SQUOTE] = ACTIONS(892),
        [anon_sym_TRUE] = ACTIONS(894),
        [anon_sym_FALSE] = ACTIONS(894),
        [sym_number_literal] = ACTIONS(896),
        [anon_sym_Object] = ACTIONS(151),
        [sym_value_base_type] = ACTIONS(79),
        [sym_identifier] = ACTIONS(155),
        [anon_sym_SLASH_SLASH] = ACTIONS(898),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [32] = {
        [sym_signed_short_int] = STATE(370),
        [sym_signed_long_int] = STATE(370),
        [sym_signed_longlong_int] = STATE(370),
        [sym_unsigned_int] = STATE(375),
        [sym_integer_type] = STATE(439),
        [sym_signed_int] = STATE(375),
        [sym_unsigned_short_int] = STATE(366),
        [sym_unsigned_long_int] = STATE(366),
        [sym_unsigned_longlong_int] = STATE(366),
        [sym_floating_pt_type] = STATE(439),
        [sym_char_type] = STATE(439),
        [sym_scoped_name] = STATE(221),
        [sym_string_type] = STATE(435),
        [sym_type_spec] = STATE(784),
        [sym_simple_type_spec] = STATE(388),
        [sym_base_type_spec] = STATE(433),
        [sym_any_type] = STATE(439),
        [sym_fixed_pt_type] = STATE(435),
        [sym_template_type_spec] = STATE(388),
        [sym_sequence_type] = STATE(435),
        [sym_map_type] = STATE(435),
        [sym_const_expr] = STATE(784),
        [sym_or_expr] = STATE(292),
        [sym_xor_expr] = STATE(272),
        [sym_and_expr] = STATE(253),
        [sym_shift_expr] = STATE(223),
        [sym_add_expr] = STATE(218),
        [sym_mult_expr] = STATE(197),
        [sym_unary_expr] = STATE(195),
        [sym_primary_expr] = STATE(196),
        [sym_unary_operator] = STATE(216),
        [sym_literal] = STATE(198),
        [sym_string_literal] = STATE(208),
        [sym_char_literal] = STATE(208),
        [sym_boolean_literal] = STATE(208),
        [sym_actual_parameter] = STATE(811),
        [sym_object_type] = STATE(439),
        [sym_comment] = STATE(32),
        [anon_sym_short] = ACTIONS(69),
        [anon_sym_int16] = ACTIONS(69),
        [anon_sym_long] = ACTIONS(71),
        [anon_sym_int32] = ACTIONS(71),
        [anon_sym_longlong] = ACTIONS(73),
        [anon_sym_int64] = ACTIONS(75),
        [sym_unsigned_tiny_int] = ACTIONS(77),
        [sym_boolean_type] = ACTIONS(79),
        [anon_sym_fixed] = ACTIONS(81),
        [sym_octet_type] = ACTIONS(79),
        [sym_signed_tiny_int] = ACTIONS(83),
        [anon_sym_unsignedshort] = ACTIONS(85),
        [anon_sym_uint16] = ACTIONS(87),
        [anon_sym_unsignedlong] = ACTIONS(89),
        [anon_sym_uint32] = ACTIONS(89),
        [anon_sym_unsignedlonglong] = ACTIONS(91),
        [anon_sym_uint64] = ACTIONS(93),
        [anon_sym_float] = ACTIONS(95),
        [anon_sym_double] = ACTIONS(95),
        [anon_sym_longdouble] = ACTIONS(97),
        [anon_sym_char] = ACTIONS(99),
        [anon_sym_wchar] = ACTIONS(99),
        [anon_sym_COLON_COLON] = ACTIONS(880),
        [anon_sym_string] = ACTIONS(103),
        [anon_sym_wstring] = ACTIONS(103),
        [anon_sym_any] = ACTIONS(105),
        [anon_sym_sequence] = ACTIONS(107),
        [anon_sym_map] = ACTIONS(109),
        [anon_sym_PLUS] = ACTIONS(882),
        [anon_sym_DASH] = ACTIONS(882),
        [anon_sym_LPAREN] = ACTIONS(884),
        [anon_sym_TILDE] = ACTIONS(886),
        [anon_sym_L] = ACTIONS(888),
        [anon_sym_DQUOTE] = ACTIONS(890),
        [anon_sym_SQUOTE] = ACTIONS(892),
        [anon_sym_TRUE] = ACTIONS(894),
        [anon_sym_FALSE] = ACTIONS(894),
        [sym_number_literal] = ACTIONS(896),
        [anon_sym_Object] = ACTIONS(151),
        [sym_value_base_type] = ACTIONS(79),
        [sym_identifier] = ACTIONS(155),
        [anon_sym_SLASH_SLASH] = ACTIONS(898),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [33] = {
        [sym_signed_short_int] = STATE(370),
        [sym_signed_long_int] = STATE(370),
        [sym_signed_longlong_int] = STATE(370),
        [sym_unsigned_int] = STATE(375),
        [sym_integer_type] = STATE(439),
        [sym_signed_int] = STATE(375),
        [sym_unsigned_short_int] = STATE(366),
        [sym_unsigned_long_int] = STATE(366),
        [sym_unsigned_longlong_int] = STATE(366),
        [sym_floating_pt_type] = STATE(439),
        [sym_char_type] = STATE(439),
        [sym_scoped_name] = STATE(376),
        [sym_string_type] = STATE(435),
        [sym_simple_type_spec] = STATE(377),
        [sym_base_type_spec] = STATE(433),
        [sym_any_type] = STATE(439),
        [sym_fixed_pt_type] = STATE(435),
        [sym_template_type_spec] = STATE(377),
        [sym_sequence_type] = STATE(435),
        [sym_map_type] = STATE(435),
        [sym_bitset_dcl] = STATE(754),
        [sym_bitmask_dcl] = STATE(754),
        [sym_annotation_appl] = STATE(286),
        [sym_extend_annotation_appl] = STATE(291),
        [sym_type_declarator] = STATE(961),
        [sym_enum_dcl] = STATE(754),
        [sym_enum_anno] = STATE(964),
        [sym_union_dcl] = STATE(754),
        [sym_union_forward_dcl] = STATE(755),
        [sym_union_def] = STATE(755),
        [sym_object_type] = STATE(439),
        [sym_constr_type_dcl] = STATE(377),
        [sym_struct_dcl] = STATE(754),
        [sym_struct_forward_dcl] = STATE(761),
        [sym_struct_def] = STATE(761),
        [sym_comment] = STATE(33),
        [aux_sym_interface_def_repeat1] = STATE(277),
        [anon_sym_short] = ACTIONS(69),
        [anon_sym_int16] = ACTIONS(69),
        [anon_sym_long] = ACTIONS(71),
        [anon_sym_int32] = ACTIONS(71),
        [anon_sym_longlong] = ACTIONS(73),
        [anon_sym_int64] = ACTIONS(75),
        [sym_unsigned_tiny_int] = ACTIONS(77),
        [sym_boolean_type] = ACTIONS(79),
        [anon_sym_fixed] = ACTIONS(81),
        [sym_octet_type] = ACTIONS(79),
        [sym_signed_tiny_int] = ACTIONS(83),
        [anon_sym_unsignedshort] = ACTIONS(85),
        [anon_sym_uint16] = ACTIONS(87),
        [anon_sym_unsignedlong] = ACTIONS(89),
        [anon_sym_uint32] = ACTIONS(89),
        [anon_sym_unsignedlonglong] = ACTIONS(91),
        [anon_sym_uint64] = ACTIONS(93),
        [anon_sym_float] = ACTIONS(95),
        [anon_sym_double] = ACTIONS(95),
        [anon_sym_longdouble] = ACTIONS(97),
        [anon_sym_char] = ACTIONS(99),
        [anon_sym_wchar] = ACTIONS(99),
        [anon_sym_COLON_COLON] = ACTIONS(101),
        [anon_sym_string] = ACTIONS(103),
        [anon_sym_wstring] = ACTIONS(103),
        [anon_sym_any] = ACTIONS(105),
        [anon_sym_sequence] = ACTIONS(107),
        [anon_sym_map] = ACTIONS(109),
        [anon_sym_bitset] = ACTIONS(123),
        [anon_sym_bitmask] = ACTIONS(125),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_ATignore_literal_names] = ACTIONS(51),
        [anon_sym_Object] = ACTIONS(151),
        [sym_value_base_type] = ACTIONS(79),
        [sym_identifier] = ACTIONS(155),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
};

static const uint16_t ts_small_parse_table[] = {
    [0] = 42,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(906),
    1,
    anon_sym_longlong,
    ACTIONS(909),
    1,
    anon_sym_int64,
    ACTIONS(912),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(918),
    1,
    anon_sym_fixed,
    ACTIONS(921),
    1,
    sym_signed_tiny_int,
    ACTIONS(924),
    1,
    anon_sym_unsignedshort,
    ACTIONS(927),
    1,
    anon_sym_uint16,
    ACTIONS(933),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(936),
    1,
    anon_sym_uint64,
    ACTIONS(942),
    1,
    anon_sym_longdouble,
    ACTIONS(948),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(954),
    1,
    anon_sym_any,
    ACTIONS(957),
    1,
    anon_sym_sequence,
    ACTIONS(960),
    1,
    anon_sym_map,
    ACTIONS(963),
    1,
    anon_sym_RBRACE,
    ACTIONS(965),
    1,
    anon_sym_AT,
    ACTIONS(968),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(971),
    1,
    anon_sym_Object,
    ACTIONS(974),
    1,
    sym_identifier,
    STATE(48),
    1,
    aux_sym_interface_def_repeat1,
    STATE(99),
    1,
    sym_member,
    STATE(113),
    1,
    sym_annotation_appl,
    STATE(120),
    1,
    sym_extend_annotation_appl,
    STATE(369),
    1,
    sym_type_spec,
    STATE(376),
    1,
    sym_scoped_name,
    STATE(433),
    1,
    sym_base_type_spec,
    ACTIONS(900),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(903),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(930),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(939),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(945),
    2,
    anon_sym_char,
    anon_sym_wchar,
    ACTIONS(951),
    2,
    anon_sym_string,
    anon_sym_wstring,
    STATE(34),
    2,
    sym_comment,
    aux_sym_except_dcl_repeat1,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(388),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    ACTIONS(915),
    3,
    sym_boolean_type,
    sym_octet_type,
    sym_value_base_type,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(435),
    4,
    sym_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    STATE(439),
    5,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_any_type,
    sym_object_type,
    [149] = 43,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    anon_sym_fixed,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_longdouble,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(105),
    1,
    anon_sym_any,
    ACTIONS(107),
    1,
    anon_sym_sequence,
    ACTIONS(109),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(977),
    1,
    anon_sym_RBRACE,
    ACTIONS(979),
    1,
    anon_sym_AT,
    ACTIONS(981),
    1,
    anon_sym_SLASH_SLASH_AT,
    STATE(35),
    1,
    sym_comment,
    STATE(42),
    1,
    aux_sym_except_dcl_repeat1,
    STATE(48),
    1,
    aux_sym_interface_def_repeat1,
    STATE(99),
    1,
    sym_member,
    STATE(113),
    1,
    sym_annotation_appl,
    STATE(120),
    1,
    sym_extend_annotation_appl,
    STATE(369),
    1,
    sym_type_spec,
    STATE(376),
    1,
    sym_scoped_name,
    STATE(433),
    1,
    sym_base_type_spec,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(95),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    ACTIONS(103),
    2,
    anon_sym_string,
    anon_sym_wstring,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(388),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    ACTIONS(79),
    3,
    sym_boolean_type,
    sym_octet_type,
    sym_value_base_type,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(435),
    4,
    sym_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    STATE(439),
    5,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_any_type,
    sym_object_type,
    [300] = 43,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    anon_sym_fixed,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_longdouble,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(105),
    1,
    anon_sym_any,
    ACTIONS(107),
    1,
    anon_sym_sequence,
    ACTIONS(109),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(979),
    1,
    anon_sym_AT,
    ACTIONS(981),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(983),
    1,
    anon_sym_RBRACE,
    STATE(36),
    1,
    sym_comment,
    STATE(39),
    1,
    aux_sym_except_dcl_repeat1,
    STATE(48),
    1,
    aux_sym_interface_def_repeat1,
    STATE(99),
    1,
    sym_member,
    STATE(113),
    1,
    sym_annotation_appl,
    STATE(120),
    1,
    sym_extend_annotation_appl,
    STATE(369),
    1,
    sym_type_spec,
    STATE(376),
    1,
    sym_scoped_name,
    STATE(433),
    1,
    sym_base_type_spec,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(95),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    ACTIONS(103),
    2,
    anon_sym_string,
    anon_sym_wstring,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(388),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    ACTIONS(79),
    3,
    sym_boolean_type,
    sym_octet_type,
    sym_value_base_type,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(435),
    4,
    sym_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    STATE(439),
    5,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_any_type,
    sym_object_type,
    [451] = 43,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    anon_sym_fixed,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_longdouble,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(105),
    1,
    anon_sym_any,
    ACTIONS(107),
    1,
    anon_sym_sequence,
    ACTIONS(109),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(979),
    1,
    anon_sym_AT,
    ACTIONS(981),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(985),
    1,
    anon_sym_RBRACE,
    STATE(34),
    1,
    aux_sym_except_dcl_repeat1,
    STATE(37),
    1,
    sym_comment,
    STATE(48),
    1,
    aux_sym_interface_def_repeat1,
    STATE(99),
    1,
    sym_member,
    STATE(113),
    1,
    sym_annotation_appl,
    STATE(120),
    1,
    sym_extend_annotation_appl,
    STATE(369),
    1,
    sym_type_spec,
    STATE(376),
    1,
    sym_scoped_name,
    STATE(433),
    1,
    sym_base_type_spec,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(95),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    ACTIONS(103),
    2,
    anon_sym_string,
    anon_sym_wstring,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(388),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    ACTIONS(79),
    3,
    sym_boolean_type,
    sym_octet_type,
    sym_value_base_type,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(435),
    4,
    sym_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    STATE(439),
    5,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_any_type,
    sym_object_type,
    [602] = 43,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    anon_sym_fixed,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_longdouble,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(105),
    1,
    anon_sym_any,
    ACTIONS(107),
    1,
    anon_sym_sequence,
    ACTIONS(109),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(979),
    1,
    anon_sym_AT,
    ACTIONS(981),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(987),
    1,
    anon_sym_RBRACE,
    STATE(38),
    1,
    sym_comment,
    STATE(44),
    1,
    aux_sym_except_dcl_repeat1,
    STATE(48),
    1,
    aux_sym_interface_def_repeat1,
    STATE(99),
    1,
    sym_member,
    STATE(113),
    1,
    sym_annotation_appl,
    STATE(120),
    1,
    sym_extend_annotation_appl,
    STATE(369),
    1,
    sym_type_spec,
    STATE(376),
    1,
    sym_scoped_name,
    STATE(433),
    1,
    sym_base_type_spec,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(95),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    ACTIONS(103),
    2,
    anon_sym_string,
    anon_sym_wstring,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(388),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    ACTIONS(79),
    3,
    sym_boolean_type,
    sym_octet_type,
    sym_value_base_type,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(435),
    4,
    sym_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    STATE(439),
    5,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_any_type,
    sym_object_type,
    [753] = 43,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    anon_sym_fixed,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_longdouble,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(105),
    1,
    anon_sym_any,
    ACTIONS(107),
    1,
    anon_sym_sequence,
    ACTIONS(109),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(979),
    1,
    anon_sym_AT,
    ACTIONS(981),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(989),
    1,
    anon_sym_RBRACE,
    STATE(34),
    1,
    aux_sym_except_dcl_repeat1,
    STATE(39),
    1,
    sym_comment,
    STATE(48),
    1,
    aux_sym_interface_def_repeat1,
    STATE(99),
    1,
    sym_member,
    STATE(113),
    1,
    sym_annotation_appl,
    STATE(120),
    1,
    sym_extend_annotation_appl,
    STATE(369),
    1,
    sym_type_spec,
    STATE(376),
    1,
    sym_scoped_name,
    STATE(433),
    1,
    sym_base_type_spec,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(95),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    ACTIONS(103),
    2,
    anon_sym_string,
    anon_sym_wstring,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(388),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    ACTIONS(79),
    3,
    sym_boolean_type,
    sym_octet_type,
    sym_value_base_type,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(435),
    4,
    sym_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    STATE(439),
    5,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_any_type,
    sym_object_type,
    [904] = 43,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    anon_sym_fixed,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_longdouble,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(105),
    1,
    anon_sym_any,
    ACTIONS(107),
    1,
    anon_sym_sequence,
    ACTIONS(109),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(979),
    1,
    anon_sym_AT,
    ACTIONS(981),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(991),
    1,
    anon_sym_RBRACE,
    STATE(34),
    1,
    aux_sym_except_dcl_repeat1,
    STATE(40),
    1,
    sym_comment,
    STATE(48),
    1,
    aux_sym_interface_def_repeat1,
    STATE(99),
    1,
    sym_member,
    STATE(113),
    1,
    sym_annotation_appl,
    STATE(120),
    1,
    sym_extend_annotation_appl,
    STATE(369),
    1,
    sym_type_spec,
    STATE(376),
    1,
    sym_scoped_name,
    STATE(433),
    1,
    sym_base_type_spec,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(95),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    ACTIONS(103),
    2,
    anon_sym_string,
    anon_sym_wstring,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(388),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    ACTIONS(79),
    3,
    sym_boolean_type,
    sym_octet_type,
    sym_value_base_type,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(435),
    4,
    sym_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    STATE(439),
    5,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_any_type,
    sym_object_type,
    [1055] = 43,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    anon_sym_fixed,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_longdouble,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(105),
    1,
    anon_sym_any,
    ACTIONS(107),
    1,
    anon_sym_sequence,
    ACTIONS(109),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(979),
    1,
    anon_sym_AT,
    ACTIONS(981),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(993),
    1,
    anon_sym_RBRACE,
    STATE(40),
    1,
    aux_sym_except_dcl_repeat1,
    STATE(41),
    1,
    sym_comment,
    STATE(48),
    1,
    aux_sym_interface_def_repeat1,
    STATE(99),
    1,
    sym_member,
    STATE(113),
    1,
    sym_annotation_appl,
    STATE(120),
    1,
    sym_extend_annotation_appl,
    STATE(369),
    1,
    sym_type_spec,
    STATE(376),
    1,
    sym_scoped_name,
    STATE(433),
    1,
    sym_base_type_spec,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(95),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    ACTIONS(103),
    2,
    anon_sym_string,
    anon_sym_wstring,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(388),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    ACTIONS(79),
    3,
    sym_boolean_type,
    sym_octet_type,
    sym_value_base_type,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(435),
    4,
    sym_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    STATE(439),
    5,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_any_type,
    sym_object_type,
    [1206] = 43,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    anon_sym_fixed,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_longdouble,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(105),
    1,
    anon_sym_any,
    ACTIONS(107),
    1,
    anon_sym_sequence,
    ACTIONS(109),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(979),
    1,
    anon_sym_AT,
    ACTIONS(981),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(993),
    1,
    anon_sym_RBRACE,
    STATE(34),
    1,
    aux_sym_except_dcl_repeat1,
    STATE(42),
    1,
    sym_comment,
    STATE(48),
    1,
    aux_sym_interface_def_repeat1,
    STATE(99),
    1,
    sym_member,
    STATE(113),
    1,
    sym_annotation_appl,
    STATE(120),
    1,
    sym_extend_annotation_appl,
    STATE(369),
    1,
    sym_type_spec,
    STATE(376),
    1,
    sym_scoped_name,
    STATE(433),
    1,
    sym_base_type_spec,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(95),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    ACTIONS(103),
    2,
    anon_sym_string,
    anon_sym_wstring,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(388),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    ACTIONS(79),
    3,
    sym_boolean_type,
    sym_octet_type,
    sym_value_base_type,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(435),
    4,
    sym_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    STATE(439),
    5,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_any_type,
    sym_object_type,
    [1357] = 43,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    anon_sym_fixed,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_longdouble,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(105),
    1,
    anon_sym_any,
    ACTIONS(107),
    1,
    anon_sym_sequence,
    ACTIONS(109),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(979),
    1,
    anon_sym_AT,
    ACTIONS(981),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(995),
    1,
    anon_sym_RBRACE,
    STATE(37),
    1,
    aux_sym_except_dcl_repeat1,
    STATE(43),
    1,
    sym_comment,
    STATE(48),
    1,
    aux_sym_interface_def_repeat1,
    STATE(99),
    1,
    sym_member,
    STATE(113),
    1,
    sym_annotation_appl,
    STATE(120),
    1,
    sym_extend_annotation_appl,
    STATE(369),
    1,
    sym_type_spec,
    STATE(376),
    1,
    sym_scoped_name,
    STATE(433),
    1,
    sym_base_type_spec,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(95),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    ACTIONS(103),
    2,
    anon_sym_string,
    anon_sym_wstring,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(388),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    ACTIONS(79),
    3,
    sym_boolean_type,
    sym_octet_type,
    sym_value_base_type,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(435),
    4,
    sym_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    STATE(439),
    5,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_any_type,
    sym_object_type,
    [1508] = 43,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    anon_sym_fixed,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_longdouble,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(105),
    1,
    anon_sym_any,
    ACTIONS(107),
    1,
    anon_sym_sequence,
    ACTIONS(109),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(979),
    1,
    anon_sym_AT,
    ACTIONS(981),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(997),
    1,
    anon_sym_RBRACE,
    STATE(34),
    1,
    aux_sym_except_dcl_repeat1,
    STATE(44),
    1,
    sym_comment,
    STATE(48),
    1,
    aux_sym_interface_def_repeat1,
    STATE(99),
    1,
    sym_member,
    STATE(113),
    1,
    sym_annotation_appl,
    STATE(120),
    1,
    sym_extend_annotation_appl,
    STATE(369),
    1,
    sym_type_spec,
    STATE(376),
    1,
    sym_scoped_name,
    STATE(433),
    1,
    sym_base_type_spec,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(95),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    ACTIONS(103),
    2,
    anon_sym_string,
    anon_sym_wstring,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(388),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    ACTIONS(79),
    3,
    sym_boolean_type,
    sym_octet_type,
    sym_value_base_type,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(435),
    4,
    sym_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    STATE(439),
    5,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_any_type,
    sym_object_type,
    [1659] = 42,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    anon_sym_fixed,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_longdouble,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(105),
    1,
    anon_sym_any,
    ACTIONS(107),
    1,
    anon_sym_sequence,
    ACTIONS(109),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(999),
    1,
    anon_sym_LBRACE,
    ACTIONS(1001),
    1,
    anon_sym_COLON,
    ACTIONS(1003),
    1,
    anon_sym_SEMI,
    ACTIONS(1005),
    1,
    anon_sym_supports,
    STATE(45),
    1,
    sym_comment,
    STATE(376),
    1,
    sym_scoped_name,
    STATE(433),
    1,
    sym_base_type_spec,
    STATE(609),
    1,
    sym_value_inheritance,
    STATE(842),
    1,
    sym_type_spec,
    STATE(930),
    1,
    sym_value_supports,
    STATE(1000),
    1,
    sym_value_inheritance_spec,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(95),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    ACTIONS(103),
    2,
    anon_sym_string,
    anon_sym_wstring,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(388),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    ACTIONS(79),
    3,
    sym_boolean_type,
    sym_octet_type,
    sym_value_base_type,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(435),
    4,
    sym_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    STATE(439),
    5,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_any_type,
    sym_object_type,
    [1807] = 40,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    anon_sym_fixed,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_longdouble,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(105),
    1,
    anon_sym_any,
    ACTIONS(107),
    1,
    anon_sym_sequence,
    ACTIONS(109),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1007),
    1,
    anon_sym_RPAREN,
    STATE(46),
    1,
    sym_comment,
    STATE(80),
    1,
    sym_param_attribute,
    STATE(376),
    1,
    sym_scoped_name,
    STATE(433),
    1,
    sym_base_type_spec,
    STATE(701),
    1,
    sym_param_dcl,
    STATE(775),
    1,
    sym_type_spec,
    STATE(1008),
    1,
    sym_parameter_dcls,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(95),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    ACTIONS(103),
    2,
    anon_sym_string,
    anon_sym_wstring,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(388),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    ACTIONS(79),
    3,
    sym_boolean_type,
    sym_octet_type,
    sym_value_base_type,
    ACTIONS(1009),
    3,
    anon_sym_in,
    anon_sym_out,
    anon_sym_inout,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(435),
    4,
    sym_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    STATE(439),
    5,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_any_type,
    sym_object_type,
    [1951] = 38,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    anon_sym_fixed,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_longdouble,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(105),
    1,
    anon_sym_any,
    ACTIONS(107),
    1,
    anon_sym_sequence,
    ACTIONS(109),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(47),
    1,
    sym_comment,
    STATE(80),
    1,
    sym_param_attribute,
    STATE(376),
    1,
    sym_scoped_name,
    STATE(433),
    1,
    sym_base_type_spec,
    STATE(775),
    1,
    sym_type_spec,
    STATE(823),
    1,
    sym_param_dcl,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(95),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    ACTIONS(103),
    2,
    anon_sym_string,
    anon_sym_wstring,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(388),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    ACTIONS(79),
    3,
    sym_boolean_type,
    sym_octet_type,
    sym_value_base_type,
    ACTIONS(1009),
    3,
    anon_sym_in,
    anon_sym_out,
    anon_sym_inout,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(435),
    4,
    sym_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    STATE(439),
    5,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_any_type,
    sym_object_type,
    [2089] = 40,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    anon_sym_fixed,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_longdouble,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(105),
    1,
    anon_sym_any,
    ACTIONS(107),
    1,
    anon_sym_sequence,
    ACTIONS(109),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(979),
    1,
    anon_sym_AT,
    ACTIONS(981),
    1,
    anon_sym_SLASH_SLASH_AT,
    STATE(48),
    1,
    sym_comment,
    STATE(89),
    1,
    aux_sym_interface_def_repeat1,
    STATE(113),
    1,
    sym_annotation_appl,
    STATE(120),
    1,
    sym_extend_annotation_appl,
    STATE(353),
    1,
    sym_type_spec,
    STATE(376),
    1,
    sym_scoped_name,
    STATE(433),
    1,
    sym_base_type_spec,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(95),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    ACTIONS(103),
    2,
    anon_sym_string,
    anon_sym_wstring,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(388),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    ACTIONS(79),
    3,
    sym_boolean_type,
    sym_octet_type,
    sym_value_base_type,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(435),
    4,
    sym_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    STATE(439),
    5,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_any_type,
    sym_object_type,
    [2231] = 41,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(51),
    1,
    anon_sym_ATignore_literal_names,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_longdouble,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(107),
    1,
    anon_sym_sequence,
    ACTIONS(135),
    1,
    anon_sym_enum,
    ACTIONS(137),
    1,
    anon_sym_const,
    ACTIONS(145),
    1,
    anon_sym_typedef,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1013),
    1,
    anon_sym_fixed,
    ACTIONS(1015),
    1,
    anon_sym_any,
    ACTIONS(1017),
    1,
    anon_sym_RBRACE,
    STATE(49),
    1,
    sym_comment,
    STATE(51),
    1,
    aux_sym_annotation_dcl_repeat1,
    STATE(116),
    1,
    sym_annotation_member,
    STATE(117),
    1,
    sym_annotation_body,
    STATE(782),
    1,
    sym_annotation_member_type,
    STATE(793),
    1,
    sym_scoped_name,
    STATE(964),
    1,
    sym_enum_anno,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(95),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    ACTIONS(103),
    2,
    anon_sym_string,
    anon_sym_wstring,
    ACTIONS(1011),
    2,
    sym_boolean_type,
    sym_octet_type,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(973),
    2,
    sym_any_const_type,
    sym_const_type,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(914),
    3,
    sym_typedef_dcl,
    sym_enum_dcl,
    sym_const_dcl,
    STATE(970),
    6,
    sym_fixed_pt_const_type,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_string_type,
    sym_sequence_type,
    [2375] = 40,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1025),
    1,
    anon_sym_longlong,
    ACTIONS(1028),
    1,
    anon_sym_int64,
    ACTIONS(1031),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(1037),
    1,
    anon_sym_fixed,
    ACTIONS(1040),
    1,
    sym_signed_tiny_int,
    ACTIONS(1043),
    1,
    anon_sym_unsignedshort,
    ACTIONS(1046),
    1,
    anon_sym_uint16,
    ACTIONS(1052),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(1055),
    1,
    anon_sym_uint64,
    ACTIONS(1061),
    1,
    anon_sym_longdouble,
    ACTIONS(1067),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(1073),
    1,
    anon_sym_any,
    ACTIONS(1076),
    1,
    anon_sym_sequence,
    ACTIONS(1079),
    1,
    anon_sym_RBRACE,
    ACTIONS(1081),
    1,
    anon_sym_enum,
    ACTIONS(1084),
    1,
    anon_sym_const,
    ACTIONS(1087),
    1,
    anon_sym_typedef,
    ACTIONS(1090),
    1,
    anon_sym_ATignore_literal_names,
    ACTIONS(1093),
    1,
    sym_identifier,
    STATE(116),
    1,
    sym_annotation_member,
    STATE(117),
    1,
    sym_annotation_body,
    STATE(782),
    1,
    sym_annotation_member_type,
    STATE(793),
    1,
    sym_scoped_name,
    STATE(964),
    1,
    sym_enum_anno,
    ACTIONS(1019),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(1022),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(1034),
    2,
    sym_boolean_type,
    sym_octet_type,
    ACTIONS(1049),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(1058),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(1064),
    2,
    anon_sym_char,
    anon_sym_wchar,
    ACTIONS(1070),
    2,
    anon_sym_string,
    anon_sym_wstring,
    STATE(50),
    2,
    sym_comment,
    aux_sym_annotation_dcl_repeat1,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(973),
    2,
    sym_any_const_type,
    sym_const_type,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(914),
    3,
    sym_typedef_dcl,
    sym_enum_dcl,
    sym_const_dcl,
    STATE(970),
    6,
    sym_fixed_pt_const_type,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_string_type,
    sym_sequence_type,
    [2517] = 41,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(51),
    1,
    anon_sym_ATignore_literal_names,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_longdouble,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(107),
    1,
    anon_sym_sequence,
    ACTIONS(135),
    1,
    anon_sym_enum,
    ACTIONS(137),
    1,
    anon_sym_const,
    ACTIONS(145),
    1,
    anon_sym_typedef,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1013),
    1,
    anon_sym_fixed,
    ACTIONS(1015),
    1,
    anon_sym_any,
    ACTIONS(1096),
    1,
    anon_sym_RBRACE,
    STATE(50),
    1,
    aux_sym_annotation_dcl_repeat1,
    STATE(51),
    1,
    sym_comment,
    STATE(116),
    1,
    sym_annotation_member,
    STATE(117),
    1,
    sym_annotation_body,
    STATE(782),
    1,
    sym_annotation_member_type,
    STATE(793),
    1,
    sym_scoped_name,
    STATE(964),
    1,
    sym_enum_anno,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(95),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    ACTIONS(103),
    2,
    anon_sym_string,
    anon_sym_wstring,
    ACTIONS(1011),
    2,
    sym_boolean_type,
    sym_octet_type,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(973),
    2,
    sym_any_const_type,
    sym_const_type,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(914),
    3,
    sym_typedef_dcl,
    sym_enum_dcl,
    sym_const_dcl,
    STATE(970),
    6,
    sym_fixed_pt_const_type,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_string_type,
    sym_sequence_type,
    [2661] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(52),
    1,
    sym_comment,
    ACTIONS(1100),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_ATignore_literal_names,
    ACTIONS(1098),
    48,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_exception,
    anon_sym_abstract,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_oneway,
    anon_sym_valuetype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_public,
    anon_sym_private,
    anon_sym_factory,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_import,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [2731] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(53),
    1,
    sym_comment,
    ACTIONS(1104),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_ATignore_literal_names,
    ACTIONS(1102),
    48,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_exception,
    anon_sym_abstract,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_oneway,
    anon_sym_valuetype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_public,
    anon_sym_private,
    anon_sym_factory,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_import,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [2801] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(54),
    1,
    sym_comment,
    ACTIONS(1108),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_ATignore_literal_names,
    ACTIONS(1106),
    48,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_exception,
    anon_sym_abstract,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_oneway,
    anon_sym_valuetype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_public,
    anon_sym_private,
    anon_sym_factory,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_import,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [2871] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(55),
    1,
    sym_comment,
    ACTIONS(1112),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_ATignore_literal_names,
    ACTIONS(1110),
    48,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_exception,
    anon_sym_abstract,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_oneway,
    anon_sym_valuetype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_public,
    anon_sym_private,
    anon_sym_factory,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_import,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [2941] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(56),
    1,
    sym_comment,
    ACTIONS(1116),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_ATignore_literal_names,
    ACTIONS(1114),
    48,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_exception,
    anon_sym_abstract,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_oneway,
    anon_sym_valuetype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_public,
    anon_sym_private,
    anon_sym_factory,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_import,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [3011] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_longdouble,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(105),
    1,
    anon_sym_any,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1118),
    1,
    anon_sym_sequence,
    ACTIONS(1122),
    1,
    anon_sym_const,
    STATE(57),
    1,
    sym_comment,
    STATE(376),
    1,
    sym_scoped_name,
    STATE(433),
    1,
    sym_base_type_spec,
    STATE(598),
    1,
    sym_formal_parameter,
    STATE(936),
    1,
    sym_formal_parameters,
    STATE(974),
    1,
    sym_formal_parameter_type,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(95),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(1006),
    2,
    sym_simple_type_spec,
    sym_sequence_type,
    ACTIONS(79),
    3,
    sym_boolean_type,
    sym_octet_type,
    sym_value_base_type,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(439),
    5,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_any_type,
    sym_object_type,
    ACTIONS(1120),
    8,
    anon_sym_exception,
    anon_sym_interface,
    anon_sym_typename,
    anon_sym_valuetype,
    anon_sym_eventtype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    [3141] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(58),
    1,
    sym_comment,
    ACTIONS(1126),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_ATignore_literal_names,
    ACTIONS(1124),
    48,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_exception,
    anon_sym_abstract,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_oneway,
    anon_sym_valuetype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_public,
    anon_sym_private,
    anon_sym_factory,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_import,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [3211] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(59),
    1,
    sym_comment,
    ACTIONS(1130),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_ATignore_literal_names,
    ACTIONS(1128),
    48,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_exception,
    anon_sym_abstract,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_oneway,
    anon_sym_valuetype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_public,
    anon_sym_private,
    anon_sym_factory,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_import,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [3281] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(60),
    1,
    sym_comment,
    ACTIONS(1130),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_ATignore_literal_names,
    ACTIONS(1128),
    47,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_exception,
    anon_sym_abstract,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_oneway,
    anon_sym_valuetype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_factory,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_import,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_finder,
    anon_sym_native,
    sym_identifier,
    [3350] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(61),
    1,
    sym_comment,
    ACTIONS(1134),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_ATignore_literal_names,
    ACTIONS(1132),
    47,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_exception,
    anon_sym_abstract,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_oneway,
    anon_sym_valuetype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_factory,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_import,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_finder,
    anon_sym_native,
    sym_identifier,
    [3419] = 34,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_longdouble,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(105),
    1,
    anon_sym_any,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1118),
    1,
    anon_sym_sequence,
    ACTIONS(1122),
    1,
    anon_sym_const,
    STATE(62),
    1,
    sym_comment,
    STATE(376),
    1,
    sym_scoped_name,
    STATE(433),
    1,
    sym_base_type_spec,
    STATE(810),
    1,
    sym_formal_parameter,
    STATE(974),
    1,
    sym_formal_parameter_type,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(95),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(1006),
    2,
    sym_simple_type_spec,
    sym_sequence_type,
    ACTIONS(79),
    3,
    sym_boolean_type,
    sym_octet_type,
    sym_value_base_type,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(439),
    5,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_any_type,
    sym_object_type,
    ACTIONS(1120),
    8,
    anon_sym_exception,
    anon_sym_interface,
    anon_sym_typename,
    anon_sym_valuetype,
    anon_sym_eventtype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    [3546] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(63),
    1,
    sym_comment,
    ACTIONS(1138),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_ATignore_literal_names,
    ACTIONS(1136),
    47,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_exception,
    anon_sym_abstract,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_oneway,
    anon_sym_valuetype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_factory,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_import,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_finder,
    anon_sym_native,
    sym_identifier,
    [3615] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(64),
    1,
    sym_comment,
    ACTIONS(1142),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_ATignore_literal_names,
    ACTIONS(1140),
    47,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_exception,
    anon_sym_abstract,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_oneway,
    anon_sym_valuetype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_factory,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_import,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_finder,
    anon_sym_native,
    sym_identifier,
    [3684] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1144),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(1146),
    1,
    anon_sym_default,
    ACTIONS(1148),
    1,
    anon_sym_id,
    ACTIONS(1150),
    1,
    anon_sym_autoid,
    ACTIONS(1152),
    1,
    anon_sym_optional,
    ACTIONS(1154),
    1,
    anon_sym_position,
    ACTIONS(1156),
    1,
    anon_sym_value,
    ACTIONS(1158),
    1,
    anon_sym_extensibility,
    ACTIONS(1160),
    1,
    anon_sym_final,
    ACTIONS(1162),
    1,
    anon_sym_appendable,
    ACTIONS(1164),
    1,
    anon_sym_mutable,
    ACTIONS(1166),
    1,
    anon_sym_key,
    ACTIONS(1168),
    1,
    anon_sym_must_understand,
    ACTIONS(1170),
    1,
    anon_sym_default_literal,
    ACTIONS(1172),
    1,
    anon_sym_range,
    ACTIONS(1174),
    1,
    anon_sym_min,
    ACTIONS(1176),
    1,
    anon_sym_max,
    ACTIONS(1178),
    1,
    anon_sym_unit,
    ACTIONS(1180),
    1,
    anon_sym_bit_bound,
    ACTIONS(1182),
    1,
    anon_sym_external,
    ACTIONS(1184),
    1,
    anon_sym_nested,
    ACTIONS(1186),
    1,
    anon_sym_verbatim,
    ACTIONS(1188),
    1,
    anon_sym_service,
    ACTIONS(1190),
    1,
    anon_sym_oneway,
    ACTIONS(1192),
    1,
    anon_sym_ami,
    ACTIONS(1194),
    1,
    sym_identifier,
    STATE(65),
    1,
    sym_comment,
    STATE(352),
    1,
    sym_scoped_name,
    STATE(340),
    2,
    sym_annotation_appl_custom_body,
    sym_annotation_appl_builtin_body,
    STATE(647),
    24,
    sym_annotation_appl_id,
    sym_annotation_appl_autoid,
    sym_annotation_appl_optional,
    sym_annotation_appl_position,
    sym_annotation_appl_value,
    sym_annotation_appl_extensibility,
    sym_annotation_appl_final,
    sym_annotation_appl_appendable,
    sym_annotation_appl_mutable,
    sym_annotation_appl_key,
    sym_annotation_appl_must_understand,
    sym_annotation_appl_default_literal,
    sym_annotation_appl_default,
    sym_annotation_appl_range,
    sym_annotation_appl_min,
    sym_annotation_appl_max,
    sym_annotation_appl_unit,
    sym_annotation_appl_bit_bound,
    sym_annotation_appl_external,
    sym_annotation_appl_nested,
    sym_annotation_appl_verbatim,
    sym_annotation_appl_service,
    sym_annotation_appl_oneway,
    sym_annotation_appl_ami,
    [3805] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(66),
    1,
    sym_comment,
    ACTIONS(1130),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_ATignore_literal_names,
    ACTIONS(1128),
    45,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_exception,
    anon_sym_abstract,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_oneway,
    anon_sym_valuetype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_import,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [3872] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1144),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(1146),
    1,
    anon_sym_default,
    ACTIONS(1148),
    1,
    anon_sym_id,
    ACTIONS(1150),
    1,
    anon_sym_autoid,
    ACTIONS(1152),
    1,
    anon_sym_optional,
    ACTIONS(1154),
    1,
    anon_sym_position,
    ACTIONS(1156),
    1,
    anon_sym_value,
    ACTIONS(1158),
    1,
    anon_sym_extensibility,
    ACTIONS(1160),
    1,
    anon_sym_final,
    ACTIONS(1162),
    1,
    anon_sym_appendable,
    ACTIONS(1164),
    1,
    anon_sym_mutable,
    ACTIONS(1166),
    1,
    anon_sym_key,
    ACTIONS(1168),
    1,
    anon_sym_must_understand,
    ACTIONS(1170),
    1,
    anon_sym_default_literal,
    ACTIONS(1172),
    1,
    anon_sym_range,
    ACTIONS(1174),
    1,
    anon_sym_min,
    ACTIONS(1176),
    1,
    anon_sym_max,
    ACTIONS(1178),
    1,
    anon_sym_unit,
    ACTIONS(1180),
    1,
    anon_sym_bit_bound,
    ACTIONS(1182),
    1,
    anon_sym_external,
    ACTIONS(1184),
    1,
    anon_sym_nested,
    ACTIONS(1186),
    1,
    anon_sym_verbatim,
    ACTIONS(1188),
    1,
    anon_sym_service,
    ACTIONS(1190),
    1,
    anon_sym_oneway,
    ACTIONS(1192),
    1,
    anon_sym_ami,
    ACTIONS(1194),
    1,
    sym_identifier,
    STATE(67),
    1,
    sym_comment,
    STATE(352),
    1,
    sym_scoped_name,
    STATE(648),
    2,
    sym_annotation_appl_custom_body,
    sym_annotation_appl_builtin_body,
    STATE(647),
    24,
    sym_annotation_appl_id,
    sym_annotation_appl_autoid,
    sym_annotation_appl_optional,
    sym_annotation_appl_position,
    sym_annotation_appl_value,
    sym_annotation_appl_extensibility,
    sym_annotation_appl_final,
    sym_annotation_appl_appendable,
    sym_annotation_appl_mutable,
    sym_annotation_appl_key,
    sym_annotation_appl_must_understand,
    sym_annotation_appl_default_literal,
    sym_annotation_appl_default,
    sym_annotation_appl_range,
    sym_annotation_appl_min,
    sym_annotation_appl_max,
    sym_annotation_appl_unit,
    sym_annotation_appl_bit_bound,
    sym_annotation_appl_external,
    sym_annotation_appl_nested,
    sym_annotation_appl_verbatim,
    sym_annotation_appl_service,
    sym_annotation_appl_oneway,
    sym_annotation_appl_ami,
    [3993] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    anon_sym_fixed,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_longdouble,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(105),
    1,
    anon_sym_any,
    ACTIONS(107),
    1,
    anon_sym_sequence,
    ACTIONS(109),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(68),
    1,
    sym_comment,
    STATE(376),
    1,
    sym_scoped_name,
    STATE(433),
    1,
    sym_base_type_spec,
    STATE(815),
    1,
    sym_type_spec,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(95),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    ACTIONS(103),
    2,
    anon_sym_string,
    anon_sym_wstring,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(388),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    ACTIONS(79),
    3,
    sym_boolean_type,
    sym_octet_type,
    sym_value_base_type,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(435),
    4,
    sym_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    STATE(439),
    5,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_any_type,
    sym_object_type,
    [4120] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    anon_sym_fixed,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_longdouble,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(105),
    1,
    anon_sym_any,
    ACTIONS(107),
    1,
    anon_sym_sequence,
    ACTIONS(109),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1196),
    1,
    sym_identifier,
    STATE(69),
    1,
    sym_comment,
    STATE(376),
    1,
    sym_scoped_name,
    STATE(433),
    1,
    sym_base_type_spec,
    STATE(763),
    1,
    sym_type_spec,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(95),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    ACTIONS(103),
    2,
    anon_sym_string,
    anon_sym_wstring,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(388),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    ACTIONS(79),
    3,
    sym_boolean_type,
    sym_octet_type,
    sym_value_base_type,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(435),
    4,
    sym_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    STATE(439),
    5,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_any_type,
    sym_object_type,
    [4247] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1144),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(1146),
    1,
    anon_sym_default,
    ACTIONS(1148),
    1,
    anon_sym_id,
    ACTIONS(1150),
    1,
    anon_sym_autoid,
    ACTIONS(1152),
    1,
    anon_sym_optional,
    ACTIONS(1154),
    1,
    anon_sym_position,
    ACTIONS(1156),
    1,
    anon_sym_value,
    ACTIONS(1158),
    1,
    anon_sym_extensibility,
    ACTIONS(1160),
    1,
    anon_sym_final,
    ACTIONS(1162),
    1,
    anon_sym_appendable,
    ACTIONS(1164),
    1,
    anon_sym_mutable,
    ACTIONS(1166),
    1,
    anon_sym_key,
    ACTIONS(1168),
    1,
    anon_sym_must_understand,
    ACTIONS(1170),
    1,
    anon_sym_default_literal,
    ACTIONS(1172),
    1,
    anon_sym_range,
    ACTIONS(1174),
    1,
    anon_sym_min,
    ACTIONS(1176),
    1,
    anon_sym_max,
    ACTIONS(1178),
    1,
    anon_sym_unit,
    ACTIONS(1180),
    1,
    anon_sym_bit_bound,
    ACTIONS(1182),
    1,
    anon_sym_external,
    ACTIONS(1184),
    1,
    anon_sym_nested,
    ACTIONS(1186),
    1,
    anon_sym_verbatim,
    ACTIONS(1188),
    1,
    anon_sym_service,
    ACTIONS(1190),
    1,
    anon_sym_oneway,
    ACTIONS(1192),
    1,
    anon_sym_ami,
    ACTIONS(1194),
    1,
    sym_identifier,
    STATE(70),
    1,
    sym_comment,
    STATE(352),
    1,
    sym_scoped_name,
    STATE(336),
    2,
    sym_annotation_appl_custom_body,
    sym_annotation_appl_builtin_body,
    STATE(647),
    24,
    sym_annotation_appl_id,
    sym_annotation_appl_autoid,
    sym_annotation_appl_optional,
    sym_annotation_appl_position,
    sym_annotation_appl_value,
    sym_annotation_appl_extensibility,
    sym_annotation_appl_final,
    sym_annotation_appl_appendable,
    sym_annotation_appl_mutable,
    sym_annotation_appl_key,
    sym_annotation_appl_must_understand,
    sym_annotation_appl_default_literal,
    sym_annotation_appl_default,
    sym_annotation_appl_range,
    sym_annotation_appl_min,
    sym_annotation_appl_max,
    sym_annotation_appl_unit,
    sym_annotation_appl_bit_bound,
    sym_annotation_appl_external,
    sym_annotation_appl_nested,
    sym_annotation_appl_verbatim,
    sym_annotation_appl_service,
    sym_annotation_appl_oneway,
    sym_annotation_appl_ami,
    [4368] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(71),
    1,
    sym_comment,
    ACTIONS(1200),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_ATignore_literal_names,
    ACTIONS(1198),
    45,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_exception,
    anon_sym_abstract,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_oneway,
    anon_sym_valuetype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_import,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [4435] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1202),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(1204),
    1,
    anon_sym_default,
    ACTIONS(1206),
    1,
    anon_sym_id,
    ACTIONS(1208),
    1,
    anon_sym_autoid,
    ACTIONS(1210),
    1,
    anon_sym_optional,
    ACTIONS(1212),
    1,
    anon_sym_position,
    ACTIONS(1214),
    1,
    anon_sym_value,
    ACTIONS(1216),
    1,
    anon_sym_extensibility,
    ACTIONS(1218),
    1,
    anon_sym_final,
    ACTIONS(1220),
    1,
    anon_sym_appendable,
    ACTIONS(1222),
    1,
    anon_sym_mutable,
    ACTIONS(1224),
    1,
    anon_sym_key,
    ACTIONS(1226),
    1,
    anon_sym_must_understand,
    ACTIONS(1228),
    1,
    anon_sym_default_literal,
    ACTIONS(1230),
    1,
    anon_sym_range,
    ACTIONS(1232),
    1,
    anon_sym_min,
    ACTIONS(1234),
    1,
    anon_sym_max,
    ACTIONS(1236),
    1,
    anon_sym_unit,
    ACTIONS(1238),
    1,
    anon_sym_bit_bound,
    ACTIONS(1240),
    1,
    anon_sym_external,
    ACTIONS(1242),
    1,
    anon_sym_nested,
    ACTIONS(1244),
    1,
    anon_sym_verbatim,
    ACTIONS(1246),
    1,
    anon_sym_service,
    ACTIONS(1248),
    1,
    anon_sym_oneway,
    ACTIONS(1250),
    1,
    anon_sym_ami,
    ACTIONS(1252),
    1,
    sym_identifier,
    STATE(72),
    1,
    sym_comment,
    STATE(258),
    1,
    sym_scoped_name,
    STATE(305),
    2,
    sym_annotation_appl_custom_body,
    sym_annotation_appl_builtin_body,
    STATE(303),
    24,
    sym_annotation_appl_id,
    sym_annotation_appl_autoid,
    sym_annotation_appl_optional,
    sym_annotation_appl_position,
    sym_annotation_appl_value,
    sym_annotation_appl_extensibility,
    sym_annotation_appl_final,
    sym_annotation_appl_appendable,
    sym_annotation_appl_mutable,
    sym_annotation_appl_key,
    sym_annotation_appl_must_understand,
    sym_annotation_appl_default_literal,
    sym_annotation_appl_default,
    sym_annotation_appl_range,
    sym_annotation_appl_min,
    sym_annotation_appl_max,
    sym_annotation_appl_unit,
    sym_annotation_appl_bit_bound,
    sym_annotation_appl_external,
    sym_annotation_appl_nested,
    sym_annotation_appl_verbatim,
    sym_annotation_appl_service,
    sym_annotation_appl_oneway,
    sym_annotation_appl_ami,
    [4556] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    anon_sym_fixed,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_longdouble,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(105),
    1,
    anon_sym_any,
    ACTIONS(107),
    1,
    anon_sym_sequence,
    ACTIONS(109),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(73),
    1,
    sym_comment,
    STATE(368),
    1,
    sym_type_spec,
    STATE(376),
    1,
    sym_scoped_name,
    STATE(433),
    1,
    sym_base_type_spec,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(95),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    ACTIONS(103),
    2,
    anon_sym_string,
    anon_sym_wstring,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(388),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    ACTIONS(79),
    3,
    sym_boolean_type,
    sym_octet_type,
    sym_value_base_type,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(435),
    4,
    sym_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    STATE(439),
    5,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_any_type,
    sym_object_type,
    [4683] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1144),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(1146),
    1,
    anon_sym_default,
    ACTIONS(1148),
    1,
    anon_sym_id,
    ACTIONS(1150),
    1,
    anon_sym_autoid,
    ACTIONS(1152),
    1,
    anon_sym_optional,
    ACTIONS(1154),
    1,
    anon_sym_position,
    ACTIONS(1156),
    1,
    anon_sym_value,
    ACTIONS(1158),
    1,
    anon_sym_extensibility,
    ACTIONS(1160),
    1,
    anon_sym_final,
    ACTIONS(1162),
    1,
    anon_sym_appendable,
    ACTIONS(1164),
    1,
    anon_sym_mutable,
    ACTIONS(1166),
    1,
    anon_sym_key,
    ACTIONS(1168),
    1,
    anon_sym_must_understand,
    ACTIONS(1170),
    1,
    anon_sym_default_literal,
    ACTIONS(1172),
    1,
    anon_sym_range,
    ACTIONS(1174),
    1,
    anon_sym_min,
    ACTIONS(1176),
    1,
    anon_sym_max,
    ACTIONS(1178),
    1,
    anon_sym_unit,
    ACTIONS(1180),
    1,
    anon_sym_bit_bound,
    ACTIONS(1182),
    1,
    anon_sym_external,
    ACTIONS(1184),
    1,
    anon_sym_nested,
    ACTIONS(1186),
    1,
    anon_sym_verbatim,
    ACTIONS(1188),
    1,
    anon_sym_service,
    ACTIONS(1190),
    1,
    anon_sym_oneway,
    ACTIONS(1192),
    1,
    anon_sym_ami,
    ACTIONS(1194),
    1,
    sym_identifier,
    STATE(74),
    1,
    sym_comment,
    STATE(352),
    1,
    sym_scoped_name,
    STATE(341),
    2,
    sym_annotation_appl_custom_body,
    sym_annotation_appl_builtin_body,
    STATE(647),
    24,
    sym_annotation_appl_id,
    sym_annotation_appl_autoid,
    sym_annotation_appl_optional,
    sym_annotation_appl_position,
    sym_annotation_appl_value,
    sym_annotation_appl_extensibility,
    sym_annotation_appl_final,
    sym_annotation_appl_appendable,
    sym_annotation_appl_mutable,
    sym_annotation_appl_key,
    sym_annotation_appl_must_understand,
    sym_annotation_appl_default_literal,
    sym_annotation_appl_default,
    sym_annotation_appl_range,
    sym_annotation_appl_min,
    sym_annotation_appl_max,
    sym_annotation_appl_unit,
    sym_annotation_appl_bit_bound,
    sym_annotation_appl_external,
    sym_annotation_appl_nested,
    sym_annotation_appl_verbatim,
    sym_annotation_appl_service,
    sym_annotation_appl_oneway,
    sym_annotation_appl_ami,
    [4804] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1254),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(1256),
    1,
    anon_sym_default,
    ACTIONS(1258),
    1,
    anon_sym_id,
    ACTIONS(1260),
    1,
    anon_sym_autoid,
    ACTIONS(1262),
    1,
    anon_sym_optional,
    ACTIONS(1264),
    1,
    anon_sym_position,
    ACTIONS(1266),
    1,
    anon_sym_value,
    ACTIONS(1268),
    1,
    anon_sym_extensibility,
    ACTIONS(1270),
    1,
    anon_sym_final,
    ACTIONS(1272),
    1,
    anon_sym_appendable,
    ACTIONS(1274),
    1,
    anon_sym_mutable,
    ACTIONS(1276),
    1,
    anon_sym_key,
    ACTIONS(1278),
    1,
    anon_sym_must_understand,
    ACTIONS(1280),
    1,
    anon_sym_default_literal,
    ACTIONS(1282),
    1,
    anon_sym_range,
    ACTIONS(1284),
    1,
    anon_sym_min,
    ACTIONS(1286),
    1,
    anon_sym_max,
    ACTIONS(1288),
    1,
    anon_sym_unit,
    ACTIONS(1290),
    1,
    anon_sym_bit_bound,
    ACTIONS(1292),
    1,
    anon_sym_external,
    ACTIONS(1294),
    1,
    anon_sym_nested,
    ACTIONS(1296),
    1,
    anon_sym_verbatim,
    ACTIONS(1298),
    1,
    anon_sym_service,
    ACTIONS(1300),
    1,
    anon_sym_oneway,
    ACTIONS(1302),
    1,
    anon_sym_ami,
    ACTIONS(1304),
    1,
    sym_identifier,
    STATE(75),
    1,
    sym_comment,
    STATE(105),
    1,
    sym_scoped_name,
    STATE(143),
    2,
    sym_annotation_appl_custom_body,
    sym_annotation_appl_builtin_body,
    STATE(148),
    24,
    sym_annotation_appl_id,
    sym_annotation_appl_autoid,
    sym_annotation_appl_optional,
    sym_annotation_appl_position,
    sym_annotation_appl_value,
    sym_annotation_appl_extensibility,
    sym_annotation_appl_final,
    sym_annotation_appl_appendable,
    sym_annotation_appl_mutable,
    sym_annotation_appl_key,
    sym_annotation_appl_must_understand,
    sym_annotation_appl_default_literal,
    sym_annotation_appl_default,
    sym_annotation_appl_range,
    sym_annotation_appl_min,
    sym_annotation_appl_max,
    sym_annotation_appl_unit,
    sym_annotation_appl_bit_bound,
    sym_annotation_appl_external,
    sym_annotation_appl_nested,
    sym_annotation_appl_verbatim,
    sym_annotation_appl_service,
    sym_annotation_appl_oneway,
    sym_annotation_appl_ami,
    [4925] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    anon_sym_fixed,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_longdouble,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(105),
    1,
    anon_sym_any,
    ACTIONS(107),
    1,
    anon_sym_sequence,
    ACTIONS(109),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(76),
    1,
    sym_comment,
    STATE(376),
    1,
    sym_scoped_name,
    STATE(433),
    1,
    sym_base_type_spec,
    STATE(534),
    1,
    sym_type_spec,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(95),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    ACTIONS(103),
    2,
    anon_sym_string,
    anon_sym_wstring,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(388),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    ACTIONS(79),
    3,
    sym_boolean_type,
    sym_octet_type,
    sym_value_base_type,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(435),
    4,
    sym_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    STATE(439),
    5,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_any_type,
    sym_object_type,
    [5052] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1144),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(1146),
    1,
    anon_sym_default,
    ACTIONS(1148),
    1,
    anon_sym_id,
    ACTIONS(1150),
    1,
    anon_sym_autoid,
    ACTIONS(1152),
    1,
    anon_sym_optional,
    ACTIONS(1154),
    1,
    anon_sym_position,
    ACTIONS(1156),
    1,
    anon_sym_value,
    ACTIONS(1158),
    1,
    anon_sym_extensibility,
    ACTIONS(1160),
    1,
    anon_sym_final,
    ACTIONS(1162),
    1,
    anon_sym_appendable,
    ACTIONS(1164),
    1,
    anon_sym_mutable,
    ACTIONS(1166),
    1,
    anon_sym_key,
    ACTIONS(1168),
    1,
    anon_sym_must_understand,
    ACTIONS(1170),
    1,
    anon_sym_default_literal,
    ACTIONS(1172),
    1,
    anon_sym_range,
    ACTIONS(1174),
    1,
    anon_sym_min,
    ACTIONS(1176),
    1,
    anon_sym_max,
    ACTIONS(1178),
    1,
    anon_sym_unit,
    ACTIONS(1180),
    1,
    anon_sym_bit_bound,
    ACTIONS(1182),
    1,
    anon_sym_external,
    ACTIONS(1184),
    1,
    anon_sym_nested,
    ACTIONS(1186),
    1,
    anon_sym_verbatim,
    ACTIONS(1188),
    1,
    anon_sym_service,
    ACTIONS(1190),
    1,
    anon_sym_oneway,
    ACTIONS(1192),
    1,
    anon_sym_ami,
    ACTIONS(1194),
    1,
    sym_identifier,
    STATE(77),
    1,
    sym_comment,
    STATE(352),
    1,
    sym_scoped_name,
    STATE(338),
    2,
    sym_annotation_appl_custom_body,
    sym_annotation_appl_builtin_body,
    STATE(647),
    24,
    sym_annotation_appl_id,
    sym_annotation_appl_autoid,
    sym_annotation_appl_optional,
    sym_annotation_appl_position,
    sym_annotation_appl_value,
    sym_annotation_appl_extensibility,
    sym_annotation_appl_final,
    sym_annotation_appl_appendable,
    sym_annotation_appl_mutable,
    sym_annotation_appl_key,
    sym_annotation_appl_must_understand,
    sym_annotation_appl_default_literal,
    sym_annotation_appl_default,
    sym_annotation_appl_range,
    sym_annotation_appl_min,
    sym_annotation_appl_max,
    sym_annotation_appl_unit,
    sym_annotation_appl_bit_bound,
    sym_annotation_appl_external,
    sym_annotation_appl_nested,
    sym_annotation_appl_verbatim,
    sym_annotation_appl_service,
    sym_annotation_appl_oneway,
    sym_annotation_appl_ami,
    [5173] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    anon_sym_fixed,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_longdouble,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(105),
    1,
    anon_sym_any,
    ACTIONS(107),
    1,
    anon_sym_sequence,
    ACTIONS(109),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(78),
    1,
    sym_comment,
    STATE(376),
    1,
    sym_scoped_name,
    STATE(433),
    1,
    sym_base_type_spec,
    STATE(1019),
    1,
    sym_type_spec,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(95),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    ACTIONS(103),
    2,
    anon_sym_string,
    anon_sym_wstring,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(388),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    ACTIONS(79),
    3,
    sym_boolean_type,
    sym_octet_type,
    sym_value_base_type,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(435),
    4,
    sym_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    STATE(439),
    5,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_any_type,
    sym_object_type,
    [5300] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    anon_sym_fixed,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_longdouble,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(105),
    1,
    anon_sym_any,
    ACTIONS(107),
    1,
    anon_sym_sequence,
    ACTIONS(109),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1196),
    1,
    sym_identifier,
    STATE(79),
    1,
    sym_comment,
    STATE(376),
    1,
    sym_scoped_name,
    STATE(433),
    1,
    sym_base_type_spec,
    STATE(835),
    1,
    sym_type_spec,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(95),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    ACTIONS(103),
    2,
    anon_sym_string,
    anon_sym_wstring,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(388),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    ACTIONS(79),
    3,
    sym_boolean_type,
    sym_octet_type,
    sym_value_base_type,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(435),
    4,
    sym_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    STATE(439),
    5,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_any_type,
    sym_object_type,
    [5427] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    anon_sym_fixed,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_longdouble,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(105),
    1,
    anon_sym_any,
    ACTIONS(107),
    1,
    anon_sym_sequence,
    ACTIONS(109),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(80),
    1,
    sym_comment,
    STATE(376),
    1,
    sym_scoped_name,
    STATE(433),
    1,
    sym_base_type_spec,
    STATE(776),
    1,
    sym_type_spec,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(95),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    ACTIONS(103),
    2,
    anon_sym_string,
    anon_sym_wstring,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(388),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    ACTIONS(79),
    3,
    sym_boolean_type,
    sym_octet_type,
    sym_value_base_type,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(435),
    4,
    sym_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    STATE(439),
    5,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_any_type,
    sym_object_type,
    [5554] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    anon_sym_fixed,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_longdouble,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(105),
    1,
    anon_sym_any,
    ACTIONS(107),
    1,
    anon_sym_sequence,
    ACTIONS(109),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(81),
    1,
    sym_comment,
    STATE(376),
    1,
    sym_scoped_name,
    STATE(433),
    1,
    sym_base_type_spec,
    STATE(591),
    1,
    sym_type_spec,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(95),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    ACTIONS(103),
    2,
    anon_sym_string,
    anon_sym_wstring,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(388),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    ACTIONS(79),
    3,
    sym_boolean_type,
    sym_octet_type,
    sym_value_base_type,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(435),
    4,
    sym_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    STATE(439),
    5,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_any_type,
    sym_object_type,
    [5681] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    anon_sym_fixed,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_longdouble,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(105),
    1,
    anon_sym_any,
    ACTIONS(107),
    1,
    anon_sym_sequence,
    ACTIONS(109),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(82),
    1,
    sym_comment,
    STATE(376),
    1,
    sym_scoped_name,
    STATE(433),
    1,
    sym_base_type_spec,
    STATE(779),
    1,
    sym_type_spec,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(95),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    ACTIONS(103),
    2,
    anon_sym_string,
    anon_sym_wstring,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(388),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    ACTIONS(79),
    3,
    sym_boolean_type,
    sym_octet_type,
    sym_value_base_type,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(435),
    4,
    sym_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    STATE(439),
    5,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_any_type,
    sym_object_type,
    [5808] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1306),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(1308),
    1,
    anon_sym_default,
    ACTIONS(1310),
    1,
    anon_sym_id,
    ACTIONS(1312),
    1,
    anon_sym_autoid,
    ACTIONS(1314),
    1,
    anon_sym_optional,
    ACTIONS(1316),
    1,
    anon_sym_position,
    ACTIONS(1318),
    1,
    anon_sym_value,
    ACTIONS(1320),
    1,
    anon_sym_extensibility,
    ACTIONS(1322),
    1,
    anon_sym_final,
    ACTIONS(1324),
    1,
    anon_sym_appendable,
    ACTIONS(1326),
    1,
    anon_sym_mutable,
    ACTIONS(1328),
    1,
    anon_sym_key,
    ACTIONS(1330),
    1,
    anon_sym_must_understand,
    ACTIONS(1332),
    1,
    anon_sym_default_literal,
    ACTIONS(1334),
    1,
    anon_sym_range,
    ACTIONS(1336),
    1,
    anon_sym_min,
    ACTIONS(1338),
    1,
    anon_sym_max,
    ACTIONS(1340),
    1,
    anon_sym_unit,
    ACTIONS(1342),
    1,
    anon_sym_bit_bound,
    ACTIONS(1344),
    1,
    anon_sym_external,
    ACTIONS(1346),
    1,
    anon_sym_nested,
    ACTIONS(1348),
    1,
    anon_sym_verbatim,
    ACTIONS(1350),
    1,
    anon_sym_service,
    ACTIONS(1352),
    1,
    anon_sym_oneway,
    ACTIONS(1354),
    1,
    anon_sym_ami,
    ACTIONS(1356),
    1,
    sym_identifier,
    STATE(83),
    1,
    sym_comment,
    STATE(359),
    1,
    sym_scoped_name,
    STATE(584),
    2,
    sym_annotation_appl_custom_body,
    sym_annotation_appl_builtin_body,
    STATE(582),
    24,
    sym_annotation_appl_id,
    sym_annotation_appl_autoid,
    sym_annotation_appl_optional,
    sym_annotation_appl_position,
    sym_annotation_appl_value,
    sym_annotation_appl_extensibility,
    sym_annotation_appl_final,
    sym_annotation_appl_appendable,
    sym_annotation_appl_mutable,
    sym_annotation_appl_key,
    sym_annotation_appl_must_understand,
    sym_annotation_appl_default_literal,
    sym_annotation_appl_default,
    sym_annotation_appl_range,
    sym_annotation_appl_min,
    sym_annotation_appl_max,
    sym_annotation_appl_unit,
    sym_annotation_appl_bit_bound,
    sym_annotation_appl_external,
    sym_annotation_appl_nested,
    sym_annotation_appl_verbatim,
    sym_annotation_appl_service,
    sym_annotation_appl_oneway,
    sym_annotation_appl_ami,
    [5929] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    anon_sym_fixed,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_longdouble,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(105),
    1,
    anon_sym_any,
    ACTIONS(107),
    1,
    anon_sym_sequence,
    ACTIONS(109),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(84),
    1,
    sym_comment,
    STATE(376),
    1,
    sym_scoped_name,
    STATE(433),
    1,
    sym_base_type_spec,
    STATE(785),
    1,
    sym_type_spec,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(95),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    ACTIONS(103),
    2,
    anon_sym_string,
    anon_sym_wstring,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(388),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    ACTIONS(79),
    3,
    sym_boolean_type,
    sym_octet_type,
    sym_value_base_type,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(435),
    4,
    sym_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    STATE(439),
    5,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_any_type,
    sym_object_type,
    [6056] = 29,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_longdouble,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(107),
    1,
    anon_sym_sequence,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1013),
    1,
    anon_sym_fixed,
    STATE(85),
    1,
    sym_comment,
    STATE(788),
    1,
    sym_scoped_name,
    STATE(966),
    1,
    sym_const_type,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(95),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    ACTIONS(103),
    2,
    anon_sym_string,
    anon_sym_wstring,
    ACTIONS(1011),
    2,
    sym_boolean_type,
    sym_octet_type,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(970),
    6,
    sym_fixed_pt_const_type,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_string_type,
    sym_sequence_type,
    [6161] = 29,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_longdouble,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(107),
    1,
    anon_sym_sequence,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1013),
    1,
    anon_sym_fixed,
    STATE(86),
    1,
    sym_comment,
    STATE(788),
    1,
    sym_scoped_name,
    STATE(1025),
    1,
    sym_const_type,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(95),
    2,
    anon_sym_float,
    anon_sym_double,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    ACTIONS(103),
    2,
    anon_sym_string,
    anon_sym_wstring,
    ACTIONS(1011),
    2,
    sym_boolean_type,
    sym_octet_type,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(970),
    6,
    sym_fixed_pt_const_type,
    sym_integer_type,
    sym_floating_pt_type,
    sym_char_type,
    sym_string_type,
    sym_sequence_type,
    [6266] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(87),
    1,
    sym_comment,
    ACTIONS(1360),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_ATignore_literal_names,
    ACTIONS(1358),
    34,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_default,
    anon_sym_AT,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_case,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [6322] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(88),
    1,
    sym_comment,
    ACTIONS(1364),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_ATignore_literal_names,
    ACTIONS(1362),
    34,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_default,
    anon_sym_AT,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_case,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [6378] = 9,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1370),
    1,
    anon_sym_AT,
    ACTIONS(1373),
    1,
    anon_sym_SLASH_SLASH_AT,
    STATE(113),
    1,
    sym_annotation_appl,
    STATE(120),
    1,
    sym_extend_annotation_appl,
    STATE(89),
    2,
    sym_comment,
    aux_sym_interface_def_repeat1,
    ACTIONS(1368),
    5,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    ACTIONS(1366),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [6436] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1380),
    1,
    anon_sym_LPAREN,
    STATE(90),
    1,
    sym_comment,
    ACTIONS(1378),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1376),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [6486] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1386),
    1,
    anon_sym_LPAREN,
    STATE(91),
    1,
    sym_comment,
    ACTIONS(1384),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1382),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [6536] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(92),
    1,
    sym_comment,
    ACTIONS(1390),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1388),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [6584] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(93),
    1,
    sym_comment,
    ACTIONS(1394),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1392),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [6632] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1400),
    1,
    anon_sym_LPAREN,
    STATE(94),
    1,
    sym_comment,
    ACTIONS(1398),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1396),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [6682] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(95),
    1,
    sym_comment,
    ACTIONS(1404),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_LPAREN,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1402),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [6730] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(96),
    1,
    sym_comment,
    ACTIONS(1408),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1406),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [6778] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1414),
    1,
    anon_sym_LPAREN,
    STATE(97),
    1,
    sym_comment,
    ACTIONS(1412),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1410),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [6828] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1420),
    1,
    anon_sym_LPAREN,
    STATE(98),
    1,
    sym_comment,
    ACTIONS(1418),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1416),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [6878] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(99),
    1,
    sym_comment,
    ACTIONS(1424),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1422),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [6926] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1430),
    1,
    anon_sym_LPAREN,
    STATE(100),
    1,
    sym_comment,
    ACTIONS(1428),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1426),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [6976] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(101),
    1,
    sym_comment,
    ACTIONS(1434),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1432),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [7024] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1440),
    1,
    anon_sym_LPAREN,
    STATE(102),
    1,
    sym_comment,
    ACTIONS(1438),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1436),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [7074] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1446),
    1,
    anon_sym_LPAREN,
    STATE(103),
    1,
    sym_comment,
    ACTIONS(1444),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1442),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [7124] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1452),
    1,
    anon_sym_LPAREN,
    STATE(104),
    1,
    sym_comment,
    ACTIONS(1450),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1448),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [7174] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1458),
    1,
    anon_sym_LPAREN,
    STATE(105),
    1,
    sym_comment,
    ACTIONS(1456),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1454),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [7224] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(106),
    1,
    sym_comment,
    ACTIONS(1462),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_LPAREN,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1460),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [7272] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(107),
    1,
    sym_comment,
    ACTIONS(1466),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_LPAREN,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1464),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [7320] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(108),
    1,
    sym_comment,
    ACTIONS(1470),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_ATignore_literal_names,
    ACTIONS(1468),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_typedef,
    sym_identifier,
    [7367] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(109),
    1,
    sym_comment,
    ACTIONS(1474),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_ATignore_literal_names,
    ACTIONS(1472),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_typedef,
    sym_identifier,
    [7414] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(110),
    1,
    sym_comment,
    ACTIONS(1478),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1476),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [7461] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(111),
    1,
    sym_comment,
    ACTIONS(1482),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1480),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [7508] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(112),
    1,
    sym_comment,
    ACTIONS(1486),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1484),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [7555] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(113),
    1,
    sym_comment,
    ACTIONS(1490),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1488),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [7602] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(114),
    1,
    sym_comment,
    ACTIONS(1494),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1492),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [7649] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(115),
    1,
    sym_comment,
    ACTIONS(1498),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1496),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [7696] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(116),
    1,
    sym_comment,
    ACTIONS(1502),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_ATignore_literal_names,
    ACTIONS(1500),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_typedef,
    sym_identifier,
    [7743] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(117),
    1,
    sym_comment,
    ACTIONS(1506),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_ATignore_literal_names,
    ACTIONS(1504),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_typedef,
    sym_identifier,
    [7790] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(118),
    1,
    sym_comment,
    ACTIONS(1510),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1508),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [7837] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(119),
    1,
    sym_comment,
    ACTIONS(1514),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1512),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [7884] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(120),
    1,
    sym_comment,
    ACTIONS(1518),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1516),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [7931] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(121),
    1,
    sym_comment,
    ACTIONS(1522),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1520),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [7978] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(122),
    1,
    sym_comment,
    ACTIONS(1526),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1524),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [8025] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(123),
    1,
    sym_comment,
    ACTIONS(1530),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1528),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [8072] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(124),
    1,
    sym_comment,
    ACTIONS(1534),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1532),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [8119] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(125),
    1,
    sym_comment,
    ACTIONS(1538),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1536),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [8166] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(126),
    1,
    sym_comment,
    ACTIONS(1542),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1540),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [8213] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(127),
    1,
    sym_comment,
    ACTIONS(1546),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1544),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [8260] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(128),
    1,
    sym_comment,
    ACTIONS(1550),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1548),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [8307] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(129),
    1,
    sym_comment,
    ACTIONS(1554),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1552),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [8354] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(130),
    1,
    sym_comment,
    ACTIONS(1558),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1556),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [8401] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(131),
    1,
    sym_comment,
    ACTIONS(1562),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1560),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [8448] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(132),
    1,
    sym_comment,
    ACTIONS(1566),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1564),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [8495] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(133),
    1,
    sym_comment,
    ACTIONS(1570),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1568),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [8542] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(134),
    1,
    sym_comment,
    ACTIONS(1574),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1572),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [8589] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(135),
    1,
    sym_comment,
    ACTIONS(1578),
    3,
    anon_sym_POUNDdefine,
    sym_preproc_directive,
    anon_sym_AT,
    ACTIONS(1576),
    30,
    ts_builtin_sym_end,
    aux_sym_preproc_include_token1,
    anon_sym_exception,
    anon_sym_RBRACE,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_ATannotation,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_valuetype,
    anon_sym_eventtype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_alias,
    anon_sym_custom,
    anon_sym_typedef,
    anon_sym_ATignore_literal_names,
    anon_sym_typeid,
    anon_sym_typeprefix,
    anon_sym_import,
    anon_sym_component,
    anon_sym_home,
    anon_sym_porttype,
    anon_sym_connector,
    anon_sym_native,
    [8636] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(136),
    1,
    sym_comment,
    ACTIONS(1582),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1580),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [8683] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(137),
    1,
    sym_comment,
    ACTIONS(1586),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_ATignore_literal_names,
    ACTIONS(1584),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_typedef,
    sym_identifier,
    [8730] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(138),
    1,
    sym_comment,
    ACTIONS(1590),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1588),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [8777] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(139),
    1,
    sym_comment,
    ACTIONS(1594),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1592),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [8824] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(140),
    1,
    sym_comment,
    ACTIONS(1598),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1596),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [8871] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(141),
    1,
    sym_comment,
    ACTIONS(1602),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1600),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [8918] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(142),
    1,
    sym_comment,
    ACTIONS(1606),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1604),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [8965] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(143),
    1,
    sym_comment,
    ACTIONS(1610),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1608),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [9012] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(144),
    1,
    sym_comment,
    ACTIONS(1614),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1612),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [9059] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(145),
    1,
    sym_comment,
    ACTIONS(1618),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1616),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [9106] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(146),
    1,
    sym_comment,
    ACTIONS(1622),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1620),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [9153] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(147),
    1,
    sym_comment,
    ACTIONS(1626),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1624),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [9200] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(148),
    1,
    sym_comment,
    ACTIONS(1630),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1628),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [9247] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(149),
    1,
    sym_comment,
    ACTIONS(1634),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1632),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [9294] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(150),
    1,
    sym_comment,
    ACTIONS(1638),
    3,
    anon_sym_POUNDdefine,
    sym_preproc_directive,
    anon_sym_AT,
    ACTIONS(1636),
    28,
    ts_builtin_sym_end,
    aux_sym_preproc_include_token1,
    anon_sym_exception,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_ATannotation,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_valuetype,
    anon_sym_eventtype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_typedef,
    anon_sym_ATignore_literal_names,
    anon_sym_typeid,
    anon_sym_typeprefix,
    anon_sym_import,
    anon_sym_component,
    anon_sym_home,
    anon_sym_porttype,
    anon_sym_connector,
    anon_sym_native,
    [9339] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(151),
    1,
    sym_comment,
    ACTIONS(1642),
    3,
    anon_sym_POUNDdefine,
    sym_preproc_directive,
    anon_sym_AT,
    ACTIONS(1640),
    28,
    ts_builtin_sym_end,
    aux_sym_preproc_include_token1,
    anon_sym_exception,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_ATannotation,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_valuetype,
    anon_sym_eventtype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_typedef,
    anon_sym_ATignore_literal_names,
    anon_sym_typeid,
    anon_sym_typeprefix,
    anon_sym_import,
    anon_sym_component,
    anon_sym_home,
    anon_sym_porttype,
    anon_sym_connector,
    anon_sym_native,
    [9384] = 24,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(73),
    1,
    anon_sym_longlong,
    ACTIONS(75),
    1,
    anon_sym_int64,
    ACTIONS(77),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(83),
    1,
    sym_signed_tiny_int,
    ACTIONS(85),
    1,
    anon_sym_unsignedshort,
    ACTIONS(87),
    1,
    anon_sym_uint16,
    ACTIONS(91),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(93),
    1,
    anon_sym_uint64,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1644),
    1,
    sym_boolean_type,
    STATE(152),
    1,
    sym_comment,
    STATE(766),
    1,
    sym_scoped_name,
    STATE(1012),
    1,
    sym_switch_type_spec,
    ACTIONS(69),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(71),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(89),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(99),
    2,
    anon_sym_char,
    anon_sym_wchar,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(1014),
    2,
    sym_integer_type,
    sym_char_type,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    [9467] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(153),
    1,
    sym_comment,
    ACTIONS(1648),
    3,
    anon_sym_POUNDdefine,
    sym_preproc_directive,
    anon_sym_AT,
    ACTIONS(1646),
    28,
    ts_builtin_sym_end,
    aux_sym_preproc_include_token1,
    anon_sym_exception,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_ATannotation,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_valuetype,
    anon_sym_eventtype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_typedef,
    anon_sym_ATignore_literal_names,
    anon_sym_typeid,
    anon_sym_typeprefix,
    anon_sym_import,
    anon_sym_component,
    anon_sym_home,
    anon_sym_porttype,
    anon_sym_connector,
    anon_sym_native,
    [9512] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(154),
    1,
    sym_comment,
    ACTIONS(1652),
    3,
    anon_sym_POUNDdefine,
    sym_preproc_directive,
    anon_sym_AT,
    ACTIONS(1650),
    28,
    ts_builtin_sym_end,
    aux_sym_preproc_include_token1,
    anon_sym_exception,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_ATannotation,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_valuetype,
    anon_sym_eventtype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_typedef,
    anon_sym_ATignore_literal_names,
    anon_sym_typeid,
    anon_sym_typeprefix,
    anon_sym_import,
    anon_sym_component,
    anon_sym_home,
    anon_sym_porttype,
    anon_sym_connector,
    anon_sym_native,
    [9557] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(155),
    1,
    sym_comment,
    ACTIONS(1656),
    3,
    anon_sym_POUNDdefine,
    sym_preproc_directive,
    anon_sym_AT,
    ACTIONS(1654),
    28,
    ts_builtin_sym_end,
    aux_sym_preproc_include_token1,
    anon_sym_exception,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_ATannotation,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_valuetype,
    anon_sym_eventtype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_typedef,
    anon_sym_ATignore_literal_names,
    anon_sym_typeid,
    anon_sym_typeprefix,
    anon_sym_import,
    anon_sym_component,
    anon_sym_home,
    anon_sym_porttype,
    anon_sym_connector,
    anon_sym_native,
    [9602] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(156),
    1,
    sym_comment,
    ACTIONS(1660),
    5,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    ACTIONS(1658),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    anon_sym_char,
    anon_sym_wchar,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [9647] = 28,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(884),
    1,
    anon_sym_LPAREN,
    ACTIONS(886),
    1,
    anon_sym_TILDE,
    ACTIONS(888),
    1,
    anon_sym_L,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(896),
    1,
    sym_number_literal,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1662),
    1,
    sym_identifier,
    STATE(157),
    1,
    sym_comment,
    STATE(191),
    1,
    sym_scoped_name,
    STATE(195),
    1,
    sym_unary_expr,
    STATE(196),
    1,
    sym_primary_expr,
    STATE(197),
    1,
    sym_mult_expr,
    STATE(198),
    1,
    sym_literal,
    STATE(216),
    1,
    sym_unary_operator,
    STATE(218),
    1,
    sym_add_expr,
    STATE(223),
    1,
    sym_shift_expr,
    STATE(253),
    1,
    sym_and_expr,
    STATE(272),
    1,
    sym_xor_expr,
    STATE(292),
    1,
    sym_or_expr,
    STATE(610),
    1,
    sym_annotation_appl_param,
    STATE(924),
    1,
    sym_const_expr,
    STATE(925),
    1,
    sym_annotation_appl_params,
    ACTIONS(882),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(894),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [9736] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1666),
    1,
    anon_sym_AT,
    STATE(158),
    1,
    sym_comment,
    ACTIONS(1664),
    28,
    anon_sym_exception,
    anon_sym_RBRACE,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_ATannotation,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_valuetype,
    anon_sym_eventtype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_alias,
    anon_sym_custom,
    anon_sym_typedef,
    anon_sym_ATignore_literal_names,
    anon_sym_typeid,
    anon_sym_typeprefix,
    anon_sym_import,
    anon_sym_component,
    anon_sym_home,
    anon_sym_porttype,
    anon_sym_connector,
    anon_sym_native,
    [9779] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1670),
    1,
    anon_sym_AT,
    STATE(159),
    1,
    sym_comment,
    ACTIONS(1668),
    28,
    anon_sym_exception,
    anon_sym_RBRACE,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_ATannotation,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_valuetype,
    anon_sym_eventtype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_alias,
    anon_sym_custom,
    anon_sym_typedef,
    anon_sym_ATignore_literal_names,
    anon_sym_typeid,
    anon_sym_typeprefix,
    anon_sym_import,
    anon_sym_component,
    anon_sym_home,
    anon_sym_porttype,
    anon_sym_connector,
    anon_sym_native,
    [9822] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1674),
    1,
    anon_sym_AT,
    STATE(160),
    1,
    sym_comment,
    ACTIONS(1672),
    28,
    anon_sym_exception,
    anon_sym_RBRACE,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_ATannotation,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_valuetype,
    anon_sym_eventtype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_alias,
    anon_sym_custom,
    anon_sym_typedef,
    anon_sym_ATignore_literal_names,
    anon_sym_typeid,
    anon_sym_typeprefix,
    anon_sym_import,
    anon_sym_component,
    anon_sym_home,
    anon_sym_porttype,
    anon_sym_connector,
    anon_sym_native,
    [9865] = 28,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(884),
    1,
    anon_sym_LPAREN,
    ACTIONS(886),
    1,
    anon_sym_TILDE,
    ACTIONS(888),
    1,
    anon_sym_L,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(896),
    1,
    sym_number_literal,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1662),
    1,
    sym_identifier,
    STATE(161),
    1,
    sym_comment,
    STATE(191),
    1,
    sym_scoped_name,
    STATE(195),
    1,
    sym_unary_expr,
    STATE(196),
    1,
    sym_primary_expr,
    STATE(197),
    1,
    sym_mult_expr,
    STATE(198),
    1,
    sym_literal,
    STATE(216),
    1,
    sym_unary_operator,
    STATE(218),
    1,
    sym_add_expr,
    STATE(223),
    1,
    sym_shift_expr,
    STATE(253),
    1,
    sym_and_expr,
    STATE(272),
    1,
    sym_xor_expr,
    STATE(292),
    1,
    sym_or_expr,
    STATE(610),
    1,
    sym_annotation_appl_param,
    STATE(924),
    1,
    sym_const_expr,
    STATE(1065),
    1,
    sym_annotation_appl_params,
    ACTIONS(882),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(894),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [9954] = 28,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(884),
    1,
    anon_sym_LPAREN,
    ACTIONS(886),
    1,
    anon_sym_TILDE,
    ACTIONS(888),
    1,
    anon_sym_L,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(896),
    1,
    sym_number_literal,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1662),
    1,
    sym_identifier,
    STATE(162),
    1,
    sym_comment,
    STATE(191),
    1,
    sym_scoped_name,
    STATE(195),
    1,
    sym_unary_expr,
    STATE(196),
    1,
    sym_primary_expr,
    STATE(197),
    1,
    sym_mult_expr,
    STATE(198),
    1,
    sym_literal,
    STATE(216),
    1,
    sym_unary_operator,
    STATE(218),
    1,
    sym_add_expr,
    STATE(223),
    1,
    sym_shift_expr,
    STATE(253),
    1,
    sym_and_expr,
    STATE(272),
    1,
    sym_xor_expr,
    STATE(292),
    1,
    sym_or_expr,
    STATE(610),
    1,
    sym_annotation_appl_param,
    STATE(924),
    1,
    sym_const_expr,
    STATE(1101),
    1,
    sym_annotation_appl_params,
    ACTIONS(882),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(894),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [10043] = 28,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(884),
    1,
    anon_sym_LPAREN,
    ACTIONS(886),
    1,
    anon_sym_TILDE,
    ACTIONS(888),
    1,
    anon_sym_L,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(896),
    1,
    sym_number_literal,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1662),
    1,
    sym_identifier,
    STATE(163),
    1,
    sym_comment,
    STATE(191),
    1,
    sym_scoped_name,
    STATE(195),
    1,
    sym_unary_expr,
    STATE(196),
    1,
    sym_primary_expr,
    STATE(197),
    1,
    sym_mult_expr,
    STATE(198),
    1,
    sym_literal,
    STATE(216),
    1,
    sym_unary_operator,
    STATE(218),
    1,
    sym_add_expr,
    STATE(223),
    1,
    sym_shift_expr,
    STATE(253),
    1,
    sym_and_expr,
    STATE(272),
    1,
    sym_xor_expr,
    STATE(292),
    1,
    sym_or_expr,
    STATE(610),
    1,
    sym_annotation_appl_param,
    STATE(924),
    1,
    sym_const_expr,
    STATE(1132),
    1,
    sym_annotation_appl_params,
    ACTIONS(882),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(894),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [10132] = 27,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(884),
    1,
    anon_sym_LPAREN,
    ACTIONS(886),
    1,
    anon_sym_TILDE,
    ACTIONS(888),
    1,
    anon_sym_L,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(896),
    1,
    sym_number_literal,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(164),
    1,
    sym_comment,
    STATE(191),
    1,
    sym_scoped_name,
    STATE(195),
    1,
    sym_unary_expr,
    STATE(196),
    1,
    sym_primary_expr,
    STATE(197),
    1,
    sym_mult_expr,
    STATE(198),
    1,
    sym_literal,
    STATE(216),
    1,
    sym_unary_operator,
    STATE(218),
    1,
    sym_add_expr,
    STATE(223),
    1,
    sym_shift_expr,
    STATE(253),
    1,
    sym_and_expr,
    STATE(272),
    1,
    sym_xor_expr,
    STATE(292),
    1,
    sym_or_expr,
    STATE(559),
    1,
    sym_const_expr,
    STATE(1011),
    1,
    sym_positive_int_const,
    ACTIONS(882),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(894),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [10218] = 27,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(884),
    1,
    anon_sym_LPAREN,
    ACTIONS(886),
    1,
    anon_sym_TILDE,
    ACTIONS(888),
    1,
    anon_sym_L,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(896),
    1,
    sym_number_literal,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(165),
    1,
    sym_comment,
    STATE(191),
    1,
    sym_scoped_name,
    STATE(195),
    1,
    sym_unary_expr,
    STATE(196),
    1,
    sym_primary_expr,
    STATE(197),
    1,
    sym_mult_expr,
    STATE(198),
    1,
    sym_literal,
    STATE(216),
    1,
    sym_unary_operator,
    STATE(218),
    1,
    sym_add_expr,
    STATE(223),
    1,
    sym_shift_expr,
    STATE(253),
    1,
    sym_and_expr,
    STATE(272),
    1,
    sym_xor_expr,
    STATE(292),
    1,
    sym_or_expr,
    STATE(559),
    1,
    sym_const_expr,
    STATE(798),
    1,
    sym_positive_int_const,
    ACTIONS(882),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(894),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [10304] = 27,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(884),
    1,
    anon_sym_LPAREN,
    ACTIONS(886),
    1,
    anon_sym_TILDE,
    ACTIONS(888),
    1,
    anon_sym_L,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(896),
    1,
    sym_number_literal,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(166),
    1,
    sym_comment,
    STATE(191),
    1,
    sym_scoped_name,
    STATE(195),
    1,
    sym_unary_expr,
    STATE(196),
    1,
    sym_primary_expr,
    STATE(197),
    1,
    sym_mult_expr,
    STATE(198),
    1,
    sym_literal,
    STATE(216),
    1,
    sym_unary_operator,
    STATE(218),
    1,
    sym_add_expr,
    STATE(223),
    1,
    sym_shift_expr,
    STATE(253),
    1,
    sym_and_expr,
    STATE(272),
    1,
    sym_xor_expr,
    STATE(292),
    1,
    sym_or_expr,
    STATE(559),
    1,
    sym_const_expr,
    STATE(850),
    1,
    sym_positive_int_const,
    ACTIONS(882),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(894),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [10390] = 27,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(884),
    1,
    anon_sym_LPAREN,
    ACTIONS(886),
    1,
    anon_sym_TILDE,
    ACTIONS(888),
    1,
    anon_sym_L,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(896),
    1,
    sym_number_literal,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(167),
    1,
    sym_comment,
    STATE(191),
    1,
    sym_scoped_name,
    STATE(195),
    1,
    sym_unary_expr,
    STATE(196),
    1,
    sym_primary_expr,
    STATE(197),
    1,
    sym_mult_expr,
    STATE(198),
    1,
    sym_literal,
    STATE(216),
    1,
    sym_unary_operator,
    STATE(218),
    1,
    sym_add_expr,
    STATE(223),
    1,
    sym_shift_expr,
    STATE(253),
    1,
    sym_and_expr,
    STATE(272),
    1,
    sym_xor_expr,
    STATE(292),
    1,
    sym_or_expr,
    STATE(559),
    1,
    sym_const_expr,
    STATE(851),
    1,
    sym_positive_int_const,
    ACTIONS(882),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(894),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [10476] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1678),
    1,
    anon_sym_AT,
    STATE(168),
    1,
    sym_comment,
    ACTIONS(1676),
    27,
    anon_sym_exception,
    anon_sym_RBRACE,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_ATannotation,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_valuetype,
    anon_sym_eventtype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_typedef,
    anon_sym_ATignore_literal_names,
    anon_sym_typeid,
    anon_sym_typeprefix,
    anon_sym_import,
    anon_sym_component,
    anon_sym_home,
    anon_sym_porttype,
    anon_sym_connector,
    anon_sym_native,
    [10518] = 27,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(884),
    1,
    anon_sym_LPAREN,
    ACTIONS(886),
    1,
    anon_sym_TILDE,
    ACTIONS(888),
    1,
    anon_sym_L,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(896),
    1,
    sym_number_literal,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(169),
    1,
    sym_comment,
    STATE(191),
    1,
    sym_scoped_name,
    STATE(195),
    1,
    sym_unary_expr,
    STATE(196),
    1,
    sym_primary_expr,
    STATE(197),
    1,
    sym_mult_expr,
    STATE(198),
    1,
    sym_literal,
    STATE(216),
    1,
    sym_unary_operator,
    STATE(218),
    1,
    sym_add_expr,
    STATE(223),
    1,
    sym_shift_expr,
    STATE(253),
    1,
    sym_and_expr,
    STATE(272),
    1,
    sym_xor_expr,
    STATE(292),
    1,
    sym_or_expr,
    STATE(559),
    1,
    sym_const_expr,
    STATE(1002),
    1,
    sym_positive_int_const,
    ACTIONS(882),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(894),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [10604] = 27,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(884),
    1,
    anon_sym_LPAREN,
    ACTIONS(886),
    1,
    anon_sym_TILDE,
    ACTIONS(888),
    1,
    anon_sym_L,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(896),
    1,
    sym_number_literal,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(170),
    1,
    sym_comment,
    STATE(191),
    1,
    sym_scoped_name,
    STATE(195),
    1,
    sym_unary_expr,
    STATE(196),
    1,
    sym_primary_expr,
    STATE(197),
    1,
    sym_mult_expr,
    STATE(198),
    1,
    sym_literal,
    STATE(216),
    1,
    sym_unary_operator,
    STATE(218),
    1,
    sym_add_expr,
    STATE(223),
    1,
    sym_shift_expr,
    STATE(253),
    1,
    sym_and_expr,
    STATE(272),
    1,
    sym_xor_expr,
    STATE(292),
    1,
    sym_or_expr,
    STATE(559),
    1,
    sym_const_expr,
    STATE(847),
    1,
    sym_positive_int_const,
    ACTIONS(882),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(894),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [10690] = 27,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(884),
    1,
    anon_sym_LPAREN,
    ACTIONS(886),
    1,
    anon_sym_TILDE,
    ACTIONS(888),
    1,
    anon_sym_L,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(896),
    1,
    sym_number_literal,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(171),
    1,
    sym_comment,
    STATE(191),
    1,
    sym_scoped_name,
    STATE(195),
    1,
    sym_unary_expr,
    STATE(196),
    1,
    sym_primary_expr,
    STATE(197),
    1,
    sym_mult_expr,
    STATE(198),
    1,
    sym_literal,
    STATE(216),
    1,
    sym_unary_operator,
    STATE(218),
    1,
    sym_add_expr,
    STATE(223),
    1,
    sym_shift_expr,
    STATE(253),
    1,
    sym_and_expr,
    STATE(272),
    1,
    sym_xor_expr,
    STATE(292),
    1,
    sym_or_expr,
    STATE(559),
    1,
    sym_const_expr,
    STATE(1018),
    1,
    sym_positive_int_const,
    ACTIONS(882),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(894),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [10776] = 26,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(884),
    1,
    anon_sym_LPAREN,
    ACTIONS(886),
    1,
    anon_sym_TILDE,
    ACTIONS(888),
    1,
    anon_sym_L,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(896),
    1,
    sym_number_literal,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(172),
    1,
    sym_comment,
    STATE(191),
    1,
    sym_scoped_name,
    STATE(195),
    1,
    sym_unary_expr,
    STATE(196),
    1,
    sym_primary_expr,
    STATE(197),
    1,
    sym_mult_expr,
    STATE(198),
    1,
    sym_literal,
    STATE(216),
    1,
    sym_unary_operator,
    STATE(218),
    1,
    sym_add_expr,
    STATE(223),
    1,
    sym_shift_expr,
    STATE(253),
    1,
    sym_and_expr,
    STATE(272),
    1,
    sym_xor_expr,
    STATE(292),
    1,
    sym_or_expr,
    STATE(956),
    1,
    sym_const_expr,
    ACTIONS(882),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(894),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [10859] = 26,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(884),
    1,
    anon_sym_LPAREN,
    ACTIONS(886),
    1,
    anon_sym_TILDE,
    ACTIONS(888),
    1,
    anon_sym_L,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(896),
    1,
    sym_number_literal,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(173),
    1,
    sym_comment,
    STATE(191),
    1,
    sym_scoped_name,
    STATE(195),
    1,
    sym_unary_expr,
    STATE(196),
    1,
    sym_primary_expr,
    STATE(197),
    1,
    sym_mult_expr,
    STATE(198),
    1,
    sym_literal,
    STATE(216),
    1,
    sym_unary_operator,
    STATE(218),
    1,
    sym_add_expr,
    STATE(223),
    1,
    sym_shift_expr,
    STATE(253),
    1,
    sym_and_expr,
    STATE(272),
    1,
    sym_xor_expr,
    STATE(292),
    1,
    sym_or_expr,
    STATE(808),
    1,
    sym_const_expr,
    ACTIONS(882),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(894),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [10942] = 26,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(884),
    1,
    anon_sym_LPAREN,
    ACTIONS(886),
    1,
    anon_sym_TILDE,
    ACTIONS(888),
    1,
    anon_sym_L,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(896),
    1,
    sym_number_literal,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(174),
    1,
    sym_comment,
    STATE(191),
    1,
    sym_scoped_name,
    STATE(195),
    1,
    sym_unary_expr,
    STATE(196),
    1,
    sym_primary_expr,
    STATE(197),
    1,
    sym_mult_expr,
    STATE(198),
    1,
    sym_literal,
    STATE(216),
    1,
    sym_unary_operator,
    STATE(218),
    1,
    sym_add_expr,
    STATE(223),
    1,
    sym_shift_expr,
    STATE(253),
    1,
    sym_and_expr,
    STATE(272),
    1,
    sym_xor_expr,
    STATE(292),
    1,
    sym_or_expr,
    STATE(1256),
    1,
    sym_const_expr,
    ACTIONS(882),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(894),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [11025] = 26,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(884),
    1,
    anon_sym_LPAREN,
    ACTIONS(886),
    1,
    anon_sym_TILDE,
    ACTIONS(888),
    1,
    anon_sym_L,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(896),
    1,
    sym_number_literal,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(175),
    1,
    sym_comment,
    STATE(191),
    1,
    sym_scoped_name,
    STATE(195),
    1,
    sym_unary_expr,
    STATE(196),
    1,
    sym_primary_expr,
    STATE(197),
    1,
    sym_mult_expr,
    STATE(198),
    1,
    sym_literal,
    STATE(216),
    1,
    sym_unary_operator,
    STATE(218),
    1,
    sym_add_expr,
    STATE(223),
    1,
    sym_shift_expr,
    STATE(253),
    1,
    sym_and_expr,
    STATE(272),
    1,
    sym_xor_expr,
    STATE(292),
    1,
    sym_or_expr,
    STATE(1196),
    1,
    sym_const_expr,
    ACTIONS(882),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(894),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [11108] = 26,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(884),
    1,
    anon_sym_LPAREN,
    ACTIONS(886),
    1,
    anon_sym_TILDE,
    ACTIONS(888),
    1,
    anon_sym_L,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(896),
    1,
    sym_number_literal,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(176),
    1,
    sym_comment,
    STATE(191),
    1,
    sym_scoped_name,
    STATE(195),
    1,
    sym_unary_expr,
    STATE(196),
    1,
    sym_primary_expr,
    STATE(197),
    1,
    sym_mult_expr,
    STATE(198),
    1,
    sym_literal,
    STATE(216),
    1,
    sym_unary_operator,
    STATE(218),
    1,
    sym_add_expr,
    STATE(223),
    1,
    sym_shift_expr,
    STATE(253),
    1,
    sym_and_expr,
    STATE(272),
    1,
    sym_xor_expr,
    STATE(292),
    1,
    sym_or_expr,
    STATE(1005),
    1,
    sym_const_expr,
    ACTIONS(882),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(894),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [11191] = 26,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(884),
    1,
    anon_sym_LPAREN,
    ACTIONS(886),
    1,
    anon_sym_TILDE,
    ACTIONS(888),
    1,
    anon_sym_L,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(896),
    1,
    sym_number_literal,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(177),
    1,
    sym_comment,
    STATE(191),
    1,
    sym_scoped_name,
    STATE(195),
    1,
    sym_unary_expr,
    STATE(196),
    1,
    sym_primary_expr,
    STATE(197),
    1,
    sym_mult_expr,
    STATE(198),
    1,
    sym_literal,
    STATE(216),
    1,
    sym_unary_operator,
    STATE(218),
    1,
    sym_add_expr,
    STATE(223),
    1,
    sym_shift_expr,
    STATE(253),
    1,
    sym_and_expr,
    STATE(272),
    1,
    sym_xor_expr,
    STATE(292),
    1,
    sym_or_expr,
    STATE(844),
    1,
    sym_const_expr,
    ACTIONS(882),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(894),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [11274] = 19,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_long,
    ACTIONS(89),
    1,
    anon_sym_unsignedlong,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1682),
    1,
    anon_sym_int32,
    ACTIONS(1684),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(1688),
    1,
    sym_signed_tiny_int,
    ACTIONS(1690),
    1,
    anon_sym_uint32,
    STATE(178),
    1,
    sym_comment,
    STATE(934),
    1,
    sym_destination_type,
    STATE(935),
    1,
    sym_integer_type,
    ACTIONS(73),
    2,
    anon_sym_longlong,
    anon_sym_int64,
    ACTIONS(85),
    2,
    anon_sym_unsignedshort,
    anon_sym_uint16,
    ACTIONS(91),
    2,
    anon_sym_unsignedlonglong,
    anon_sym_uint64,
    ACTIONS(1680),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(1686),
    2,
    sym_boolean_type,
    sym_octet_type,
    STATE(375),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(366),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(370),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    [11342] = 24,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(884),
    1,
    anon_sym_LPAREN,
    ACTIONS(886),
    1,
    anon_sym_TILDE,
    ACTIONS(888),
    1,
    anon_sym_L,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(896),
    1,
    sym_number_literal,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(179),
    1,
    sym_comment,
    STATE(191),
    1,
    sym_scoped_name,
    STATE(195),
    1,
    sym_unary_expr,
    STATE(196),
    1,
    sym_primary_expr,
    STATE(197),
    1,
    sym_mult_expr,
    STATE(198),
    1,
    sym_literal,
    STATE(216),
    1,
    sym_unary_operator,
    STATE(218),
    1,
    sym_add_expr,
    STATE(223),
    1,
    sym_shift_expr,
    STATE(253),
    1,
    sym_and_expr,
    STATE(265),
    1,
    sym_xor_expr,
    ACTIONS(882),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(894),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [11419] = 23,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(884),
    1,
    anon_sym_LPAREN,
    ACTIONS(886),
    1,
    anon_sym_TILDE,
    ACTIONS(888),
    1,
    anon_sym_L,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(896),
    1,
    sym_number_literal,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(180),
    1,
    sym_comment,
    STATE(191),
    1,
    sym_scoped_name,
    STATE(195),
    1,
    sym_unary_expr,
    STATE(196),
    1,
    sym_primary_expr,
    STATE(197),
    1,
    sym_mult_expr,
    STATE(198),
    1,
    sym_literal,
    STATE(216),
    1,
    sym_unary_operator,
    STATE(218),
    1,
    sym_add_expr,
    STATE(223),
    1,
    sym_shift_expr,
    STATE(256),
    1,
    sym_and_expr,
    ACTIONS(882),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(894),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [11493] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(181),
    1,
    sym_comment,
    ACTIONS(1464),
    3,
    anon_sym_GT,
    anon_sym_SLASH,
    anon_sym_COLON,
    ACTIONS(1466),
    20,
    anon_sym_COLON_COLON,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_L,
    anon_sym_DQUOTE,
    anon_sym_LBRACE,
    anon_sym_SEMI,
    anon_sym_supports,
    anon_sym_RBRACK,
    anon_sym_manages,
    anon_sym_primarykey,
    [11530] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(182),
    1,
    sym_comment,
    ACTIONS(1402),
    3,
    anon_sym_GT,
    anon_sym_SLASH,
    anon_sym_COLON,
    ACTIONS(1404),
    20,
    anon_sym_COLON_COLON,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_L,
    anon_sym_DQUOTE,
    anon_sym_LBRACE,
    anon_sym_SEMI,
    anon_sym_supports,
    anon_sym_RBRACK,
    anon_sym_manages,
    anon_sym_primarykey,
    [11567] = 22,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(884),
    1,
    anon_sym_LPAREN,
    ACTIONS(886),
    1,
    anon_sym_TILDE,
    ACTIONS(888),
    1,
    anon_sym_L,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(896),
    1,
    sym_number_literal,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(183),
    1,
    sym_comment,
    STATE(191),
    1,
    sym_scoped_name,
    STATE(195),
    1,
    sym_unary_expr,
    STATE(196),
    1,
    sym_primary_expr,
    STATE(197),
    1,
    sym_mult_expr,
    STATE(198),
    1,
    sym_literal,
    STATE(216),
    1,
    sym_unary_operator,
    STATE(218),
    1,
    sym_add_expr,
    STATE(224),
    1,
    sym_shift_expr,
    ACTIONS(882),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(894),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [11638] = 17,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1692),
    1,
    anon_sym_RBRACE,
    ACTIONS(1694),
    1,
    anon_sym_readonly,
    ACTIONS(1696),
    1,
    anon_sym_attribute,
    ACTIONS(1698),
    1,
    anon_sym_provides,
    ACTIONS(1700),
    1,
    anon_sym_uses,
    ACTIONS(1702),
    1,
    anon_sym_emits,
    ACTIONS(1704),
    1,
    anon_sym_publishes,
    ACTIONS(1706),
    1,
    anon_sym_consumes,
    STATE(184),
    1,
    sym_comment,
    STATE(186),
    1,
    aux_sym_component_body_repeat1,
    STATE(225),
    1,
    sym_component_export,
    STATE(1003),
    1,
    sym_component_body,
    ACTIONS(1708),
    2,
    anon_sym_port,
    anon_sym_mirrorport,
    STATE(843),
    2,
    sym_readonly_attr_spec,
    sym_attr_spec,
    STATE(940),
    7,
    sym_attr_dcl,
    sym_provides_dcl,
    sym_uses_dcl,
    sym_emits_dcl,
    sym_publishes_dcl,
    sym_consumes_dcl,
    sym_port_dcl,
    [11698] = 21,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(884),
    1,
    anon_sym_LPAREN,
    ACTIONS(886),
    1,
    anon_sym_TILDE,
    ACTIONS(888),
    1,
    anon_sym_L,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(896),
    1,
    sym_number_literal,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(185),
    1,
    sym_comment,
    STATE(191),
    1,
    sym_scoped_name,
    STATE(195),
    1,
    sym_unary_expr,
    STATE(196),
    1,
    sym_primary_expr,
    STATE(197),
    1,
    sym_mult_expr,
    STATE(198),
    1,
    sym_literal,
    STATE(216),
    1,
    sym_unary_operator,
    STATE(220),
    1,
    sym_add_expr,
    ACTIONS(882),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(894),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [11766] = 16,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1694),
    1,
    anon_sym_readonly,
    ACTIONS(1696),
    1,
    anon_sym_attribute,
    ACTIONS(1698),
    1,
    anon_sym_provides,
    ACTIONS(1700),
    1,
    anon_sym_uses,
    ACTIONS(1702),
    1,
    anon_sym_emits,
    ACTIONS(1704),
    1,
    anon_sym_publishes,
    ACTIONS(1706),
    1,
    anon_sym_consumes,
    ACTIONS(1710),
    1,
    anon_sym_RBRACE,
    STATE(186),
    1,
    sym_comment,
    STATE(187),
    1,
    aux_sym_component_body_repeat1,
    STATE(225),
    1,
    sym_component_export,
    ACTIONS(1708),
    2,
    anon_sym_port,
    anon_sym_mirrorport,
    STATE(843),
    2,
    sym_readonly_attr_spec,
    sym_attr_spec,
    STATE(940),
    7,
    sym_attr_dcl,
    sym_provides_dcl,
    sym_uses_dcl,
    sym_emits_dcl,
    sym_publishes_dcl,
    sym_consumes_dcl,
    sym_port_dcl,
    [11823] = 15,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1712),
    1,
    anon_sym_RBRACE,
    ACTIONS(1714),
    1,
    anon_sym_readonly,
    ACTIONS(1717),
    1,
    anon_sym_attribute,
    ACTIONS(1720),
    1,
    anon_sym_provides,
    ACTIONS(1723),
    1,
    anon_sym_uses,
    ACTIONS(1726),
    1,
    anon_sym_emits,
    ACTIONS(1729),
    1,
    anon_sym_publishes,
    ACTIONS(1732),
    1,
    anon_sym_consumes,
    STATE(225),
    1,
    sym_component_export,
    ACTIONS(1735),
    2,
    anon_sym_port,
    anon_sym_mirrorport,
    STATE(187),
    2,
    sym_comment,
    aux_sym_component_body_repeat1,
    STATE(843),
    2,
    sym_readonly_attr_spec,
    sym_attr_spec,
    STATE(940),
    7,
    sym_attr_dcl,
    sym_provides_dcl,
    sym_uses_dcl,
    sym_emits_dcl,
    sym_publishes_dcl,
    sym_consumes_dcl,
    sym_port_dcl,
    [11878] = 20,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(884),
    1,
    anon_sym_LPAREN,
    ACTIONS(886),
    1,
    anon_sym_TILDE,
    ACTIONS(888),
    1,
    anon_sym_L,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(896),
    1,
    sym_number_literal,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(188),
    1,
    sym_comment,
    STATE(191),
    1,
    sym_scoped_name,
    STATE(195),
    1,
    sym_unary_expr,
    STATE(196),
    1,
    sym_primary_expr,
    STATE(198),
    1,
    sym_literal,
    STATE(207),
    1,
    sym_mult_expr,
    STATE(216),
    1,
    sym_unary_operator,
    ACTIONS(882),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(894),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [11943] = 19,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(884),
    1,
    anon_sym_LPAREN,
    ACTIONS(886),
    1,
    anon_sym_TILDE,
    ACTIONS(888),
    1,
    anon_sym_L,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(896),
    1,
    sym_number_literal,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(189),
    1,
    sym_comment,
    STATE(191),
    1,
    sym_scoped_name,
    STATE(196),
    1,
    sym_primary_expr,
    STATE(198),
    1,
    sym_literal,
    STATE(212),
    1,
    sym_unary_expr,
    STATE(216),
    1,
    sym_unary_operator,
    ACTIONS(882),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(894),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [12005] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(190),
    1,
    sym_comment,
    ACTIONS(1460),
    3,
    anon_sym_GT,
    anon_sym_SLASH,
    anon_sym_COLON,
    ACTIONS(1462),
    16,
    anon_sym_COLON_COLON,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_LBRACE,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    sym_identifier,
    [12038] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1738),
    1,
    anon_sym_COLON_COLON,
    STATE(191),
    1,
    sym_comment,
    ACTIONS(1740),
    3,
    anon_sym_GT,
    anon_sym_SLASH,
    anon_sym_COLON,
    ACTIONS(1742),
    13,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [12071] = 15,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1694),
    1,
    anon_sym_readonly,
    ACTIONS(1696),
    1,
    anon_sym_attribute,
    ACTIONS(1698),
    1,
    anon_sym_provides,
    ACTIONS(1700),
    1,
    anon_sym_uses,
    ACTIONS(1744),
    1,
    anon_sym_RBRACE,
    STATE(192),
    1,
    sym_comment,
    STATE(201),
    1,
    aux_sym_port_body_repeat1,
    STATE(304),
    1,
    sym_port_ref,
    STATE(309),
    1,
    sym_port_export,
    STATE(993),
    1,
    sym_attr_dcl,
    ACTIONS(1708),
    2,
    anon_sym_port,
    anon_sym_mirrorport,
    STATE(843),
    2,
    sym_readonly_attr_spec,
    sym_attr_spec,
    STATE(1172),
    3,
    sym_provides_dcl,
    sym_uses_dcl,
    sym_port_dcl,
    [12121] = 15,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1694),
    1,
    anon_sym_readonly,
    ACTIONS(1696),
    1,
    anon_sym_attribute,
    ACTIONS(1698),
    1,
    anon_sym_provides,
    ACTIONS(1700),
    1,
    anon_sym_uses,
    ACTIONS(1746),
    1,
    anon_sym_RBRACE,
    STATE(193),
    1,
    sym_comment,
    STATE(205),
    1,
    aux_sym_connector_dcl_repeat1,
    STATE(293),
    1,
    sym_port_ref,
    STATE(294),
    1,
    sym_connector_export,
    STATE(1171),
    1,
    sym_attr_dcl,
    ACTIONS(1708),
    2,
    anon_sym_port,
    anon_sym_mirrorport,
    STATE(843),
    2,
    sym_readonly_attr_spec,
    sym_attr_spec,
    STATE(1172),
    3,
    sym_provides_dcl,
    sym_uses_dcl,
    sym_port_dcl,
    [12171] = 11,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1750),
    1,
    anon_sym_L,
    ACTIONS(1752),
    1,
    anon_sym_c,
    STATE(194),
    1,
    sym_comment,
    STATE(1128),
    1,
    sym_string_literal,
    STATE(1251),
    1,
    sym_verbatim_language,
    STATE(1252),
    1,
    sym_placement_kind,
    ACTIONS(1748),
    4,
    anon_sym_STAR,
    anon_sym_c_PLUS_PLUS,
    anon_sym_java,
    anon_sym_idl,
    ACTIONS(1754),
    6,
    anon_sym_BEGIN_FILE,
    anon_sym_BEFORE_DECLARATION,
    anon_sym_BEGIN_DECLARATION,
    anon_sym_END_DECLARATION,
    anon_sym_AFTER_DECLARATION,
    anon_sym_END_FILE,
    [12213] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(195),
    1,
    sym_comment,
    ACTIONS(1756),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(1758),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [12243] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(196),
    1,
    sym_comment,
    ACTIONS(1760),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(1762),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [12273] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1764),
    1,
    anon_sym_GT,
    ACTIONS(1770),
    1,
    anon_sym_SLASH,
    STATE(197),
    1,
    sym_comment,
    ACTIONS(1768),
    2,
    anon_sym_STAR,
    anon_sym_PERCENT,
    ACTIONS(1766),
    12,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [12307] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(198),
    1,
    sym_comment,
    ACTIONS(1740),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(1742),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [12337] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(199),
    1,
    sym_comment,
    ACTIONS(1772),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(1774),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [12367] = 11,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1750),
    1,
    anon_sym_L,
    ACTIONS(1752),
    1,
    anon_sym_c,
    STATE(200),
    1,
    sym_comment,
    STATE(1097),
    1,
    sym_string_literal,
    STATE(1237),
    1,
    sym_verbatim_language,
    STATE(1238),
    1,
    sym_placement_kind,
    ACTIONS(1748),
    4,
    anon_sym_STAR,
    anon_sym_c_PLUS_PLUS,
    anon_sym_java,
    anon_sym_idl,
    ACTIONS(1754),
    6,
    anon_sym_BEGIN_FILE,
    anon_sym_BEFORE_DECLARATION,
    anon_sym_BEGIN_DECLARATION,
    anon_sym_END_DECLARATION,
    anon_sym_AFTER_DECLARATION,
    anon_sym_END_FILE,
    [12409] = 15,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1694),
    1,
    anon_sym_readonly,
    ACTIONS(1696),
    1,
    anon_sym_attribute,
    ACTIONS(1698),
    1,
    anon_sym_provides,
    ACTIONS(1700),
    1,
    anon_sym_uses,
    ACTIONS(1776),
    1,
    anon_sym_RBRACE,
    STATE(201),
    1,
    sym_comment,
    STATE(203),
    1,
    aux_sym_port_body_repeat1,
    STATE(304),
    1,
    sym_port_ref,
    STATE(309),
    1,
    sym_port_export,
    STATE(993),
    1,
    sym_attr_dcl,
    ACTIONS(1708),
    2,
    anon_sym_port,
    anon_sym_mirrorport,
    STATE(843),
    2,
    sym_readonly_attr_spec,
    sym_attr_spec,
    STATE(1172),
    3,
    sym_provides_dcl,
    sym_uses_dcl,
    sym_port_dcl,
    [12459] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(202),
    1,
    sym_comment,
    ACTIONS(1778),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(1780),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [12489] = 14,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1782),
    1,
    anon_sym_RBRACE,
    ACTIONS(1784),
    1,
    anon_sym_readonly,
    ACTIONS(1787),
    1,
    anon_sym_attribute,
    ACTIONS(1790),
    1,
    anon_sym_provides,
    ACTIONS(1793),
    1,
    anon_sym_uses,
    STATE(304),
    1,
    sym_port_ref,
    STATE(309),
    1,
    sym_port_export,
    STATE(993),
    1,
    sym_attr_dcl,
    ACTIONS(1796),
    2,
    anon_sym_port,
    anon_sym_mirrorport,
    STATE(203),
    2,
    sym_comment,
    aux_sym_port_body_repeat1,
    STATE(843),
    2,
    sym_readonly_attr_spec,
    sym_attr_spec,
    STATE(1172),
    3,
    sym_provides_dcl,
    sym_uses_dcl,
    sym_port_dcl,
    [12537] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(204),
    1,
    sym_comment,
    ACTIONS(1799),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(1801),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [12567] = 14,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1803),
    1,
    anon_sym_RBRACE,
    ACTIONS(1805),
    1,
    anon_sym_readonly,
    ACTIONS(1808),
    1,
    anon_sym_attribute,
    ACTIONS(1811),
    1,
    anon_sym_provides,
    ACTIONS(1814),
    1,
    anon_sym_uses,
    STATE(293),
    1,
    sym_port_ref,
    STATE(294),
    1,
    sym_connector_export,
    STATE(1171),
    1,
    sym_attr_dcl,
    ACTIONS(1817),
    2,
    anon_sym_port,
    anon_sym_mirrorport,
    STATE(205),
    2,
    sym_comment,
    aux_sym_connector_dcl_repeat1,
    STATE(843),
    2,
    sym_readonly_attr_spec,
    sym_attr_spec,
    STATE(1172),
    3,
    sym_provides_dcl,
    sym_uses_dcl,
    sym_port_dcl,
    [12615] = 11,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1750),
    1,
    anon_sym_L,
    ACTIONS(1752),
    1,
    anon_sym_c,
    STATE(206),
    1,
    sym_comment,
    STATE(909),
    1,
    sym_string_literal,
    STATE(911),
    1,
    sym_verbatim_language,
    STATE(913),
    1,
    sym_placement_kind,
    ACTIONS(1748),
    4,
    anon_sym_STAR,
    anon_sym_c_PLUS_PLUS,
    anon_sym_java,
    anon_sym_idl,
    ACTIONS(1754),
    6,
    anon_sym_BEGIN_FILE,
    anon_sym_BEFORE_DECLARATION,
    anon_sym_BEGIN_DECLARATION,
    anon_sym_END_DECLARATION,
    anon_sym_AFTER_DECLARATION,
    anon_sym_END_FILE,
    [12657] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1770),
    1,
    anon_sym_SLASH,
    ACTIONS(1820),
    1,
    anon_sym_GT,
    STATE(207),
    1,
    sym_comment,
    ACTIONS(1768),
    2,
    anon_sym_STAR,
    anon_sym_PERCENT,
    ACTIONS(1822),
    12,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [12691] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(208),
    1,
    sym_comment,
    ACTIONS(1824),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(1826),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [12721] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(209),
    1,
    sym_comment,
    ACTIONS(1828),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(1830),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [12751] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(210),
    1,
    sym_comment,
    ACTIONS(1832),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(1834),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [12781] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(211),
    1,
    sym_comment,
    ACTIONS(1836),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(1838),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [12811] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(212),
    1,
    sym_comment,
    ACTIONS(1840),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(1842),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [12841] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(213),
    1,
    sym_comment,
    ACTIONS(1844),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(1846),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [12871] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(214),
    1,
    sym_comment,
    ACTIONS(1848),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(1850),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [12901] = 11,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1750),
    1,
    anon_sym_L,
    ACTIONS(1752),
    1,
    anon_sym_c,
    STATE(215),
    1,
    sym_comment,
    STATE(1061),
    1,
    sym_string_literal,
    STATE(1223),
    1,
    sym_verbatim_language,
    STATE(1224),
    1,
    sym_placement_kind,
    ACTIONS(1748),
    4,
    anon_sym_STAR,
    anon_sym_c_PLUS_PLUS,
    anon_sym_java,
    anon_sym_idl,
    ACTIONS(1754),
    6,
    anon_sym_BEGIN_FILE,
    anon_sym_BEFORE_DECLARATION,
    anon_sym_BEGIN_DECLARATION,
    anon_sym_END_DECLARATION,
    anon_sym_AFTER_DECLARATION,
    anon_sym_END_FILE,
    [12943] = 15,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(884),
    1,
    anon_sym_LPAREN,
    ACTIONS(888),
    1,
    anon_sym_L,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(896),
    1,
    sym_number_literal,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(191),
    1,
    sym_scoped_name,
    STATE(198),
    1,
    sym_literal,
    STATE(199),
    1,
    sym_primary_expr,
    STATE(216),
    1,
    sym_comment,
    ACTIONS(894),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [12992] = 14,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1694),
    1,
    anon_sym_readonly,
    ACTIONS(1696),
    1,
    anon_sym_attribute,
    ACTIONS(1698),
    1,
    anon_sym_provides,
    ACTIONS(1700),
    1,
    anon_sym_uses,
    STATE(193),
    1,
    aux_sym_connector_dcl_repeat1,
    STATE(217),
    1,
    sym_comment,
    STATE(293),
    1,
    sym_port_ref,
    STATE(294),
    1,
    sym_connector_export,
    STATE(1171),
    1,
    sym_attr_dcl,
    ACTIONS(1708),
    2,
    anon_sym_port,
    anon_sym_mirrorport,
    STATE(843),
    2,
    sym_readonly_attr_spec,
    sym_attr_spec,
    STATE(1172),
    3,
    sym_provides_dcl,
    sym_uses_dcl,
    sym_port_dcl,
    [13039] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1852),
    1,
    anon_sym_GT,
    STATE(218),
    1,
    sym_comment,
    ACTIONS(1856),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(1854),
    10,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [13068] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1460),
    1,
    anon_sym_SLASH,
    ACTIONS(1858),
    1,
    anon_sym_EQ,
    STATE(219),
    1,
    sym_comment,
    ACTIONS(1462),
    11,
    anon_sym_COLON_COLON,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    [13097] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1860),
    1,
    anon_sym_GT,
    STATE(220),
    1,
    sym_comment,
    ACTIONS(1856),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(1862),
    10,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [13126] = 8,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1738),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(1740),
    1,
    anon_sym_SLASH,
    ACTIONS(1864),
    1,
    anon_sym_GT,
    ACTIONS(1866),
    1,
    anon_sym_COMMA,
    STATE(221),
    1,
    sym_comment,
    ACTIONS(1742),
    9,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    [13159] = 14,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(21),
    1,
    anon_sym_interface,
    ACTIONS(31),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1868),
    1,
    anon_sym_bitmask,
    ACTIONS(1870),
    1,
    anon_sym_AT,
    ACTIONS(1872),
    1,
    anon_sym_struct,
    STATE(222),
    1,
    sym_comment,
    STATE(228),
    1,
    aux_sym_interface_def_repeat1,
    STATE(286),
    1,
    sym_annotation_appl,
    STATE(291),
    1,
    sym_extend_annotation_appl,
    STATE(950),
    1,
    sym_interface_header,
    STATE(951),
    1,
    sym_interface_kind,
    ACTIONS(17),
    2,
    anon_sym_local,
    anon_sym_abstract,
    [13203] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1874),
    1,
    anon_sym_GT,
    STATE(223),
    1,
    sym_comment,
    ACTIONS(1878),
    2,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    ACTIONS(1876),
    8,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [13230] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1880),
    1,
    anon_sym_GT,
    STATE(224),
    1,
    sym_comment,
    ACTIONS(1878),
    2,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    ACTIONS(1882),
    8,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [13257] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(225),
    1,
    sym_comment,
    ACTIONS(1884),
    10,
    anon_sym_RBRACE,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_provides,
    anon_sym_uses,
    anon_sym_emits,
    anon_sym_publishes,
    anon_sym_consumes,
    anon_sym_port,
    anon_sym_mirrorport,
    [13279] = 10,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1886),
    1,
    anon_sym_L,
    ACTIONS(1890),
    1,
    sym_number_literal,
    STATE(226),
    1,
    sym_comment,
    STATE(1092),
    1,
    sym_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [13313] = 8,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1750),
    1,
    anon_sym_L,
    STATE(227),
    1,
    sym_comment,
    STATE(896),
    1,
    sym_placement_kind,
    STATE(898),
    1,
    sym_string_literal,
    ACTIONS(1754),
    6,
    anon_sym_BEGIN_FILE,
    anon_sym_BEFORE_DECLARATION,
    anon_sym_BEGIN_DECLARATION,
    anon_sym_END_DECLARATION,
    anon_sym_AFTER_DECLARATION,
    anon_sym_END_FILE,
    [13343] = 8,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1892),
    1,
    anon_sym_AT,
    ACTIONS(1895),
    1,
    anon_sym_SLASH_SLASH_AT,
    STATE(286),
    1,
    sym_annotation_appl,
    STATE(291),
    1,
    sym_extend_annotation_appl,
    STATE(228),
    2,
    sym_comment,
    aux_sym_interface_def_repeat1,
    ACTIONS(1368),
    5,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_struct,
    [13373] = 8,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1750),
    1,
    anon_sym_L,
    STATE(229),
    1,
    sym_comment,
    STATE(1134),
    1,
    sym_string_literal,
    STATE(1253),
    1,
    sym_placement_kind,
    ACTIONS(1754),
    6,
    anon_sym_BEGIN_FILE,
    anon_sym_BEFORE_DECLARATION,
    anon_sym_BEGIN_DECLARATION,
    anon_sym_END_DECLARATION,
    anon_sym_AFTER_DECLARATION,
    anon_sym_END_FILE,
    [13403] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(230),
    1,
    sym_comment,
    ACTIONS(1462),
    10,
    anon_sym_COLON_COLON,
    anon_sym_LT,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_L,
    anon_sym_DQUOTE,
    anon_sym_LBRACE,
    anon_sym_supports,
    anon_sym_manages,
    anon_sym_primarykey,
    [13425] = 10,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1886),
    1,
    anon_sym_L,
    ACTIONS(1890),
    1,
    sym_number_literal,
    STATE(231),
    1,
    sym_comment,
    STATE(931),
    1,
    sym_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [13459] = 10,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1886),
    1,
    anon_sym_L,
    ACTIONS(1890),
    1,
    sym_number_literal,
    STATE(232),
    1,
    sym_comment,
    STATE(903),
    1,
    sym_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [13493] = 10,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1886),
    1,
    anon_sym_L,
    ACTIONS(1890),
    1,
    sym_number_literal,
    STATE(233),
    1,
    sym_comment,
    STATE(1046),
    1,
    sym_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [13527] = 10,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1886),
    1,
    anon_sym_L,
    ACTIONS(1890),
    1,
    sym_number_literal,
    STATE(234),
    1,
    sym_comment,
    STATE(892),
    1,
    sym_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [13561] = 10,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1698),
    1,
    anon_sym_provides,
    ACTIONS(1700),
    1,
    anon_sym_uses,
    ACTIONS(1898),
    1,
    anon_sym_RBRACE,
    STATE(192),
    1,
    sym_port_ref,
    STATE(235),
    1,
    sym_comment,
    STATE(1067),
    1,
    sym_port_body,
    ACTIONS(1708),
    2,
    anon_sym_port,
    anon_sym_mirrorport,
    STATE(1172),
    3,
    sym_provides_dcl,
    sym_uses_dcl,
    sym_port_dcl,
    [13595] = 8,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1750),
    1,
    anon_sym_L,
    STATE(236),
    1,
    sym_comment,
    STATE(1069),
    1,
    sym_string_literal,
    STATE(1225),
    1,
    sym_placement_kind,
    ACTIONS(1754),
    6,
    anon_sym_BEGIN_FILE,
    anon_sym_BEFORE_DECLARATION,
    anon_sym_BEGIN_DECLARATION,
    anon_sym_END_DECLARATION,
    anon_sym_AFTER_DECLARATION,
    anon_sym_END_FILE,
    [13625] = 10,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1886),
    1,
    anon_sym_L,
    ACTIONS(1890),
    1,
    sym_number_literal,
    STATE(237),
    1,
    sym_comment,
    STATE(1055),
    1,
    sym_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [13659] = 10,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1886),
    1,
    anon_sym_L,
    ACTIONS(1890),
    1,
    sym_number_literal,
    STATE(238),
    1,
    sym_comment,
    STATE(1082),
    1,
    sym_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [13693] = 10,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1886),
    1,
    anon_sym_L,
    ACTIONS(1890),
    1,
    sym_number_literal,
    STATE(239),
    1,
    sym_comment,
    STATE(1087),
    1,
    sym_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [13727] = 10,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1886),
    1,
    anon_sym_L,
    ACTIONS(1890),
    1,
    sym_number_literal,
    STATE(240),
    1,
    sym_comment,
    STATE(1051),
    1,
    sym_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [13761] = 10,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1886),
    1,
    anon_sym_L,
    ACTIONS(1890),
    1,
    sym_number_literal,
    STATE(241),
    1,
    sym_comment,
    STATE(1091),
    1,
    sym_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [13795] = 10,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1886),
    1,
    anon_sym_L,
    ACTIONS(1890),
    1,
    sym_number_literal,
    STATE(242),
    1,
    sym_comment,
    STATE(1056),
    1,
    sym_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [13829] = 10,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1886),
    1,
    anon_sym_L,
    ACTIONS(1890),
    1,
    sym_number_literal,
    STATE(243),
    1,
    sym_comment,
    STATE(891),
    1,
    sym_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [13863] = 10,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1886),
    1,
    anon_sym_L,
    ACTIONS(1890),
    1,
    sym_number_literal,
    STATE(244),
    1,
    sym_comment,
    STATE(871),
    1,
    sym_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [13897] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(245),
    1,
    sym_comment,
    ACTIONS(1900),
    10,
    anon_sym_RBRACE,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_provides,
    anon_sym_uses,
    anon_sym_emits,
    anon_sym_publishes,
    anon_sym_consumes,
    anon_sym_port,
    anon_sym_mirrorport,
    [13919] = 10,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1886),
    1,
    anon_sym_L,
    ACTIONS(1890),
    1,
    sym_number_literal,
    STATE(246),
    1,
    sym_comment,
    STATE(1123),
    1,
    sym_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [13953] = 10,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1886),
    1,
    anon_sym_L,
    ACTIONS(1890),
    1,
    sym_number_literal,
    STATE(247),
    1,
    sym_comment,
    STATE(1122),
    1,
    sym_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [13987] = 8,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1750),
    1,
    anon_sym_L,
    STATE(248),
    1,
    sym_comment,
    STATE(1103),
    1,
    sym_string_literal,
    STATE(1239),
    1,
    sym_placement_kind,
    ACTIONS(1754),
    6,
    anon_sym_BEGIN_FILE,
    anon_sym_BEFORE_DECLARATION,
    anon_sym_BEGIN_DECLARATION,
    anon_sym_END_DECLARATION,
    anon_sym_AFTER_DECLARATION,
    anon_sym_END_FILE,
    [14017] = 10,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1886),
    1,
    anon_sym_L,
    ACTIONS(1890),
    1,
    sym_number_literal,
    STATE(249),
    1,
    sym_comment,
    STATE(1113),
    1,
    sym_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [14051] = 10,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1886),
    1,
    anon_sym_L,
    ACTIONS(1890),
    1,
    sym_number_literal,
    STATE(250),
    1,
    sym_comment,
    STATE(1118),
    1,
    sym_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [14085] = 10,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(892),
    1,
    anon_sym_SQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1886),
    1,
    anon_sym_L,
    ACTIONS(1890),
    1,
    sym_number_literal,
    STATE(251),
    1,
    sym_comment,
    STATE(868),
    1,
    sym_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(208),
    3,
    sym_string_literal,
    sym_char_literal,
    sym_boolean_literal,
    [14119] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(252),
    1,
    sym_comment,
    ACTIONS(1462),
    9,
    anon_sym_COLON_COLON,
    anon_sym_LPAREN,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [14140] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1904),
    1,
    anon_sym_AMP,
    STATE(253),
    1,
    sym_comment,
    ACTIONS(1902),
    8,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [14163] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(254),
    1,
    sym_comment,
    ACTIONS(1404),
    9,
    anon_sym_COLON_COLON,
    anon_sym_LPAREN,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [14184] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(255),
    1,
    sym_comment,
    ACTIONS(1466),
    9,
    anon_sym_COLON_COLON,
    anon_sym_LPAREN,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [14205] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1904),
    1,
    anon_sym_AMP,
    STATE(256),
    1,
    sym_comment,
    ACTIONS(1906),
    8,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [14228] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(257),
    1,
    sym_comment,
    ACTIONS(1908),
    4,
    anon_sym_COLON_COLON,
    anon_sym_LPAREN,
    anon_sym_DQUOTE,
    anon_sym_SQUOTE,
    ACTIONS(1910),
    5,
    anon_sym_L,
    anon_sym_TRUE,
    anon_sym_FALSE,
    sym_number_literal,
    sym_identifier,
    [14251] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1912),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(1914),
    1,
    anon_sym_LPAREN,
    STATE(258),
    1,
    sym_comment,
    ACTIONS(1456),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [14276] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1916),
    1,
    anon_sym_LPAREN,
    STATE(259),
    1,
    sym_comment,
    ACTIONS(1418),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [14298] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(260),
    1,
    sym_comment,
    ACTIONS(1404),
    8,
    anon_sym_COLON_COLON,
    anon_sym_LT,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    anon_sym_LBRACE,
    anon_sym_SEMI,
    sym_identifier,
    [14318] = 11,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1918),
    1,
    anon_sym_RBRACE,
    ACTIONS(1920),
    1,
    anon_sym_AT,
    ACTIONS(1922),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1924),
    1,
    sym_identifier,
    STATE(261),
    1,
    sym_comment,
    STATE(324),
    1,
    aux_sym_interface_def_repeat1,
    STATE(509),
    1,
    sym_bit_value,
    STATE(593),
    1,
    sym_extend_annotation_appl,
    STATE(594),
    1,
    sym_annotation_appl,
    [14352] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1926),
    1,
    anon_sym_LPAREN,
    STATE(262),
    1,
    sym_comment,
    ACTIONS(1384),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [14374] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1928),
    1,
    anon_sym_LPAREN,
    STATE(263),
    1,
    sym_comment,
    ACTIONS(1398),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [14396] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1930),
    1,
    anon_sym_LPAREN,
    STATE(264),
    1,
    sym_comment,
    ACTIONS(1412),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [14418] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1934),
    1,
    anon_sym_CARET,
    STATE(265),
    1,
    sym_comment,
    ACTIONS(1932),
    7,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [14440] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1936),
    1,
    anon_sym_LPAREN,
    STATE(266),
    1,
    sym_comment,
    ACTIONS(1428),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [14462] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1938),
    1,
    anon_sym_LPAREN,
    STATE(267),
    1,
    sym_comment,
    ACTIONS(1438),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [14484] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1940),
    1,
    anon_sym_LPAREN,
    STATE(268),
    1,
    sym_comment,
    ACTIONS(1378),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [14506] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1942),
    1,
    anon_sym_LPAREN,
    STATE(269),
    1,
    sym_comment,
    ACTIONS(1450),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [14528] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1944),
    1,
    anon_sym_LPAREN,
    STATE(270),
    1,
    sym_comment,
    ACTIONS(1444),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [14550] = 11,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1946),
    1,
    anon_sym_COMMA,
    ACTIONS(1948),
    1,
    anon_sym_SEMI,
    ACTIONS(1950),
    1,
    anon_sym_getraises,
    ACTIONS(1952),
    1,
    anon_sym_setraises,
    STATE(271),
    1,
    sym_comment,
    STATE(691),
    1,
    sym_get_excep_expr,
    STATE(693),
    1,
    aux_sym_readonly_attr_declarator_repeat1,
    STATE(957),
    1,
    sym_attr_raises_expr,
    STATE(960),
    1,
    sym_set_excep_expr,
    [14584] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1934),
    1,
    anon_sym_CARET,
    STATE(272),
    1,
    sym_comment,
    ACTIONS(1954),
    7,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [14606] = 11,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1920),
    1,
    anon_sym_AT,
    ACTIONS(1922),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1924),
    1,
    sym_identifier,
    ACTIONS(1956),
    1,
    anon_sym_RBRACE,
    STATE(273),
    1,
    sym_comment,
    STATE(322),
    1,
    aux_sym_interface_def_repeat1,
    STATE(593),
    1,
    sym_extend_annotation_appl,
    STATE(594),
    1,
    sym_annotation_appl,
    STATE(705),
    1,
    sym_bit_value,
    [14640] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(274),
    1,
    sym_comment,
    ACTIONS(1466),
    8,
    anon_sym_COLON_COLON,
    anon_sym_LT,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    anon_sym_LBRACE,
    anon_sym_SEMI,
    sym_identifier,
    [14660] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(275),
    1,
    sym_comment,
    ACTIONS(1498),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [14679] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(276),
    1,
    sym_comment,
    ACTIONS(1558),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [14698] = 10,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(31),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1868),
    1,
    anon_sym_bitmask,
    ACTIONS(1870),
    1,
    anon_sym_AT,
    ACTIONS(1872),
    1,
    anon_sym_struct,
    STATE(228),
    1,
    aux_sym_interface_def_repeat1,
    STATE(277),
    1,
    sym_comment,
    STATE(286),
    1,
    sym_annotation_appl,
    STATE(291),
    1,
    sym_extend_annotation_appl,
    [14729] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(278),
    1,
    sym_comment,
    ACTIONS(1582),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [14748] = 10,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1958),
    1,
    anon_sym_L,
    STATE(279),
    1,
    sym_comment,
    STATE(789),
    1,
    sym_scoped_name,
    STATE(958),
    1,
    sym_imported_scope,
    STATE(959),
    1,
    sym_string_literal,
    [14779] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(280),
    1,
    sym_comment,
    ACTIONS(1534),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [14798] = 10,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1960),
    1,
    anon_sym_LBRACE,
    ACTIONS(1962),
    1,
    anon_sym_COLON,
    ACTIONS(1964),
    1,
    anon_sym_SEMI,
    ACTIONS(1966),
    1,
    anon_sym_supports,
    STATE(281),
    1,
    sym_comment,
    STATE(609),
    1,
    sym_value_inheritance,
    STATE(930),
    1,
    sym_value_supports,
    STATE(1195),
    1,
    sym_value_inheritance_spec,
    [14829] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(282),
    1,
    sym_comment,
    ACTIONS(1634),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [14848] = 10,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1920),
    1,
    anon_sym_AT,
    ACTIONS(1922),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1924),
    1,
    sym_identifier,
    STATE(283),
    1,
    sym_comment,
    STATE(298),
    1,
    aux_sym_interface_def_repeat1,
    STATE(593),
    1,
    sym_extend_annotation_appl,
    STATE(594),
    1,
    sym_annotation_appl,
    STATE(803),
    1,
    sym_bit_value,
    [14879] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(284),
    1,
    sym_comment,
    ACTIONS(1968),
    7,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    anon_sym_SEMI,
    anon_sym_raises,
    anon_sym_getraises,
    anon_sym_setraises,
    anon_sym_default,
    [14898] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(285),
    1,
    sym_comment,
    ACTIONS(1510),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [14917] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(286),
    1,
    sym_comment,
    ACTIONS(1490),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [14936] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(287),
    1,
    sym_comment,
    ACTIONS(1486),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [14955] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(288),
    1,
    sym_comment,
    ACTIONS(1514),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [14974] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(289),
    1,
    sym_comment,
    ACTIONS(1522),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [14993] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(290),
    1,
    sym_comment,
    ACTIONS(1526),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [15012] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(291),
    1,
    sym_comment,
    ACTIONS(1518),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [15031] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1972),
    1,
    anon_sym_PIPE,
    STATE(292),
    1,
    sym_comment,
    ACTIONS(1970),
    6,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [15052] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(293),
    1,
    sym_comment,
    ACTIONS(1974),
    7,
    anon_sym_RBRACE,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_provides,
    anon_sym_uses,
    anon_sym_port,
    anon_sym_mirrorport,
    [15071] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(294),
    1,
    sym_comment,
    ACTIONS(1976),
    7,
    anon_sym_RBRACE,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_provides,
    anon_sym_uses,
    anon_sym_port,
    anon_sym_mirrorport,
    [15090] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(295),
    1,
    sym_comment,
    ACTIONS(1538),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [15109] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(296),
    1,
    sym_comment,
    ACTIONS(1546),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [15128] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(297),
    1,
    sym_comment,
    ACTIONS(1550),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [15147] = 10,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1920),
    1,
    anon_sym_AT,
    ACTIONS(1922),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1924),
    1,
    sym_identifier,
    STATE(298),
    1,
    sym_comment,
    STATE(339),
    1,
    aux_sym_interface_def_repeat1,
    STATE(593),
    1,
    sym_extend_annotation_appl,
    STATE(594),
    1,
    sym_annotation_appl,
    STATE(734),
    1,
    sym_bit_value,
    [15178] = 10,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1962),
    1,
    anon_sym_COLON,
    ACTIONS(1966),
    1,
    anon_sym_supports,
    ACTIONS(1978),
    1,
    anon_sym_LBRACE,
    ACTIONS(1980),
    1,
    anon_sym_SEMI,
    STATE(299),
    1,
    sym_comment,
    STATE(609),
    1,
    sym_value_inheritance,
    STATE(930),
    1,
    sym_value_supports,
    STATE(932),
    1,
    sym_value_inheritance_spec,
    [15209] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(300),
    1,
    sym_comment,
    ACTIONS(1626),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [15228] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(301),
    1,
    sym_comment,
    ACTIONS(1494),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [15247] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(302),
    1,
    sym_comment,
    ACTIONS(1482),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [15266] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(303),
    1,
    sym_comment,
    ACTIONS(1630),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [15285] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(304),
    1,
    sym_comment,
    ACTIONS(1982),
    7,
    anon_sym_RBRACE,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_provides,
    anon_sym_uses,
    anon_sym_port,
    anon_sym_mirrorport,
    [15304] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(305),
    1,
    sym_comment,
    ACTIONS(1610),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [15323] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(306),
    1,
    sym_comment,
    ACTIONS(1602),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [15342] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(307),
    1,
    sym_comment,
    ACTIONS(1606),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [15361] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(308),
    1,
    sym_comment,
    ACTIONS(1478),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [15380] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(309),
    1,
    sym_comment,
    ACTIONS(1984),
    7,
    anon_sym_RBRACE,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_provides,
    anon_sym_uses,
    anon_sym_port,
    anon_sym_mirrorport,
    [15399] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(310),
    1,
    sym_comment,
    ACTIONS(1986),
    7,
    anon_sym_RBRACE,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_provides,
    anon_sym_uses,
    anon_sym_port,
    anon_sym_mirrorport,
    [15418] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(311),
    1,
    sym_comment,
    ACTIONS(1554),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [15437] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(312),
    1,
    sym_comment,
    ACTIONS(1988),
    7,
    anon_sym_RBRACE,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_provides,
    anon_sym_uses,
    anon_sym_port,
    anon_sym_mirrorport,
    [15456] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(313),
    1,
    sym_comment,
    ACTIONS(1566),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [15475] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(314),
    1,
    sym_comment,
    ACTIONS(1574),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [15494] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(315),
    1,
    sym_comment,
    ACTIONS(1594),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [15513] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(316),
    1,
    sym_comment,
    ACTIONS(1990),
    7,
    anon_sym_RBRACE,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_provides,
    anon_sym_uses,
    anon_sym_port,
    anon_sym_mirrorport,
    [15532] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(317),
    1,
    sym_comment,
    ACTIONS(1590),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [15551] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(318),
    1,
    sym_comment,
    ACTIONS(1570),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [15570] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(319),
    1,
    sym_comment,
    ACTIONS(1562),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [15589] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(320),
    1,
    sym_comment,
    ACTIONS(1542),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [15608] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(321),
    1,
    sym_comment,
    ACTIONS(1598),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [15627] = 10,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1920),
    1,
    anon_sym_AT,
    ACTIONS(1922),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1924),
    1,
    sym_identifier,
    STATE(322),
    1,
    sym_comment,
    STATE(339),
    1,
    aux_sym_interface_def_repeat1,
    STATE(509),
    1,
    sym_bit_value,
    STATE(593),
    1,
    sym_extend_annotation_appl,
    STATE(594),
    1,
    sym_annotation_appl,
    [15658] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(323),
    1,
    sym_comment,
    ACTIONS(1614),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [15677] = 10,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1920),
    1,
    anon_sym_AT,
    ACTIONS(1922),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1924),
    1,
    sym_identifier,
    STATE(324),
    1,
    sym_comment,
    STATE(339),
    1,
    aux_sym_interface_def_repeat1,
    STATE(593),
    1,
    sym_extend_annotation_appl,
    STATE(594),
    1,
    sym_annotation_appl,
    STATE(716),
    1,
    sym_bit_value,
    [15708] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(325),
    1,
    sym_comment,
    ACTIONS(1530),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [15727] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(326),
    1,
    sym_comment,
    ACTIONS(1618),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [15746] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(327),
    1,
    sym_comment,
    ACTIONS(1622),
    7,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_struct,
    [15765] = 8,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1992),
    1,
    anon_sym_RBRACE,
    ACTIONS(1994),
    1,
    anon_sym_default,
    ACTIONS(1997),
    1,
    anon_sym_case,
    STATE(30),
    1,
    sym_case_label,
    STATE(680),
    1,
    sym_case,
    STATE(328),
    2,
    sym_comment,
    aux_sym_union_def_repeat1,
    [15791] = 9,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2000),
    1,
    anon_sym_RBRACE,
    ACTIONS(2002),
    1,
    anon_sym_default,
    ACTIONS(2004),
    1,
    anon_sym_case,
    STATE(30),
    1,
    sym_case_label,
    STATE(328),
    1,
    aux_sym_union_def_repeat1,
    STATE(329),
    1,
    sym_comment,
    STATE(680),
    1,
    sym_case,
    [15819] = 9,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1962),
    1,
    anon_sym_COLON,
    ACTIONS(1966),
    1,
    anon_sym_supports,
    ACTIONS(2006),
    1,
    anon_sym_LBRACE,
    STATE(330),
    1,
    sym_comment,
    STATE(609),
    1,
    sym_value_inheritance,
    STATE(930),
    1,
    sym_value_supports,
    STATE(1017),
    1,
    sym_value_inheritance_spec,
    [15847] = 8,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1366),
    1,
    aux_sym_extend_annotation_appl_token1,
    ACTIONS(2008),
    1,
    anon_sym_AT,
    ACTIONS(2011),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(659),
    1,
    sym_extend_annotation_appl,
    STATE(661),
    1,
    sym_annotation_appl,
    STATE(331),
    2,
    sym_comment,
    aux_sym_interface_def_repeat1,
    [15873] = 9,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2016),
    1,
    anon_sym_Object,
    ACTIONS(2018),
    1,
    anon_sym_multiple,
    STATE(332),
    1,
    sym_comment,
    STATE(751),
    1,
    sym_scoped_name,
    STATE(1166),
    1,
    sym_interface_type,
    [15901] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2022),
    1,
    anon_sym_LBRACK,
    STATE(422),
    1,
    sym_fixed_array_size,
    STATE(333),
    2,
    sym_comment,
    aux_sym_array_declarator_repeat1,
    ACTIONS(2020),
    3,
    anon_sym_COMMA,
    anon_sym_SEMI,
    anon_sym_default,
    [15923] = 9,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2025),
    1,
    anon_sym_AT,
    ACTIONS(2027),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2029),
    1,
    aux_sym_extend_annotation_appl_token1,
    STATE(331),
    1,
    aux_sym_interface_def_repeat1,
    STATE(334),
    1,
    sym_comment,
    STATE(659),
    1,
    sym_extend_annotation_appl,
    STATE(661),
    1,
    sym_annotation_appl,
    [15951] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2031),
    1,
    anon_sym_LBRACK,
    STATE(335),
    1,
    sym_comment,
    STATE(346),
    1,
    aux_sym_array_declarator_repeat1,
    STATE(422),
    1,
    sym_fixed_array_size,
    ACTIONS(1968),
    3,
    anon_sym_COMMA,
    anon_sym_SEMI,
    anon_sym_default,
    [15975] = 9,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2025),
    1,
    anon_sym_AT,
    ACTIONS(2027),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2033),
    1,
    aux_sym_extend_annotation_appl_token1,
    STATE(336),
    1,
    sym_comment,
    STATE(345),
    1,
    aux_sym_interface_def_repeat1,
    STATE(659),
    1,
    sym_extend_annotation_appl,
    STATE(661),
    1,
    sym_annotation_appl,
    [16003] = 9,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2025),
    1,
    anon_sym_AT,
    ACTIONS(2027),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2035),
    1,
    aux_sym_extend_annotation_appl_token1,
    STATE(331),
    1,
    aux_sym_interface_def_repeat1,
    STATE(337),
    1,
    sym_comment,
    STATE(659),
    1,
    sym_extend_annotation_appl,
    STATE(661),
    1,
    sym_annotation_appl,
    [16031] = 9,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2025),
    1,
    anon_sym_AT,
    ACTIONS(2027),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2037),
    1,
    aux_sym_extend_annotation_appl_token1,
    STATE(334),
    1,
    aux_sym_interface_def_repeat1,
    STATE(338),
    1,
    sym_comment,
    STATE(659),
    1,
    sym_extend_annotation_appl,
    STATE(661),
    1,
    sym_annotation_appl,
    [16059] = 8,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1368),
    1,
    sym_identifier,
    ACTIONS(2039),
    1,
    anon_sym_AT,
    ACTIONS(2042),
    1,
    anon_sym_SLASH_SLASH_AT,
    STATE(593),
    1,
    sym_extend_annotation_appl,
    STATE(594),
    1,
    sym_annotation_appl,
    STATE(339),
    2,
    sym_comment,
    aux_sym_interface_def_repeat1,
    [16085] = 9,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2025),
    1,
    anon_sym_AT,
    ACTIONS(2027),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2045),
    1,
    aux_sym_extend_annotation_appl_token1,
    STATE(337),
    1,
    aux_sym_interface_def_repeat1,
    STATE(340),
    1,
    sym_comment,
    STATE(659),
    1,
    sym_extend_annotation_appl,
    STATE(661),
    1,
    sym_annotation_appl,
    [16113] = 9,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2025),
    1,
    anon_sym_AT,
    ACTIONS(2027),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2047),
    1,
    aux_sym_extend_annotation_appl_token1,
    STATE(341),
    1,
    sym_comment,
    STATE(348),
    1,
    aux_sym_interface_def_repeat1,
    STATE(659),
    1,
    sym_extend_annotation_appl,
    STATE(661),
    1,
    sym_annotation_appl,
    [16141] = 9,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2049),
    1,
    anon_sym_RBRACE,
    ACTIONS(2051),
    1,
    anon_sym_ATdefault_literal,
    ACTIONS(2053),
    1,
    sym_identifier,
    STATE(342),
    1,
    sym_comment,
    STATE(413),
    1,
    aux_sym_enumerator_repeat1,
    STATE(599),
    1,
    sym_enumerator,
    STATE(769),
    1,
    sym_enum_modifier,
    [16169] = 9,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2002),
    1,
    anon_sym_default,
    ACTIONS(2004),
    1,
    anon_sym_case,
    ACTIONS(2055),
    1,
    anon_sym_RBRACE,
    STATE(30),
    1,
    sym_case_label,
    STATE(329),
    1,
    aux_sym_union_def_repeat1,
    STATE(343),
    1,
    sym_comment,
    STATE(680),
    1,
    sym_case,
    [16197] = 9,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2057),
    1,
    anon_sym_LBRACE,
    ACTIONS(2059),
    1,
    anon_sym_COLON,
    ACTIONS(2061),
    1,
    anon_sym_SEMI,
    ACTIONS(2063),
    1,
    anon_sym_supports,
    STATE(344),
    1,
    sym_comment,
    STATE(646),
    1,
    sym_component_inheritance_spec,
    STATE(890),
    1,
    sym_supported_interface_spec,
    [16225] = 9,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2025),
    1,
    anon_sym_AT,
    ACTIONS(2027),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2065),
    1,
    aux_sym_extend_annotation_appl_token1,
    STATE(331),
    1,
    aux_sym_interface_def_repeat1,
    STATE(345),
    1,
    sym_comment,
    STATE(659),
    1,
    sym_extend_annotation_appl,
    STATE(661),
    1,
    sym_annotation_appl,
    [16253] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2031),
    1,
    anon_sym_LBRACK,
    STATE(333),
    1,
    aux_sym_array_declarator_repeat1,
    STATE(346),
    1,
    sym_comment,
    STATE(422),
    1,
    sym_fixed_array_size,
    ACTIONS(2067),
    3,
    anon_sym_COMMA,
    anon_sym_SEMI,
    anon_sym_default,
    [16277] = 9,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1962),
    1,
    anon_sym_COLON,
    ACTIONS(1966),
    1,
    anon_sym_supports,
    ACTIONS(2069),
    1,
    anon_sym_LBRACE,
    STATE(347),
    1,
    sym_comment,
    STATE(609),
    1,
    sym_value_inheritance,
    STATE(930),
    1,
    sym_value_supports,
    STATE(1188),
    1,
    sym_value_inheritance_spec,
    [16305] = 9,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2025),
    1,
    anon_sym_AT,
    ACTIONS(2027),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2071),
    1,
    aux_sym_extend_annotation_appl_token1,
    STATE(331),
    1,
    aux_sym_interface_def_repeat1,
    STATE(348),
    1,
    sym_comment,
    STATE(659),
    1,
    sym_extend_annotation_appl,
    STATE(661),
    1,
    sym_annotation_appl,
    [16333] = 9,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2051),
    1,
    anon_sym_ATdefault_literal,
    ACTIONS(2053),
    1,
    sym_identifier,
    ACTIONS(2073),
    1,
    anon_sym_RBRACE,
    STATE(349),
    1,
    sym_comment,
    STATE(413),
    1,
    aux_sym_enumerator_repeat1,
    STATE(568),
    1,
    sym_enumerator,
    STATE(769),
    1,
    sym_enum_modifier,
    [16361] = 8,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2075),
    1,
    anon_sym_LT,
    ACTIONS(2077),
    1,
    anon_sym_L,
    ACTIONS(2079),
    1,
    anon_sym_DQUOTE,
    ACTIONS(2081),
    1,
    sym_identifier,
    STATE(350),
    1,
    sym_comment,
    STATE(1030),
    2,
    sym_string_literal,
    sym_system_lib_string,
    [16387] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(351),
    1,
    sym_comment,
    ACTIONS(2083),
    5,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    anon_sym_SEMI,
    sym_identifier,
    [16404] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2085),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2087),
    1,
    anon_sym_LPAREN,
    STATE(352),
    1,
    sym_comment,
    ACTIONS(1454),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [16425] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2089),
    1,
    sym_identifier,
    STATE(353),
    1,
    sym_comment,
    STATE(480),
    1,
    sym_declarator,
    STATE(618),
    1,
    sym_declarators,
    STATE(498),
    2,
    sym_simple_declarator,
    sym_array_declarator,
    [16448] = 8,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2091),
    1,
    anon_sym_RBRACE,
    ACTIONS(2093),
    1,
    anon_sym_bitfield,
    STATE(354),
    1,
    sym_comment,
    STATE(360),
    1,
    aux_sym_bitset_dcl_repeat1,
    STATE(715),
    1,
    sym_bitfield_spec,
    STATE(727),
    1,
    sym_bitfield,
    [16473] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2095),
    1,
    anon_sym_RBRACE,
    ACTIONS(2097),
    1,
    anon_sym_bitfield,
    STATE(715),
    1,
    sym_bitfield_spec,
    STATE(727),
    1,
    sym_bitfield,
    STATE(355),
    2,
    sym_comment,
    aux_sym_bitset_dcl_repeat1,
    [16496] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(356),
    1,
    sym_comment,
    ACTIONS(1404),
    5,
    anon_sym_COLON_COLON,
    anon_sym_LPAREN,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [16513] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(357),
    1,
    sym_comment,
    ACTIONS(1466),
    5,
    anon_sym_COLON_COLON,
    anon_sym_LPAREN,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [16530] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(358),
    1,
    sym_comment,
    ACTIONS(1462),
    5,
    anon_sym_COLON_COLON,
    anon_sym_LPAREN,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [16547] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2100),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2102),
    1,
    anon_sym_LPAREN,
    STATE(359),
    1,
    sym_comment,
    ACTIONS(1456),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [16568] = 8,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2093),
    1,
    anon_sym_bitfield,
    ACTIONS(2104),
    1,
    anon_sym_RBRACE,
    STATE(355),
    1,
    aux_sym_bitset_dcl_repeat1,
    STATE(360),
    1,
    sym_comment,
    STATE(715),
    1,
    sym_bitfield_spec,
    STATE(727),
    1,
    sym_bitfield,
    [16593] = 8,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2016),
    1,
    anon_sym_Object,
    STATE(361),
    1,
    sym_comment,
    STATE(751),
    1,
    sym_scoped_name,
    STATE(947),
    1,
    sym_interface_type,
    [16618] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(362),
    1,
    sym_comment,
    ACTIONS(2106),
    5,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    anon_sym_SEMI,
    sym_identifier,
    [16635] = 8,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1946),
    1,
    anon_sym_COMMA,
    ACTIONS(2108),
    1,
    anon_sym_SEMI,
    ACTIONS(2110),
    1,
    anon_sym_raises,
    STATE(363),
    1,
    sym_comment,
    STATE(709),
    1,
    aux_sym_readonly_attr_declarator_repeat1,
    STATE(1079),
    1,
    sym_raises_expr,
    [16660] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(364),
    1,
    sym_comment,
    ACTIONS(2112),
    5,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    anon_sym_SEMI,
    sym_identifier,
    [16677] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(365),
    1,
    sym_comment,
    ACTIONS(2114),
    5,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    anon_sym_SEMI,
    sym_identifier,
    [16694] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(366),
    1,
    sym_comment,
    ACTIONS(2116),
    5,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    anon_sym_SEMI,
    sym_identifier,
    [16711] = 8,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2093),
    1,
    anon_sym_bitfield,
    ACTIONS(2118),
    1,
    anon_sym_RBRACE,
    STATE(355),
    1,
    aux_sym_bitset_dcl_repeat1,
    STATE(367),
    1,
    sym_comment,
    STATE(715),
    1,
    sym_bitfield_spec,
    STATE(727),
    1,
    sym_bitfield,
    [16736] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2089),
    1,
    sym_identifier,
    STATE(368),
    1,
    sym_comment,
    STATE(480),
    1,
    sym_declarator,
    STATE(972),
    1,
    sym_declarators,
    STATE(498),
    2,
    sym_simple_declarator,
    sym_array_declarator,
    [16759] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2089),
    1,
    sym_identifier,
    STATE(369),
    1,
    sym_comment,
    STATE(480),
    1,
    sym_declarator,
    STATE(499),
    1,
    sym_declarators,
    STATE(498),
    2,
    sym_simple_declarator,
    sym_array_declarator,
    [16782] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(370),
    1,
    sym_comment,
    ACTIONS(2120),
    5,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    anon_sym_SEMI,
    sym_identifier,
    [16799] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(371),
    1,
    sym_comment,
    ACTIONS(2122),
    5,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    anon_sym_SEMI,
    sym_identifier,
    [16816] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(372),
    1,
    sym_comment,
    ACTIONS(2124),
    5,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    anon_sym_SEMI,
    sym_identifier,
    [16833] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(373),
    1,
    sym_comment,
    ACTIONS(2126),
    5,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    anon_sym_SEMI,
    sym_identifier,
    [16850] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2128),
    1,
    anon_sym_LT,
    STATE(374),
    1,
    sym_comment,
    ACTIONS(2130),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [16869] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(375),
    1,
    sym_comment,
    ACTIONS(2132),
    5,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    anon_sym_SEMI,
    sym_identifier,
    [16886] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2134),
    1,
    anon_sym_COLON_COLON,
    STATE(376),
    1,
    sym_comment,
    ACTIONS(1866),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [16905] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2089),
    1,
    sym_identifier,
    STATE(377),
    1,
    sym_comment,
    STATE(612),
    1,
    sym_any_declarator,
    STATE(926),
    1,
    sym_any_declarators,
    STATE(807),
    2,
    sym_simple_declarator,
    sym_array_declarator,
    [16928] = 8,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(155),
    1,
    sym_identifier,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2016),
    1,
    anon_sym_Object,
    STATE(378),
    1,
    sym_comment,
    STATE(751),
    1,
    sym_scoped_name,
    STATE(1165),
    1,
    sym_interface_type,
    [16953] = 8,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2136),
    1,
    anon_sym_COLON,
    ACTIONS(2138),
    1,
    anon_sym_supports,
    ACTIONS(2140),
    1,
    anon_sym_manages,
    STATE(379),
    1,
    sym_comment,
    STATE(651),
    1,
    sym_home_inheritance_spec,
    STATE(884),
    1,
    sym_supported_interface_spec,
    [16978] = 8,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2093),
    1,
    anon_sym_bitfield,
    ACTIONS(2142),
    1,
    anon_sym_RBRACE,
    STATE(367),
    1,
    aux_sym_bitset_dcl_repeat1,
    STATE(380),
    1,
    sym_comment,
    STATE(715),
    1,
    sym_bitfield_spec,
    STATE(727),
    1,
    sym_bitfield,
    [17003] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(381),
    1,
    sym_comment,
    ACTIONS(1464),
    5,
    anon_sym_COLON_COLON,
    anon_sym_LPAREN,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [17020] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(382),
    1,
    sym_comment,
    ACTIONS(1402),
    5,
    anon_sym_COLON_COLON,
    anon_sym_LPAREN,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [17037] = 8,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2051),
    1,
    anon_sym_ATdefault_literal,
    ACTIONS(2053),
    1,
    sym_identifier,
    STATE(383),
    1,
    sym_comment,
    STATE(413),
    1,
    aux_sym_enumerator_repeat1,
    STATE(769),
    1,
    sym_enum_modifier,
    STATE(824),
    1,
    sym_enumerator,
    [17062] = 8,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1196),
    1,
    sym_identifier,
    ACTIONS(2144),
    1,
    anon_sym_truncatable,
    STATE(384),
    1,
    sym_comment,
    STATE(405),
    1,
    sym_scoped_name,
    STATE(406),
    1,
    sym_value_name,
    [17087] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(385),
    1,
    sym_comment,
    ACTIONS(1460),
    5,
    anon_sym_COLON_COLON,
    anon_sym_LPAREN,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [17104] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2146),
    1,
    anon_sym_RPAREN,
    STATE(386),
    1,
    sym_comment,
    STATE(862),
    1,
    sym_boolean_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [17124] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(387),
    1,
    sym_comment,
    ACTIONS(2148),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [17140] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(388),
    1,
    sym_comment,
    ACTIONS(2150),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [17156] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2134),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2152),
    1,
    anon_sym_COMMA,
    ACTIONS(2154),
    1,
    anon_sym_RPAREN,
    STATE(389),
    1,
    sym_comment,
    STATE(666),
    1,
    aux_sym_raises_expr_repeat1,
    [17178] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2156),
    1,
    anon_sym_LPAREN,
    STATE(390),
    1,
    sym_comment,
    ACTIONS(1382),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [17196] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2158),
    1,
    anon_sym_RPAREN,
    ACTIONS(2160),
    1,
    anon_sym_in,
    STATE(391),
    1,
    sym_comment,
    STATE(707),
    1,
    sym_init_param_dcl,
    STATE(1140),
    1,
    sym_init_param_dcls,
    [17218] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2162),
    1,
    anon_sym_RPAREN,
    ACTIONS(2164),
    1,
    anon_sym_in,
    STATE(392),
    1,
    sym_comment,
    STATE(713),
    1,
    sym_factory_param_dcl,
    STATE(989),
    1,
    sym_factory_param_dcls,
    [17240] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2166),
    1,
    anon_sym_LPAREN,
    STATE(393),
    1,
    sym_comment,
    ACTIONS(1396),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [17258] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2160),
    1,
    anon_sym_in,
    ACTIONS(2168),
    1,
    anon_sym_RPAREN,
    STATE(394),
    1,
    sym_comment,
    STATE(707),
    1,
    sym_init_param_dcl,
    STATE(1022),
    1,
    sym_init_param_dcls,
    [17280] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2170),
    1,
    anon_sym_LPAREN,
    STATE(395),
    1,
    sym_comment,
    ACTIONS(1410),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [17298] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1750),
    1,
    anon_sym_L,
    ACTIONS(2172),
    1,
    anon_sym_RPAREN,
    STATE(396),
    1,
    sym_comment,
    STATE(696),
    1,
    sym_string_literal,
    [17320] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2174),
    1,
    anon_sym_LPAREN,
    STATE(397),
    1,
    sym_comment,
    ACTIONS(1416),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [17338] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2176),
    1,
    sym_identifier,
    STATE(398),
    1,
    sym_comment,
    STATE(535),
    1,
    sym_interface_name,
    STATE(587),
    1,
    sym_scoped_name,
    [17360] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2178),
    1,
    anon_sym_LPAREN,
    STATE(399),
    1,
    sym_comment,
    ACTIONS(1426),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [17378] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2180),
    1,
    anon_sym_LPAREN,
    STATE(400),
    1,
    sym_comment,
    ACTIONS(1436),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [17396] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2176),
    1,
    sym_identifier,
    STATE(401),
    1,
    sym_comment,
    STATE(587),
    1,
    sym_scoped_name,
    STATE(805),
    1,
    sym_interface_name,
    [17418] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2182),
    1,
    anon_sym_LPAREN,
    STATE(402),
    1,
    sym_comment,
    ACTIONS(1376),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [17436] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2184),
    1,
    anon_sym_LPAREN,
    STATE(403),
    1,
    sym_comment,
    ACTIONS(1448),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [17454] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2186),
    1,
    sym_identifier,
    STATE(404),
    1,
    sym_comment,
    STATE(405),
    1,
    sym_scoped_name,
    STATE(419),
    1,
    sym_value_name,
    [17476] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1738),
    1,
    anon_sym_COLON_COLON,
    STATE(405),
    1,
    sym_comment,
    ACTIONS(2188),
    3,
    anon_sym_COMMA,
    anon_sym_LBRACE,
    anon_sym_supports,
    [17494] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2190),
    1,
    anon_sym_COMMA,
    ACTIONS(2192),
    1,
    anon_sym_LBRACE,
    ACTIONS(2194),
    1,
    anon_sym_supports,
    STATE(406),
    1,
    sym_comment,
    STATE(415),
    1,
    aux_sym_value_inheritance_spec_repeat1,
    [17516] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2196),
    1,
    anon_sym_LPAREN,
    STATE(407),
    1,
    sym_comment,
    ACTIONS(1442),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [17534] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1738),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2198),
    1,
    anon_sym_LBRACE,
    ACTIONS(2200),
    1,
    anon_sym_primarykey,
    STATE(408),
    1,
    sym_comment,
    STATE(865),
    1,
    sym_primary_key_spec,
    [17556] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2176),
    1,
    sym_identifier,
    STATE(409),
    1,
    sym_comment,
    STATE(587),
    1,
    sym_scoped_name,
    STATE(985),
    1,
    sym_interface_name,
    [17578] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(410),
    1,
    sym_comment,
    ACTIONS(2202),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [17594] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(411),
    1,
    sym_comment,
    ACTIONS(2204),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [17610] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2206),
    1,
    anon_sym_ATdefault_literal,
    ACTIONS(2209),
    1,
    sym_identifier,
    STATE(769),
    1,
    sym_enum_modifier,
    STATE(412),
    2,
    sym_comment,
    aux_sym_enumerator_repeat1,
    [17630] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2051),
    1,
    anon_sym_ATdefault_literal,
    ACTIONS(2211),
    1,
    sym_identifier,
    STATE(412),
    1,
    aux_sym_enumerator_repeat1,
    STATE(413),
    1,
    sym_comment,
    STATE(769),
    1,
    sym_enum_modifier,
    [17652] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(414),
    1,
    sym_comment,
    STATE(919),
    1,
    sym_service_platform,
    ACTIONS(2213),
    3,
    anon_sym_STAR,
    anon_sym_CORBA,
    anon_sym_DDS,
    [17670] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2190),
    1,
    anon_sym_COMMA,
    ACTIONS(2215),
    1,
    anon_sym_LBRACE,
    ACTIONS(2217),
    1,
    anon_sym_supports,
    STATE(415),
    1,
    sym_comment,
    STATE(478),
    1,
    aux_sym_value_inheritance_spec_repeat1,
    [17692] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2176),
    1,
    sym_identifier,
    STATE(416),
    1,
    sym_comment,
    STATE(587),
    1,
    sym_scoped_name,
    STATE(664),
    1,
    sym_interface_name,
    [17714] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(417),
    1,
    sym_comment,
    STATE(880),
    1,
    sym_extensibility_kind,
    ACTIONS(2219),
    3,
    anon_sym_FINAL,
    anon_sym_APPENDABLE,
    anon_sym_MUTABLE,
    [17732] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2186),
    1,
    sym_identifier,
    STATE(405),
    1,
    sym_scoped_name,
    STATE(418),
    1,
    sym_comment,
    STATE(663),
    1,
    sym_value_name,
    [17754] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2190),
    1,
    anon_sym_COMMA,
    ACTIONS(2215),
    1,
    anon_sym_LBRACE,
    ACTIONS(2217),
    1,
    anon_sym_supports,
    STATE(419),
    1,
    sym_comment,
    STATE(477),
    1,
    aux_sym_value_inheritance_spec_repeat1,
    [17776] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2221),
    1,
    anon_sym_COMMA,
    ACTIONS(2224),
    2,
    anon_sym_RPAREN,
    anon_sym_LBRACE,
    STATE(420),
    2,
    sym_comment,
    aux_sym_raises_expr_repeat1,
    [17794] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2226),
    1,
    anon_sym_RPAREN,
    STATE(421),
    1,
    sym_comment,
    STATE(1050),
    1,
    sym_autoid_kind,
    ACTIONS(2228),
    2,
    anon_sym_SEQUENTIAL,
    anon_sym_HASH,
    [17814] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(422),
    1,
    sym_comment,
    ACTIONS(2230),
    4,
    anon_sym_COMMA,
    anon_sym_SEMI,
    anon_sym_default,
    anon_sym_LBRACK,
    [17830] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2134),
    1,
    anon_sym_COLON_COLON,
    STATE(423),
    1,
    sym_comment,
    ACTIONS(2224),
    3,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    anon_sym_LBRACE,
    [17848] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2089),
    1,
    sym_identifier,
    STATE(424),
    1,
    sym_comment,
    STATE(780),
    1,
    sym_any_declarator,
    STATE(807),
    2,
    sym_simple_declarator,
    sym_array_declarator,
    [17868] = 7,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2232),
    1,
    sym_escape_sequence,
    ACTIONS(2234),
    1,
    anon_sym_DQUOTE,
    ACTIONS(2236),
    1,
    aux_sym_string_literal_token1,
    STATE(425),
    1,
    sym_comment,
    STATE(447),
    1,
    aux_sym_string_literal_repeat1,
    [17890] = 7,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2232),
    1,
    sym_escape_sequence,
    ACTIONS(2234),
    1,
    anon_sym_DQUOTE,
    ACTIONS(2236),
    1,
    aux_sym_string_literal_token1,
    STATE(426),
    1,
    sym_comment,
    STATE(445),
    1,
    aux_sym_string_literal_repeat1,
    [17912] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2134),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2152),
    1,
    anon_sym_COMMA,
    ACTIONS(2238),
    1,
    anon_sym_LBRACE,
    STATE(427),
    1,
    sym_comment,
    STATE(579),
    1,
    aux_sym_raises_expr_repeat1,
    [17934] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2240),
    1,
    anon_sym_LBRACE,
    ACTIONS(2242),
    1,
    anon_sym_COLON,
    ACTIONS(2244),
    1,
    anon_sym_SEMI,
    STATE(428),
    1,
    sym_comment,
    STATE(881),
    1,
    sym_interface_inheritance_spec,
    [17956] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2089),
    1,
    sym_identifier,
    STATE(429),
    1,
    sym_comment,
    STATE(859),
    1,
    sym_declarator,
    STATE(498),
    2,
    sym_simple_declarator,
    sym_array_declarator,
    [17976] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1738),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2200),
    1,
    anon_sym_primarykey,
    ACTIONS(2246),
    1,
    anon_sym_LBRACE,
    STATE(430),
    1,
    sym_comment,
    STATE(998),
    1,
    sym_primary_key_spec,
    [17998] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1738),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(1750),
    1,
    anon_sym_L,
    STATE(431),
    1,
    sym_comment,
    STATE(897),
    1,
    sym_string_literal,
    [18020] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1738),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(1750),
    1,
    anon_sym_L,
    STATE(432),
    1,
    sym_comment,
    STATE(899),
    1,
    sym_string_literal,
    [18042] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(433),
    1,
    sym_comment,
    ACTIONS(1866),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [18058] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(434),
    1,
    sym_comment,
    ACTIONS(2248),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [18074] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(435),
    1,
    sym_comment,
    ACTIONS(2250),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [18090] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2110),
    1,
    anon_sym_raises,
    STATE(436),
    1,
    sym_comment,
    STATE(822),
    1,
    sym_raises_expr,
    ACTIONS(2252),
    2,
    anon_sym_SEMI,
    anon_sym_context,
    [18110] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(437),
    1,
    sym_comment,
    ACTIONS(2254),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [18126] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(438),
    1,
    sym_comment,
    STATE(1129),
    1,
    sym_service_platform,
    ACTIONS(2213),
    3,
    anon_sym_STAR,
    anon_sym_CORBA,
    anon_sym_DDS,
    [18144] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(439),
    1,
    sym_comment,
    ACTIONS(2256),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [18160] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(440),
    1,
    sym_comment,
    ACTIONS(2258),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [18176] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(441),
    1,
    sym_comment,
    ACTIONS(2260),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [18192] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(442),
    1,
    sym_comment,
    ACTIONS(2262),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [18208] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(443),
    1,
    sym_comment,
    ACTIONS(2264),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [18224] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2176),
    1,
    sym_identifier,
    STATE(444),
    1,
    sym_comment,
    STATE(587),
    1,
    sym_scoped_name,
    STATE(682),
    1,
    sym_interface_name,
    [18246] = 7,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2232),
    1,
    sym_escape_sequence,
    ACTIONS(2236),
    1,
    aux_sym_string_literal_token1,
    ACTIONS(2266),
    1,
    anon_sym_DQUOTE,
    STATE(445),
    1,
    sym_comment,
    STATE(447),
    1,
    aux_sym_string_literal_repeat1,
    [18268] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2089),
    1,
    sym_identifier,
    STATE(446),
    1,
    sym_comment,
    STATE(719),
    1,
    sym_declarator,
    STATE(498),
    2,
    sym_simple_declarator,
    sym_array_declarator,
    [18288] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2268),
    1,
    sym_escape_sequence,
    ACTIONS(2271),
    1,
    anon_sym_DQUOTE,
    ACTIONS(2273),
    1,
    aux_sym_string_literal_token1,
    STATE(447),
    2,
    sym_comment,
    aux_sym_string_literal_repeat1,
    [18308] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2276),
    1,
    anon_sym_COMMA,
    ACTIONS(2279),
    2,
    anon_sym_SEMI,
    anon_sym_default,
    STATE(448),
    2,
    sym_comment,
    aux_sym_declarators_repeat1,
    [18326] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2110),
    1,
    anon_sym_raises,
    STATE(449),
    1,
    sym_comment,
    STATE(771),
    1,
    sym_raises_expr,
    ACTIONS(2281),
    2,
    anon_sym_SEMI,
    anon_sym_context,
    [18346] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2283),
    1,
    anon_sym_COMMA,
    STATE(448),
    1,
    aux_sym_declarators_repeat1,
    STATE(450),
    1,
    sym_comment,
    ACTIONS(2285),
    2,
    anon_sym_SEMI,
    anon_sym_default,
    [18366] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2287),
    1,
    anon_sym_RPAREN,
    ACTIONS(2289),
    1,
    anon_sym_in,
    STATE(451),
    1,
    sym_comment,
    STATE(702),
    1,
    sym_in_param_dcl,
    STATE(1015),
    1,
    sym_in_parameter_dcls,
    [18388] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2291),
    1,
    anon_sym_LBRACE,
    ACTIONS(2293),
    1,
    anon_sym_COLON,
    STATE(452),
    1,
    sym_comment,
    ACTIONS(2295),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [18408] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2297),
    1,
    anon_sym_LPAREN,
    STATE(453),
    1,
    sym_comment,
    ACTIONS(1384),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [18426] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2299),
    1,
    anon_sym_LPAREN,
    STATE(454),
    1,
    sym_comment,
    ACTIONS(1398),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [18444] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1738),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2200),
    1,
    anon_sym_primarykey,
    ACTIONS(2301),
    1,
    anon_sym_LBRACE,
    STATE(455),
    1,
    sym_comment,
    STATE(1155),
    1,
    sym_primary_key_spec,
    [18466] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2303),
    1,
    anon_sym_LPAREN,
    STATE(456),
    1,
    sym_comment,
    ACTIONS(1412),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [18484] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2305),
    1,
    anon_sym_LPAREN,
    STATE(457),
    1,
    sym_comment,
    ACTIONS(1418),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [18502] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2307),
    1,
    anon_sym_LPAREN,
    STATE(458),
    1,
    sym_comment,
    ACTIONS(1428),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [18520] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2309),
    1,
    anon_sym_LPAREN,
    STATE(459),
    1,
    sym_comment,
    ACTIONS(1438),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [18538] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2311),
    1,
    anon_sym_LPAREN,
    STATE(460),
    1,
    sym_comment,
    ACTIONS(1378),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [18556] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2313),
    1,
    anon_sym_LPAREN,
    STATE(461),
    1,
    sym_comment,
    ACTIONS(1450),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [18574] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2315),
    1,
    anon_sym_LPAREN,
    STATE(462),
    1,
    sym_comment,
    ACTIONS(1444),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [18592] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2134),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2152),
    1,
    anon_sym_COMMA,
    ACTIONS(2317),
    1,
    anon_sym_RPAREN,
    STATE(463),
    1,
    sym_comment,
    STATE(670),
    1,
    aux_sym_raises_expr_repeat1,
    [18614] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2321),
    1,
    anon_sym_SQUOTE,
    STATE(464),
    1,
    sym_comment,
    STATE(466),
    1,
    aux_sym_char_literal_repeat1,
    ACTIONS(2319),
    2,
    sym_escape_sequence,
    aux_sym_char_literal_token1,
    [18634] = 7,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2232),
    1,
    sym_escape_sequence,
    ACTIONS(2236),
    1,
    aux_sym_string_literal_token1,
    ACTIONS(2323),
    1,
    anon_sym_DQUOTE,
    STATE(425),
    1,
    aux_sym_string_literal_repeat1,
    STATE(465),
    1,
    sym_comment,
    [18656] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2328),
    1,
    anon_sym_SQUOTE,
    ACTIONS(2325),
    2,
    sym_escape_sequence,
    aux_sym_char_literal_token1,
    STATE(466),
    2,
    sym_comment,
    aux_sym_char_literal_repeat1,
    [18674] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2176),
    1,
    sym_identifier,
    STATE(467),
    1,
    sym_comment,
    STATE(587),
    1,
    sym_scoped_name,
    STATE(717),
    1,
    sym_interface_name,
    [18696] = 7,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2232),
    1,
    sym_escape_sequence,
    ACTIONS(2236),
    1,
    aux_sym_string_literal_token1,
    ACTIONS(2330),
    1,
    anon_sym_DQUOTE,
    STATE(468),
    1,
    sym_comment,
    STATE(470),
    1,
    aux_sym_string_literal_repeat1,
    [18718] = 7,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2232),
    1,
    sym_escape_sequence,
    ACTIONS(2236),
    1,
    aux_sym_string_literal_token1,
    ACTIONS(2332),
    1,
    anon_sym_DQUOTE,
    STATE(469),
    1,
    sym_comment,
    STATE(473),
    1,
    aux_sym_string_literal_repeat1,
    [18740] = 7,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2232),
    1,
    sym_escape_sequence,
    ACTIONS(2236),
    1,
    aux_sym_string_literal_token1,
    ACTIONS(2332),
    1,
    anon_sym_DQUOTE,
    STATE(447),
    1,
    aux_sym_string_literal_repeat1,
    STATE(470),
    1,
    sym_comment,
    [18762] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2334),
    1,
    anon_sym_RPAREN,
    STATE(471),
    1,
    sym_comment,
    STATE(1048),
    1,
    sym_autoid_kind,
    ACTIONS(2228),
    2,
    anon_sym_SEQUENTIAL,
    anon_sym_HASH,
    [18782] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2336),
    1,
    anon_sym_RPAREN,
    STATE(472),
    1,
    sym_comment,
    STATE(1049),
    1,
    sym_boolean_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [18802] = 7,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2232),
    1,
    sym_escape_sequence,
    ACTIONS(2236),
    1,
    aux_sym_string_literal_token1,
    ACTIONS(2338),
    1,
    anon_sym_DQUOTE,
    STATE(447),
    1,
    aux_sym_string_literal_repeat1,
    STATE(473),
    1,
    sym_comment,
    [18824] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2340),
    1,
    anon_sym_RPAREN,
    STATE(474),
    1,
    sym_comment,
    STATE(1084),
    1,
    sym_autoid_kind,
    ACTIONS(2228),
    2,
    anon_sym_SEQUENTIAL,
    anon_sym_HASH,
    [18844] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2342),
    1,
    anon_sym_RPAREN,
    STATE(475),
    1,
    sym_comment,
    STATE(1085),
    1,
    sym_boolean_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [18864] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2344),
    1,
    anon_sym_RPAREN,
    STATE(476),
    1,
    sym_comment,
    STATE(1115),
    1,
    sym_autoid_kind,
    ACTIONS(2228),
    2,
    anon_sym_SEQUENTIAL,
    anon_sym_HASH,
    [18884] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2190),
    1,
    anon_sym_COMMA,
    ACTIONS(2346),
    1,
    anon_sym_LBRACE,
    ACTIONS(2348),
    1,
    anon_sym_supports,
    STATE(477),
    1,
    sym_comment,
    STATE(478),
    1,
    aux_sym_value_inheritance_spec_repeat1,
    [18906] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2350),
    1,
    anon_sym_COMMA,
    ACTIONS(2353),
    2,
    anon_sym_LBRACE,
    anon_sym_supports,
    STATE(478),
    2,
    sym_comment,
    aux_sym_value_inheritance_spec_repeat1,
    [18924] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2355),
    1,
    anon_sym_RPAREN,
    STATE(479),
    1,
    sym_comment,
    STATE(1116),
    1,
    sym_boolean_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [18944] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2283),
    1,
    anon_sym_COMMA,
    STATE(450),
    1,
    aux_sym_declarators_repeat1,
    STATE(480),
    1,
    sym_comment,
    ACTIONS(2357),
    2,
    anon_sym_SEMI,
    anon_sym_default,
    [18964] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(481),
    1,
    sym_comment,
    STATE(1052),
    1,
    sym_extensibility_kind,
    ACTIONS(2219),
    3,
    anon_sym_FINAL,
    anon_sym_APPENDABLE,
    anon_sym_MUTABLE,
    [18982] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2359),
    1,
    anon_sym_SQUOTE,
    STATE(466),
    1,
    aux_sym_char_literal_repeat1,
    STATE(482),
    1,
    sym_comment,
    ACTIONS(2319),
    2,
    sym_escape_sequence,
    aux_sym_char_literal_token1,
    [19002] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(483),
    1,
    sym_comment,
    STATE(1062),
    1,
    sym_service_platform,
    ACTIONS(2213),
    3,
    anon_sym_STAR,
    anon_sym_CORBA,
    anon_sym_DDS,
    [19020] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(484),
    1,
    sym_comment,
    ACTIONS(2361),
    4,
    anon_sym_COMMA,
    anon_sym_SEMI,
    anon_sym_default,
    anon_sym_LBRACK,
    [19036] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1738),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2238),
    1,
    anon_sym_manages,
    ACTIONS(2363),
    1,
    anon_sym_COMMA,
    STATE(485),
    1,
    sym_comment,
    STATE(536),
    1,
    aux_sym_raises_expr_repeat1,
    [19058] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(486),
    1,
    sym_comment,
    STATE(1088),
    1,
    sym_extensibility_kind,
    ACTIONS(2219),
    3,
    anon_sym_FINAL,
    anon_sym_APPENDABLE,
    anon_sym_MUTABLE,
    [19076] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(487),
    1,
    sym_comment,
    STATE(1098),
    1,
    sym_service_platform,
    ACTIONS(2213),
    3,
    anon_sym_STAR,
    anon_sym_CORBA,
    anon_sym_DDS,
    [19094] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(488),
    1,
    sym_comment,
    STATE(1119),
    1,
    sym_extensibility_kind,
    ACTIONS(2219),
    3,
    anon_sym_FINAL,
    anon_sym_APPENDABLE,
    anon_sym_MUTABLE,
    [19112] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2365),
    1,
    anon_sym_COMMA,
    ACTIONS(2368),
    1,
    anon_sym_RBRACE,
    STATE(489),
    2,
    sym_comment,
    aux_sym_bitmask_dcl_repeat1,
    [19129] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1750),
    1,
    anon_sym_L,
    STATE(490),
    1,
    sym_comment,
    STATE(916),
    1,
    sym_string_literal,
    [19148] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1750),
    1,
    anon_sym_L,
    STATE(491),
    1,
    sym_comment,
    STATE(1136),
    1,
    sym_string_literal,
    [19167] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1750),
    1,
    anon_sym_L,
    STATE(492),
    1,
    sym_comment,
    STATE(1135),
    1,
    sym_string_literal,
    [19186] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(493),
    1,
    sym_comment,
    STATE(1131),
    1,
    sym_boolean_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [19203] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(494),
    1,
    sym_comment,
    STATE(1130),
    1,
    sym_boolean_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [19220] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2176),
    1,
    sym_identifier,
    STATE(495),
    1,
    sym_comment,
    STATE(796),
    1,
    sym_scoped_name,
    [19239] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(496),
    1,
    sym_comment,
    STATE(1127),
    1,
    sym_boolean_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [19256] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(497),
    1,
    sym_comment,
    STATE(1126),
    1,
    sym_boolean_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [19273] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(498),
    1,
    sym_comment,
    ACTIONS(2370),
    3,
    anon_sym_COMMA,
    anon_sym_SEMI,
    anon_sym_default,
    [19288] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2372),
    1,
    anon_sym_SEMI,
    ACTIONS(2374),
    1,
    anon_sym_default,
    STATE(499),
    1,
    sym_comment,
    STATE(921),
    1,
    sym_default,
    [19307] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1750),
    1,
    anon_sym_L,
    STATE(500),
    1,
    sym_comment,
    STATE(1124),
    1,
    sym_string_literal,
    [19326] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2376),
    1,
    anon_sym_interface,
    ACTIONS(2378),
    1,
    anon_sym_valuetype,
    ACTIONS(2380),
    1,
    anon_sym_eventtype,
    STATE(501),
    1,
    sym_comment,
    [19345] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(502),
    1,
    sym_comment,
    STATE(1121),
    1,
    sym_boolean_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [19362] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(503),
    1,
    sym_comment,
    STATE(1120),
    1,
    sym_boolean_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [19379] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1750),
    1,
    anon_sym_L,
    STATE(504),
    1,
    sym_comment,
    STATE(1105),
    1,
    sym_string_literal,
    [19398] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2382),
    1,
    anon_sym_SEMI,
    ACTIONS(2384),
    1,
    sym_identifier,
    STATE(505),
    1,
    sym_comment,
    STATE(625),
    1,
    aux_sym_bitfield_repeat1,
    [19417] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1750),
    1,
    anon_sym_L,
    STATE(506),
    1,
    sym_comment,
    STATE(1104),
    1,
    sym_string_literal,
    [19436] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2386),
    1,
    sym_identifier,
    STATE(507),
    1,
    sym_comment,
    STATE(786),
    1,
    sym_scoped_name,
    [19455] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2388),
    1,
    anon_sym_COMMA,
    ACTIONS(2390),
    1,
    anon_sym_RBRACE,
    STATE(489),
    1,
    aux_sym_bitmask_dcl_repeat1,
    STATE(508),
    1,
    sym_comment,
    [19474] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2388),
    1,
    anon_sym_COMMA,
    ACTIONS(2390),
    1,
    anon_sym_RBRACE,
    STATE(509),
    1,
    sym_comment,
    STATE(632),
    1,
    aux_sym_bitmask_dcl_repeat1,
    [19493] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(510),
    1,
    sym_comment,
    STATE(1100),
    1,
    sym_boolean_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [19510] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(511),
    1,
    sym_comment,
    STATE(1099),
    1,
    sym_boolean_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [19527] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(464),
    1,
    aux_sym_char_literal_repeat1,
    STATE(512),
    1,
    sym_comment,
    ACTIONS(2319),
    2,
    sym_escape_sequence,
    aux_sym_char_literal_token1,
    [19544] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(513),
    1,
    sym_comment,
    ACTIONS(2392),
    3,
    sym_escape_sequence,
    anon_sym_SQUOTE,
    aux_sym_char_literal_token1,
    [19559] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(514),
    1,
    sym_comment,
    STATE(1096),
    1,
    sym_boolean_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [19576] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(515),
    1,
    sym_comment,
    STATE(1095),
    1,
    sym_boolean_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [19593] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1750),
    1,
    anon_sym_L,
    STATE(516),
    1,
    sym_comment,
    STATE(1093),
    1,
    sym_string_literal,
    [19612] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(517),
    1,
    sym_comment,
    STATE(1090),
    1,
    sym_boolean_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [19629] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(518),
    1,
    sym_comment,
    STATE(1089),
    1,
    sym_boolean_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [19646] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2186),
    1,
    sym_identifier,
    STATE(432),
    1,
    sym_scoped_name,
    STATE(519),
    1,
    sym_comment,
    [19665] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2186),
    1,
    sym_identifier,
    STATE(431),
    1,
    sym_scoped_name,
    STATE(520),
    1,
    sym_comment,
    [19684] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1750),
    1,
    anon_sym_L,
    STATE(521),
    1,
    sym_comment,
    STATE(1072),
    1,
    sym_string_literal,
    [19703] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1738),
    1,
    anon_sym_COLON_COLON,
    STATE(522),
    1,
    sym_comment,
    ACTIONS(2224),
    2,
    anon_sym_COMMA,
    anon_sym_manages,
    [19720] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1750),
    1,
    anon_sym_L,
    STATE(523),
    1,
    sym_comment,
    STATE(1070),
    1,
    sym_string_literal,
    [19739] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(524),
    1,
    sym_comment,
    STATE(1064),
    1,
    sym_boolean_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [19756] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(525),
    1,
    sym_comment,
    STATE(1063),
    1,
    sym_boolean_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [19773] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(526),
    1,
    sym_comment,
    STATE(1060),
    1,
    sym_boolean_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [19790] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(527),
    1,
    sym_comment,
    STATE(1059),
    1,
    sym_boolean_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [19807] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1750),
    1,
    anon_sym_L,
    STATE(528),
    1,
    sym_comment,
    STATE(895),
    1,
    sym_string_literal,
    [19826] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1750),
    1,
    anon_sym_L,
    STATE(529),
    1,
    sym_comment,
    STATE(1057),
    1,
    sym_string_literal,
    [19845] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(530),
    1,
    sym_comment,
    STATE(1054),
    1,
    sym_boolean_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [19862] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(531),
    1,
    sym_comment,
    STATE(1053),
    1,
    sym_boolean_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [19879] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2394),
    1,
    anon_sym_SEMI,
    ACTIONS(2396),
    1,
    anon_sym_context,
    STATE(532),
    1,
    sym_comment,
    STATE(1153),
    1,
    sym_context_expr,
    [19898] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2224),
    1,
    anon_sym_manages,
    ACTIONS(2398),
    1,
    anon_sym_COMMA,
    STATE(533),
    2,
    sym_comment,
    aux_sym_raises_expr_repeat1,
    [19915] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2401),
    1,
    sym_identifier,
    STATE(271),
    1,
    sym_simple_declarator,
    STATE(534),
    1,
    sym_comment,
    STATE(981),
    1,
    sym_attr_declarator,
    [19934] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2403),
    1,
    anon_sym_COMMA,
    ACTIONS(2405),
    1,
    anon_sym_LBRACE,
    STATE(535),
    1,
    sym_comment,
    STATE(590),
    1,
    aux_sym_interface_inheritance_spec_repeat1,
    [19953] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2363),
    1,
    anon_sym_COMMA,
    ACTIONS(2407),
    1,
    anon_sym_manages,
    STATE(533),
    1,
    aux_sym_raises_expr_repeat1,
    STATE(536),
    1,
    sym_comment,
    [19972] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2186),
    1,
    sym_identifier,
    STATE(522),
    1,
    sym_scoped_name,
    STATE(537),
    1,
    sym_comment,
    [19991] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2396),
    1,
    anon_sym_context,
    ACTIONS(2409),
    1,
    anon_sym_SEMI,
    STATE(538),
    1,
    sym_comment,
    STATE(1153),
    1,
    sym_context_expr,
    [20010] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2186),
    1,
    sym_identifier,
    STATE(485),
    1,
    sym_scoped_name,
    STATE(539),
    1,
    sym_comment,
    [20029] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2186),
    1,
    sym_identifier,
    STATE(408),
    1,
    sym_scoped_name,
    STATE(540),
    1,
    sym_comment,
    [20048] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1738),
    1,
    anon_sym_COLON_COLON,
    STATE(541),
    1,
    sym_comment,
    ACTIONS(2411),
    2,
    anon_sym_supports,
    anon_sym_manages,
    [20065] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(542),
    1,
    sym_comment,
    ACTIONS(1602),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20080] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2413),
    1,
    anon_sym_COMMA,
    ACTIONS(2415),
    1,
    anon_sym_RPAREN,
    STATE(543),
    1,
    sym_comment,
    STATE(654),
    1,
    aux_sym_annotation_appl_params_repeat1,
    [20099] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(544),
    1,
    sym_comment,
    ACTIONS(1626),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20114] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(545),
    1,
    sym_comment,
    ACTIONS(1494),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20129] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(546),
    1,
    sym_comment,
    ACTIONS(1498),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20144] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2417),
    1,
    anon_sym_GT,
    ACTIONS(2419),
    1,
    anon_sym_COMMA,
    STATE(547),
    1,
    sym_comment,
    STATE(657),
    1,
    aux_sym_formal_parameters_repeat1,
    [20163] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(548),
    1,
    sym_comment,
    ACTIONS(1510),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20178] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(549),
    1,
    sym_comment,
    ACTIONS(1514),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20193] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1738),
    1,
    anon_sym_COLON_COLON,
    STATE(550),
    1,
    sym_comment,
    ACTIONS(2421),
    2,
    anon_sym_LBRACE,
    anon_sym_supports,
    [20210] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(551),
    1,
    sym_comment,
    ACTIONS(1522),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20225] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2423),
    1,
    anon_sym_COMMA,
    ACTIONS(2425),
    1,
    anon_sym_SEMI,
    STATE(552),
    1,
    sym_comment,
    STATE(577),
    1,
    aux_sym_any_declarators_repeat1,
    [20244] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2427),
    1,
    anon_sym_GT,
    ACTIONS(2429),
    1,
    anon_sym_COMMA,
    STATE(553),
    1,
    sym_comment,
    STATE(660),
    1,
    aux_sym_actual_parameters_repeat1,
    [20263] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(554),
    1,
    sym_comment,
    ACTIONS(1526),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20278] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(555),
    1,
    sym_comment,
    ACTIONS(1538),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20293] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(556),
    1,
    sym_comment,
    ACTIONS(1546),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20308] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(557),
    1,
    sym_comment,
    ACTIONS(1550),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20323] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(558),
    1,
    sym_comment,
    ACTIONS(1554),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20338] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(559),
    1,
    sym_comment,
    ACTIONS(2431),
    3,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_RBRACK,
    [20353] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(560),
    1,
    sym_comment,
    ACTIONS(1558),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20368] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(561),
    1,
    sym_comment,
    ACTIONS(1566),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20383] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(562),
    1,
    sym_comment,
    ACTIONS(1574),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20398] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(563),
    1,
    sym_comment,
    ACTIONS(1598),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20413] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(564),
    1,
    sym_comment,
    ACTIONS(1614),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20428] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2433),
    1,
    anon_sym_COMMA,
    ACTIONS(2435),
    1,
    anon_sym_RBRACE,
    STATE(565),
    1,
    sym_comment,
    STATE(671),
    1,
    aux_sym_enum_dcl_repeat1,
    [20447] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(566),
    1,
    sym_comment,
    ACTIONS(1618),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20462] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(567),
    1,
    sym_comment,
    ACTIONS(1622),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20477] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2049),
    1,
    anon_sym_RBRACE,
    ACTIONS(2433),
    1,
    anon_sym_COMMA,
    STATE(565),
    1,
    aux_sym_enum_dcl_repeat1,
    STATE(568),
    1,
    sym_comment,
    [20496] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(569),
    1,
    sym_comment,
    ACTIONS(1634),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20511] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(570),
    1,
    sym_comment,
    ACTIONS(1606),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20526] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(571),
    1,
    sym_comment,
    ACTIONS(1590),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20541] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(572),
    1,
    sym_comment,
    ACTIONS(1486),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20556] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(573),
    1,
    sym_comment,
    ACTIONS(1582),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20571] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(574),
    1,
    sym_comment,
    ACTIONS(1530),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20586] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(575),
    1,
    sym_comment,
    ACTIONS(1482),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20601] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(576),
    1,
    sym_comment,
    ACTIONS(1478),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20616] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2437),
    1,
    anon_sym_COMMA,
    ACTIONS(2440),
    1,
    anon_sym_SEMI,
    STATE(577),
    2,
    sym_comment,
    aux_sym_any_declarators_repeat1,
    [20633] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2176),
    1,
    sym_identifier,
    STATE(423),
    1,
    sym_scoped_name,
    STATE(578),
    1,
    sym_comment,
    [20652] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2152),
    1,
    anon_sym_COMMA,
    ACTIONS(2407),
    1,
    anon_sym_LBRACE,
    STATE(420),
    1,
    aux_sym_raises_expr_repeat1,
    STATE(579),
    1,
    sym_comment,
    [20671] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2176),
    1,
    sym_identifier,
    STATE(580),
    1,
    sym_comment,
    STATE(821),
    1,
    sym_scoped_name,
    [20690] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(581),
    1,
    sym_comment,
    ACTIONS(1534),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20705] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(582),
    1,
    sym_comment,
    ACTIONS(1630),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20720] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2186),
    1,
    sym_identifier,
    STATE(455),
    1,
    sym_scoped_name,
    STATE(583),
    1,
    sym_comment,
    [20739] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(584),
    1,
    sym_comment,
    ACTIONS(1610),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20754] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(585),
    1,
    sym_comment,
    ACTIONS(1594),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20769] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(586),
    1,
    sym_comment,
    ACTIONS(1570),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20784] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2134),
    1,
    anon_sym_COLON_COLON,
    STATE(587),
    1,
    sym_comment,
    ACTIONS(2442),
    2,
    anon_sym_COMMA,
    anon_sym_LBRACE,
    [20801] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2429),
    1,
    anon_sym_COMMA,
    ACTIONS(2444),
    1,
    anon_sym_GT,
    STATE(553),
    1,
    aux_sym_actual_parameters_repeat1,
    STATE(588),
    1,
    sym_comment,
    [20820] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(589),
    1,
    sym_comment,
    ACTIONS(1562),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20835] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2403),
    1,
    anon_sym_COMMA,
    ACTIONS(2446),
    1,
    anon_sym_LBRACE,
    STATE(590),
    1,
    sym_comment,
    STATE(684),
    1,
    aux_sym_interface_inheritance_spec_repeat1,
    [20854] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2401),
    1,
    sym_identifier,
    STATE(363),
    1,
    sym_simple_declarator,
    STATE(591),
    1,
    sym_comment,
    STATE(912),
    1,
    sym_readonly_attr_declarator,
    [20873] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(592),
    1,
    sym_comment,
    ACTIONS(1542),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20888] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(593),
    1,
    sym_comment,
    ACTIONS(1518),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20903] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(594),
    1,
    sym_comment,
    ACTIONS(1490),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [20918] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1462),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2448),
    1,
    anon_sym_LT,
    ACTIONS(2450),
    1,
    anon_sym_LBRACE,
    STATE(595),
    1,
    sym_comment,
    [20937] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2452),
    1,
    anon_sym_SEMI,
    ACTIONS(2454),
    1,
    anon_sym_switch,
    ACTIONS(2456),
    1,
    sym_identifier,
    STATE(596),
    1,
    sym_comment,
    [20956] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2458),
    1,
    anon_sym_LBRACE,
    ACTIONS(2460),
    1,
    anon_sym_COLON,
    STATE(597),
    1,
    sym_comment,
    STATE(882),
    1,
    sym_connector_inherit_spec,
    [20975] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2419),
    1,
    anon_sym_COMMA,
    ACTIONS(2462),
    1,
    anon_sym_GT,
    STATE(547),
    1,
    aux_sym_formal_parameters_repeat1,
    STATE(598),
    1,
    sym_comment,
    [20994] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2433),
    1,
    anon_sym_COMMA,
    ACTIONS(2435),
    1,
    anon_sym_RBRACE,
    STATE(599),
    1,
    sym_comment,
    STATE(708),
    1,
    aux_sym_enum_dcl_repeat1,
    [21013] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2466),
    1,
    aux_sym_string_literal_token1,
    STATE(600),
    1,
    sym_comment,
    ACTIONS(2464),
    2,
    sym_escape_sequence,
    anon_sym_DQUOTE,
    [21030] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2176),
    1,
    sym_identifier,
    STATE(601),
    1,
    sym_comment,
    STATE(725),
    1,
    sym_scoped_name,
    [21049] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(602),
    1,
    sym_comment,
    STATE(886),
    1,
    sym_boolean_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [21066] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(603),
    1,
    sym_comment,
    STATE(887),
    1,
    sym_boolean_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [21083] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1750),
    1,
    anon_sym_L,
    STATE(604),
    1,
    sym_comment,
    STATE(894),
    1,
    sym_string_literal,
    [21102] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(605),
    1,
    sym_comment,
    STATE(905),
    1,
    sym_boolean_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [21119] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(606),
    1,
    sym_comment,
    STATE(906),
    1,
    sym_boolean_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [21136] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(607),
    1,
    sym_comment,
    STATE(922),
    1,
    sym_boolean_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [21153] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(608),
    1,
    sym_comment,
    STATE(923),
    1,
    sym_boolean_literal,
    ACTIONS(1888),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [21170] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1966),
    1,
    anon_sym_supports,
    ACTIONS(2468),
    1,
    anon_sym_LBRACE,
    STATE(609),
    1,
    sym_comment,
    STATE(997),
    1,
    sym_value_supports,
    [21189] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2413),
    1,
    anon_sym_COMMA,
    ACTIONS(2470),
    1,
    anon_sym_RPAREN,
    STATE(543),
    1,
    aux_sym_annotation_appl_params_repeat1,
    STATE(610),
    1,
    sym_comment,
    [21208] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2176),
    1,
    sym_identifier,
    STATE(611),
    1,
    sym_comment,
    STATE(774),
    1,
    sym_scoped_name,
    [21227] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2423),
    1,
    anon_sym_COMMA,
    ACTIONS(2472),
    1,
    anon_sym_SEMI,
    STATE(552),
    1,
    aux_sym_any_declarators_repeat1,
    STATE(612),
    1,
    sym_comment,
    [21246] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(613),
    1,
    sym_comment,
    ACTIONS(1600),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21261] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(614),
    1,
    sym_comment,
    ACTIONS(1624),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21276] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(615),
    1,
    sym_comment,
    ACTIONS(1492),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21291] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(616),
    1,
    sym_comment,
    ACTIONS(1496),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21306] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(617),
    1,
    sym_comment,
    ACTIONS(1508),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21321] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2374),
    1,
    anon_sym_default,
    ACTIONS(2474),
    1,
    anon_sym_SEMI,
    STATE(618),
    1,
    sym_comment,
    STATE(1255),
    1,
    sym_default,
    [21340] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(619),
    1,
    sym_comment,
    ACTIONS(1512),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21355] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(620),
    1,
    sym_comment,
    ACTIONS(1520),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21370] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(621),
    1,
    sym_comment,
    ACTIONS(1524),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21385] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(622),
    1,
    sym_comment,
    ACTIONS(1536),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21400] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(623),
    1,
    sym_comment,
    ACTIONS(1544),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21415] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(624),
    1,
    sym_comment,
    ACTIONS(1548),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21430] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2476),
    1,
    anon_sym_SEMI,
    ACTIONS(2478),
    1,
    sym_identifier,
    STATE(625),
    2,
    sym_comment,
    aux_sym_bitfield_repeat1,
    [21447] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(626),
    1,
    sym_comment,
    ACTIONS(1552),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21462] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(627),
    1,
    sym_comment,
    ACTIONS(1556),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21477] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(628),
    1,
    sym_comment,
    ACTIONS(1564),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21492] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(629),
    1,
    sym_comment,
    ACTIONS(1572),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21507] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(630),
    1,
    sym_comment,
    ACTIONS(1596),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21522] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(631),
    1,
    sym_comment,
    ACTIONS(1612),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21537] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2388),
    1,
    anon_sym_COMMA,
    ACTIONS(2481),
    1,
    anon_sym_RBRACE,
    STATE(489),
    1,
    aux_sym_bitmask_dcl_repeat1,
    STATE(632),
    1,
    sym_comment,
    [21556] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(633),
    1,
    sym_comment,
    ACTIONS(1616),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21571] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(634),
    1,
    sym_comment,
    ACTIONS(1620),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21586] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(635),
    1,
    sym_comment,
    ACTIONS(1632),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21601] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(636),
    1,
    sym_comment,
    ACTIONS(1604),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21616] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(637),
    1,
    sym_comment,
    ACTIONS(1588),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21631] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(638),
    1,
    sym_comment,
    ACTIONS(1484),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21646] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(639),
    1,
    sym_comment,
    ACTIONS(1580),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21661] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(640),
    1,
    sym_comment,
    ACTIONS(1528),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21676] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(641),
    1,
    sym_comment,
    ACTIONS(1480),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21691] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(642),
    1,
    sym_comment,
    ACTIONS(1476),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21706] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2186),
    1,
    sym_identifier,
    STATE(550),
    1,
    sym_scoped_name,
    STATE(643),
    1,
    sym_comment,
    [21725] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(644),
    1,
    sym_comment,
    ACTIONS(1532),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21740] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2176),
    1,
    sym_identifier,
    STATE(427),
    1,
    sym_scoped_name,
    STATE(645),
    1,
    sym_comment,
    [21759] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2063),
    1,
    anon_sym_supports,
    ACTIONS(2483),
    1,
    anon_sym_LBRACE,
    STATE(646),
    1,
    sym_comment,
    STATE(1023),
    1,
    sym_supported_interface_spec,
    [21778] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(647),
    1,
    sym_comment,
    ACTIONS(1628),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21793] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(648),
    1,
    sym_comment,
    ACTIONS(1608),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21808] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2186),
    1,
    sym_identifier,
    STATE(541),
    1,
    sym_scoped_name,
    STATE(649),
    1,
    sym_comment,
    [21827] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(880),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2186),
    1,
    sym_identifier,
    STATE(430),
    1,
    sym_scoped_name,
    STATE(650),
    1,
    sym_comment,
    [21846] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2138),
    1,
    anon_sym_supports,
    ACTIONS(2485),
    1,
    anon_sym_manages,
    STATE(651),
    1,
    sym_comment,
    STATE(1044),
    1,
    sym_supported_interface_spec,
    [21865] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2176),
    1,
    sym_identifier,
    STATE(652),
    1,
    sym_comment,
    STATE(756),
    1,
    sym_scoped_name,
    [21884] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(653),
    1,
    sym_comment,
    ACTIONS(1592),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21899] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2487),
    1,
    anon_sym_COMMA,
    ACTIONS(2490),
    1,
    anon_sym_RPAREN,
    STATE(654),
    2,
    sym_comment,
    aux_sym_annotation_appl_params_repeat1,
    [21916] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(655),
    1,
    sym_comment,
    ACTIONS(1568),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21931] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(656),
    1,
    sym_comment,
    ACTIONS(1560),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21946] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2492),
    1,
    anon_sym_GT,
    ACTIONS(2494),
    1,
    anon_sym_COMMA,
    STATE(657),
    2,
    sym_comment,
    aux_sym_formal_parameters_repeat1,
    [21963] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(658),
    1,
    sym_comment,
    ACTIONS(1540),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21978] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(659),
    1,
    sym_comment,
    ACTIONS(1516),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [21993] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2497),
    1,
    anon_sym_GT,
    ACTIONS(2499),
    1,
    anon_sym_COMMA,
    STATE(660),
    2,
    sym_comment,
    aux_sym_actual_parameters_repeat1,
    [22010] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(661),
    1,
    sym_comment,
    ACTIONS(1488),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [22025] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2502),
    1,
    anon_sym_GT,
    ACTIONS(2504),
    1,
    anon_sym_COMMA,
    STATE(662),
    2,
    sym_comment,
    aux_sym_formal_parameter_names_repeat1,
    [22042] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(663),
    1,
    sym_comment,
    ACTIONS(2353),
    3,
    anon_sym_COMMA,
    anon_sym_LBRACE,
    anon_sym_supports,
    [22057] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2346),
    1,
    anon_sym_LBRACE,
    ACTIONS(2403),
    1,
    anon_sym_COMMA,
    STATE(664),
    1,
    sym_comment,
    STATE(711),
    1,
    aux_sym_interface_inheritance_spec_repeat1,
    [22076] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2507),
    1,
    anon_sym_GT,
    ACTIONS(2509),
    1,
    anon_sym_COMMA,
    STATE(662),
    1,
    aux_sym_formal_parameter_names_repeat1,
    STATE(665),
    1,
    sym_comment,
    [22095] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2152),
    1,
    anon_sym_COMMA,
    ACTIONS(2511),
    1,
    anon_sym_RPAREN,
    STATE(420),
    1,
    aux_sym_raises_expr_repeat1,
    STATE(666),
    1,
    sym_comment,
    [22114] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(667),
    1,
    sym_comment,
    ACTIONS(2513),
    3,
    anon_sym_RBRACE,
    anon_sym_default,
    anon_sym_case,
    [22129] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2509),
    1,
    anon_sym_COMMA,
    ACTIONS(2515),
    1,
    anon_sym_GT,
    STATE(665),
    1,
    aux_sym_formal_parameter_names_repeat1,
    STATE(668),
    1,
    sym_comment,
    [22148] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2517),
    1,
    anon_sym_COMMA,
    ACTIONS(2520),
    1,
    anon_sym_RPAREN,
    STATE(669),
    2,
    sym_comment,
    aux_sym_in_parameter_dcls_repeat1,
    [22165] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2152),
    1,
    anon_sym_COMMA,
    ACTIONS(2522),
    1,
    anon_sym_RPAREN,
    STATE(420),
    1,
    aux_sym_raises_expr_repeat1,
    STATE(670),
    1,
    sym_comment,
    [22184] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2524),
    1,
    anon_sym_COMMA,
    ACTIONS(2527),
    1,
    anon_sym_RBRACE,
    STATE(671),
    2,
    sym_comment,
    aux_sym_enum_dcl_repeat1,
    [22201] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2396),
    1,
    anon_sym_context,
    ACTIONS(2529),
    1,
    anon_sym_SEMI,
    STATE(672),
    1,
    sym_comment,
    STATE(1153),
    1,
    sym_context_expr,
    [22220] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2403),
    1,
    anon_sym_COMMA,
    ACTIONS(2531),
    1,
    anon_sym_LBRACE,
    STATE(673),
    1,
    sym_comment,
    STATE(684),
    1,
    aux_sym_interface_inheritance_spec_repeat1,
    [22239] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2533),
    1,
    anon_sym_COMMA,
    ACTIONS(2536),
    1,
    anon_sym_RPAREN,
    STATE(674),
    2,
    sym_comment,
    aux_sym_factory_param_dcls_repeat1,
    [22256] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2538),
    1,
    anon_sym_COMMA,
    ACTIONS(2541),
    1,
    anon_sym_RPAREN,
    STATE(675),
    2,
    sym_comment,
    aux_sym_init_param_dcls_repeat1,
    [22273] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2543),
    1,
    anon_sym_COMMA,
    ACTIONS(2546),
    1,
    anon_sym_RPAREN,
    STATE(676),
    2,
    sym_comment,
    aux_sym_parameter_dcls_repeat1,
    [22290] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2548),
    1,
    anon_sym_COMMA,
    ACTIONS(2551),
    1,
    anon_sym_RPAREN,
    STATE(677),
    2,
    sym_comment,
    aux_sym_context_expr_repeat1,
    [22307] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2553),
    1,
    anon_sym_COMMA,
    ACTIONS(2555),
    1,
    anon_sym_RPAREN,
    STATE(669),
    1,
    aux_sym_in_parameter_dcls_repeat1,
    STATE(678),
    1,
    sym_comment,
    [22326] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2176),
    1,
    sym_identifier,
    STATE(389),
    1,
    sym_scoped_name,
    STATE(679),
    1,
    sym_comment,
    [22345] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(680),
    1,
    sym_comment,
    ACTIONS(2557),
    3,
    anon_sym_RBRACE,
    anon_sym_default,
    anon_sym_case,
    [22360] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(482),
    1,
    aux_sym_char_literal_repeat1,
    STATE(681),
    1,
    sym_comment,
    ACTIONS(2319),
    2,
    sym_escape_sequence,
    aux_sym_char_literal_token1,
    [22377] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2403),
    1,
    anon_sym_COMMA,
    ACTIONS(2559),
    1,
    anon_sym_LBRACE,
    STATE(673),
    1,
    aux_sym_interface_inheritance_spec_repeat1,
    STATE(682),
    1,
    sym_comment,
    [22396] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2403),
    1,
    anon_sym_COMMA,
    ACTIONS(2559),
    1,
    anon_sym_LBRACE,
    STATE(683),
    1,
    sym_comment,
    STATE(684),
    1,
    aux_sym_interface_inheritance_spec_repeat1,
    [22415] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2561),
    1,
    anon_sym_COMMA,
    ACTIONS(2564),
    1,
    anon_sym_LBRACE,
    STATE(684),
    2,
    sym_comment,
    aux_sym_interface_inheritance_spec_repeat1,
    [22432] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2176),
    1,
    sym_identifier,
    STATE(685),
    1,
    sym_comment,
    STATE(750),
    1,
    sym_scoped_name,
    [22451] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2176),
    1,
    sym_identifier,
    STATE(686),
    1,
    sym_comment,
    STATE(746),
    1,
    sym_scoped_name,
    [22470] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2176),
    1,
    sym_identifier,
    STATE(687),
    1,
    sym_comment,
    STATE(744),
    1,
    sym_scoped_name,
    [22489] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2176),
    1,
    sym_identifier,
    STATE(688),
    1,
    sym_comment,
    STATE(743),
    1,
    sym_scoped_name,
    [22508] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2388),
    1,
    anon_sym_COMMA,
    ACTIONS(2566),
    1,
    anon_sym_RBRACE,
    STATE(489),
    1,
    aux_sym_bitmask_dcl_repeat1,
    STATE(689),
    1,
    sym_comment,
    [22527] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2110),
    1,
    anon_sym_raises,
    ACTIONS(2568),
    1,
    anon_sym_SEMI,
    STATE(690),
    1,
    sym_comment,
    STATE(841),
    1,
    sym_raises_expr,
    [22546] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1952),
    1,
    anon_sym_setraises,
    ACTIONS(2570),
    1,
    anon_sym_SEMI,
    STATE(691),
    1,
    sym_comment,
    STATE(1037),
    1,
    sym_set_excep_expr,
    [22565] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2572),
    1,
    anon_sym_COMMA,
    ACTIONS(2574),
    1,
    anon_sym_RPAREN,
    STATE(674),
    1,
    aux_sym_factory_param_dcls_repeat1,
    STATE(692),
    1,
    sym_comment,
    [22584] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1946),
    1,
    anon_sym_COMMA,
    ACTIONS(2576),
    1,
    anon_sym_SEMI,
    STATE(693),
    1,
    sym_comment,
    STATE(703),
    1,
    aux_sym_readonly_attr_declarator_repeat1,
    [22603] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2110),
    1,
    anon_sym_raises,
    ACTIONS(2578),
    1,
    anon_sym_SEMI,
    STATE(694),
    1,
    sym_comment,
    STATE(852),
    1,
    sym_raises_expr,
    [22622] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2580),
    1,
    anon_sym_COMMA,
    ACTIONS(2582),
    1,
    anon_sym_RPAREN,
    STATE(675),
    1,
    aux_sym_init_param_dcls_repeat1,
    STATE(695),
    1,
    sym_comment,
    [22641] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2584),
    1,
    anon_sym_COMMA,
    ACTIONS(2586),
    1,
    anon_sym_RPAREN,
    STATE(696),
    1,
    sym_comment,
    STATE(699),
    1,
    aux_sym_context_expr_repeat1,
    [22660] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2110),
    1,
    anon_sym_raises,
    ACTIONS(2588),
    1,
    anon_sym_SEMI,
    STATE(697),
    1,
    sym_comment,
    STATE(854),
    1,
    sym_raises_expr,
    [22679] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2590),
    1,
    anon_sym_COMMA,
    ACTIONS(2592),
    1,
    anon_sym_RPAREN,
    STATE(676),
    1,
    aux_sym_parameter_dcls_repeat1,
    STATE(698),
    1,
    sym_comment,
    [22698] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2584),
    1,
    anon_sym_COMMA,
    ACTIONS(2594),
    1,
    anon_sym_RPAREN,
    STATE(677),
    1,
    aux_sym_context_expr_repeat1,
    STATE(699),
    1,
    sym_comment,
    [22717] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(890),
    1,
    anon_sym_DQUOTE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1750),
    1,
    anon_sym_L,
    STATE(700),
    1,
    sym_comment,
    STATE(819),
    1,
    sym_string_literal,
    [22736] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2590),
    1,
    anon_sym_COMMA,
    ACTIONS(2596),
    1,
    anon_sym_RPAREN,
    STATE(698),
    1,
    aux_sym_parameter_dcls_repeat1,
    STATE(701),
    1,
    sym_comment,
    [22755] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2553),
    1,
    anon_sym_COMMA,
    ACTIONS(2598),
    1,
    anon_sym_RPAREN,
    STATE(678),
    1,
    aux_sym_in_parameter_dcls_repeat1,
    STATE(702),
    1,
    sym_comment,
    [22774] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2600),
    1,
    anon_sym_COMMA,
    ACTIONS(2603),
    1,
    anon_sym_SEMI,
    STATE(703),
    2,
    sym_comment,
    aux_sym_readonly_attr_declarator_repeat1,
    [22791] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2110),
    1,
    anon_sym_raises,
    ACTIONS(2605),
    1,
    anon_sym_SEMI,
    STATE(704),
    1,
    sym_comment,
    STATE(875),
    1,
    sym_raises_expr,
    [22810] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1918),
    1,
    anon_sym_RBRACE,
    ACTIONS(2388),
    1,
    anon_sym_COMMA,
    STATE(508),
    1,
    aux_sym_bitmask_dcl_repeat1,
    STATE(705),
    1,
    sym_comment,
    [22829] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2176),
    1,
    sym_identifier,
    STATE(463),
    1,
    sym_scoped_name,
    STATE(706),
    1,
    sym_comment,
    [22848] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2580),
    1,
    anon_sym_COMMA,
    ACTIONS(2607),
    1,
    anon_sym_RPAREN,
    STATE(695),
    1,
    aux_sym_init_param_dcls_repeat1,
    STATE(707),
    1,
    sym_comment,
    [22867] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2433),
    1,
    anon_sym_COMMA,
    ACTIONS(2609),
    1,
    anon_sym_RBRACE,
    STATE(671),
    1,
    aux_sym_enum_dcl_repeat1,
    STATE(708),
    1,
    sym_comment,
    [22886] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1946),
    1,
    anon_sym_COMMA,
    ACTIONS(2611),
    1,
    anon_sym_SEMI,
    STATE(703),
    1,
    aux_sym_readonly_attr_declarator_repeat1,
    STATE(709),
    1,
    sym_comment,
    [22905] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2110),
    1,
    anon_sym_raises,
    ACTIONS(2613),
    1,
    anon_sym_SEMI,
    STATE(710),
    1,
    sym_comment,
    STATE(999),
    1,
    sym_raises_expr,
    [22924] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2403),
    1,
    anon_sym_COMMA,
    ACTIONS(2615),
    1,
    anon_sym_LBRACE,
    STATE(684),
    1,
    aux_sym_interface_inheritance_spec_repeat1,
    STATE(711),
    1,
    sym_comment,
    [22943] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2240),
    1,
    anon_sym_LBRACE,
    ACTIONS(2242),
    1,
    anon_sym_COLON,
    STATE(712),
    1,
    sym_comment,
    STATE(881),
    1,
    sym_interface_inheritance_spec,
    [22962] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2572),
    1,
    anon_sym_COMMA,
    ACTIONS(2617),
    1,
    anon_sym_RPAREN,
    STATE(692),
    1,
    aux_sym_factory_param_dcls_repeat1,
    STATE(713),
    1,
    sym_comment,
    [22981] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2110),
    1,
    anon_sym_raises,
    ACTIONS(2619),
    1,
    anon_sym_SEMI,
    STATE(714),
    1,
    sym_comment,
    STATE(967),
    1,
    sym_raises_expr,
    [23000] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2384),
    1,
    sym_identifier,
    ACTIONS(2621),
    1,
    anon_sym_SEMI,
    STATE(505),
    1,
    aux_sym_bitfield_repeat1,
    STATE(715),
    1,
    sym_comment,
    [23019] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2388),
    1,
    anon_sym_COMMA,
    ACTIONS(2481),
    1,
    anon_sym_RBRACE,
    STATE(689),
    1,
    aux_sym_bitmask_dcl_repeat1,
    STATE(716),
    1,
    sym_comment,
    [23038] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2403),
    1,
    anon_sym_COMMA,
    ACTIONS(2615),
    1,
    anon_sym_LBRACE,
    STATE(683),
    1,
    aux_sym_interface_inheritance_spec_repeat1,
    STATE(717),
    1,
    sym_comment,
    [23057] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(101),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2186),
    1,
    sym_identifier,
    STATE(718),
    1,
    sym_comment,
    STATE(800),
    1,
    sym_scoped_name,
    [23076] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(719),
    1,
    sym_comment,
    ACTIONS(2279),
    3,
    anon_sym_COMMA,
    anon_sym_SEMI,
    anon_sym_default,
    [23091] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2623),
    1,
    anon_sym_DQUOTE,
    ACTIONS(2625),
    1,
    anon_sym_SQUOTE,
    STATE(720),
    1,
    sym_comment,
    [23107] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(721),
    1,
    sym_comment,
    ACTIONS(2627),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [23121] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2629),
    1,
    anon_sym_min,
    STATE(722),
    1,
    sym_comment,
    STATE(1250),
    1,
    sym_min_expr,
    [23137] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(723),
    1,
    sym_comment,
    ACTIONS(2631),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [23151] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(724),
    1,
    sym_comment,
    ACTIONS(2633),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [23165] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2134),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2635),
    1,
    anon_sym_LBRACE,
    STATE(725),
    1,
    sym_comment,
    [23181] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2629),
    1,
    anon_sym_min,
    STATE(726),
    1,
    sym_comment,
    STATE(1236),
    1,
    sym_min_expr,
    [23197] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(727),
    1,
    sym_comment,
    ACTIONS(2637),
    2,
    anon_sym_RBRACE,
    anon_sym_bitfield,
    [23211] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2629),
    1,
    anon_sym_min,
    STATE(728),
    1,
    sym_comment,
    STATE(1222),
    1,
    sym_min_expr,
    [23227] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2639),
    1,
    anon_sym_max,
    STATE(729),
    1,
    sym_comment,
    STATE(1133),
    1,
    sym_max_expr,
    [23243] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2641),
    1,
    aux_sym_preproc_call_token1,
    ACTIONS(2643),
    1,
    sym_preproc_arg,
    STATE(730),
    1,
    sym_comment,
    [23259] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(731),
    1,
    sym_comment,
    ACTIONS(2645),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [23273] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(732),
    1,
    sym_comment,
    ACTIONS(2647),
    2,
    anon_sym_RBRACE,
    anon_sym_bitfield,
    [23287] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(733),
    1,
    sym_comment,
    ACTIONS(2649),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [23301] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(734),
    1,
    sym_comment,
    ACTIONS(2651),
    2,
    anon_sym_COMMA,
    anon_sym_RBRACE,
    [23315] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(735),
    1,
    sym_comment,
    ACTIONS(2653),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [23329] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(736),
    1,
    sym_comment,
    ACTIONS(2655),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [23343] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(737),
    1,
    sym_comment,
    ACTIONS(2657),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [23357] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(738),
    1,
    sym_comment,
    ACTIONS(2659),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [23371] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(739),
    1,
    sym_comment,
    ACTIONS(2661),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [23385] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2663),
    1,
    anon_sym_SEMI,
    ACTIONS(2665),
    1,
    anon_sym_default,
    STATE(740),
    1,
    sym_comment,
    [23401] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2639),
    1,
    anon_sym_max,
    STATE(741),
    1,
    sym_comment,
    STATE(1102),
    1,
    sym_max_expr,
    [23417] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(742),
    1,
    sym_comment,
    ACTIONS(2667),
    2,
    anon_sym_ATdefault_literal,
    sym_identifier,
    [23431] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2134),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2669),
    1,
    sym_identifier,
    STATE(743),
    1,
    sym_comment,
    [23447] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2134),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2671),
    1,
    sym_identifier,
    STATE(744),
    1,
    sym_comment,
    [23463] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2673),
    1,
    anon_sym_LBRACE,
    ACTIONS(2675),
    1,
    anon_sym_COLON,
    STATE(745),
    1,
    sym_comment,
    [23479] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2134),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2677),
    1,
    sym_identifier,
    STATE(746),
    1,
    sym_comment,
    [23495] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2639),
    1,
    anon_sym_max,
    STATE(747),
    1,
    sym_comment,
    STATE(901),
    1,
    sym_max_expr,
    [23511] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(748),
    1,
    sym_comment,
    ACTIONS(2679),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [23525] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2681),
    1,
    anon_sym_valuetype,
    ACTIONS(2683),
    1,
    anon_sym_eventtype,
    STATE(749),
    1,
    sym_comment,
    [23541] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2134),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2685),
    1,
    sym_identifier,
    STATE(750),
    1,
    sym_comment,
    [23557] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2134),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2687),
    1,
    sym_identifier,
    STATE(751),
    1,
    sym_comment,
    [23573] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2639),
    1,
    anon_sym_max,
    STATE(752),
    1,
    sym_comment,
    STATE(1068),
    1,
    sym_max_expr,
    [23589] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2401),
    1,
    sym_identifier,
    STATE(753),
    1,
    sym_comment,
    STATE(955),
    1,
    sym_simple_declarator,
    [23605] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(754),
    1,
    sym_comment,
    ACTIONS(2689),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [23619] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(755),
    1,
    sym_comment,
    ACTIONS(2691),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [23633] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2134),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2693),
    1,
    anon_sym_LBRACE,
    STATE(756),
    1,
    sym_comment,
    [23649] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(757),
    1,
    sym_comment,
    ACTIONS(2695),
    2,
    anon_sym_COMMA,
    anon_sym_RBRACE,
    [23663] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(758),
    1,
    sym_comment,
    ACTIONS(2603),
    2,
    anon_sym_COMMA,
    anon_sym_SEMI,
    [23677] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2697),
    1,
    sym_identifier,
    STATE(759),
    1,
    sym_comment,
    STATE(809),
    1,
    sym_annotation_appl_param,
    [23693] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(760),
    1,
    sym_comment,
    ACTIONS(2699),
    2,
    anon_sym_SEMI,
    anon_sym_setraises,
    [23707] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(761),
    1,
    sym_comment,
    ACTIONS(2701),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [23721] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(762),
    1,
    sym_comment,
    ACTIONS(2703),
    2,
    anon_sym_GT,
    anon_sym_COMMA,
    [23735] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2705),
    1,
    anon_sym_GT,
    ACTIONS(2707),
    1,
    anon_sym_COMMA,
    STATE(763),
    1,
    sym_comment,
    [23751] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(764),
    1,
    sym_comment,
    ACTIONS(2709),
    2,
    anon_sym_SEMI,
    anon_sym_context,
    [23765] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(765),
    1,
    sym_comment,
    ACTIONS(2711),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [23779] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2134),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2713),
    1,
    anon_sym_RPAREN,
    STATE(766),
    1,
    sym_comment,
    [23795] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(767),
    1,
    sym_comment,
    ACTIONS(2715),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [23809] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(768),
    1,
    sym_comment,
    ACTIONS(2717),
    2,
    anon_sym_COMMA,
    anon_sym_RBRACE,
    [23823] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(769),
    1,
    sym_comment,
    ACTIONS(2719),
    2,
    anon_sym_ATdefault_literal,
    sym_identifier,
    [23837] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(770),
    1,
    sym_comment,
    ACTIONS(2721),
    2,
    anon_sym_COMMA,
    anon_sym_RBRACE,
    [23851] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(771),
    1,
    sym_comment,
    ACTIONS(2252),
    2,
    anon_sym_SEMI,
    anon_sym_context,
    [23865] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(772),
    1,
    sym_comment,
    ACTIONS(2723),
    2,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    [23879] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(773),
    1,
    sym_comment,
    ACTIONS(2725),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [23893] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2134),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2727),
    1,
    anon_sym_LBRACE,
    STATE(774),
    1,
    sym_comment,
    [23909] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2401),
    1,
    sym_identifier,
    STATE(772),
    1,
    sym_simple_declarator,
    STATE(775),
    1,
    sym_comment,
    [23925] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2401),
    1,
    sym_identifier,
    STATE(776),
    1,
    sym_comment,
    STATE(825),
    1,
    sym_simple_declarator,
    [23941] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(777),
    1,
    sym_comment,
    ACTIONS(2729),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [23955] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2731),
    1,
    anon_sym_LBRACE,
    ACTIONS(2733),
    1,
    anon_sym_COLON,
    STATE(778),
    1,
    sym_comment,
    [23971] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2401),
    1,
    sym_identifier,
    STATE(779),
    1,
    sym_comment,
    STATE(827),
    1,
    sym_simple_declarator,
    [23987] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(780),
    1,
    sym_comment,
    ACTIONS(2440),
    2,
    anon_sym_COMMA,
    anon_sym_SEMI,
    [24001] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2160),
    1,
    anon_sym_in,
    STATE(781),
    1,
    sym_comment,
    STATE(829),
    1,
    sym_init_param_dcl,
    [24017] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2401),
    1,
    sym_identifier,
    STATE(740),
    1,
    sym_simple_declarator,
    STATE(782),
    1,
    sym_comment,
    [24033] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(783),
    1,
    sym_comment,
    ACTIONS(2735),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [24047] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(784),
    1,
    sym_comment,
    ACTIONS(2737),
    2,
    anon_sym_GT,
    anon_sym_COMMA,
    [24061] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2401),
    1,
    sym_identifier,
    STATE(785),
    1,
    sym_comment,
    STATE(831),
    1,
    sym_simple_declarator,
    [24077] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2134),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2739),
    1,
    anon_sym_LT,
    STATE(786),
    1,
    sym_comment,
    [24093] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2164),
    1,
    anon_sym_in,
    STATE(787),
    1,
    sym_comment,
    STATE(833),
    1,
    sym_factory_param_dcl,
    [24109] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2134),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2741),
    1,
    sym_identifier,
    STATE(788),
    1,
    sym_comment,
    [24125] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2134),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2743),
    1,
    anon_sym_SEMI,
    STATE(789),
    1,
    sym_comment,
    [24141] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2745),
    1,
    anon_sym_LBRACE,
    ACTIONS(2747),
    1,
    anon_sym_SEMI,
    STATE(790),
    1,
    sym_comment,
    [24157] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2629),
    1,
    anon_sym_min,
    STATE(791),
    1,
    sym_comment,
    STATE(889),
    1,
    sym_min_expr,
    [24173] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(792),
    1,
    sym_comment,
    ACTIONS(2749),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [24187] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2134),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2751),
    1,
    sym_identifier,
    STATE(793),
    1,
    sym_comment,
    [24203] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2753),
    1,
    anon_sym_LPAREN,
    STATE(794),
    1,
    sym_comment,
    STATE(1042),
    1,
    sym_exception_list,
    [24219] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2755),
    1,
    anon_sym_LT,
    ACTIONS(2757),
    1,
    sym_identifier,
    STATE(795),
    1,
    sym_comment,
    [24235] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2134),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2759),
    1,
    anon_sym_LBRACE,
    STATE(796),
    1,
    sym_comment,
    [24251] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2753),
    1,
    anon_sym_LPAREN,
    STATE(760),
    1,
    sym_exception_list,
    STATE(797),
    1,
    sym_comment,
    [24267] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2761),
    1,
    anon_sym_GT,
    ACTIONS(2763),
    1,
    anon_sym_COMMA,
    STATE(798),
    1,
    sym_comment,
    [24283] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(799),
    1,
    sym_comment,
    ACTIONS(2765),
    2,
    anon_sym_RBRACE,
    anon_sym_bitfield,
    [24297] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2134),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2767),
    1,
    anon_sym_LT,
    STATE(800),
    1,
    sym_comment,
    [24313] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2401),
    1,
    sym_identifier,
    STATE(758),
    1,
    sym_simple_declarator,
    STATE(801),
    1,
    sym_comment,
    [24329] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(802),
    1,
    sym_comment,
    ACTIONS(2769),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [24343] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(803),
    1,
    sym_comment,
    ACTIONS(2368),
    2,
    anon_sym_COMMA,
    anon_sym_RBRACE,
    [24357] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(804),
    1,
    sym_comment,
    ACTIONS(2771),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [24371] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(805),
    1,
    sym_comment,
    ACTIONS(2564),
    2,
    anon_sym_COMMA,
    anon_sym_LBRACE,
    [24385] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(806),
    1,
    sym_comment,
    ACTIONS(2773),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [24399] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(807),
    1,
    sym_comment,
    ACTIONS(2775),
    2,
    anon_sym_COMMA,
    anon_sym_SEMI,
    [24413] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(808),
    1,
    sym_comment,
    ACTIONS(2777),
    2,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    [24427] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(809),
    1,
    sym_comment,
    ACTIONS(2490),
    2,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    [24441] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(810),
    1,
    sym_comment,
    ACTIONS(2492),
    2,
    anon_sym_GT,
    anon_sym_COMMA,
    [24455] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(811),
    1,
    sym_comment,
    ACTIONS(2497),
    2,
    anon_sym_GT,
    anon_sym_COMMA,
    [24469] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(812),
    1,
    sym_comment,
    ACTIONS(2502),
    2,
    anon_sym_GT,
    anon_sym_COMMA,
    [24483] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(813),
    1,
    sym_comment,
    ACTIONS(2779),
    2,
    anon_sym_SEMI,
    anon_sym_context,
    [24497] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(814),
    1,
    sym_comment,
    ACTIONS(2781),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [24511] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2401),
    1,
    sym_identifier,
    STATE(815),
    1,
    sym_comment,
    STATE(830),
    1,
    sym_simple_declarator,
    [24527] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(816),
    1,
    sym_comment,
    ACTIONS(2783),
    2,
    anon_sym_SEMI,
    anon_sym_context,
    [24541] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2289),
    1,
    anon_sym_in,
    STATE(817),
    1,
    sym_comment,
    STATE(828),
    1,
    sym_in_param_dcl,
    [24557] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(818),
    1,
    sym_comment,
    ACTIONS(2785),
    2,
    anon_sym_SEMI,
    anon_sym_setraises,
    [24571] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(819),
    1,
    sym_comment,
    ACTIONS(2551),
    2,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    [24585] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(820),
    1,
    sym_comment,
    ACTIONS(2787),
    2,
    anon_sym_SEMI,
    anon_sym_context,
    [24599] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2134),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2789),
    1,
    anon_sym_LBRACE,
    STATE(821),
    1,
    sym_comment,
    [24615] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(822),
    1,
    sym_comment,
    ACTIONS(2791),
    2,
    anon_sym_SEMI,
    anon_sym_context,
    [24629] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(823),
    1,
    sym_comment,
    ACTIONS(2546),
    2,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    [24643] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(824),
    1,
    sym_comment,
    ACTIONS(2527),
    2,
    anon_sym_COMMA,
    anon_sym_RBRACE,
    [24657] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(825),
    1,
    sym_comment,
    ACTIONS(2793),
    2,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    [24671] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(826),
    1,
    sym_comment,
    ACTIONS(2795),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [24685] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(827),
    1,
    sym_comment,
    ACTIONS(2797),
    2,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    [24699] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(828),
    1,
    sym_comment,
    ACTIONS(2520),
    2,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    [24713] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(829),
    1,
    sym_comment,
    ACTIONS(2541),
    2,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    [24727] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(830),
    1,
    sym_comment,
    ACTIONS(2799),
    2,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    [24741] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(831),
    1,
    sym_comment,
    ACTIONS(2801),
    2,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    [24755] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(832),
    1,
    sym_comment,
    ACTIONS(2803),
    2,
    anon_sym_SEMI,
    anon_sym_setraises,
    [24769] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(833),
    1,
    sym_comment,
    ACTIONS(2536),
    2,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    [24783] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2805),
    1,
    sym_identifier,
    STATE(834),
    1,
    sym_comment,
    STATE(857),
    1,
    sym_formal_parameter_names,
    [24799] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2807),
    1,
    anon_sym_GT,
    ACTIONS(2809),
    1,
    anon_sym_COMMA,
    STATE(835),
    1,
    sym_comment,
    [24815] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(836),
    1,
    sym_comment,
    ACTIONS(2811),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [24829] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(837),
    1,
    sym_comment,
    ACTIONS(2813),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [24843] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(838),
    1,
    sym_comment,
    ACTIONS(2815),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [24857] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2817),
    1,
    anon_sym_LPAREN,
    STATE(839),
    1,
    sym_comment,
    [24870] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2819),
    1,
    anon_sym_RPAREN,
    STATE(840),
    1,
    sym_comment,
    [24883] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2821),
    1,
    anon_sym_SEMI,
    STATE(841),
    1,
    sym_comment,
    [24896] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2823),
    1,
    anon_sym_SEMI,
    STATE(842),
    1,
    sym_comment,
    [24909] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2825),
    1,
    anon_sym_SEMI,
    STATE(843),
    1,
    sym_comment,
    [24922] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2827),
    1,
    anon_sym_COLON,
    STATE(844),
    1,
    sym_comment,
    [24935] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2829),
    1,
    sym_identifier,
    STATE(845),
    1,
    sym_comment,
    [24948] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2831),
    1,
    anon_sym_SEMI,
    STATE(846),
    1,
    sym_comment,
    [24961] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2833),
    1,
    anon_sym_GT,
    STATE(847),
    1,
    sym_comment,
    [24974] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(451),
    1,
    anon_sym_RBRACE,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    STATE(848),
    1,
    sym_comment,
    [24987] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2529),
    1,
    anon_sym_SEMI,
    STATE(849),
    1,
    sym_comment,
    [25000] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2835),
    1,
    anon_sym_GT,
    STATE(850),
    1,
    sym_comment,
    [25013] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2837),
    1,
    anon_sym_GT,
    STATE(851),
    1,
    sym_comment,
    [25026] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2839),
    1,
    anon_sym_SEMI,
    STATE(852),
    1,
    sym_comment,
    [25039] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2841),
    1,
    anon_sym_SEMI,
    STATE(853),
    1,
    sym_comment,
    [25052] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2843),
    1,
    anon_sym_SEMI,
    STATE(854),
    1,
    sym_comment,
    [25065] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2681),
    1,
    anon_sym_valuetype,
    STATE(855),
    1,
    sym_comment,
    [25078] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2845),
    1,
    sym_identifier,
    STATE(856),
    1,
    sym_comment,
    [25091] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2847),
    1,
    anon_sym_GT,
    STATE(857),
    1,
    sym_comment,
    [25104] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2849),
    1,
    anon_sym_void,
    STATE(858),
    1,
    sym_comment,
    [25117] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2851),
    1,
    anon_sym_SEMI,
    STATE(859),
    1,
    sym_comment,
    [25130] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2853),
    1,
    anon_sym_LBRACE,
    STATE(860),
    1,
    sym_comment,
    [25143] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2855),
    1,
    anon_sym_RPAREN,
    STATE(861),
    1,
    sym_comment,
    [25156] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2857),
    1,
    anon_sym_RPAREN,
    STATE(862),
    1,
    sym_comment,
    [25169] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2859),
    1,
    anon_sym_SEMI,
    STATE(863),
    1,
    sym_comment,
    [25182] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2861),
    1,
    sym_identifier,
    STATE(864),
    1,
    sym_comment,
    [25195] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2301),
    1,
    anon_sym_LBRACE,
    STATE(865),
    1,
    sym_comment,
    [25208] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2863),
    1,
    sym_identifier,
    STATE(866),
    1,
    sym_comment,
    [25221] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2865),
    1,
    anon_sym_SEMI,
    STATE(867),
    1,
    sym_comment,
    [25234] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2867),
    1,
    anon_sym_RPAREN,
    STATE(868),
    1,
    sym_comment,
    [25247] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2869),
    1,
    anon_sym_RPAREN,
    STATE(869),
    1,
    sym_comment,
    [25260] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2871),
    1,
    anon_sym_SEMI,
    STATE(870),
    1,
    sym_comment,
    [25273] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2873),
    1,
    anon_sym_RPAREN,
    STATE(871),
    1,
    sym_comment,
    [25286] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2875),
    1,
    anon_sym_RPAREN,
    STATE(872),
    1,
    sym_comment,
    [25299] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2877),
    1,
    anon_sym_attribute,
    STATE(873),
    1,
    sym_comment,
    [25312] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2879),
    1,
    sym_identifier,
    STATE(874),
    1,
    sym_comment,
    [25325] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2588),
    1,
    anon_sym_SEMI,
    STATE(875),
    1,
    sym_comment,
    [25338] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2881),
    1,
    anon_sym_SEMI,
    STATE(876),
    1,
    sym_comment,
    [25351] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2883),
    1,
    sym_identifier,
    STATE(877),
    1,
    sym_comment,
    [25364] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2378),
    1,
    anon_sym_valuetype,
    STATE(878),
    1,
    sym_comment,
    [25377] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2885),
    1,
    anon_sym_SEMI,
    STATE(879),
    1,
    sym_comment,
    [25390] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2887),
    1,
    anon_sym_RPAREN,
    STATE(880),
    1,
    sym_comment,
    [25403] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2889),
    1,
    anon_sym_LBRACE,
    STATE(881),
    1,
    sym_comment,
    [25416] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2891),
    1,
    anon_sym_LBRACE,
    STATE(882),
    1,
    sym_comment,
    [25429] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2893),
    1,
    anon_sym_LBRACE,
    STATE(883),
    1,
    sym_comment,
    [25442] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2485),
    1,
    anon_sym_manages,
    STATE(884),
    1,
    sym_comment,
    [25455] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1858),
    1,
    anon_sym_EQ,
    STATE(885),
    1,
    sym_comment,
    [25468] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2895),
    1,
    anon_sym_RPAREN,
    STATE(886),
    1,
    sym_comment,
    [25481] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2897),
    1,
    anon_sym_RPAREN,
    STATE(887),
    1,
    sym_comment,
    [25494] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2899),
    1,
    anon_sym_EQ,
    STATE(888),
    1,
    sym_comment,
    [25507] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2901),
    1,
    anon_sym_COMMA,
    STATE(889),
    1,
    sym_comment,
    [25520] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2483),
    1,
    anon_sym_LBRACE,
    STATE(890),
    1,
    sym_comment,
    [25533] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2903),
    1,
    anon_sym_RPAREN,
    STATE(891),
    1,
    sym_comment,
    [25546] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2905),
    1,
    anon_sym_RPAREN,
    STATE(892),
    1,
    sym_comment,
    [25559] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2907),
    1,
    anon_sym_LPAREN,
    STATE(893),
    1,
    sym_comment,
    [25572] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2909),
    1,
    anon_sym_RPAREN,
    STATE(894),
    1,
    sym_comment,
    [25585] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2911),
    1,
    anon_sym_RPAREN,
    STATE(895),
    1,
    sym_comment,
    [25598] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2913),
    1,
    anon_sym_COMMA,
    STATE(896),
    1,
    sym_comment,
    [25611] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2915),
    1,
    anon_sym_SEMI,
    STATE(897),
    1,
    sym_comment,
    [25624] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2917),
    1,
    anon_sym_RPAREN,
    STATE(898),
    1,
    sym_comment,
    [25637] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2919),
    1,
    anon_sym_SEMI,
    STATE(899),
    1,
    sym_comment,
    [25650] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2921),
    1,
    anon_sym_SEMI,
    STATE(900),
    1,
    sym_comment,
    [25663] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2923),
    1,
    anon_sym_RPAREN,
    STATE(901),
    1,
    sym_comment,
    [25676] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2925),
    1,
    anon_sym_EQ,
    STATE(902),
    1,
    sym_comment,
    [25689] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2927),
    1,
    anon_sym_COMMA,
    STATE(903),
    1,
    sym_comment,
    [25702] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2929),
    1,
    anon_sym_RPAREN,
    STATE(904),
    1,
    sym_comment,
    [25715] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2931),
    1,
    anon_sym_RPAREN,
    STATE(905),
    1,
    sym_comment,
    [25728] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2933),
    1,
    anon_sym_RPAREN,
    STATE(906),
    1,
    sym_comment,
    [25741] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2935),
    1,
    anon_sym_COMMA,
    STATE(907),
    1,
    sym_comment,
    [25754] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2937),
    1,
    anon_sym_COMMA,
    STATE(908),
    1,
    sym_comment,
    [25767] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2939),
    1,
    anon_sym_RPAREN,
    STATE(909),
    1,
    sym_comment,
    [25780] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2941),
    1,
    anon_sym_COLON,
    STATE(910),
    1,
    sym_comment,
    [25793] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2943),
    1,
    anon_sym_COMMA,
    STATE(911),
    1,
    sym_comment,
    [25806] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2945),
    1,
    anon_sym_SEMI,
    STATE(912),
    1,
    sym_comment,
    [25819] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2947),
    1,
    anon_sym_COMMA,
    STATE(913),
    1,
    sym_comment,
    [25832] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2949),
    1,
    anon_sym_SEMI,
    STATE(914),
    1,
    sym_comment,
    [25845] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2951),
    1,
    anon_sym_SEMI,
    STATE(915),
    1,
    sym_comment,
    [25858] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2953),
    1,
    anon_sym_RPAREN,
    STATE(916),
    1,
    sym_comment,
    [25871] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2955),
    1,
    anon_sym_RPAREN,
    STATE(917),
    1,
    sym_comment,
    [25884] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2957),
    1,
    anon_sym_SEMI,
    STATE(918),
    1,
    sym_comment,
    [25897] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2959),
    1,
    anon_sym_RPAREN,
    STATE(919),
    1,
    sym_comment,
    [25910] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2961),
    1,
    anon_sym_SEMI,
    STATE(920),
    1,
    sym_comment,
    [25923] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2963),
    1,
    anon_sym_SEMI,
    STATE(921),
    1,
    sym_comment,
    [25936] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2965),
    1,
    anon_sym_RPAREN,
    STATE(922),
    1,
    sym_comment,
    [25949] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2967),
    1,
    anon_sym_RPAREN,
    STATE(923),
    1,
    sym_comment,
    [25962] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2470),
    1,
    anon_sym_RPAREN,
    STATE(924),
    1,
    sym_comment,
    [25975] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2969),
    1,
    anon_sym_RPAREN,
    STATE(925),
    1,
    sym_comment,
    [25988] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2971),
    1,
    anon_sym_SEMI,
    STATE(926),
    1,
    sym_comment,
    [26001] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2973),
    1,
    anon_sym_EQ,
    STATE(927),
    1,
    sym_comment,
    [26014] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2975),
    1,
    anon_sym_LPAREN,
    STATE(928),
    1,
    sym_comment,
    [26027] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2977),
    1,
    anon_sym_SEMI,
    STATE(929),
    1,
    sym_comment,
    [26040] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2468),
    1,
    anon_sym_LBRACE,
    STATE(930),
    1,
    sym_comment,
    [26053] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2979),
    1,
    anon_sym_RPAREN,
    STATE(931),
    1,
    sym_comment,
    [26066] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2006),
    1,
    anon_sym_LBRACE,
    STATE(932),
    1,
    sym_comment,
    [26079] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2981),
    1,
    sym_identifier,
    STATE(933),
    1,
    sym_comment,
    [26092] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2983),
    1,
    anon_sym_GT,
    STATE(934),
    1,
    sym_comment,
    [26105] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2985),
    1,
    anon_sym_GT,
    STATE(935),
    1,
    sym_comment,
    [26118] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2987),
    1,
    anon_sym_GT,
    STATE(936),
    1,
    sym_comment,
    [26131] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2989),
    1,
    anon_sym_SEMI,
    STATE(937),
    1,
    sym_comment,
    [26144] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2991),
    1,
    sym_number_literal,
    STATE(938),
    1,
    sym_comment,
    [26157] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2993),
    1,
    anon_sym_SEMI,
    STATE(939),
    1,
    sym_comment,
    [26170] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2995),
    1,
    anon_sym_SEMI,
    STATE(940),
    1,
    sym_comment,
    [26183] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2997),
    1,
    anon_sym_SEMI,
    STATE(941),
    1,
    sym_comment,
    [26196] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2999),
    1,
    anon_sym_SEMI,
    STATE(942),
    1,
    sym_comment,
    [26209] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3001),
    1,
    sym_number_literal,
    STATE(943),
    1,
    sym_comment,
    [26222] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3003),
    1,
    sym_number_literal,
    STATE(944),
    1,
    sym_comment,
    [26235] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3005),
    1,
    anon_sym_SEMI,
    STATE(945),
    1,
    sym_comment,
    [26248] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1780),
    1,
    aux_sym_preproc_call_token1,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(946),
    1,
    sym_comment,
    [26261] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3007),
    1,
    sym_identifier,
    STATE(947),
    1,
    sym_comment,
    [26274] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3009),
    1,
    anon_sym_GT,
    STATE(948),
    1,
    sym_comment,
    [26287] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3011),
    1,
    anon_sym_LPAREN,
    STATE(949),
    1,
    sym_comment,
    [26300] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3013),
    1,
    anon_sym_LBRACE,
    STATE(950),
    1,
    sym_comment,
    [26313] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3015),
    1,
    sym_identifier,
    STATE(951),
    1,
    sym_comment,
    [26326] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3017),
    1,
    sym_identifier,
    STATE(952),
    1,
    sym_comment,
    [26339] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3019),
    1,
    sym_identifier,
    STATE(953),
    1,
    sym_comment,
    [26352] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3021),
    1,
    sym_identifier,
    STATE(954),
    1,
    sym_comment,
    [26365] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3023),
    1,
    anon_sym_SEMI,
    STATE(955),
    1,
    sym_comment,
    [26378] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3025),
    1,
    anon_sym_RPAREN,
    STATE(956),
    1,
    sym_comment,
    [26391] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2576),
    1,
    anon_sym_SEMI,
    STATE(957),
    1,
    sym_comment,
    [26404] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3027),
    1,
    anon_sym_SEMI,
    STATE(958),
    1,
    sym_comment,
    [26417] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2743),
    1,
    anon_sym_SEMI,
    STATE(959),
    1,
    sym_comment,
    [26430] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2570),
    1,
    anon_sym_SEMI,
    STATE(960),
    1,
    sym_comment,
    [26443] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3029),
    1,
    anon_sym_SEMI,
    STATE(961),
    1,
    sym_comment,
    [26456] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3031),
    1,
    anon_sym_LT,
    STATE(962),
    1,
    sym_comment,
    [26469] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3033),
    1,
    anon_sym_LT,
    STATE(963),
    1,
    sym_comment,
    [26482] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3035),
    1,
    anon_sym_enum,
    STATE(964),
    1,
    sym_comment,
    [26495] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3037),
    1,
    sym_identifier,
    STATE(965),
    1,
    sym_comment,
    [26508] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3039),
    1,
    sym_identifier,
    STATE(966),
    1,
    sym_comment,
    [26521] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2568),
    1,
    anon_sym_SEMI,
    STATE(967),
    1,
    sym_comment,
    [26534] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2755),
    1,
    anon_sym_LT,
    STATE(968),
    1,
    sym_comment,
    [26547] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3041),
    1,
    sym_identifier,
    STATE(969),
    1,
    sym_comment,
    [26560] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2741),
    1,
    sym_identifier,
    STATE(970),
    1,
    sym_comment,
    [26573] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3043),
    1,
    anon_sym_LBRACE,
    STATE(971),
    1,
    sym_comment,
    [26586] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3045),
    1,
    anon_sym_SEMI,
    STATE(972),
    1,
    sym_comment,
    [26599] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2751),
    1,
    sym_identifier,
    STATE(973),
    1,
    sym_comment,
    [26612] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3047),
    1,
    sym_identifier,
    STATE(974),
    1,
    sym_comment,
    [26625] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3049),
    1,
    anon_sym_LPAREN,
    STATE(975),
    1,
    sym_comment,
    [26638] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3051),
    1,
    anon_sym_SEMI,
    STATE(976),
    1,
    sym_comment,
    [26651] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3053),
    1,
    anon_sym_LPAREN,
    STATE(977),
    1,
    sym_comment,
    [26664] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3055),
    1,
    anon_sym_LPAREN,
    STATE(978),
    1,
    sym_comment,
    [26677] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3057),
    1,
    anon_sym_LPAREN,
    STATE(979),
    1,
    sym_comment,
    [26690] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3059),
    1,
    anon_sym_SEMI,
    STATE(980),
    1,
    sym_comment,
    [26703] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3061),
    1,
    anon_sym_SEMI,
    STATE(981),
    1,
    sym_comment,
    [26716] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3063),
    1,
    anon_sym_GT,
    STATE(982),
    1,
    sym_comment,
    [26729] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3065),
    1,
    anon_sym_LPAREN,
    STATE(983),
    1,
    sym_comment,
    [26742] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3067),
    1,
    anon_sym_LPAREN,
    STATE(984),
    1,
    sym_comment,
    [26755] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3069),
    1,
    anon_sym_LBRACE,
    STATE(985),
    1,
    sym_comment,
    [26768] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3071),
    1,
    anon_sym_LPAREN,
    STATE(986),
    1,
    sym_comment,
    [26781] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3073),
    1,
    anon_sym_LPAREN,
    STATE(987),
    1,
    sym_comment,
    [26794] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3075),
    1,
    anon_sym_LPAREN,
    STATE(988),
    1,
    sym_comment,
    [26807] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3077),
    1,
    anon_sym_RPAREN,
    STATE(989),
    1,
    sym_comment,
    [26820] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3079),
    1,
    anon_sym_LPAREN,
    STATE(990),
    1,
    sym_comment,
    [26833] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3081),
    1,
    anon_sym_LPAREN,
    STATE(991),
    1,
    sym_comment,
    [26846] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3083),
    1,
    sym_identifier,
    STATE(992),
    1,
    sym_comment,
    [26859] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3085),
    1,
    anon_sym_SEMI,
    STATE(993),
    1,
    sym_comment,
    [26872] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3087),
    1,
    anon_sym_SEMI,
    STATE(994),
    1,
    sym_comment,
    [26885] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3089),
    1,
    anon_sym_LBRACE,
    STATE(995),
    1,
    sym_comment,
    [26898] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3091),
    1,
    anon_sym_LBRACE,
    STATE(996),
    1,
    sym_comment,
    [26911] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2192),
    1,
    anon_sym_LBRACE,
    STATE(997),
    1,
    sym_comment,
    [26924] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2198),
    1,
    anon_sym_LBRACE,
    STATE(998),
    1,
    sym_comment,
    [26937] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2578),
    1,
    anon_sym_SEMI,
    STATE(999),
    1,
    sym_comment,
    [26950] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3093),
    1,
    anon_sym_LBRACE,
    STATE(1000),
    1,
    sym_comment,
    [26963] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3095),
    1,
    anon_sym_LPAREN,
    STATE(1001),
    1,
    sym_comment,
    [26976] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3097),
    1,
    anon_sym_RBRACK,
    STATE(1002),
    1,
    sym_comment,
    [26989] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3099),
    1,
    anon_sym_RBRACE,
    STATE(1003),
    1,
    sym_comment,
    [27002] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3101),
    1,
    anon_sym_SEMI,
    STATE(1004),
    1,
    sym_comment,
    [27015] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3103),
    1,
    anon_sym_SEMI,
    STATE(1005),
    1,
    sym_comment,
    [27028] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2757),
    1,
    sym_identifier,
    STATE(1006),
    1,
    sym_comment,
    [27041] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3105),
    1,
    sym_identifier,
    STATE(1007),
    1,
    sym_comment,
    [27054] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3107),
    1,
    anon_sym_RPAREN,
    STATE(1008),
    1,
    sym_comment,
    [27067] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3109),
    1,
    anon_sym_SEMI,
    STATE(1009),
    1,
    sym_comment,
    [27080] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3111),
    1,
    anon_sym_SEMI,
    STATE(1010),
    1,
    sym_comment,
    [27093] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3113),
    1,
    anon_sym_GT,
    STATE(1011),
    1,
    sym_comment,
    [27106] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3115),
    1,
    anon_sym_RPAREN,
    STATE(1012),
    1,
    sym_comment,
    [27119] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3117),
    1,
    sym_identifier,
    STATE(1013),
    1,
    sym_comment,
    [27132] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2713),
    1,
    anon_sym_RPAREN,
    STATE(1014),
    1,
    sym_comment,
    [27145] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3119),
    1,
    anon_sym_RPAREN,
    STATE(1015),
    1,
    sym_comment,
    [27158] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3121),
    1,
    sym_identifier,
    STATE(1016),
    1,
    sym_comment,
    [27171] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3123),
    1,
    anon_sym_LBRACE,
    STATE(1017),
    1,
    sym_comment,
    [27184] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3125),
    1,
    anon_sym_COMMA,
    STATE(1018),
    1,
    sym_comment,
    [27197] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3127),
    1,
    anon_sym_COMMA,
    STATE(1019),
    1,
    sym_comment,
    [27210] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3129),
    1,
    sym_identifier,
    STATE(1020),
    1,
    sym_comment,
    [27223] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3131),
    1,
    anon_sym_SEMI,
    STATE(1021),
    1,
    sym_comment,
    [27236] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3133),
    1,
    anon_sym_RPAREN,
    STATE(1022),
    1,
    sym_comment,
    [27249] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3135),
    1,
    anon_sym_LBRACE,
    STATE(1023),
    1,
    sym_comment,
    [27262] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3137),
    1,
    anon_sym_LBRACE,
    STATE(1024),
    1,
    sym_comment,
    [27275] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3139),
    1,
    sym_identifier,
    STATE(1025),
    1,
    sym_comment,
    [27288] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3141),
    1,
    sym_identifier,
    STATE(1026),
    1,
    sym_comment,
    [27301] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3143),
    1,
    sym_identifier,
    STATE(1027),
    1,
    sym_comment,
    [27314] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3145),
    1,
    sym_identifier,
    STATE(1028),
    1,
    sym_comment,
    [27327] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3147),
    1,
    anon_sym_LBRACE,
    STATE(1029),
    1,
    sym_comment,
    [27340] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(3149),
    1,
    aux_sym_preproc_call_token1,
    STATE(1030),
    1,
    sym_comment,
    [27353] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3151),
    1,
    anon_sym_DQUOTE,
    STATE(1031),
    1,
    sym_comment,
    [27366] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(3153),
    1,
    sym_system_lib_path,
    STATE(1032),
    1,
    sym_comment,
    [27379] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(3155),
    1,
    aux_sym_preproc_call_token1,
    STATE(1033),
    1,
    sym_comment,
    [27392] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3157),
    1,
    sym_identifier,
    STATE(1034),
    1,
    sym_comment,
    [27405] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3159),
    1,
    anon_sym_SLASH,
    STATE(1035),
    1,
    sym_comment,
    [27418] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3161),
    1,
    anon_sym_LPAREN,
    STATE(1036),
    1,
    sym_comment,
    [27431] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3163),
    1,
    anon_sym_SEMI,
    STATE(1037),
    1,
    sym_comment,
    [27444] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3165),
    1,
    anon_sym_SEMI,
    STATE(1038),
    1,
    sym_comment,
    [27457] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3167),
    1,
    anon_sym_LBRACE,
    STATE(1039),
    1,
    sym_comment,
    [27470] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3169),
    1,
    sym_identifier,
    STATE(1040),
    1,
    sym_comment,
    [27483] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3171),
    1,
    anon_sym_SEMI,
    STATE(1041),
    1,
    sym_comment,
    [27496] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3173),
    1,
    anon_sym_SEMI,
    STATE(1042),
    1,
    sym_comment,
    [27509] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2409),
    1,
    anon_sym_SEMI,
    STATE(1043),
    1,
    sym_comment,
    [27522] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3175),
    1,
    anon_sym_manages,
    STATE(1044),
    1,
    sym_comment,
    [27535] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3177),
    1,
    anon_sym_LBRACE,
    STATE(1045),
    1,
    sym_comment,
    [27548] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3179),
    1,
    anon_sym_RPAREN,
    STATE(1046),
    1,
    sym_comment,
    [27561] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3181),
    1,
    anon_sym_RPAREN,
    STATE(1047),
    1,
    sym_comment,
    [27574] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3183),
    1,
    anon_sym_RPAREN,
    STATE(1048),
    1,
    sym_comment,
    [27587] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3185),
    1,
    anon_sym_RPAREN,
    STATE(1049),
    1,
    sym_comment,
    [27600] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3187),
    1,
    anon_sym_RPAREN,
    STATE(1050),
    1,
    sym_comment,
    [27613] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3189),
    1,
    anon_sym_RPAREN,
    STATE(1051),
    1,
    sym_comment,
    [27626] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3191),
    1,
    anon_sym_RPAREN,
    STATE(1052),
    1,
    sym_comment,
    [27639] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3193),
    1,
    anon_sym_RPAREN,
    STATE(1053),
    1,
    sym_comment,
    [27652] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3195),
    1,
    anon_sym_RPAREN,
    STATE(1054),
    1,
    sym_comment,
    [27665] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3197),
    1,
    anon_sym_RPAREN,
    STATE(1055),
    1,
    sym_comment,
    [27678] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3199),
    1,
    anon_sym_RPAREN,
    STATE(1056),
    1,
    sym_comment,
    [27691] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3201),
    1,
    anon_sym_RPAREN,
    STATE(1057),
    1,
    sym_comment,
    [27704] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3203),
    1,
    anon_sym_RPAREN,
    STATE(1058),
    1,
    sym_comment,
    [27717] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3205),
    1,
    anon_sym_RPAREN,
    STATE(1059),
    1,
    sym_comment,
    [27730] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3207),
    1,
    anon_sym_RPAREN,
    STATE(1060),
    1,
    sym_comment,
    [27743] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3209),
    1,
    anon_sym_RPAREN,
    STATE(1061),
    1,
    sym_comment,
    [27756] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3211),
    1,
    anon_sym_RPAREN,
    STATE(1062),
    1,
    sym_comment,
    [27769] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3213),
    1,
    anon_sym_RPAREN,
    STATE(1063),
    1,
    sym_comment,
    [27782] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3215),
    1,
    anon_sym_RPAREN,
    STATE(1064),
    1,
    sym_comment,
    [27795] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3217),
    1,
    anon_sym_RPAREN,
    STATE(1065),
    1,
    sym_comment,
    [27808] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3219),
    1,
    anon_sym_SEMI,
    STATE(1066),
    1,
    sym_comment,
    [27821] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3221),
    1,
    anon_sym_RBRACE,
    STATE(1067),
    1,
    sym_comment,
    [27834] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3223),
    1,
    anon_sym_RPAREN,
    STATE(1068),
    1,
    sym_comment,
    [27847] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3225),
    1,
    anon_sym_RPAREN,
    STATE(1069),
    1,
    sym_comment,
    [27860] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3227),
    1,
    anon_sym_RPAREN,
    STATE(1070),
    1,
    sym_comment,
    [27873] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3229),
    1,
    anon_sym_SEMI,
    STATE(1071),
    1,
    sym_comment,
    [27886] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3231),
    1,
    anon_sym_RPAREN,
    STATE(1072),
    1,
    sym_comment,
    [27899] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3233),
    1,
    anon_sym_SEMI,
    STATE(1073),
    1,
    sym_comment,
    [27912] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3235),
    1,
    sym_identifier,
    STATE(1074),
    1,
    sym_comment,
    [27925] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3237),
    1,
    anon_sym_LBRACE,
    STATE(1075),
    1,
    sym_comment,
    [27938] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3239),
    1,
    anon_sym_LBRACE,
    STATE(1076),
    1,
    sym_comment,
    [27951] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3241),
    1,
    anon_sym_SEMI,
    STATE(1077),
    1,
    sym_comment,
    [27964] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3243),
    1,
    sym_identifier,
    STATE(1078),
    1,
    sym_comment,
    [27977] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2611),
    1,
    anon_sym_SEMI,
    STATE(1079),
    1,
    sym_comment,
    [27990] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2394),
    1,
    anon_sym_SEMI,
    STATE(1080),
    1,
    sym_comment,
    [28003] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3245),
    1,
    sym_identifier,
    STATE(1081),
    1,
    sym_comment,
    [28016] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3247),
    1,
    anon_sym_RPAREN,
    STATE(1082),
    1,
    sym_comment,
    [28029] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3249),
    1,
    anon_sym_RPAREN,
    STATE(1083),
    1,
    sym_comment,
    [28042] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3251),
    1,
    anon_sym_RPAREN,
    STATE(1084),
    1,
    sym_comment,
    [28055] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3253),
    1,
    anon_sym_RPAREN,
    STATE(1085),
    1,
    sym_comment,
    [28068] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3255),
    1,
    anon_sym_RPAREN,
    STATE(1086),
    1,
    sym_comment,
    [28081] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3257),
    1,
    anon_sym_RPAREN,
    STATE(1087),
    1,
    sym_comment,
    [28094] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3259),
    1,
    anon_sym_RPAREN,
    STATE(1088),
    1,
    sym_comment,
    [28107] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3261),
    1,
    anon_sym_RPAREN,
    STATE(1089),
    1,
    sym_comment,
    [28120] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3263),
    1,
    anon_sym_RPAREN,
    STATE(1090),
    1,
    sym_comment,
    [28133] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3265),
    1,
    anon_sym_RPAREN,
    STATE(1091),
    1,
    sym_comment,
    [28146] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3267),
    1,
    anon_sym_RPAREN,
    STATE(1092),
    1,
    sym_comment,
    [28159] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3269),
    1,
    anon_sym_RPAREN,
    STATE(1093),
    1,
    sym_comment,
    [28172] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3271),
    1,
    anon_sym_RPAREN,
    STATE(1094),
    1,
    sym_comment,
    [28185] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3273),
    1,
    anon_sym_RPAREN,
    STATE(1095),
    1,
    sym_comment,
    [28198] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3275),
    1,
    anon_sym_RPAREN,
    STATE(1096),
    1,
    sym_comment,
    [28211] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3277),
    1,
    anon_sym_RPAREN,
    STATE(1097),
    1,
    sym_comment,
    [28224] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3279),
    1,
    anon_sym_RPAREN,
    STATE(1098),
    1,
    sym_comment,
    [28237] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3281),
    1,
    anon_sym_RPAREN,
    STATE(1099),
    1,
    sym_comment,
    [28250] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3283),
    1,
    anon_sym_RPAREN,
    STATE(1100),
    1,
    sym_comment,
    [28263] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3285),
    1,
    anon_sym_RPAREN,
    STATE(1101),
    1,
    sym_comment,
    [28276] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3287),
    1,
    anon_sym_RPAREN,
    STATE(1102),
    1,
    sym_comment,
    [28289] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3289),
    1,
    anon_sym_RPAREN,
    STATE(1103),
    1,
    sym_comment,
    [28302] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3291),
    1,
    anon_sym_RPAREN,
    STATE(1104),
    1,
    sym_comment,
    [28315] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3293),
    1,
    anon_sym_RPAREN,
    STATE(1105),
    1,
    sym_comment,
    [28328] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(3295),
    1,
    aux_sym_comment_token1,
    STATE(1106),
    1,
    sym_comment,
    [28341] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3297),
    1,
    sym_identifier,
    STATE(1107),
    1,
    sym_comment,
    [28354] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3299),
    1,
    anon_sym_SEMI,
    STATE(1108),
    1,
    sym_comment,
    [28367] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3301),
    1,
    anon_sym_LBRACE,
    STATE(1109),
    1,
    sym_comment,
    [28380] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3303),
    1,
    sym_identifier,
    STATE(1110),
    1,
    sym_comment,
    [28393] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3305),
    1,
    sym_identifier,
    STATE(1111),
    1,
    sym_comment,
    [28406] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3307),
    1,
    anon_sym_SEMI,
    STATE(1112),
    1,
    sym_comment,
    [28419] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3309),
    1,
    anon_sym_RPAREN,
    STATE(1113),
    1,
    sym_comment,
    [28432] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3311),
    1,
    anon_sym_RPAREN,
    STATE(1114),
    1,
    sym_comment,
    [28445] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3313),
    1,
    anon_sym_RPAREN,
    STATE(1115),
    1,
    sym_comment,
    [28458] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3315),
    1,
    anon_sym_RPAREN,
    STATE(1116),
    1,
    sym_comment,
    [28471] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3317),
    1,
    anon_sym_RPAREN,
    STATE(1117),
    1,
    sym_comment,
    [28484] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3319),
    1,
    anon_sym_RPAREN,
    STATE(1118),
    1,
    sym_comment,
    [28497] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3321),
    1,
    anon_sym_RPAREN,
    STATE(1119),
    1,
    sym_comment,
    [28510] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3323),
    1,
    anon_sym_RPAREN,
    STATE(1120),
    1,
    sym_comment,
    [28523] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3325),
    1,
    anon_sym_RPAREN,
    STATE(1121),
    1,
    sym_comment,
    [28536] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3327),
    1,
    anon_sym_RPAREN,
    STATE(1122),
    1,
    sym_comment,
    [28549] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3329),
    1,
    anon_sym_RPAREN,
    STATE(1123),
    1,
    sym_comment,
    [28562] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3331),
    1,
    anon_sym_RPAREN,
    STATE(1124),
    1,
    sym_comment,
    [28575] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3333),
    1,
    anon_sym_RPAREN,
    STATE(1125),
    1,
    sym_comment,
    [28588] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3335),
    1,
    anon_sym_RPAREN,
    STATE(1126),
    1,
    sym_comment,
    [28601] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3337),
    1,
    anon_sym_RPAREN,
    STATE(1127),
    1,
    sym_comment,
    [28614] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3339),
    1,
    anon_sym_RPAREN,
    STATE(1128),
    1,
    sym_comment,
    [28627] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3341),
    1,
    anon_sym_RPAREN,
    STATE(1129),
    1,
    sym_comment,
    [28640] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3343),
    1,
    anon_sym_RPAREN,
    STATE(1130),
    1,
    sym_comment,
    [28653] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3345),
    1,
    anon_sym_RPAREN,
    STATE(1131),
    1,
    sym_comment,
    [28666] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3347),
    1,
    anon_sym_RPAREN,
    STATE(1132),
    1,
    sym_comment,
    [28679] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3349),
    1,
    anon_sym_RPAREN,
    STATE(1133),
    1,
    sym_comment,
    [28692] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3351),
    1,
    anon_sym_RPAREN,
    STATE(1134),
    1,
    sym_comment,
    [28705] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3353),
    1,
    anon_sym_RPAREN,
    STATE(1135),
    1,
    sym_comment,
    [28718] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3355),
    1,
    anon_sym_RPAREN,
    STATE(1136),
    1,
    sym_comment,
    [28731] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3357),
    1,
    sym_identifier,
    STATE(1137),
    1,
    sym_comment,
    [28744] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3359),
    1,
    sym_identifier,
    STATE(1138),
    1,
    sym_comment,
    [28757] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3361),
    1,
    sym_identifier,
    STATE(1139),
    1,
    sym_comment,
    [28770] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3363),
    1,
    anon_sym_RPAREN,
    STATE(1140),
    1,
    sym_comment,
    [28783] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2623),
    1,
    anon_sym_DQUOTE,
    STATE(1141),
    1,
    sym_comment,
    [28796] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3365),
    1,
    anon_sym_LBRACE,
    STATE(1142),
    1,
    sym_comment,
    [28809] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3367),
    1,
    sym_number_literal,
    STATE(1143),
    1,
    sym_comment,
    [28822] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3369),
    1,
    sym_number_literal,
    STATE(1144),
    1,
    sym_comment,
    [28835] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3371),
    1,
    anon_sym_SEMI,
    STATE(1145),
    1,
    sym_comment,
    [28848] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3373),
    1,
    sym_identifier,
    STATE(1146),
    1,
    sym_comment,
    [28861] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3375),
    1,
    anon_sym_LPAREN,
    STATE(1147),
    1,
    sym_comment,
    [28874] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3377),
    1,
    anon_sym_SEMI,
    STATE(1148),
    1,
    sym_comment,
    [28887] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3299),
    1,
    anon_sym_SEMI,
    STATE(1149),
    1,
    sym_comment,
    [28900] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3379),
    1,
    ts_builtin_sym_end,
    STATE(1150),
    1,
    sym_comment,
    [28913] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3381),
    1,
    anon_sym_LPAREN,
    STATE(1151),
    1,
    sym_comment,
    [28926] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3383),
    1,
    sym_number_literal,
    STATE(1152),
    1,
    sym_comment,
    [28939] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3385),
    1,
    anon_sym_SEMI,
    STATE(1153),
    1,
    sym_comment,
    [28952] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3387),
    1,
    anon_sym_LPAREN,
    STATE(1154),
    1,
    sym_comment,
    [28965] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3389),
    1,
    anon_sym_LBRACE,
    STATE(1155),
    1,
    sym_comment,
    [28978] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3391),
    1,
    sym_identifier,
    STATE(1156),
    1,
    sym_comment,
    [28991] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3393),
    1,
    anon_sym_LPAREN,
    STATE(1157),
    1,
    sym_comment,
    [29004] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3395),
    1,
    anon_sym_SEMI,
    STATE(1158),
    1,
    sym_comment,
    [29017] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3397),
    1,
    sym_identifier,
    STATE(1159),
    1,
    sym_comment,
    [29030] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3399),
    1,
    sym_identifier,
    STATE(1160),
    1,
    sym_comment,
    [29043] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3401),
    1,
    anon_sym_RBRACE,
    STATE(1161),
    1,
    sym_comment,
    [29056] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3403),
    1,
    sym_identifier,
    STATE(1162),
    1,
    sym_comment,
    [29069] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2687),
    1,
    sym_identifier,
    STATE(1163),
    1,
    sym_comment,
    [29082] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3405),
    1,
    anon_sym_SEMI,
    STATE(1164),
    1,
    sym_comment,
    [29095] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3407),
    1,
    sym_identifier,
    STATE(1165),
    1,
    sym_comment,
    [29108] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3409),
    1,
    sym_identifier,
    STATE(1166),
    1,
    sym_comment,
    [29121] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3411),
    1,
    anon_sym_SEMI,
    STATE(1167),
    1,
    sym_comment,
    [29134] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3413),
    1,
    sym_number_literal,
    STATE(1168),
    1,
    sym_comment,
    [29147] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3415),
    1,
    sym_number_literal,
    STATE(1169),
    1,
    sym_comment,
    [29160] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3417),
    1,
    anon_sym_enum,
    STATE(1170),
    1,
    sym_comment,
    [29173] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3419),
    1,
    anon_sym_SEMI,
    STATE(1171),
    1,
    sym_comment,
    [29186] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3421),
    1,
    anon_sym_SEMI,
    STATE(1172),
    1,
    sym_comment,
    [29199] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3423),
    1,
    anon_sym_RPAREN,
    STATE(1173),
    1,
    sym_comment,
    [29212] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3425),
    1,
    sym_identifier,
    STATE(1174),
    1,
    sym_comment,
    [29225] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3427),
    1,
    sym_identifier,
    STATE(1175),
    1,
    sym_comment,
    [29238] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3429),
    1,
    anon_sym_LBRACE,
    STATE(1176),
    1,
    sym_comment,
    [29251] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3431),
    1,
    sym_number_literal,
    STATE(1177),
    1,
    sym_comment,
    [29264] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3433),
    1,
    anon_sym_SEMI,
    STATE(1178),
    1,
    sym_comment,
    [29277] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3435),
    1,
    anon_sym_SEMI,
    STATE(1179),
    1,
    sym_comment,
    [29290] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3437),
    1,
    sym_identifier,
    STATE(1180),
    1,
    sym_comment,
    [29303] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3439),
    1,
    sym_identifier,
    STATE(1181),
    1,
    sym_comment,
    [29316] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(3441),
    1,
    aux_sym_preproc_call_token1,
    STATE(1182),
    1,
    sym_comment,
    [29329] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3443),
    1,
    anon_sym_SEMI,
    STATE(1183),
    1,
    sym_comment,
    [29342] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3445),
    1,
    sym_identifier,
    STATE(1184),
    1,
    sym_comment,
    [29355] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3447),
    1,
    anon_sym_SEMI,
    STATE(1185),
    1,
    sym_comment,
    [29368] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1838),
    1,
    aux_sym_preproc_call_token1,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(1186),
    1,
    sym_comment,
    [29381] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3449),
    1,
    anon_sym_SEMI,
    STATE(1187),
    1,
    sym_comment,
    [29394] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3451),
    1,
    anon_sym_LBRACE,
    STATE(1188),
    1,
    sym_comment,
    [29407] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3453),
    1,
    sym_identifier,
    STATE(1189),
    1,
    sym_comment,
    [29420] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3455),
    1,
    sym_identifier,
    STATE(1190),
    1,
    sym_comment,
    [29433] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3457),
    1,
    sym_number_literal,
    STATE(1191),
    1,
    sym_comment,
    [29446] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3459),
    1,
    sym_number_literal,
    STATE(1192),
    1,
    sym_comment,
    [29459] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3461),
    1,
    sym_identifier,
    STATE(1193),
    1,
    sym_comment,
    [29472] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3463),
    1,
    sym_identifier,
    STATE(1194),
    1,
    sym_comment,
    [29485] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3465),
    1,
    anon_sym_LBRACE,
    STATE(1195),
    1,
    sym_comment,
    [29498] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3467),
    1,
    anon_sym_SEMI,
    STATE(1196),
    1,
    sym_comment,
    [29511] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3469),
    1,
    anon_sym_SEMI,
    STATE(1197),
    1,
    sym_comment,
    [29524] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2376),
    1,
    anon_sym_interface,
    STATE(1198),
    1,
    sym_comment,
    [29537] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3471),
    1,
    anon_sym_SEMI,
    STATE(1199),
    1,
    sym_comment,
    [29550] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3473),
    1,
    sym_number_literal,
    STATE(1200),
    1,
    sym_comment,
    [29563] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3475),
    1,
    anon_sym_SEMI,
    STATE(1201),
    1,
    sym_comment,
    [29576] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1850),
    1,
    aux_sym_preproc_call_token1,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    STATE(1202),
    1,
    sym_comment,
    [29589] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3477),
    1,
    sym_identifier,
    STATE(1203),
    1,
    sym_comment,
    [29602] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3479),
    1,
    anon_sym_LT,
    STATE(1204),
    1,
    sym_comment,
    [29615] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3481),
    1,
    anon_sym_RBRACE,
    STATE(1205),
    1,
    sym_comment,
    [29628] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3483),
    1,
    anon_sym_SEMI,
    STATE(1206),
    1,
    sym_comment,
    [29641] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(3485),
    1,
    aux_sym_preproc_define_token1,
    STATE(1207),
    1,
    sym_comment,
    [29654] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3487),
    1,
    anon_sym_SEMI,
    STATE(1208),
    1,
    sym_comment,
    [29667] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2014),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(3489),
    1,
    aux_sym_comment_token2,
    STATE(1209),
    1,
    sym_comment,
    [29680] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3491),
    1,
    anon_sym_SEMI,
    STATE(1210),
    1,
    sym_comment,
    [29693] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3493),
    1,
    anon_sym_SEMI,
    STATE(1211),
    1,
    sym_comment,
    [29706] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3495),
    1,
    anon_sym_LPAREN,
    STATE(1212),
    1,
    sym_comment,
    [29719] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3497),
    1,
    anon_sym_LPAREN,
    STATE(1213),
    1,
    sym_comment,
    [29732] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3499),
    1,
    anon_sym_LPAREN,
    STATE(1214),
    1,
    sym_comment,
    [29745] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3501),
    1,
    anon_sym_LPAREN,
    STATE(1215),
    1,
    sym_comment,
    [29758] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3503),
    1,
    anon_sym_LPAREN,
    STATE(1216),
    1,
    sym_comment,
    [29771] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3505),
    1,
    anon_sym_LPAREN,
    STATE(1217),
    1,
    sym_comment,
    [29784] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3507),
    1,
    anon_sym_LPAREN,
    STATE(1218),
    1,
    sym_comment,
    [29797] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3509),
    1,
    anon_sym_LPAREN,
    STATE(1219),
    1,
    sym_comment,
    [29810] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3511),
    1,
    anon_sym_LPAREN,
    STATE(1220),
    1,
    sym_comment,
    [29823] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3513),
    1,
    anon_sym_LPAREN,
    STATE(1221),
    1,
    sym_comment,
    [29836] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3515),
    1,
    anon_sym_COMMA,
    STATE(1222),
    1,
    sym_comment,
    [29849] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3517),
    1,
    anon_sym_COMMA,
    STATE(1223),
    1,
    sym_comment,
    [29862] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3519),
    1,
    anon_sym_COMMA,
    STATE(1224),
    1,
    sym_comment,
    [29875] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3521),
    1,
    anon_sym_COMMA,
    STATE(1225),
    1,
    sym_comment,
    [29888] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3523),
    1,
    anon_sym_LPAREN,
    STATE(1226),
    1,
    sym_comment,
    [29901] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3525),
    1,
    anon_sym_LPAREN,
    STATE(1227),
    1,
    sym_comment,
    [29914] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3527),
    1,
    anon_sym_LPAREN,
    STATE(1228),
    1,
    sym_comment,
    [29927] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3529),
    1,
    anon_sym_LPAREN,
    STATE(1229),
    1,
    sym_comment,
    [29940] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3531),
    1,
    anon_sym_LPAREN,
    STATE(1230),
    1,
    sym_comment,
    [29953] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3533),
    1,
    anon_sym_LPAREN,
    STATE(1231),
    1,
    sym_comment,
    [29966] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3535),
    1,
    anon_sym_LPAREN,
    STATE(1232),
    1,
    sym_comment,
    [29979] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3537),
    1,
    anon_sym_LPAREN,
    STATE(1233),
    1,
    sym_comment,
    [29992] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3539),
    1,
    anon_sym_LPAREN,
    STATE(1234),
    1,
    sym_comment,
    [30005] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3541),
    1,
    anon_sym_LPAREN,
    STATE(1235),
    1,
    sym_comment,
    [30018] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3543),
    1,
    anon_sym_COMMA,
    STATE(1236),
    1,
    sym_comment,
    [30031] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3545),
    1,
    anon_sym_COMMA,
    STATE(1237),
    1,
    sym_comment,
    [30044] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3547),
    1,
    anon_sym_COMMA,
    STATE(1238),
    1,
    sym_comment,
    [30057] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3549),
    1,
    anon_sym_COMMA,
    STATE(1239),
    1,
    sym_comment,
    [30070] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3551),
    1,
    anon_sym_LPAREN,
    STATE(1240),
    1,
    sym_comment,
    [30083] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3553),
    1,
    anon_sym_LPAREN,
    STATE(1241),
    1,
    sym_comment,
    [30096] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3555),
    1,
    anon_sym_LPAREN,
    STATE(1242),
    1,
    sym_comment,
    [30109] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3557),
    1,
    anon_sym_LPAREN,
    STATE(1243),
    1,
    sym_comment,
    [30122] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3559),
    1,
    anon_sym_LPAREN,
    STATE(1244),
    1,
    sym_comment,
    [30135] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3561),
    1,
    anon_sym_LPAREN,
    STATE(1245),
    1,
    sym_comment,
    [30148] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3563),
    1,
    anon_sym_LPAREN,
    STATE(1246),
    1,
    sym_comment,
    [30161] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3565),
    1,
    anon_sym_LPAREN,
    STATE(1247),
    1,
    sym_comment,
    [30174] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3567),
    1,
    anon_sym_LPAREN,
    STATE(1248),
    1,
    sym_comment,
    [30187] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3569),
    1,
    anon_sym_LPAREN,
    STATE(1249),
    1,
    sym_comment,
    [30200] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3571),
    1,
    anon_sym_COMMA,
    STATE(1250),
    1,
    sym_comment,
    [30213] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3573),
    1,
    anon_sym_COMMA,
    STATE(1251),
    1,
    sym_comment,
    [30226] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3575),
    1,
    anon_sym_COMMA,
    STATE(1252),
    1,
    sym_comment,
    [30239] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3577),
    1,
    anon_sym_COMMA,
    STATE(1253),
    1,
    sym_comment,
    [30252] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3579),
    1,
    anon_sym_SEMI,
    STATE(1254),
    1,
    sym_comment,
    [30265] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3581),
    1,
    anon_sym_SEMI,
    STATE(1255),
    1,
    sym_comment,
    [30278] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3583),
    1,
    anon_sym_SEMI,
    STATE(1256),
    1,
    sym_comment,
    [30291] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(898),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3585),
    1,
    anon_sym_LPAREN,
    STATE(1257),
    1,
    sym_comment,
    [30304] = 1,
    ACTIONS(3587),
    1,
    ts_builtin_sym_end,
    [30308] = 1,
    ACTIONS(3589),
    1,
    ts_builtin_sym_end,
};

static const uint32_t ts_small_parse_table_map[] = {
    [SMALL_STATE(34)] = 0,
    [SMALL_STATE(35)] = 149,
    [SMALL_STATE(36)] = 300,
    [SMALL_STATE(37)] = 451,
    [SMALL_STATE(38)] = 602,
    [SMALL_STATE(39)] = 753,
    [SMALL_STATE(40)] = 904,
    [SMALL_STATE(41)] = 1055,
    [SMALL_STATE(42)] = 1206,
    [SMALL_STATE(43)] = 1357,
    [SMALL_STATE(44)] = 1508,
    [SMALL_STATE(45)] = 1659,
    [SMALL_STATE(46)] = 1807,
    [SMALL_STATE(47)] = 1951,
    [SMALL_STATE(48)] = 2089,
    [SMALL_STATE(49)] = 2231,
    [SMALL_STATE(50)] = 2375,
    [SMALL_STATE(51)] = 2517,
    [SMALL_STATE(52)] = 2661,
    [SMALL_STATE(53)] = 2731,
    [SMALL_STATE(54)] = 2801,
    [SMALL_STATE(55)] = 2871,
    [SMALL_STATE(56)] = 2941,
    [SMALL_STATE(57)] = 3011,
    [SMALL_STATE(58)] = 3141,
    [SMALL_STATE(59)] = 3211,
    [SMALL_STATE(60)] = 3281,
    [SMALL_STATE(61)] = 3350,
    [SMALL_STATE(62)] = 3419,
    [SMALL_STATE(63)] = 3546,
    [SMALL_STATE(64)] = 3615,
    [SMALL_STATE(65)] = 3684,
    [SMALL_STATE(66)] = 3805,
    [SMALL_STATE(67)] = 3872,
    [SMALL_STATE(68)] = 3993,
    [SMALL_STATE(69)] = 4120,
    [SMALL_STATE(70)] = 4247,
    [SMALL_STATE(71)] = 4368,
    [SMALL_STATE(72)] = 4435,
    [SMALL_STATE(73)] = 4556,
    [SMALL_STATE(74)] = 4683,
    [SMALL_STATE(75)] = 4804,
    [SMALL_STATE(76)] = 4925,
    [SMALL_STATE(77)] = 5052,
    [SMALL_STATE(78)] = 5173,
    [SMALL_STATE(79)] = 5300,
    [SMALL_STATE(80)] = 5427,
    [SMALL_STATE(81)] = 5554,
    [SMALL_STATE(82)] = 5681,
    [SMALL_STATE(83)] = 5808,
    [SMALL_STATE(84)] = 5929,
    [SMALL_STATE(85)] = 6056,
    [SMALL_STATE(86)] = 6161,
    [SMALL_STATE(87)] = 6266,
    [SMALL_STATE(88)] = 6322,
    [SMALL_STATE(89)] = 6378,
    [SMALL_STATE(90)] = 6436,
    [SMALL_STATE(91)] = 6486,
    [SMALL_STATE(92)] = 6536,
    [SMALL_STATE(93)] = 6584,
    [SMALL_STATE(94)] = 6632,
    [SMALL_STATE(95)] = 6682,
    [SMALL_STATE(96)] = 6730,
    [SMALL_STATE(97)] = 6778,
    [SMALL_STATE(98)] = 6828,
    [SMALL_STATE(99)] = 6878,
    [SMALL_STATE(100)] = 6926,
    [SMALL_STATE(101)] = 6976,
    [SMALL_STATE(102)] = 7024,
    [SMALL_STATE(103)] = 7074,
    [SMALL_STATE(104)] = 7124,
    [SMALL_STATE(105)] = 7174,
    [SMALL_STATE(106)] = 7224,
    [SMALL_STATE(107)] = 7272,
    [SMALL_STATE(108)] = 7320,
    [SMALL_STATE(109)] = 7367,
    [SMALL_STATE(110)] = 7414,
    [SMALL_STATE(111)] = 7461,
    [SMALL_STATE(112)] = 7508,
    [SMALL_STATE(113)] = 7555,
    [SMALL_STATE(114)] = 7602,
    [SMALL_STATE(115)] = 7649,
    [SMALL_STATE(116)] = 7696,
    [SMALL_STATE(117)] = 7743,
    [SMALL_STATE(118)] = 7790,
    [SMALL_STATE(119)] = 7837,
    [SMALL_STATE(120)] = 7884,
    [SMALL_STATE(121)] = 7931,
    [SMALL_STATE(122)] = 7978,
    [SMALL_STATE(123)] = 8025,
    [SMALL_STATE(124)] = 8072,
    [SMALL_STATE(125)] = 8119,
    [SMALL_STATE(126)] = 8166,
    [SMALL_STATE(127)] = 8213,
    [SMALL_STATE(128)] = 8260,
    [SMALL_STATE(129)] = 8307,
    [SMALL_STATE(130)] = 8354,
    [SMALL_STATE(131)] = 8401,
    [SMALL_STATE(132)] = 8448,
    [SMALL_STATE(133)] = 8495,
    [SMALL_STATE(134)] = 8542,
    [SMALL_STATE(135)] = 8589,
    [SMALL_STATE(136)] = 8636,
    [SMALL_STATE(137)] = 8683,
    [SMALL_STATE(138)] = 8730,
    [SMALL_STATE(139)] = 8777,
    [SMALL_STATE(140)] = 8824,
    [SMALL_STATE(141)] = 8871,
    [SMALL_STATE(142)] = 8918,
    [SMALL_STATE(143)] = 8965,
    [SMALL_STATE(144)] = 9012,
    [SMALL_STATE(145)] = 9059,
    [SMALL_STATE(146)] = 9106,
    [SMALL_STATE(147)] = 9153,
    [SMALL_STATE(148)] = 9200,
    [SMALL_STATE(149)] = 9247,
    [SMALL_STATE(150)] = 9294,
    [SMALL_STATE(151)] = 9339,
    [SMALL_STATE(152)] = 9384,
    [SMALL_STATE(153)] = 9467,
    [SMALL_STATE(154)] = 9512,
    [SMALL_STATE(155)] = 9557,
    [SMALL_STATE(156)] = 9602,
    [SMALL_STATE(157)] = 9647,
    [SMALL_STATE(158)] = 9736,
    [SMALL_STATE(159)] = 9779,
    [SMALL_STATE(160)] = 9822,
    [SMALL_STATE(161)] = 9865,
    [SMALL_STATE(162)] = 9954,
    [SMALL_STATE(163)] = 10043,
    [SMALL_STATE(164)] = 10132,
    [SMALL_STATE(165)] = 10218,
    [SMALL_STATE(166)] = 10304,
    [SMALL_STATE(167)] = 10390,
    [SMALL_STATE(168)] = 10476,
    [SMALL_STATE(169)] = 10518,
    [SMALL_STATE(170)] = 10604,
    [SMALL_STATE(171)] = 10690,
    [SMALL_STATE(172)] = 10776,
    [SMALL_STATE(173)] = 10859,
    [SMALL_STATE(174)] = 10942,
    [SMALL_STATE(175)] = 11025,
    [SMALL_STATE(176)] = 11108,
    [SMALL_STATE(177)] = 11191,
    [SMALL_STATE(178)] = 11274,
    [SMALL_STATE(179)] = 11342,
    [SMALL_STATE(180)] = 11419,
    [SMALL_STATE(181)] = 11493,
    [SMALL_STATE(182)] = 11530,
    [SMALL_STATE(183)] = 11567,
    [SMALL_STATE(184)] = 11638,
    [SMALL_STATE(185)] = 11698,
    [SMALL_STATE(186)] = 11766,
    [SMALL_STATE(187)] = 11823,
    [SMALL_STATE(188)] = 11878,
    [SMALL_STATE(189)] = 11943,
    [SMALL_STATE(190)] = 12005,
    [SMALL_STATE(191)] = 12038,
    [SMALL_STATE(192)] = 12071,
    [SMALL_STATE(193)] = 12121,
    [SMALL_STATE(194)] = 12171,
    [SMALL_STATE(195)] = 12213,
    [SMALL_STATE(196)] = 12243,
    [SMALL_STATE(197)] = 12273,
    [SMALL_STATE(198)] = 12307,
    [SMALL_STATE(199)] = 12337,
    [SMALL_STATE(200)] = 12367,
    [SMALL_STATE(201)] = 12409,
    [SMALL_STATE(202)] = 12459,
    [SMALL_STATE(203)] = 12489,
    [SMALL_STATE(204)] = 12537,
    [SMALL_STATE(205)] = 12567,
    [SMALL_STATE(206)] = 12615,
    [SMALL_STATE(207)] = 12657,
    [SMALL_STATE(208)] = 12691,
    [SMALL_STATE(209)] = 12721,
    [SMALL_STATE(210)] = 12751,
    [SMALL_STATE(211)] = 12781,
    [SMALL_STATE(212)] = 12811,
    [SMALL_STATE(213)] = 12841,
    [SMALL_STATE(214)] = 12871,
    [SMALL_STATE(215)] = 12901,
    [SMALL_STATE(216)] = 12943,
    [SMALL_STATE(217)] = 12992,
    [SMALL_STATE(218)] = 13039,
    [SMALL_STATE(219)] = 13068,
    [SMALL_STATE(220)] = 13097,
    [SMALL_STATE(221)] = 13126,
    [SMALL_STATE(222)] = 13159,
    [SMALL_STATE(223)] = 13203,
    [SMALL_STATE(224)] = 13230,
    [SMALL_STATE(225)] = 13257,
    [SMALL_STATE(226)] = 13279,
    [SMALL_STATE(227)] = 13313,
    [SMALL_STATE(228)] = 13343,
    [SMALL_STATE(229)] = 13373,
    [SMALL_STATE(230)] = 13403,
    [SMALL_STATE(231)] = 13425,
    [SMALL_STATE(232)] = 13459,
    [SMALL_STATE(233)] = 13493,
    [SMALL_STATE(234)] = 13527,
    [SMALL_STATE(235)] = 13561,
    [SMALL_STATE(236)] = 13595,
    [SMALL_STATE(237)] = 13625,
    [SMALL_STATE(238)] = 13659,
    [SMALL_STATE(239)] = 13693,
    [SMALL_STATE(240)] = 13727,
    [SMALL_STATE(241)] = 13761,
    [SMALL_STATE(242)] = 13795,
    [SMALL_STATE(243)] = 13829,
    [SMALL_STATE(244)] = 13863,
    [SMALL_STATE(245)] = 13897,
    [SMALL_STATE(246)] = 13919,
    [SMALL_STATE(247)] = 13953,
    [SMALL_STATE(248)] = 13987,
    [SMALL_STATE(249)] = 14017,
    [SMALL_STATE(250)] = 14051,
    [SMALL_STATE(251)] = 14085,
    [SMALL_STATE(252)] = 14119,
    [SMALL_STATE(253)] = 14140,
    [SMALL_STATE(254)] = 14163,
    [SMALL_STATE(255)] = 14184,
    [SMALL_STATE(256)] = 14205,
    [SMALL_STATE(257)] = 14228,
    [SMALL_STATE(258)] = 14251,
    [SMALL_STATE(259)] = 14276,
    [SMALL_STATE(260)] = 14298,
    [SMALL_STATE(261)] = 14318,
    [SMALL_STATE(262)] = 14352,
    [SMALL_STATE(263)] = 14374,
    [SMALL_STATE(264)] = 14396,
    [SMALL_STATE(265)] = 14418,
    [SMALL_STATE(266)] = 14440,
    [SMALL_STATE(267)] = 14462,
    [SMALL_STATE(268)] = 14484,
    [SMALL_STATE(269)] = 14506,
    [SMALL_STATE(270)] = 14528,
    [SMALL_STATE(271)] = 14550,
    [SMALL_STATE(272)] = 14584,
    [SMALL_STATE(273)] = 14606,
    [SMALL_STATE(274)] = 14640,
    [SMALL_STATE(275)] = 14660,
    [SMALL_STATE(276)] = 14679,
    [SMALL_STATE(277)] = 14698,
    [SMALL_STATE(278)] = 14729,
    [SMALL_STATE(279)] = 14748,
    [SMALL_STATE(280)] = 14779,
    [SMALL_STATE(281)] = 14798,
    [SMALL_STATE(282)] = 14829,
    [SMALL_STATE(283)] = 14848,
    [SMALL_STATE(284)] = 14879,
    [SMALL_STATE(285)] = 14898,
    [SMALL_STATE(286)] = 14917,
    [SMALL_STATE(287)] = 14936,
    [SMALL_STATE(288)] = 14955,
    [SMALL_STATE(289)] = 14974,
    [SMALL_STATE(290)] = 14993,
    [SMALL_STATE(291)] = 15012,
    [SMALL_STATE(292)] = 15031,
    [SMALL_STATE(293)] = 15052,
    [SMALL_STATE(294)] = 15071,
    [SMALL_STATE(295)] = 15090,
    [SMALL_STATE(296)] = 15109,
    [SMALL_STATE(297)] = 15128,
    [SMALL_STATE(298)] = 15147,
    [SMALL_STATE(299)] = 15178,
    [SMALL_STATE(300)] = 15209,
    [SMALL_STATE(301)] = 15228,
    [SMALL_STATE(302)] = 15247,
    [SMALL_STATE(303)] = 15266,
    [SMALL_STATE(304)] = 15285,
    [SMALL_STATE(305)] = 15304,
    [SMALL_STATE(306)] = 15323,
    [SMALL_STATE(307)] = 15342,
    [SMALL_STATE(308)] = 15361,
    [SMALL_STATE(309)] = 15380,
    [SMALL_STATE(310)] = 15399,
    [SMALL_STATE(311)] = 15418,
    [SMALL_STATE(312)] = 15437,
    [SMALL_STATE(313)] = 15456,
    [SMALL_STATE(314)] = 15475,
    [SMALL_STATE(315)] = 15494,
    [SMALL_STATE(316)] = 15513,
    [SMALL_STATE(317)] = 15532,
    [SMALL_STATE(318)] = 15551,
    [SMALL_STATE(319)] = 15570,
    [SMALL_STATE(320)] = 15589,
    [SMALL_STATE(321)] = 15608,
    [SMALL_STATE(322)] = 15627,
    [SMALL_STATE(323)] = 15658,
    [SMALL_STATE(324)] = 15677,
    [SMALL_STATE(325)] = 15708,
    [SMALL_STATE(326)] = 15727,
    [SMALL_STATE(327)] = 15746,
    [SMALL_STATE(328)] = 15765,
    [SMALL_STATE(329)] = 15791,
    [SMALL_STATE(330)] = 15819,
    [SMALL_STATE(331)] = 15847,
    [SMALL_STATE(332)] = 15873,
    [SMALL_STATE(333)] = 15901,
    [SMALL_STATE(334)] = 15923,
    [SMALL_STATE(335)] = 15951,
    [SMALL_STATE(336)] = 15975,
    [SMALL_STATE(337)] = 16003,
    [SMALL_STATE(338)] = 16031,
    [SMALL_STATE(339)] = 16059,
    [SMALL_STATE(340)] = 16085,
    [SMALL_STATE(341)] = 16113,
    [SMALL_STATE(342)] = 16141,
    [SMALL_STATE(343)] = 16169,
    [SMALL_STATE(344)] = 16197,
    [SMALL_STATE(345)] = 16225,
    [SMALL_STATE(346)] = 16253,
    [SMALL_STATE(347)] = 16277,
    [SMALL_STATE(348)] = 16305,
    [SMALL_STATE(349)] = 16333,
    [SMALL_STATE(350)] = 16361,
    [SMALL_STATE(351)] = 16387,
    [SMALL_STATE(352)] = 16404,
    [SMALL_STATE(353)] = 16425,
    [SMALL_STATE(354)] = 16448,
    [SMALL_STATE(355)] = 16473,
    [SMALL_STATE(356)] = 16496,
    [SMALL_STATE(357)] = 16513,
    [SMALL_STATE(358)] = 16530,
    [SMALL_STATE(359)] = 16547,
    [SMALL_STATE(360)] = 16568,
    [SMALL_STATE(361)] = 16593,
    [SMALL_STATE(362)] = 16618,
    [SMALL_STATE(363)] = 16635,
    [SMALL_STATE(364)] = 16660,
    [SMALL_STATE(365)] = 16677,
    [SMALL_STATE(366)] = 16694,
    [SMALL_STATE(367)] = 16711,
    [SMALL_STATE(368)] = 16736,
    [SMALL_STATE(369)] = 16759,
    [SMALL_STATE(370)] = 16782,
    [SMALL_STATE(371)] = 16799,
    [SMALL_STATE(372)] = 16816,
    [SMALL_STATE(373)] = 16833,
    [SMALL_STATE(374)] = 16850,
    [SMALL_STATE(375)] = 16869,
    [SMALL_STATE(376)] = 16886,
    [SMALL_STATE(377)] = 16905,
    [SMALL_STATE(378)] = 16928,
    [SMALL_STATE(379)] = 16953,
    [SMALL_STATE(380)] = 16978,
    [SMALL_STATE(381)] = 17003,
    [SMALL_STATE(382)] = 17020,
    [SMALL_STATE(383)] = 17037,
    [SMALL_STATE(384)] = 17062,
    [SMALL_STATE(385)] = 17087,
    [SMALL_STATE(386)] = 17104,
    [SMALL_STATE(387)] = 17124,
    [SMALL_STATE(388)] = 17140,
    [SMALL_STATE(389)] = 17156,
    [SMALL_STATE(390)] = 17178,
    [SMALL_STATE(391)] = 17196,
    [SMALL_STATE(392)] = 17218,
    [SMALL_STATE(393)] = 17240,
    [SMALL_STATE(394)] = 17258,
    [SMALL_STATE(395)] = 17280,
    [SMALL_STATE(396)] = 17298,
    [SMALL_STATE(397)] = 17320,
    [SMALL_STATE(398)] = 17338,
    [SMALL_STATE(399)] = 17360,
    [SMALL_STATE(400)] = 17378,
    [SMALL_STATE(401)] = 17396,
    [SMALL_STATE(402)] = 17418,
    [SMALL_STATE(403)] = 17436,
    [SMALL_STATE(404)] = 17454,
    [SMALL_STATE(405)] = 17476,
    [SMALL_STATE(406)] = 17494,
    [SMALL_STATE(407)] = 17516,
    [SMALL_STATE(408)] = 17534,
    [SMALL_STATE(409)] = 17556,
    [SMALL_STATE(410)] = 17578,
    [SMALL_STATE(411)] = 17594,
    [SMALL_STATE(412)] = 17610,
    [SMALL_STATE(413)] = 17630,
    [SMALL_STATE(414)] = 17652,
    [SMALL_STATE(415)] = 17670,
    [SMALL_STATE(416)] = 17692,
    [SMALL_STATE(417)] = 17714,
    [SMALL_STATE(418)] = 17732,
    [SMALL_STATE(419)] = 17754,
    [SMALL_STATE(420)] = 17776,
    [SMALL_STATE(421)] = 17794,
    [SMALL_STATE(422)] = 17814,
    [SMALL_STATE(423)] = 17830,
    [SMALL_STATE(424)] = 17848,
    [SMALL_STATE(425)] = 17868,
    [SMALL_STATE(426)] = 17890,
    [SMALL_STATE(427)] = 17912,
    [SMALL_STATE(428)] = 17934,
    [SMALL_STATE(429)] = 17956,
    [SMALL_STATE(430)] = 17976,
    [SMALL_STATE(431)] = 17998,
    [SMALL_STATE(432)] = 18020,
    [SMALL_STATE(433)] = 18042,
    [SMALL_STATE(434)] = 18058,
    [SMALL_STATE(435)] = 18074,
    [SMALL_STATE(436)] = 18090,
    [SMALL_STATE(437)] = 18110,
    [SMALL_STATE(438)] = 18126,
    [SMALL_STATE(439)] = 18144,
    [SMALL_STATE(440)] = 18160,
    [SMALL_STATE(441)] = 18176,
    [SMALL_STATE(442)] = 18192,
    [SMALL_STATE(443)] = 18208,
    [SMALL_STATE(444)] = 18224,
    [SMALL_STATE(445)] = 18246,
    [SMALL_STATE(446)] = 18268,
    [SMALL_STATE(447)] = 18288,
    [SMALL_STATE(448)] = 18308,
    [SMALL_STATE(449)] = 18326,
    [SMALL_STATE(450)] = 18346,
    [SMALL_STATE(451)] = 18366,
    [SMALL_STATE(452)] = 18388,
    [SMALL_STATE(453)] = 18408,
    [SMALL_STATE(454)] = 18426,
    [SMALL_STATE(455)] = 18444,
    [SMALL_STATE(456)] = 18466,
    [SMALL_STATE(457)] = 18484,
    [SMALL_STATE(458)] = 18502,
    [SMALL_STATE(459)] = 18520,
    [SMALL_STATE(460)] = 18538,
    [SMALL_STATE(461)] = 18556,
    [SMALL_STATE(462)] = 18574,
    [SMALL_STATE(463)] = 18592,
    [SMALL_STATE(464)] = 18614,
    [SMALL_STATE(465)] = 18634,
    [SMALL_STATE(466)] = 18656,
    [SMALL_STATE(467)] = 18674,
    [SMALL_STATE(468)] = 18696,
    [SMALL_STATE(469)] = 18718,
    [SMALL_STATE(470)] = 18740,
    [SMALL_STATE(471)] = 18762,
    [SMALL_STATE(472)] = 18782,
    [SMALL_STATE(473)] = 18802,
    [SMALL_STATE(474)] = 18824,
    [SMALL_STATE(475)] = 18844,
    [SMALL_STATE(476)] = 18864,
    [SMALL_STATE(477)] = 18884,
    [SMALL_STATE(478)] = 18906,
    [SMALL_STATE(479)] = 18924,
    [SMALL_STATE(480)] = 18944,
    [SMALL_STATE(481)] = 18964,
    [SMALL_STATE(482)] = 18982,
    [SMALL_STATE(483)] = 19002,
    [SMALL_STATE(484)] = 19020,
    [SMALL_STATE(485)] = 19036,
    [SMALL_STATE(486)] = 19058,
    [SMALL_STATE(487)] = 19076,
    [SMALL_STATE(488)] = 19094,
    [SMALL_STATE(489)] = 19112,
    [SMALL_STATE(490)] = 19129,
    [SMALL_STATE(491)] = 19148,
    [SMALL_STATE(492)] = 19167,
    [SMALL_STATE(493)] = 19186,
    [SMALL_STATE(494)] = 19203,
    [SMALL_STATE(495)] = 19220,
    [SMALL_STATE(496)] = 19239,
    [SMALL_STATE(497)] = 19256,
    [SMALL_STATE(498)] = 19273,
    [SMALL_STATE(499)] = 19288,
    [SMALL_STATE(500)] = 19307,
    [SMALL_STATE(501)] = 19326,
    [SMALL_STATE(502)] = 19345,
    [SMALL_STATE(503)] = 19362,
    [SMALL_STATE(504)] = 19379,
    [SMALL_STATE(505)] = 19398,
    [SMALL_STATE(506)] = 19417,
    [SMALL_STATE(507)] = 19436,
    [SMALL_STATE(508)] = 19455,
    [SMALL_STATE(509)] = 19474,
    [SMALL_STATE(510)] = 19493,
    [SMALL_STATE(511)] = 19510,
    [SMALL_STATE(512)] = 19527,
    [SMALL_STATE(513)] = 19544,
    [SMALL_STATE(514)] = 19559,
    [SMALL_STATE(515)] = 19576,
    [SMALL_STATE(516)] = 19593,
    [SMALL_STATE(517)] = 19612,
    [SMALL_STATE(518)] = 19629,
    [SMALL_STATE(519)] = 19646,
    [SMALL_STATE(520)] = 19665,
    [SMALL_STATE(521)] = 19684,
    [SMALL_STATE(522)] = 19703,
    [SMALL_STATE(523)] = 19720,
    [SMALL_STATE(524)] = 19739,
    [SMALL_STATE(525)] = 19756,
    [SMALL_STATE(526)] = 19773,
    [SMALL_STATE(527)] = 19790,
    [SMALL_STATE(528)] = 19807,
    [SMALL_STATE(529)] = 19826,
    [SMALL_STATE(530)] = 19845,
    [SMALL_STATE(531)] = 19862,
    [SMALL_STATE(532)] = 19879,
    [SMALL_STATE(533)] = 19898,
    [SMALL_STATE(534)] = 19915,
    [SMALL_STATE(535)] = 19934,
    [SMALL_STATE(536)] = 19953,
    [SMALL_STATE(537)] = 19972,
    [SMALL_STATE(538)] = 19991,
    [SMALL_STATE(539)] = 20010,
    [SMALL_STATE(540)] = 20029,
    [SMALL_STATE(541)] = 20048,
    [SMALL_STATE(542)] = 20065,
    [SMALL_STATE(543)] = 20080,
    [SMALL_STATE(544)] = 20099,
    [SMALL_STATE(545)] = 20114,
    [SMALL_STATE(546)] = 20129,
    [SMALL_STATE(547)] = 20144,
    [SMALL_STATE(548)] = 20163,
    [SMALL_STATE(549)] = 20178,
    [SMALL_STATE(550)] = 20193,
    [SMALL_STATE(551)] = 20210,
    [SMALL_STATE(552)] = 20225,
    [SMALL_STATE(553)] = 20244,
    [SMALL_STATE(554)] = 20263,
    [SMALL_STATE(555)] = 20278,
    [SMALL_STATE(556)] = 20293,
    [SMALL_STATE(557)] = 20308,
    [SMALL_STATE(558)] = 20323,
    [SMALL_STATE(559)] = 20338,
    [SMALL_STATE(560)] = 20353,
    [SMALL_STATE(561)] = 20368,
    [SMALL_STATE(562)] = 20383,
    [SMALL_STATE(563)] = 20398,
    [SMALL_STATE(564)] = 20413,
    [SMALL_STATE(565)] = 20428,
    [SMALL_STATE(566)] = 20447,
    [SMALL_STATE(567)] = 20462,
    [SMALL_STATE(568)] = 20477,
    [SMALL_STATE(569)] = 20496,
    [SMALL_STATE(570)] = 20511,
    [SMALL_STATE(571)] = 20526,
    [SMALL_STATE(572)] = 20541,
    [SMALL_STATE(573)] = 20556,
    [SMALL_STATE(574)] = 20571,
    [SMALL_STATE(575)] = 20586,
    [SMALL_STATE(576)] = 20601,
    [SMALL_STATE(577)] = 20616,
    [SMALL_STATE(578)] = 20633,
    [SMALL_STATE(579)] = 20652,
    [SMALL_STATE(580)] = 20671,
    [SMALL_STATE(581)] = 20690,
    [SMALL_STATE(582)] = 20705,
    [SMALL_STATE(583)] = 20720,
    [SMALL_STATE(584)] = 20739,
    [SMALL_STATE(585)] = 20754,
    [SMALL_STATE(586)] = 20769,
    [SMALL_STATE(587)] = 20784,
    [SMALL_STATE(588)] = 20801,
    [SMALL_STATE(589)] = 20820,
    [SMALL_STATE(590)] = 20835,
    [SMALL_STATE(591)] = 20854,
    [SMALL_STATE(592)] = 20873,
    [SMALL_STATE(593)] = 20888,
    [SMALL_STATE(594)] = 20903,
    [SMALL_STATE(595)] = 20918,
    [SMALL_STATE(596)] = 20937,
    [SMALL_STATE(597)] = 20956,
    [SMALL_STATE(598)] = 20975,
    [SMALL_STATE(599)] = 20994,
    [SMALL_STATE(600)] = 21013,
    [SMALL_STATE(601)] = 21030,
    [SMALL_STATE(602)] = 21049,
    [SMALL_STATE(603)] = 21066,
    [SMALL_STATE(604)] = 21083,
    [SMALL_STATE(605)] = 21102,
    [SMALL_STATE(606)] = 21119,
    [SMALL_STATE(607)] = 21136,
    [SMALL_STATE(608)] = 21153,
    [SMALL_STATE(609)] = 21170,
    [SMALL_STATE(610)] = 21189,
    [SMALL_STATE(611)] = 21208,
    [SMALL_STATE(612)] = 21227,
    [SMALL_STATE(613)] = 21246,
    [SMALL_STATE(614)] = 21261,
    [SMALL_STATE(615)] = 21276,
    [SMALL_STATE(616)] = 21291,
    [SMALL_STATE(617)] = 21306,
    [SMALL_STATE(618)] = 21321,
    [SMALL_STATE(619)] = 21340,
    [SMALL_STATE(620)] = 21355,
    [SMALL_STATE(621)] = 21370,
    [SMALL_STATE(622)] = 21385,
    [SMALL_STATE(623)] = 21400,
    [SMALL_STATE(624)] = 21415,
    [SMALL_STATE(625)] = 21430,
    [SMALL_STATE(626)] = 21447,
    [SMALL_STATE(627)] = 21462,
    [SMALL_STATE(628)] = 21477,
    [SMALL_STATE(629)] = 21492,
    [SMALL_STATE(630)] = 21507,
    [SMALL_STATE(631)] = 21522,
    [SMALL_STATE(632)] = 21537,
    [SMALL_STATE(633)] = 21556,
    [SMALL_STATE(634)] = 21571,
    [SMALL_STATE(635)] = 21586,
    [SMALL_STATE(636)] = 21601,
    [SMALL_STATE(637)] = 21616,
    [SMALL_STATE(638)] = 21631,
    [SMALL_STATE(639)] = 21646,
    [SMALL_STATE(640)] = 21661,
    [SMALL_STATE(641)] = 21676,
    [SMALL_STATE(642)] = 21691,
    [SMALL_STATE(643)] = 21706,
    [SMALL_STATE(644)] = 21725,
    [SMALL_STATE(645)] = 21740,
    [SMALL_STATE(646)] = 21759,
    [SMALL_STATE(647)] = 21778,
    [SMALL_STATE(648)] = 21793,
    [SMALL_STATE(649)] = 21808,
    [SMALL_STATE(650)] = 21827,
    [SMALL_STATE(651)] = 21846,
    [SMALL_STATE(652)] = 21865,
    [SMALL_STATE(653)] = 21884,
    [SMALL_STATE(654)] = 21899,
    [SMALL_STATE(655)] = 21916,
    [SMALL_STATE(656)] = 21931,
    [SMALL_STATE(657)] = 21946,
    [SMALL_STATE(658)] = 21963,
    [SMALL_STATE(659)] = 21978,
    [SMALL_STATE(660)] = 21993,
    [SMALL_STATE(661)] = 22010,
    [SMALL_STATE(662)] = 22025,
    [SMALL_STATE(663)] = 22042,
    [SMALL_STATE(664)] = 22057,
    [SMALL_STATE(665)] = 22076,
    [SMALL_STATE(666)] = 22095,
    [SMALL_STATE(667)] = 22114,
    [SMALL_STATE(668)] = 22129,
    [SMALL_STATE(669)] = 22148,
    [SMALL_STATE(670)] = 22165,
    [SMALL_STATE(671)] = 22184,
    [SMALL_STATE(672)] = 22201,
    [SMALL_STATE(673)] = 22220,
    [SMALL_STATE(674)] = 22239,
    [SMALL_STATE(675)] = 22256,
    [SMALL_STATE(676)] = 22273,
    [SMALL_STATE(677)] = 22290,
    [SMALL_STATE(678)] = 22307,
    [SMALL_STATE(679)] = 22326,
    [SMALL_STATE(680)] = 22345,
    [SMALL_STATE(681)] = 22360,
    [SMALL_STATE(682)] = 22377,
    [SMALL_STATE(683)] = 22396,
    [SMALL_STATE(684)] = 22415,
    [SMALL_STATE(685)] = 22432,
    [SMALL_STATE(686)] = 22451,
    [SMALL_STATE(687)] = 22470,
    [SMALL_STATE(688)] = 22489,
    [SMALL_STATE(689)] = 22508,
    [SMALL_STATE(690)] = 22527,
    [SMALL_STATE(691)] = 22546,
    [SMALL_STATE(692)] = 22565,
    [SMALL_STATE(693)] = 22584,
    [SMALL_STATE(694)] = 22603,
    [SMALL_STATE(695)] = 22622,
    [SMALL_STATE(696)] = 22641,
    [SMALL_STATE(697)] = 22660,
    [SMALL_STATE(698)] = 22679,
    [SMALL_STATE(699)] = 22698,
    [SMALL_STATE(700)] = 22717,
    [SMALL_STATE(701)] = 22736,
    [SMALL_STATE(702)] = 22755,
    [SMALL_STATE(703)] = 22774,
    [SMALL_STATE(704)] = 22791,
    [SMALL_STATE(705)] = 22810,
    [SMALL_STATE(706)] = 22829,
    [SMALL_STATE(707)] = 22848,
    [SMALL_STATE(708)] = 22867,
    [SMALL_STATE(709)] = 22886,
    [SMALL_STATE(710)] = 22905,
    [SMALL_STATE(711)] = 22924,
    [SMALL_STATE(712)] = 22943,
    [SMALL_STATE(713)] = 22962,
    [SMALL_STATE(714)] = 22981,
    [SMALL_STATE(715)] = 23000,
    [SMALL_STATE(716)] = 23019,
    [SMALL_STATE(717)] = 23038,
    [SMALL_STATE(718)] = 23057,
    [SMALL_STATE(719)] = 23076,
    [SMALL_STATE(720)] = 23091,
    [SMALL_STATE(721)] = 23107,
    [SMALL_STATE(722)] = 23121,
    [SMALL_STATE(723)] = 23137,
    [SMALL_STATE(724)] = 23151,
    [SMALL_STATE(725)] = 23165,
    [SMALL_STATE(726)] = 23181,
    [SMALL_STATE(727)] = 23197,
    [SMALL_STATE(728)] = 23211,
    [SMALL_STATE(729)] = 23227,
    [SMALL_STATE(730)] = 23243,
    [SMALL_STATE(731)] = 23259,
    [SMALL_STATE(732)] = 23273,
    [SMALL_STATE(733)] = 23287,
    [SMALL_STATE(734)] = 23301,
    [SMALL_STATE(735)] = 23315,
    [SMALL_STATE(736)] = 23329,
    [SMALL_STATE(737)] = 23343,
    [SMALL_STATE(738)] = 23357,
    [SMALL_STATE(739)] = 23371,
    [SMALL_STATE(740)] = 23385,
    [SMALL_STATE(741)] = 23401,
    [SMALL_STATE(742)] = 23417,
    [SMALL_STATE(743)] = 23431,
    [SMALL_STATE(744)] = 23447,
    [SMALL_STATE(745)] = 23463,
    [SMALL_STATE(746)] = 23479,
    [SMALL_STATE(747)] = 23495,
    [SMALL_STATE(748)] = 23511,
    [SMALL_STATE(749)] = 23525,
    [SMALL_STATE(750)] = 23541,
    [SMALL_STATE(751)] = 23557,
    [SMALL_STATE(752)] = 23573,
    [SMALL_STATE(753)] = 23589,
    [SMALL_STATE(754)] = 23605,
    [SMALL_STATE(755)] = 23619,
    [SMALL_STATE(756)] = 23633,
    [SMALL_STATE(757)] = 23649,
    [SMALL_STATE(758)] = 23663,
    [SMALL_STATE(759)] = 23677,
    [SMALL_STATE(760)] = 23693,
    [SMALL_STATE(761)] = 23707,
    [SMALL_STATE(762)] = 23721,
    [SMALL_STATE(763)] = 23735,
    [SMALL_STATE(764)] = 23751,
    [SMALL_STATE(765)] = 23765,
    [SMALL_STATE(766)] = 23779,
    [SMALL_STATE(767)] = 23795,
    [SMALL_STATE(768)] = 23809,
    [SMALL_STATE(769)] = 23823,
    [SMALL_STATE(770)] = 23837,
    [SMALL_STATE(771)] = 23851,
    [SMALL_STATE(772)] = 23865,
    [SMALL_STATE(773)] = 23879,
    [SMALL_STATE(774)] = 23893,
    [SMALL_STATE(775)] = 23909,
    [SMALL_STATE(776)] = 23925,
    [SMALL_STATE(777)] = 23941,
    [SMALL_STATE(778)] = 23955,
    [SMALL_STATE(779)] = 23971,
    [SMALL_STATE(780)] = 23987,
    [SMALL_STATE(781)] = 24001,
    [SMALL_STATE(782)] = 24017,
    [SMALL_STATE(783)] = 24033,
    [SMALL_STATE(784)] = 24047,
    [SMALL_STATE(785)] = 24061,
    [SMALL_STATE(786)] = 24077,
    [SMALL_STATE(787)] = 24093,
    [SMALL_STATE(788)] = 24109,
    [SMALL_STATE(789)] = 24125,
    [SMALL_STATE(790)] = 24141,
    [SMALL_STATE(791)] = 24157,
    [SMALL_STATE(792)] = 24173,
    [SMALL_STATE(793)] = 24187,
    [SMALL_STATE(794)] = 24203,
    [SMALL_STATE(795)] = 24219,
    [SMALL_STATE(796)] = 24235,
    [SMALL_STATE(797)] = 24251,
    [SMALL_STATE(798)] = 24267,
    [SMALL_STATE(799)] = 24283,
    [SMALL_STATE(800)] = 24297,
    [SMALL_STATE(801)] = 24313,
    [SMALL_STATE(802)] = 24329,
    [SMALL_STATE(803)] = 24343,
    [SMALL_STATE(804)] = 24357,
    [SMALL_STATE(805)] = 24371,
    [SMALL_STATE(806)] = 24385,
    [SMALL_STATE(807)] = 24399,
    [SMALL_STATE(808)] = 24413,
    [SMALL_STATE(809)] = 24427,
    [SMALL_STATE(810)] = 24441,
    [SMALL_STATE(811)] = 24455,
    [SMALL_STATE(812)] = 24469,
    [SMALL_STATE(813)] = 24483,
    [SMALL_STATE(814)] = 24497,
    [SMALL_STATE(815)] = 24511,
    [SMALL_STATE(816)] = 24527,
    [SMALL_STATE(817)] = 24541,
    [SMALL_STATE(818)] = 24557,
    [SMALL_STATE(819)] = 24571,
    [SMALL_STATE(820)] = 24585,
    [SMALL_STATE(821)] = 24599,
    [SMALL_STATE(822)] = 24615,
    [SMALL_STATE(823)] = 24629,
    [SMALL_STATE(824)] = 24643,
    [SMALL_STATE(825)] = 24657,
    [SMALL_STATE(826)] = 24671,
    [SMALL_STATE(827)] = 24685,
    [SMALL_STATE(828)] = 24699,
    [SMALL_STATE(829)] = 24713,
    [SMALL_STATE(830)] = 24727,
    [SMALL_STATE(831)] = 24741,
    [SMALL_STATE(832)] = 24755,
    [SMALL_STATE(833)] = 24769,
    [SMALL_STATE(834)] = 24783,
    [SMALL_STATE(835)] = 24799,
    [SMALL_STATE(836)] = 24815,
    [SMALL_STATE(837)] = 24829,
    [SMALL_STATE(838)] = 24843,
    [SMALL_STATE(839)] = 24857,
    [SMALL_STATE(840)] = 24870,
    [SMALL_STATE(841)] = 24883,
    [SMALL_STATE(842)] = 24896,
    [SMALL_STATE(843)] = 24909,
    [SMALL_STATE(844)] = 24922,
    [SMALL_STATE(845)] = 24935,
    [SMALL_STATE(846)] = 24948,
    [SMALL_STATE(847)] = 24961,
    [SMALL_STATE(848)] = 24974,
    [SMALL_STATE(849)] = 24987,
    [SMALL_STATE(850)] = 25000,
    [SMALL_STATE(851)] = 25013,
    [SMALL_STATE(852)] = 25026,
    [SMALL_STATE(853)] = 25039,
    [SMALL_STATE(854)] = 25052,
    [SMALL_STATE(855)] = 25065,
    [SMALL_STATE(856)] = 25078,
    [SMALL_STATE(857)] = 25091,
    [SMALL_STATE(858)] = 25104,
    [SMALL_STATE(859)] = 25117,
    [SMALL_STATE(860)] = 25130,
    [SMALL_STATE(861)] = 25143,
    [SMALL_STATE(862)] = 25156,
    [SMALL_STATE(863)] = 25169,
    [SMALL_STATE(864)] = 25182,
    [SMALL_STATE(865)] = 25195,
    [SMALL_STATE(866)] = 25208,
    [SMALL_STATE(867)] = 25221,
    [SMALL_STATE(868)] = 25234,
    [SMALL_STATE(869)] = 25247,
    [SMALL_STATE(870)] = 25260,
    [SMALL_STATE(871)] = 25273,
    [SMALL_STATE(872)] = 25286,
    [SMALL_STATE(873)] = 25299,
    [SMALL_STATE(874)] = 25312,
    [SMALL_STATE(875)] = 25325,
    [SMALL_STATE(876)] = 25338,
    [SMALL_STATE(877)] = 25351,
    [SMALL_STATE(878)] = 25364,
    [SMALL_STATE(879)] = 25377,
    [SMALL_STATE(880)] = 25390,
    [SMALL_STATE(881)] = 25403,
    [SMALL_STATE(882)] = 25416,
    [SMALL_STATE(883)] = 25429,
    [SMALL_STATE(884)] = 25442,
    [SMALL_STATE(885)] = 25455,
    [SMALL_STATE(886)] = 25468,
    [SMALL_STATE(887)] = 25481,
    [SMALL_STATE(888)] = 25494,
    [SMALL_STATE(889)] = 25507,
    [SMALL_STATE(890)] = 25520,
    [SMALL_STATE(891)] = 25533,
    [SMALL_STATE(892)] = 25546,
    [SMALL_STATE(893)] = 25559,
    [SMALL_STATE(894)] = 25572,
    [SMALL_STATE(895)] = 25585,
    [SMALL_STATE(896)] = 25598,
    [SMALL_STATE(897)] = 25611,
    [SMALL_STATE(898)] = 25624,
    [SMALL_STATE(899)] = 25637,
    [SMALL_STATE(900)] = 25650,
    [SMALL_STATE(901)] = 25663,
    [SMALL_STATE(902)] = 25676,
    [SMALL_STATE(903)] = 25689,
    [SMALL_STATE(904)] = 25702,
    [SMALL_STATE(905)] = 25715,
    [SMALL_STATE(906)] = 25728,
    [SMALL_STATE(907)] = 25741,
    [SMALL_STATE(908)] = 25754,
    [SMALL_STATE(909)] = 25767,
    [SMALL_STATE(910)] = 25780,
    [SMALL_STATE(911)] = 25793,
    [SMALL_STATE(912)] = 25806,
    [SMALL_STATE(913)] = 25819,
    [SMALL_STATE(914)] = 25832,
    [SMALL_STATE(915)] = 25845,
    [SMALL_STATE(916)] = 25858,
    [SMALL_STATE(917)] = 25871,
    [SMALL_STATE(918)] = 25884,
    [SMALL_STATE(919)] = 25897,
    [SMALL_STATE(920)] = 25910,
    [SMALL_STATE(921)] = 25923,
    [SMALL_STATE(922)] = 25936,
    [SMALL_STATE(923)] = 25949,
    [SMALL_STATE(924)] = 25962,
    [SMALL_STATE(925)] = 25975,
    [SMALL_STATE(926)] = 25988,
    [SMALL_STATE(927)] = 26001,
    [SMALL_STATE(928)] = 26014,
    [SMALL_STATE(929)] = 26027,
    [SMALL_STATE(930)] = 26040,
    [SMALL_STATE(931)] = 26053,
    [SMALL_STATE(932)] = 26066,
    [SMALL_STATE(933)] = 26079,
    [SMALL_STATE(934)] = 26092,
    [SMALL_STATE(935)] = 26105,
    [SMALL_STATE(936)] = 26118,
    [SMALL_STATE(937)] = 26131,
    [SMALL_STATE(938)] = 26144,
    [SMALL_STATE(939)] = 26157,
    [SMALL_STATE(940)] = 26170,
    [SMALL_STATE(941)] = 26183,
    [SMALL_STATE(942)] = 26196,
    [SMALL_STATE(943)] = 26209,
    [SMALL_STATE(944)] = 26222,
    [SMALL_STATE(945)] = 26235,
    [SMALL_STATE(946)] = 26248,
    [SMALL_STATE(947)] = 26261,
    [SMALL_STATE(948)] = 26274,
    [SMALL_STATE(949)] = 26287,
    [SMALL_STATE(950)] = 26300,
    [SMALL_STATE(951)] = 26313,
    [SMALL_STATE(952)] = 26326,
    [SMALL_STATE(953)] = 26339,
    [SMALL_STATE(954)] = 26352,
    [SMALL_STATE(955)] = 26365,
    [SMALL_STATE(956)] = 26378,
    [SMALL_STATE(957)] = 26391,
    [SMALL_STATE(958)] = 26404,
    [SMALL_STATE(959)] = 26417,
    [SMALL_STATE(960)] = 26430,
    [SMALL_STATE(961)] = 26443,
    [SMALL_STATE(962)] = 26456,
    [SMALL_STATE(963)] = 26469,
    [SMALL_STATE(964)] = 26482,
    [SMALL_STATE(965)] = 26495,
    [SMALL_STATE(966)] = 26508,
    [SMALL_STATE(967)] = 26521,
    [SMALL_STATE(968)] = 26534,
    [SMALL_STATE(969)] = 26547,
    [SMALL_STATE(970)] = 26560,
    [SMALL_STATE(971)] = 26573,
    [SMALL_STATE(972)] = 26586,
    [SMALL_STATE(973)] = 26599,
    [SMALL_STATE(974)] = 26612,
    [SMALL_STATE(975)] = 26625,
    [SMALL_STATE(976)] = 26638,
    [SMALL_STATE(977)] = 26651,
    [SMALL_STATE(978)] = 26664,
    [SMALL_STATE(979)] = 26677,
    [SMALL_STATE(980)] = 26690,
    [SMALL_STATE(981)] = 26703,
    [SMALL_STATE(982)] = 26716,
    [SMALL_STATE(983)] = 26729,
    [SMALL_STATE(984)] = 26742,
    [SMALL_STATE(985)] = 26755,
    [SMALL_STATE(986)] = 26768,
    [SMALL_STATE(987)] = 26781,
    [SMALL_STATE(988)] = 26794,
    [SMALL_STATE(989)] = 26807,
    [SMALL_STATE(990)] = 26820,
    [SMALL_STATE(991)] = 26833,
    [SMALL_STATE(992)] = 26846,
    [SMALL_STATE(993)] = 26859,
    [SMALL_STATE(994)] = 26872,
    [SMALL_STATE(995)] = 26885,
    [SMALL_STATE(996)] = 26898,
    [SMALL_STATE(997)] = 26911,
    [SMALL_STATE(998)] = 26924,
    [SMALL_STATE(999)] = 26937,
    [SMALL_STATE(1000)] = 26950,
    [SMALL_STATE(1001)] = 26963,
    [SMALL_STATE(1002)] = 26976,
    [SMALL_STATE(1003)] = 26989,
    [SMALL_STATE(1004)] = 27002,
    [SMALL_STATE(1005)] = 27015,
    [SMALL_STATE(1006)] = 27028,
    [SMALL_STATE(1007)] = 27041,
    [SMALL_STATE(1008)] = 27054,
    [SMALL_STATE(1009)] = 27067,
    [SMALL_STATE(1010)] = 27080,
    [SMALL_STATE(1011)] = 27093,
    [SMALL_STATE(1012)] = 27106,
    [SMALL_STATE(1013)] = 27119,
    [SMALL_STATE(1014)] = 27132,
    [SMALL_STATE(1015)] = 27145,
    [SMALL_STATE(1016)] = 27158,
    [SMALL_STATE(1017)] = 27171,
    [SMALL_STATE(1018)] = 27184,
    [SMALL_STATE(1019)] = 27197,
    [SMALL_STATE(1020)] = 27210,
    [SMALL_STATE(1021)] = 27223,
    [SMALL_STATE(1022)] = 27236,
    [SMALL_STATE(1023)] = 27249,
    [SMALL_STATE(1024)] = 27262,
    [SMALL_STATE(1025)] = 27275,
    [SMALL_STATE(1026)] = 27288,
    [SMALL_STATE(1027)] = 27301,
    [SMALL_STATE(1028)] = 27314,
    [SMALL_STATE(1029)] = 27327,
    [SMALL_STATE(1030)] = 27340,
    [SMALL_STATE(1031)] = 27353,
    [SMALL_STATE(1032)] = 27366,
    [SMALL_STATE(1033)] = 27379,
    [SMALL_STATE(1034)] = 27392,
    [SMALL_STATE(1035)] = 27405,
    [SMALL_STATE(1036)] = 27418,
    [SMALL_STATE(1037)] = 27431,
    [SMALL_STATE(1038)] = 27444,
    [SMALL_STATE(1039)] = 27457,
    [SMALL_STATE(1040)] = 27470,
    [SMALL_STATE(1041)] = 27483,
    [SMALL_STATE(1042)] = 27496,
    [SMALL_STATE(1043)] = 27509,
    [SMALL_STATE(1044)] = 27522,
    [SMALL_STATE(1045)] = 27535,
    [SMALL_STATE(1046)] = 27548,
    [SMALL_STATE(1047)] = 27561,
    [SMALL_STATE(1048)] = 27574,
    [SMALL_STATE(1049)] = 27587,
    [SMALL_STATE(1050)] = 27600,
    [SMALL_STATE(1051)] = 27613,
    [SMALL_STATE(1052)] = 27626,
    [SMALL_STATE(1053)] = 27639,
    [SMALL_STATE(1054)] = 27652,
    [SMALL_STATE(1055)] = 27665,
    [SMALL_STATE(1056)] = 27678,
    [SMALL_STATE(1057)] = 27691,
    [SMALL_STATE(1058)] = 27704,
    [SMALL_STATE(1059)] = 27717,
    [SMALL_STATE(1060)] = 27730,
    [SMALL_STATE(1061)] = 27743,
    [SMALL_STATE(1062)] = 27756,
    [SMALL_STATE(1063)] = 27769,
    [SMALL_STATE(1064)] = 27782,
    [SMALL_STATE(1065)] = 27795,
    [SMALL_STATE(1066)] = 27808,
    [SMALL_STATE(1067)] = 27821,
    [SMALL_STATE(1068)] = 27834,
    [SMALL_STATE(1069)] = 27847,
    [SMALL_STATE(1070)] = 27860,
    [SMALL_STATE(1071)] = 27873,
    [SMALL_STATE(1072)] = 27886,
    [SMALL_STATE(1073)] = 27899,
    [SMALL_STATE(1074)] = 27912,
    [SMALL_STATE(1075)] = 27925,
    [SMALL_STATE(1076)] = 27938,
    [SMALL_STATE(1077)] = 27951,
    [SMALL_STATE(1078)] = 27964,
    [SMALL_STATE(1079)] = 27977,
    [SMALL_STATE(1080)] = 27990,
    [SMALL_STATE(1081)] = 28003,
    [SMALL_STATE(1082)] = 28016,
    [SMALL_STATE(1083)] = 28029,
    [SMALL_STATE(1084)] = 28042,
    [SMALL_STATE(1085)] = 28055,
    [SMALL_STATE(1086)] = 28068,
    [SMALL_STATE(1087)] = 28081,
    [SMALL_STATE(1088)] = 28094,
    [SMALL_STATE(1089)] = 28107,
    [SMALL_STATE(1090)] = 28120,
    [SMALL_STATE(1091)] = 28133,
    [SMALL_STATE(1092)] = 28146,
    [SMALL_STATE(1093)] = 28159,
    [SMALL_STATE(1094)] = 28172,
    [SMALL_STATE(1095)] = 28185,
    [SMALL_STATE(1096)] = 28198,
    [SMALL_STATE(1097)] = 28211,
    [SMALL_STATE(1098)] = 28224,
    [SMALL_STATE(1099)] = 28237,
    [SMALL_STATE(1100)] = 28250,
    [SMALL_STATE(1101)] = 28263,
    [SMALL_STATE(1102)] = 28276,
    [SMALL_STATE(1103)] = 28289,
    [SMALL_STATE(1104)] = 28302,
    [SMALL_STATE(1105)] = 28315,
    [SMALL_STATE(1106)] = 28328,
    [SMALL_STATE(1107)] = 28341,
    [SMALL_STATE(1108)] = 28354,
    [SMALL_STATE(1109)] = 28367,
    [SMALL_STATE(1110)] = 28380,
    [SMALL_STATE(1111)] = 28393,
    [SMALL_STATE(1112)] = 28406,
    [SMALL_STATE(1113)] = 28419,
    [SMALL_STATE(1114)] = 28432,
    [SMALL_STATE(1115)] = 28445,
    [SMALL_STATE(1116)] = 28458,
    [SMALL_STATE(1117)] = 28471,
    [SMALL_STATE(1118)] = 28484,
    [SMALL_STATE(1119)] = 28497,
    [SMALL_STATE(1120)] = 28510,
    [SMALL_STATE(1121)] = 28523,
    [SMALL_STATE(1122)] = 28536,
    [SMALL_STATE(1123)] = 28549,
    [SMALL_STATE(1124)] = 28562,
    [SMALL_STATE(1125)] = 28575,
    [SMALL_STATE(1126)] = 28588,
    [SMALL_STATE(1127)] = 28601,
    [SMALL_STATE(1128)] = 28614,
    [SMALL_STATE(1129)] = 28627,
    [SMALL_STATE(1130)] = 28640,
    [SMALL_STATE(1131)] = 28653,
    [SMALL_STATE(1132)] = 28666,
    [SMALL_STATE(1133)] = 28679,
    [SMALL_STATE(1134)] = 28692,
    [SMALL_STATE(1135)] = 28705,
    [SMALL_STATE(1136)] = 28718,
    [SMALL_STATE(1137)] = 28731,
    [SMALL_STATE(1138)] = 28744,
    [SMALL_STATE(1139)] = 28757,
    [SMALL_STATE(1140)] = 28770,
    [SMALL_STATE(1141)] = 28783,
    [SMALL_STATE(1142)] = 28796,
    [SMALL_STATE(1143)] = 28809,
    [SMALL_STATE(1144)] = 28822,
    [SMALL_STATE(1145)] = 28835,
    [SMALL_STATE(1146)] = 28848,
    [SMALL_STATE(1147)] = 28861,
    [SMALL_STATE(1148)] = 28874,
    [SMALL_STATE(1149)] = 28887,
    [SMALL_STATE(1150)] = 28900,
    [SMALL_STATE(1151)] = 28913,
    [SMALL_STATE(1152)] = 28926,
    [SMALL_STATE(1153)] = 28939,
    [SMALL_STATE(1154)] = 28952,
    [SMALL_STATE(1155)] = 28965,
    [SMALL_STATE(1156)] = 28978,
    [SMALL_STATE(1157)] = 28991,
    [SMALL_STATE(1158)] = 29004,
    [SMALL_STATE(1159)] = 29017,
    [SMALL_STATE(1160)] = 29030,
    [SMALL_STATE(1161)] = 29043,
    [SMALL_STATE(1162)] = 29056,
    [SMALL_STATE(1163)] = 29069,
    [SMALL_STATE(1164)] = 29082,
    [SMALL_STATE(1165)] = 29095,
    [SMALL_STATE(1166)] = 29108,
    [SMALL_STATE(1167)] = 29121,
    [SMALL_STATE(1168)] = 29134,
    [SMALL_STATE(1169)] = 29147,
    [SMALL_STATE(1170)] = 29160,
    [SMALL_STATE(1171)] = 29173,
    [SMALL_STATE(1172)] = 29186,
    [SMALL_STATE(1173)] = 29199,
    [SMALL_STATE(1174)] = 29212,
    [SMALL_STATE(1175)] = 29225,
    [SMALL_STATE(1176)] = 29238,
    [SMALL_STATE(1177)] = 29251,
    [SMALL_STATE(1178)] = 29264,
    [SMALL_STATE(1179)] = 29277,
    [SMALL_STATE(1180)] = 29290,
    [SMALL_STATE(1181)] = 29303,
    [SMALL_STATE(1182)] = 29316,
    [SMALL_STATE(1183)] = 29329,
    [SMALL_STATE(1184)] = 29342,
    [SMALL_STATE(1185)] = 29355,
    [SMALL_STATE(1186)] = 29368,
    [SMALL_STATE(1187)] = 29381,
    [SMALL_STATE(1188)] = 29394,
    [SMALL_STATE(1189)] = 29407,
    [SMALL_STATE(1190)] = 29420,
    [SMALL_STATE(1191)] = 29433,
    [SMALL_STATE(1192)] = 29446,
    [SMALL_STATE(1193)] = 29459,
    [SMALL_STATE(1194)] = 29472,
    [SMALL_STATE(1195)] = 29485,
    [SMALL_STATE(1196)] = 29498,
    [SMALL_STATE(1197)] = 29511,
    [SMALL_STATE(1198)] = 29524,
    [SMALL_STATE(1199)] = 29537,
    [SMALL_STATE(1200)] = 29550,
    [SMALL_STATE(1201)] = 29563,
    [SMALL_STATE(1202)] = 29576,
    [SMALL_STATE(1203)] = 29589,
    [SMALL_STATE(1204)] = 29602,
    [SMALL_STATE(1205)] = 29615,
    [SMALL_STATE(1206)] = 29628,
    [SMALL_STATE(1207)] = 29641,
    [SMALL_STATE(1208)] = 29654,
    [SMALL_STATE(1209)] = 29667,
    [SMALL_STATE(1210)] = 29680,
    [SMALL_STATE(1211)] = 29693,
    [SMALL_STATE(1212)] = 29706,
    [SMALL_STATE(1213)] = 29719,
    [SMALL_STATE(1214)] = 29732,
    [SMALL_STATE(1215)] = 29745,
    [SMALL_STATE(1216)] = 29758,
    [SMALL_STATE(1217)] = 29771,
    [SMALL_STATE(1218)] = 29784,
    [SMALL_STATE(1219)] = 29797,
    [SMALL_STATE(1220)] = 29810,
    [SMALL_STATE(1221)] = 29823,
    [SMALL_STATE(1222)] = 29836,
    [SMALL_STATE(1223)] = 29849,
    [SMALL_STATE(1224)] = 29862,
    [SMALL_STATE(1225)] = 29875,
    [SMALL_STATE(1226)] = 29888,
    [SMALL_STATE(1227)] = 29901,
    [SMALL_STATE(1228)] = 29914,
    [SMALL_STATE(1229)] = 29927,
    [SMALL_STATE(1230)] = 29940,
    [SMALL_STATE(1231)] = 29953,
    [SMALL_STATE(1232)] = 29966,
    [SMALL_STATE(1233)] = 29979,
    [SMALL_STATE(1234)] = 29992,
    [SMALL_STATE(1235)] = 30005,
    [SMALL_STATE(1236)] = 30018,
    [SMALL_STATE(1237)] = 30031,
    [SMALL_STATE(1238)] = 30044,
    [SMALL_STATE(1239)] = 30057,
    [SMALL_STATE(1240)] = 30070,
    [SMALL_STATE(1241)] = 30083,
    [SMALL_STATE(1242)] = 30096,
    [SMALL_STATE(1243)] = 30109,
    [SMALL_STATE(1244)] = 30122,
    [SMALL_STATE(1245)] = 30135,
    [SMALL_STATE(1246)] = 30148,
    [SMALL_STATE(1247)] = 30161,
    [SMALL_STATE(1248)] = 30174,
    [SMALL_STATE(1249)] = 30187,
    [SMALL_STATE(1250)] = 30200,
    [SMALL_STATE(1251)] = 30213,
    [SMALL_STATE(1252)] = 30226,
    [SMALL_STATE(1253)] = 30239,
    [SMALL_STATE(1254)] = 30252,
    [SMALL_STATE(1255)] = 30265,
    [SMALL_STATE(1256)] = 30278,
    [SMALL_STATE(1257)] = 30291,
    [SMALL_STATE(1258)] = 30304,
    [SMALL_STATE(1259)] = 30308,
};

static const TSParseActionEntry ts_parse_actions[] = {
    [0] = { .entry = { .count = 0, .reusable = false } },
    [1] = { .entry = { .count = 1, .reusable = false } },
    RECOVER(),
    [3] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1106),
    [5] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1209),
    [7] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_specification, 0, 0, 0),
    [9] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1207),
    [11] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(730),
    [13] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(350),
    [15] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1203),
    [17] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1198),
    [19] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(501),
    [21] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1194),
    [23] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1193),
    [25] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1190),
    [27] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1189),
    [29] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(72),
    [31] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(74),
    [33] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(507),
    [35] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1184),
    [37] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1181),
    [39] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1180),
    [41] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1175),
    [43] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1174),
    [45] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(85),
    [47] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(749),
    [49] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(33),
    [51] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1170),
    [53] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(519),
    [55] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(520),
    [57] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(279),
    [59] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1162),
    [61] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1160),
    [63] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1159),
    [65] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1156),
    [67] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(753),
    [69] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(362),
    [71] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(364),
    [73] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(365),
    [75] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(365),
    [77] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(366),
    [79] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(439),
    [81] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(963),
    [83] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(370),
    [85] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(371),
    [87] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(371),
    [89] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(372),
    [91] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(373),
    [93] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(373),
    [95] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(442),
    [97] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(442),
    [99] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(351),
    [101] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1074),
    [103] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(374),
    [105] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(434),
    [107] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(968),
    [109] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(962),
    [111] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1203),
    [113] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1158),
    [115] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(878),
    [117] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(874),
    [119] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(873),
    [121] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(76),
    [123] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1193),
    [125] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1190),
    [127] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(858),
    [129] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1184),
    [131] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1180),
    [133] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1175),
    [135] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1174),
    [137] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(85),
    [139] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(855),
    [141] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(73),
    [143] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(877),
    [145] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(33),
    [147] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(519),
    [149] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(279),
    [151] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(387),
    [153] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(753),
    [155] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(190),
    [157] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1167),
    [159] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1004),
    [161] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1007),
    [163] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1016),
    [165] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(867),
    [167] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1210),
    [169] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(362),
    [172] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(364),
    [175] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(365),
    [178] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(365),
    [181] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(366),
    [184] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(439),
    [187] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(963),
    [190] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(370),
    [193] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(371),
    [196] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(371),
    [199] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(372),
    [202] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(373),
    [205] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(373),
    [208] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(442),
    [211] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(442),
    [214] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(351),
    [217] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1074),
    [220] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(374),
    [223] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(434),
    [226] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(968),
    [229] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(962),
    [232] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1203),
    [235] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    [237] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(878),
    [240] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(874),
    [243] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(873),
    [246] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(76),
    [249] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1193),
    [252] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1190),
    [255] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(72),
    [258] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(74),
    [261] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(858),
    [264] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1184),
    [267] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1180),
    [270] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1175),
    [273] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1174),
    [276] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(85),
    [279] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(855),
    [282] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(73),
    [285] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(877),
    [288] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(33),
    [291] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1170),
    [294] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(519),
    [297] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(279),
    [300] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(387),
    [303] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(753),
    [306] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(190),
    [309] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(362),
    [312] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(364),
    [315] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(365),
    [318] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(365),
    [321] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(366),
    [324] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(439),
    [327] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(963),
    [330] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(370),
    [333] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(371),
    [336] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(371),
    [339] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(372),
    [342] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(373),
    [345] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(373),
    [348] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(442),
    [351] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(442),
    [354] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(351),
    [357] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1074),
    [360] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(374),
    [363] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(434),
    [366] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(968),
    [369] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(962),
    [372] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1203),
    [375] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    [377] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(878),
    [380] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(874),
    [383] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(873),
    [386] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(76),
    [389] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1193),
    [392] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1190),
    [395] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(72),
    [398] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(74),
    [401] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(858),
    [404] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1184),
    [407] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1180),
    [410] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1175),
    [413] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1174),
    [416] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(85),
    [419] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(855),
    [422] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1007),
    [425] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(33),
    [428] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1170),
    [431] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(519),
    [434] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(279),
    [437] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(387),
    [440] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1016),
    [443] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(753),
    [446] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(190),
    [449] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_home_body, 1, 0, 0),
    [451] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1148),
    [453] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(879),
    [455] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1197),
    [457] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1254),
    [459] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_interface_body, 1, 0, 0),
    [461] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1208),
    [463] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(918),
    [465] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(362),
    [468] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(364),
    [471] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(365),
    [474] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(365),
    [477] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(366),
    [480] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(439),
    [483] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(963),
    [486] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(370),
    [489] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(371),
    [492] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(371),
    [495] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(372),
    [498] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(373),
    [501] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(373),
    [504] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(442),
    [507] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(442),
    [510] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(351),
    [513] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1074),
    [516] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(374),
    [519] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(434),
    [522] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(968),
    [525] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(962),
    [528] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1203),
    [531] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    [533] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(878),
    [536] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(874),
    [539] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(873),
    [542] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(76),
    [545] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1193),
    [548] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1190),
    [551] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(72),
    [554] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(74),
    [557] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(858),
    [560] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1184),
    [563] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1180),
    [566] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1175),
    [569] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1174),
    [572] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(85),
    [575] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(855),
    [578] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(33),
    [581] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1170),
    [584] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(519),
    [587] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(279),
    [590] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(387),
    [593] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(753),
    [596] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(190),
    [599] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(853),
    [601] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1199),
    [603] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    [605] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1207),
    [608] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(730),
    [611] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(350),
    [614] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1203),
    [617] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1198),
    [620] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(501),
    [623] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1194),
    [626] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1193),
    [629] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1190),
    [632] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1189),
    [635] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(72),
    [638] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(74),
    [641] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(507),
    [644] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1184),
    [647] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1181),
    [650] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1180),
    [653] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1175),
    [656] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1174),
    [659] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(85),
    [662] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(749),
    [665] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(33),
    [668] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1170),
    [671] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(519),
    [674] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(520),
    [677] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(279),
    [680] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1162),
    [683] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1160),
    [686] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1159),
    [689] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1156),
    [692] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(753),
    [695] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_specification, 1, 0, 0),
    [697] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1185),
    [699] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(718),
    [701] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(915),
    [703] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1203),
    [706] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    [708] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1198),
    [711] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(501),
    [714] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1194),
    [717] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1193),
    [720] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1190),
    [723] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1189),
    [726] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(72),
    [729] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(74),
    [732] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(507),
    [735] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1184),
    [738] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1181),
    [741] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1180),
    [744] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1175),
    [747] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1174),
    [750] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(85),
    [753] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(718),
    [756] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(749),
    [759] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(33),
    [762] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1170),
    [765] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(519),
    [768] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(520),
    [771] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(279),
    [774] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1162),
    [777] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1160),
    [780] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1159),
    [783] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1156),
    [786] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(753),
    [789] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1021),
    [791] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1203),
    [794] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_module_dcl_repeat1, 2, 0, 0),
    [796] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1198),
    [799] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(501),
    [802] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1194),
    [805] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1193),
    [808] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1190),
    [811] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1189),
    [814] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(72),
    [817] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(74),
    [820] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(507),
    [823] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1184),
    [826] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1181),
    [829] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1180),
    [832] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1175),
    [835] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1174),
    [838] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(85),
    [841] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(749),
    [844] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(33),
    [847] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1170),
    [850] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(519),
    [853] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(520),
    [856] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(279),
    [859] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1162),
    [862] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1160),
    [865] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1159),
    [868] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1156),
    [871] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(753),
    [874] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(976),
    [876] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_case, 1, 0, 0),
    [878] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_case, 1, 0, 0),
    [880] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1107),
    [882] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(257),
    [884] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(172),
    [886] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(257),
    [888] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(720),
    [890] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(468),
    [892] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(681),
    [894] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(204),
    [896] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(208),
    [898] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1106),
    [900] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(362),
    [903] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(364),
    [906] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(365),
    [909] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(365),
    [912] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(366),
    [915] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(439),
    [918] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(963),
    [921] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(370),
    [924] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(371),
    [927] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(371),
    [930] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(372),
    [933] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(373),
    [936] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(373),
    [939] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(442),
    [942] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(442),
    [945] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(351),
    [948] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1074),
    [951] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(374),
    [954] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(434),
    [957] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(968),
    [960] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(962),
    [963] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    [965] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(75),
    [968] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(65),
    [971] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(387),
    [974] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(190),
    [977] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(777),
    [979] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(75),
    [981] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(65),
    [983] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(814),
    [985] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1201),
    [987] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(792),
    [989] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(748),
    [991] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(723),
    [993] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(765),
    [995] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1187),
    [997] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(837),
    [999] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_header, 2, 0, 0),
    [1001] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(384),
    [1003] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_forward_dcl, 2, 0, 0),
    [1005] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(409),
    [1007] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(449),
    [1009] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(156),
    [1011] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(970),
    [1013] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(969),
    [1015] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1013),
    [1017] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1010),
    [1019] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(362),
    [1022] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(364),
    [1025] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(365),
    [1028] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(365),
    [1031] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(366),
    [1034] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(970),
    [1037] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(969),
    [1040] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(370),
    [1043] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(371),
    [1046] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(371),
    [1049] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(372),
    [1052] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(373),
    [1055] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(373),
    [1058] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(442),
    [1061] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(442),
    [1064] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(351),
    [1067] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1074),
    [1070] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(374),
    [1073] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1013),
    [1076] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(968),
    [1079] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    [1081] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1174),
    [1084] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(85),
    [1087] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(33),
    [1090] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1170),
    [1093] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(190),
    [1096] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1183),
    [1098] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_init_dcl, 6, 0, 0),
    [1100] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_init_dcl, 6, 0, 0),
    [1102] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_value_element, 1, 0, 0),
    [1104] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_element, 1, 0, 0),
    [1106] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_state_member, 4, 0, 0),
    [1108] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_state_member, 4, 0, 0),
    [1110] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_init_dcl, 7, 0, 0),
    [1112] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_init_dcl, 7, 0, 0),
    [1114] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 1, 0, 0),
    [1116] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_value_def_repeat1, 1, 0, 0),
    [1118] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(795),
    [1120] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1006),
    [1122] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(86),
    [1124] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_init_dcl, 5, 0, 0),
    [1126] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_init_dcl, 5, 0, 0),
    [1128] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_export, 2, 0, 0),
    [1130] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_export, 2, 0, 0),
    [1132] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_home_export, 2, 0, 0),
    [1134] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_home_export, 2, 0, 0),
    [1136] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_home_export, 1, 0, 0),
    [1138] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_home_export, 1, 0, 0),
    [1140] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 1, 0, 0),
    [1142] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_home_body_repeat1, 1, 0, 0),
    [1144] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1034),
    [1146] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1212),
    [1148] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1213),
    [1150] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(390),
    [1152] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(393),
    [1154] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1214),
    [1156] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1215),
    [1158] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1216),
    [1160] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(658),
    [1162] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(656),
    [1164] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(655),
    [1166] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(395),
    [1168] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(397),
    [1170] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(653),
    [1172] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1257),
    [1174] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1217),
    [1176] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1218),
    [1178] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1219),
    [1180] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1220),
    [1182] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(399),
    [1184] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(400),
    [1186] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1221),
    [1188] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(402),
    [1190] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(403),
    [1192] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(407),
    [1194] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(385),
    [1196] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(230),
    [1198] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 1, 0, 0),
    [1200] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_interface_body_repeat1, 1, 0, 0),
    [1202] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(992),
    [1204] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(991),
    [1206] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(990),
    [1208] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(262),
    [1210] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(263),
    [1212] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(839),
    [1214] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(988),
    [1216] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(987),
    [1218] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(320),
    [1220] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(319),
    [1222] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(318),
    [1224] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(264),
    [1226] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(259),
    [1228] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(315),
    [1230] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(986),
    [1232] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(984),
    [1234] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(983),
    [1236] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(979),
    [1238] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(978),
    [1240] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(266),
    [1242] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(267),
    [1244] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(975),
    [1246] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(268),
    [1248] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(269),
    [1250] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(270),
    [1252] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(252),
    [1254] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1137),
    [1256] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1226),
    [1258] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1227),
    [1260] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(91),
    [1262] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(94),
    [1264] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1228),
    [1266] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1229),
    [1268] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1230),
    [1270] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(126),
    [1272] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(131),
    [1274] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(133),
    [1276] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(97),
    [1278] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(98),
    [1280] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(139),
    [1282] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1036),
    [1284] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1231),
    [1286] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1232),
    [1288] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1233),
    [1290] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1234),
    [1292] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(100),
    [1294] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(102),
    [1296] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1235),
    [1298] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(90),
    [1300] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(104),
    [1302] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(103),
    [1304] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(106),
    [1306] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1138),
    [1308] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1240),
    [1310] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1241),
    [1312] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(453),
    [1314] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(454),
    [1316] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1242),
    [1318] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1243),
    [1320] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1244),
    [1322] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(592),
    [1324] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(589),
    [1326] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(586),
    [1328] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(456),
    [1330] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(457),
    [1332] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(585),
    [1334] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(949),
    [1336] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1245),
    [1338] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1246),
    [1340] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1247),
    [1342] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1248),
    [1344] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(458),
    [1346] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(459),
    [1348] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1249),
    [1350] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(460),
    [1352] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(461),
    [1354] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(462),
    [1356] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(358),
    [1358] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_case_label, 3, 0, 0),
    [1360] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_case_label, 3, 0, 0),
    [1362] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_case_label, 2, 0, 0),
    [1364] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_case_label, 2, 0, 0),
    [1366] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(aux_sym_interface_def_repeat1, 2, 0, 0),
    [1368] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_interface_def_repeat1, 2, 0, 0),
    [1370] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_interface_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(75),
    [1373] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_interface_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(65),
    [1376] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_service, 1, 0, 2),
    [1378] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_service, 1, 0, 2),
    [1380] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(487),
    [1382] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_autoid, 1, 0, 2),
    [1384] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_autoid, 1, 0, 2),
    [1386] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(474),
    [1388] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_member, 4, 0, 6),
    [1390] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_member, 4, 0, 6),
    [1392] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_member, 4, 0, 8),
    [1394] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_member, 4, 0, 8),
    [1396] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_optional, 1, 0, 2),
    [1398] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_optional, 1, 0, 2),
    [1400] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(475),
    [1402] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_scoped_name, 3, 0, 0),
    [1404] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_scoped_name, 3, 0, 0),
    [1406] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_member, 5, 0, 8),
    [1408] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_member, 5, 0, 8),
    [1410] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_key, 1, 0, 2),
    [1412] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_key, 1, 0, 2),
    [1414] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(518),
    [1416] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_must_understand, 1, 0, 2),
    [1418] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_must_understand, 1, 0, 2),
    [1420] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(517),
    [1422] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 1, 0, 0),
    [1424] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_except_dcl_repeat1, 1, 0, 0),
    [1426] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_external, 1, 0, 2),
    [1428] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_external, 1, 0, 2),
    [1430] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(515),
    [1432] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_member, 3, 0, 6),
    [1434] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_member, 3, 0, 6),
    [1436] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_nested, 1, 0, 2),
    [1438] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_nested, 1, 0, 2),
    [1440] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(514),
    [1442] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_ami, 1, 0, 2),
    [1444] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_ami, 1, 0, 2),
    [1446] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(510),
    [1448] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_oneway, 1, 0, 2),
    [1450] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_oneway, 1, 0, 2),
    [1452] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(511),
    [1454] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_custom_body, 1, 0, 0),
    [1456] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_custom_body, 1, 0, 0),
    [1458] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(162),
    [1460] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_scoped_name, 1, 0, 0),
    [1462] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_scoped_name, 1, 0, 0),
    [1464] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_scoped_name, 2, 0, 0),
    [1466] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_scoped_name, 2, 0, 0),
    [1468] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_body, 2, 0, 0),
    [1470] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_body, 2, 0, 0),
    [1472] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_member, 3, 0, 0),
    [1474] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_member, 3, 0, 0),
    [1476] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_autoid, 3, 0, 2),
    [1478] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_autoid, 3, 0, 2),
    [1480] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_optional, 3, 0, 2),
    [1482] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_optional, 3, 0, 2),
    [1484] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_id, 4, 0, 2),
    [1486] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_id, 4, 0, 2),
    [1488] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(aux_sym_interface_def_repeat1, 1, 0, 0),
    [1490] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_interface_def_repeat1, 1, 0, 0),
    [1492] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_verbatim, 6, 0, 10),
    [1494] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_verbatim, 6, 0, 10),
    [1496] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_range, 6, 0, 9),
    [1498] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_range, 6, 0, 9),
    [1500] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_body, 1, 0, 0),
    [1502] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_body, 1, 0, 0),
    [1504] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 1, 0, 0),
    [1506] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 1, 0, 0),
    [1508] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_custom_body, 4, 0, 0),
    [1510] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_custom_body, 4, 0, 0),
    [1512] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_ami, 4, 0, 2),
    [1514] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_ami, 4, 0, 2),
    [1516] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl, 1, 0, 0),
    [1518] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl, 1, 0, 0),
    [1520] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_oneway, 4, 0, 2),
    [1522] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_oneway, 4, 0, 2),
    [1524] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_service, 4, 0, 2),
    [1526] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_service, 4, 0, 2),
    [1528] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_extend_annotation_appl, 4, 0, 0),
    [1530] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_extend_annotation_appl, 4, 0, 0),
    [1532] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_extend_annotation_appl, 3, 0, 0),
    [1534] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_extend_annotation_appl, 3, 0, 0),
    [1536] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_verbatim, 4, 0, 5),
    [1538] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_verbatim, 4, 0, 5),
    [1540] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_final, 1, 0, 2),
    [1542] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_final, 1, 0, 2),
    [1544] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_nested, 4, 0, 2),
    [1546] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_nested, 4, 0, 2),
    [1548] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_external, 4, 0, 2),
    [1550] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_external, 4, 0, 2),
    [1552] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_bit_bound, 4, 0, 2),
    [1554] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_bit_bound, 4, 0, 2),
    [1556] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_unit, 4, 0, 2),
    [1558] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_unit, 4, 0, 2),
    [1560] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_appendable, 1, 0, 2),
    [1562] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_appendable, 1, 0, 2),
    [1564] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_max, 4, 0, 2),
    [1566] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_max, 4, 0, 2),
    [1568] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_mutable, 1, 0, 2),
    [1570] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_mutable, 1, 0, 2),
    [1572] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_min, 4, 0, 2),
    [1574] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_min, 4, 0, 2),
    [1576] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_definition, 2, 0, 0),
    [1578] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_definition, 2, 0, 0),
    [1580] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_default, 4, 0, 2),
    [1582] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_default, 4, 0, 2),
    [1584] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_member, 5, 0, 0),
    [1586] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_member, 5, 0, 0),
    [1588] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_autoid, 4, 0, 2),
    [1590] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_autoid, 4, 0, 2),
    [1592] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_default_literal, 1, 0, 2),
    [1594] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_default_literal, 1, 0, 2),
    [1596] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_must_understand, 4, 0, 2),
    [1598] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_must_understand, 4, 0, 2),
    [1600] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_verbatim, 8, 0, 13),
    [1602] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_verbatim, 8, 0, 13),
    [1604] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_optional, 4, 0, 2),
    [1606] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_optional, 4, 0, 2),
    [1608] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl, 2, 0, 0),
    [1610] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl, 2, 0, 0),
    [1612] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_key, 4, 0, 2),
    [1614] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_key, 4, 0, 2),
    [1616] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_extensibility, 4, 0, 2),
    [1618] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_extensibility, 4, 0, 2),
    [1620] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_value, 4, 0, 2),
    [1622] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_value, 4, 0, 2),
    [1624] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_verbatim, 6, 0, 11),
    [1626] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_verbatim, 6, 0, 11),
    [1628] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_builtin_body, 1, 0, 0),
    [1630] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_builtin_body, 1, 0, 0),
    [1632] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_position, 4, 0, 2),
    [1634] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_position, 4, 0, 2),
    [1636] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_preproc_call, 2, 0, 1),
    [1638] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_preproc_call, 2, 0, 1),
    [1640] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_preproc_define, 2, 0, 0),
    [1642] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_preproc_define, 2, 0, 0),
    [1644] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1014),
    [1646] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 1, 0, 0),
    [1648] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(aux_sym_specification_repeat1, 1, 0, 0),
    [1650] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_preproc_call, 3, 0, 3),
    [1652] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_preproc_call, 3, 0, 3),
    [1654] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_preproc_include, 3, 0, 4),
    [1656] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_preproc_include, 3, 0, 4),
    [1658] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_param_attribute, 1, 0, 0),
    [1660] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_param_attribute, 1, 0, 0),
    [1662] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(219),
    [1664] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_tpl_definition, 2, 0, 0),
    [1666] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_tpl_definition, 2, 0, 0),
    [1668] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_tpl_definition, 1, 0, 0),
    [1670] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_tpl_definition, 1, 0, 0),
    [1672] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 1, 0, 0),
    [1674] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 1, 0, 0),
    [1676] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_module_dcl_repeat1, 1, 0, 0),
    [1678] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(aux_sym_module_dcl_repeat1, 1, 0, 0),
    [1680] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(362),
    [1682] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(364),
    [1684] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(366),
    [1686] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(935),
    [1688] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(370),
    [1690] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(372),
    [1692] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(900),
    [1694] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(873),
    [1696] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(76),
    [1698] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(378),
    [1700] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(332),
    [1702] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(685),
    [1704] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(686),
    [1706] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(687),
    [1708] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(688),
    [1710] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_component_body, 1, 0, 0),
    [1712] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_component_body_repeat1, 2, 0, 0),
    [1714] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_component_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(873),
    [1717] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_component_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(76),
    [1720] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_component_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(378),
    [1723] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_component_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(332),
    [1726] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_component_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(685),
    [1729] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_component_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(686),
    [1732] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_component_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(687),
    [1735] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_component_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(688),
    [1738] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1111),
    [1740] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_primary_expr, 1, 0, 0),
    [1742] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_primary_expr, 1, 0, 0),
    [1744] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_port_body, 1, 0, 0),
    [1746] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1206),
    [1748] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(907),
    [1750] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1141),
    [1752] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(907),
    [1754] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(908),
    [1756] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_mult_expr, 1, 0, 0),
    [1758] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_mult_expr, 1, 0, 0),
    [1760] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_unary_expr, 1, 0, 0),
    [1762] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_unary_expr, 1, 0, 0),
    [1764] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_add_expr, 1, 0, 0),
    [1766] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_add_expr, 1, 0, 0),
    [1768] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(189),
    [1770] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(189),
    [1772] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_unary_expr, 2, 0, 0),
    [1774] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_unary_expr, 2, 0, 0),
    [1776] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_port_body, 2, 0, 0),
    [1778] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_string_literal, 2, 0, 0),
    [1780] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_string_literal, 2, 0, 0),
    [1782] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_port_body_repeat1, 2, 0, 0),
    [1784] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_port_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(873),
    [1787] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_port_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(76),
    [1790] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_port_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(378),
    [1793] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_port_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(332),
    [1796] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_port_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(688),
    [1799] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_boolean_literal, 1, 0, 0),
    [1801] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_boolean_literal, 1, 0, 0),
    [1803] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_connector_dcl_repeat1, 2, 0, 0),
    [1805] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_connector_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(873),
    [1808] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_connector_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(76),
    [1811] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_connector_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(378),
    [1814] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_connector_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(332),
    [1817] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_connector_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(688),
    [1820] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_add_expr, 3, 0, 0),
    [1822] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_add_expr, 3, 0, 0),
    [1824] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_literal, 1, 0, 0),
    [1826] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_literal, 1, 0, 0),
    [1828] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_primary_expr, 3, 0, 0),
    [1830] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_primary_expr, 3, 0, 0),
    [1832] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_char_literal, 3, 0, 0),
    [1834] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_char_literal, 3, 0, 0),
    [1836] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_string_literal, 3, 0, 0),
    [1838] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_string_literal, 3, 0, 0),
    [1840] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_mult_expr, 3, 0, 0),
    [1842] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_mult_expr, 3, 0, 0),
    [1844] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_char_literal, 4, 0, 0),
    [1846] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_char_literal, 4, 0, 0),
    [1848] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_string_literal, 4, 0, 0),
    [1850] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_string_literal, 4, 0, 0),
    [1852] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_shift_expr, 1, 0, 0),
    [1854] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_shift_expr, 1, 0, 0),
    [1856] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(188),
    [1858] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(173),
    [1860] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_shift_expr, 3, 0, 0),
    [1862] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_shift_expr, 3, 0, 0),
    [1864] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_simple_type_spec, 1, 0, 0),
    [1866] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_simple_type_spec, 1, 0, 0),
    [1868] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(953),
    [1870] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(72),
    [1872] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(952),
    [1874] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_and_expr, 1, 0, 0),
    [1876] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_and_expr, 1, 0, 0),
    [1878] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(185),
    [1880] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_and_expr, 3, 0, 0),
    [1882] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_and_expr, 3, 0, 0),
    [1884] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_component_body_repeat1, 1, 0, 0),
    [1886] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(720),
    [1888] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(204),
    [1890] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(208),
    [1892] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_interface_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(72),
    [1895] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_interface_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(74),
    [1898] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1066),
    [1900] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_component_export, 2, 0, 0),
    [1902] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_xor_expr, 1, 0, 0),
    [1904] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(183),
    [1906] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_xor_expr, 3, 0, 0),
    [1908] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_unary_operator, 1, 0, 0),
    [1910] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_unary_operator, 1, 0, 0),
    [1912] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(933),
    [1914] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(157),
    [1916] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(603),
    [1918] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(739),
    [1920] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(83),
    [1922] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(70),
    [1924] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(757),
    [1926] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(421),
    [1928] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(386),
    [1930] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(602),
    [1932] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_or_expr, 3, 0, 0),
    [1934] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(180),
    [1936] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(605),
    [1938] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(606),
    [1940] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(414),
    [1942] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(607),
    [1944] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(608),
    [1946] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(801),
    [1948] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_attr_declarator, 1, 0, 0),
    [1950] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(797),
    [1952] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(794),
    [1954] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_or_expr, 1, 0, 0),
    [1956] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(724),
    [1958] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1141),
    [1960] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(12),
    [1962] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(384),
    [1964] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_event_forward_dcl, 3, 0, 0),
    [1966] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(409),
    [1968] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_simple_declarator, 1, 0, 0),
    [1970] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_const_expr, 1, 0, 0),
    [1972] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(179),
    [1974] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_connector_export, 1, 0, 0),
    [1976] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_connector_dcl_repeat1, 1, 0, 0),
    [1978] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_event_header, 2, 0, 0),
    [1980] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_event_forward_dcl, 2, 0, 0),
    [1982] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_port_export, 1, 0, 0),
    [1984] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_port_body_repeat1, 1, 0, 0),
    [1986] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_port_ref, 2, 0, 0),
    [1988] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_port_export, 2, 0, 0),
    [1990] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_connector_export, 2, 0, 0),
    [1992] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_union_def_repeat1, 2, 0, 0),
    [1994] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_union_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(910),
    [1997] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_union_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(177),
    [2000] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(721),
    [2002] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(910),
    [2004] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(177),
    [2006] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_event_header, 3, 0, 0),
    [2008] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(67),
    [2011] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(77),
    [2014] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1209),
    [2016] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1163),
    [2018] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(361),
    [2020] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_array_declarator_repeat1, 2, 0, 0),
    [2022] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_array_declarator_repeat1, 2, 0, 0),
    SHIFT_REPEAT(169),
    [2025] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(67),
    [2027] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(77),
    [2029] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(640),
    [2031] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(169),
    [2033] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(581),
    [2035] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(123),
    [2037] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(644),
    [2039] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_interface_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(83),
    [2042] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_interface_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(70),
    [2045] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(124),
    [2047] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(280),
    [2049] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(767),
    [2051] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(742),
    [2053] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(770),
    [2055] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(806),
    [2057] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_component_header, 2, 0, 0),
    [2059] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(643),
    [2061] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_component_forward_dcl, 2, 0, 0),
    [2063] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(645),
    [2065] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(574),
    [2067] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_array_declarator, 2, 0, 0),
    [2069] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(21),
    [2071] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(325),
    [2073] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(773),
    [2075] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1032),
    [2077] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1031),
    [2079] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(465),
    [2081] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1030),
    [2083] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_char_type, 1, 0, 0),
    [2085] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1040),
    [2087] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(161),
    [2089] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(335),
    [2091] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(802),
    [2093] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1204),
    [2095] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_bitset_dcl_repeat1, 2, 0, 0),
    [2097] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_bitset_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1204),
    [2100] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1139),
    [2102] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(163),
    [2104] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(733),
    [2106] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_signed_short_int, 1, 0, 0),
    [2108] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_readonly_attr_declarator, 1, 0, 0),
    [2110] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1001),
    [2112] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_signed_long_int, 1, 0, 0),
    [2114] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_signed_longlong_int, 1, 0, 0),
    [2116] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_unsigned_int, 1, 0, 0),
    [2118] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(738),
    [2120] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_signed_int, 1, 0, 0),
    [2122] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_unsigned_short_int, 1, 0, 0),
    [2124] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_unsigned_long_int, 1, 0, 0),
    [2126] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_unsigned_longlong_int, 1, 0, 0),
    [2128] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(164),
    [2130] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_string_type, 1, 0, 0),
    [2132] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_integer_type, 1, 0, 0),
    [2134] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1078),
    [2136] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(649),
    [2138] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(539),
    [2140] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(650),
    [2142] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(737),
    [2144] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(404),
    [2146] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(302),
    [2148] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_object_type, 1, 0, 0),
    [2150] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_type_spec, 1, 0, 0),
    [2152] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(578),
    [2154] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(820),
    [2156] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(471),
    [2158] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(714),
    [2160] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(82),
    [2162] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(710),
    [2164] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(84),
    [2166] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(472),
    [2168] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(704),
    [2170] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(531),
    [2172] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(980),
    [2174] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(530),
    [2176] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(190),
    [2178] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(527),
    [2180] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(526),
    [2182] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(483),
    [2184] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(525),
    [2186] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(230),
    [2188] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_name, 1, 0, 0),
    [2190] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(418),
    [2192] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_inheritance_spec, 2, 0, 0),
    [2194] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(416),
    [2196] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(524),
    [2198] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_home_header, 5, 0, 0),
    [2200] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(580),
    [2202] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_sequence_type, 4, 0, 0),
    [2204] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_string_type, 4, 0, 0),
    [2206] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_enumerator_repeat1, 2, 0, 0),
    SHIFT_REPEAT(742),
    [2209] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_enumerator_repeat1, 2, 0, 0),
    [2211] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(768),
    [2213] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(917),
    [2215] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_inheritance_spec, 3, 0, 0),
    [2217] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(467),
    [2219] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(872),
    [2221] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_raises_expr_repeat1, 2, 0, 0),
    SHIFT_REPEAT(578),
    [2224] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_raises_expr_repeat1, 2, 0, 0),
    [2226] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(308),
    [2228] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1173),
    [2230] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_array_declarator_repeat1, 1, 0, 0),
    [2232] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(600),
    [2234] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1186),
    [2236] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(600),
    [2238] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_supported_interface_spec, 2, 0, 0),
    [2240] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_interface_header, 2, 0, 0),
    [2242] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(398),
    [2244] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_interface_forward_dcl, 2, 0, 0),
    [2246] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_home_header, 4, 0, 0),
    [2248] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_any_type, 1, 0, 0),
    [2250] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_template_type_spec, 1, 0, 0),
    [2252] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_op_dcl, 5, 0, 0),
    [2254] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_map_type, 8, 0, 0),
    [2256] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_base_type_spec, 1, 0, 0),
    [2258] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_map_type, 6, 0, 0),
    [2260] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_fixed_pt_type, 6, 0, 0),
    [2262] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_floating_pt_type, 1, 0, 0),
    [2264] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_sequence_type, 6, 0, 0),
    [2266] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1202),
    [2268] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_string_literal_repeat1, 2, 0, 0),
    SHIFT_REPEAT(600),
    [2271] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(aux_sym_string_literal_repeat1, 2, 0, 0),
    [2273] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_string_literal_repeat1, 2, 0, 0),
    SHIFT_REPEAT(600),
    [2276] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_declarators_repeat1, 2, 0, 0),
    SHIFT_REPEAT(446),
    [2279] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_declarators_repeat1, 2, 0, 0),
    [2281] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_op_dcl, 4, 0, 0),
    [2283] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(446),
    [2285] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_declarators, 2, 0, 0),
    [2287] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(764),
    [2289] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(68),
    [2291] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(35),
    [2293] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(611),
    [2295] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_struct_forward_dcl, 2, 0, 0),
    [2297] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(476),
    [2299] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(479),
    [2301] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_home_header, 6, 0, 0),
    [2303] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(503),
    [2305] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(502),
    [2307] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(497),
    [2309] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(496),
    [2311] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(438),
    [2313] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(494),
    [2315] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(493),
    [2317] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(832),
    [2319] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(513),
    [2321] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(213),
    [2323] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(946),
    [2325] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_char_literal_repeat1, 2, 0, 0),
    SHIFT_REPEAT(513),
    [2328] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(aux_sym_char_literal_repeat1, 2, 0, 0),
    [2330] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(202),
    [2332] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(211),
    [2334] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(642),
    [2336] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(641),
    [2338] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(214),
    [2340] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(110),
    [2342] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(111),
    [2344] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(576),
    [2346] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_inheritance_spec, 4, 0, 0),
    [2348] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(444),
    [2350] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_value_inheritance_spec_repeat1, 2, 0, 0),
    SHIFT_REPEAT(418),
    [2353] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_value_inheritance_spec_repeat1, 2, 0, 0),
    [2355] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(575),
    [2357] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_declarators, 1, 0, 0),
    [2359] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(210),
    [2361] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_fixed_array_size, 3, 0, 0),
    [2363] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(537),
    [2365] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_bitmask_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(283),
    [2368] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_bitmask_dcl_repeat1, 2, 0, 0),
    [2370] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_declarator, 1, 0, 0),
    [2372] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(101),
    [2374] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(174),
    [2376] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1028),
    [2378] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1027),
    [2380] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1026),
    [2382] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(799),
    [2384] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(736),
    [2386] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(595),
    [2388] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(283),
    [2390] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(804),
    [2392] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(aux_sym_char_literal_repeat1, 1, 0, 0),
    [2394] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(60),
    [2396] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1151),
    [2398] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_raises_expr_repeat1, 2, 0, 0),
    SHIFT_REPEAT(537),
    [2401] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(284),
    [2403] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(401),
    [2405] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_interface_inheritance_spec, 2, 0, 0),
    [2407] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_supported_interface_spec, 3, 0, 0),
    [2409] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(59),
    [2411] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_home_inheritance_spec, 2, 0, 0),
    [2413] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(759),
    [2415] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_params, 2, 0, 0),
    [2417] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_formal_parameters, 2, 0, 0),
    [2419] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(62),
    [2421] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_component_inheritance_spec, 2, 0, 0),
    [2423] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(424),
    [2425] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_any_declarators, 2, 0, 0),
    [2427] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_actual_parameters, 2, 0, 0),
    [2429] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(32),
    [2431] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_positive_int_const, 1, 0, 0),
    [2433] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(383),
    [2435] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(826),
    [2437] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_any_declarators_repeat1, 2, 0, 0),
    SHIFT_REPEAT(424),
    [2440] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_any_declarators_repeat1, 2, 0, 0),
    [2442] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_interface_name, 1, 0, 0),
    [2444] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_actual_parameters, 1, 0, 0),
    [2446] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_interface_inheritance_spec, 3, 0, 0),
    [2448] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(57),
    [2450] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(29),
    [2452] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_union_forward_dcl, 2, 0, 0),
    [2454] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(928),
    [2456] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_union_forward_dcl, 2, 0, 0),
    [2458] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_connector_header, 2, 0, 0),
    [2460] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(652),
    [2462] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_formal_parameters, 1, 0, 0),
    [2464] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(aux_sym_string_literal_repeat1, 1, 0, 0),
    [2466] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_string_literal_repeat1, 1, 0, 0),
    [2468] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_inheritance_spec, 1, 0, 0),
    [2470] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_params, 1, 0, 0),
    [2472] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_any_declarators, 1, 0, 0),
    [2474] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(93),
    [2476] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_bitfield_repeat1, 2, 0, 0),
    [2478] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_bitfield_repeat1, 2, 0, 0),
    SHIFT_REPEAT(736),
    [2481] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(735),
    [2483] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_component_header, 3, 0, 0),
    [2485] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(540),
    [2487] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_annotation_appl_params_repeat1, 2, 0, 0),
    SHIFT_REPEAT(759),
    [2490] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_annotation_appl_params_repeat1, 2, 0, 0),
    [2492] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_formal_parameters_repeat1, 2, 0, 0),
    [2494] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_formal_parameters_repeat1, 2, 0, 0),
    SHIFT_REPEAT(62),
    [2497] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_actual_parameters_repeat1, 2, 0, 0),
    [2499] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_actual_parameters_repeat1, 2, 0, 0),
    SHIFT_REPEAT(32),
    [2502] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_formal_parameter_names_repeat1, 2, 0, 0),
    [2504] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_formal_parameter_names_repeat1, 2, 0, 0),
    SHIFT_REPEAT(864),
    [2507] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_formal_parameter_names, 2, 0, 0),
    [2509] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(864),
    [2511] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(813),
    [2513] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_case, 3, 0, 0),
    [2515] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_formal_parameter_names, 1, 0, 0),
    [2517] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_in_parameter_dcls_repeat1, 2, 0, 0),
    SHIFT_REPEAT(817),
    [2520] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_in_parameter_dcls_repeat1, 2, 0, 0),
    [2522] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(818),
    [2524] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_enum_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(383),
    [2527] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_enum_dcl_repeat1, 2, 0, 0),
    [2529] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(66),
    [2531] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_inheritance_spec, 7, 0, 0),
    [2533] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_factory_param_dcls_repeat1, 2, 0, 0),
    SHIFT_REPEAT(787),
    [2536] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_factory_param_dcls_repeat1, 2, 0, 0),
    [2538] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_init_param_dcls_repeat1, 2, 0, 0),
    SHIFT_REPEAT(781),
    [2541] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_init_param_dcls_repeat1, 2, 0, 0),
    [2543] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_parameter_dcls_repeat1, 2, 0, 0),
    SHIFT_REPEAT(47),
    [2546] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_parameter_dcls_repeat1, 2, 0, 0),
    [2548] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_context_expr_repeat1, 2, 0, 0),
    SHIFT_REPEAT(700),
    [2551] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_context_expr_repeat1, 2, 0, 0),
    [2553] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(817),
    [2555] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_in_parameter_dcls, 2, 0, 0),
    [2557] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_union_def_repeat1, 1, 0, 0),
    [2559] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_inheritance_spec, 6, 0, 0),
    [2561] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_interface_inheritance_spec_repeat1, 2, 0, 0),
    SHIFT_REPEAT(401),
    [2564] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_interface_inheritance_spec_repeat1, 2, 0, 0),
    [2566] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(836),
    [2568] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_finder_dcl, 5, 0, 0),
    [2570] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_attr_raises_expr, 1, 0, 0),
    [2572] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(787),
    [2574] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_factory_param_dcls, 2, 0, 0),
    [2576] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_attr_declarator, 2, 0, 0),
    [2578] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_factory_dcl, 5, 0, 0),
    [2580] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(781),
    [2582] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_init_param_dcls, 2, 0, 0),
    [2584] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(700),
    [2586] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1009),
    [2588] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(52),
    [2590] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(47),
    [2592] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_parameter_dcls, 2, 0, 0),
    [2594] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(863),
    [2596] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_parameter_dcls, 1, 0, 0),
    [2598] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_in_parameter_dcls, 1, 0, 0),
    [2600] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_readonly_attr_declarator_repeat1, 2, 0, 0),
    SHIFT_REPEAT(801),
    [2603] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_readonly_attr_declarator_repeat1, 2, 0, 0),
    [2605] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(58),
    [2607] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_init_param_dcls, 1, 0, 0),
    [2609] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(783),
    [2611] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_readonly_attr_declarator, 2, 0, 0),
    [2613] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_factory_dcl, 4, 0, 0),
    [2615] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_inheritance_spec, 5, 0, 0),
    [2617] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_factory_param_dcls, 1, 0, 0),
    [2619] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_finder_dcl, 4, 0, 0),
    [2621] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(732),
    [2623] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(469),
    [2625] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(512),
    [2627] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_union_def, 9, 0, 0),
    [2629] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(888),
    [2631] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_struct_def, 6, 0, 0),
    [2633] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_bitmask_dcl, 4, 0, 0),
    [2635] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(354),
    [2637] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_bitset_dcl_repeat1, 1, 0, 0),
    [2639] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(902),
    [2641] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(150),
    [2643] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1033),
    [2645] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_bitfield_spec, 4, 0, 0),
    [2647] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_bitfield, 2, 0, 0),
    [2649] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_bitset_dcl, 7, 0, 0),
    [2651] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_bitmask_dcl_repeat1, 3, 0, 0),
    [2653] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_bitmask_dcl, 7, 0, 0),
    [2655] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_bitfield_repeat1, 1, 0, 0),
    [2657] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_bitset_dcl, 4, 0, 0),
    [2659] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_bitset_dcl, 5, 0, 0),
    [2661] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_bitmask_dcl, 5, 0, 0),
    [2663] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(109),
    [2665] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(175),
    [2667] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_enum_modifier, 1, 0, 0),
    [2669] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(937),
    [2671] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(939),
    [2673] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(41),
    [2675] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(495),
    [2677] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(941),
    [2679] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_struct_def, 7, 0, 7),
    [2681] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(965),
    [2683] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(954),
    [2685] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(942),
    [2687] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_interface_type, 1, 0, 0),
    [2689] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_constr_type_dcl, 1, 0, 0),
    [2691] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_union_dcl, 1, 0, 0),
    [2693] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_connector_inherit_spec, 2, 0, 0),
    [2695] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_bit_value, 1, 0, 0),
    [2697] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(885),
    [2699] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_get_excep_expr, 2, 0, 0),
    [2701] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_struct_dcl, 1, 0, 0),
    [2703] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_formal_parameter, 2, 0, 0),
    [2705] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(410),
    [2707] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(167),
    [2709] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_op_oneway_dcl, 5, 0, 0),
    [2711] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_struct_def, 5, 0, 0),
    [2713] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_switch_type_spec, 1, 0, 0),
    [2715] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_enum_dcl, 5, 0, 0),
    [2717] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_enumerator, 2, 0, 0),
    [2719] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_enumerator_repeat1, 1, 0, 0),
    [2721] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_enumerator, 1, 0, 0),
    [2723] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_param_dcl, 2, 0, 0),
    [2725] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_enum_dcl, 4, 0, 0),
    [2727] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(36),
    [2729] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_struct_def, 4, 0, 0),
    [2731] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(380),
    [2733] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(601),
    [2735] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_enum_dcl, 7, 0, 0),
    [2737] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_actual_parameter, 1, 0, 0),
    [2739] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(31),
    [2741] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_const_type, 1, 0, 0),
    [2743] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_imported_scope, 1, 0, 0),
    [2745] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(235),
    [2747] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_porttype_forward_dcl, 2, 0, 0),
    [2749] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_struct_def, 7, 0, 12),
    [2751] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_member_type, 1, 0, 0),
    [2753] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(706),
    [2755] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(69),
    [2757] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_formal_parameter_type, 1, 0, 0),
    [2759] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(38),
    [2761] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(731),
    [2763] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(178),
    [2765] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_bitfield, 3, 0, 0),
    [2767] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(834),
    [2769] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_bitset_dcl, 6, 0, 0),
    [2771] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_bitmask_dcl, 6, 0, 0),
    [2773] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_union_def, 8, 0, 0),
    [2775] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_any_declarator, 1, 0, 0),
    [2777] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_param, 3, 0, 0),
    [2779] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_raises_expr, 5, 0, 0),
    [2781] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_struct_def, 6, 0, 7),
    [2783] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_op_oneway_dcl, 6, 0, 0),
    [2785] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_exception_list, 4, 0, 0),
    [2787] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_raises_expr, 4, 0, 0),
    [2789] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_primary_key_spec, 2, 0, 0),
    [2791] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_op_dcl, 6, 0, 0),
    [2793] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_param_dcl, 3, 0, 0),
    [2795] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_enum_dcl, 6, 0, 0),
    [2797] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_init_param_dcl, 3, 0, 0),
    [2799] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_in_param_dcl, 3, 0, 0),
    [2801] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_factory_param_dcl, 3, 0, 0),
    [2803] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_exception_list, 3, 0, 0),
    [2805] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(668),
    [2807] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(440),
    [2809] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(166),
    [2811] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_bitmask_dcl, 8, 0, 0),
    [2813] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_struct_def, 8, 0, 12),
    [2815] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_bitfield_spec, 6, 0, 0),
    [2817] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(943),
    [2819] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(635),
    [2821] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_finder_dcl, 6, 0, 0),
    [2823] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_box_def, 3, 0, 0),
    [2825] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_attr_dcl, 1, 0, 0),
    [2827] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(87),
    [2829] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(883),
    [2831] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(667),
    [2833] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(441),
    [2835] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(437),
    [2837] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(443),
    [2839] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_factory_dcl, 6, 0, 0),
    [2841] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_abs_def, 6, 0, 0),
    [2843] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(55),
    [2845] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1154),
    [2847] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(866),
    [2849] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1081),
    [2851] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_element_spec, 2, 0, 0),
    [2853] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(343),
    [2855] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(287),
    [2857] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(307),
    [2859] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_context_expr, 5, 0, 0),
    [2861] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(812),
    [2863] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(870),
    [2865] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_def, 3, 0, 0),
    [2867] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(278),
    [2869] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(282),
    [2871] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_template_module_ref, 6, 0, 0),
    [2873] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(327),
    [2875] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_extensibility_kind, 1, 0, 0),
    [2877] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(81),
    [2879] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_op_type_spec, 1, 0, 0),
    [2881] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_template_module_inst, 6, 0, 0),
    [2883] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1157),
    [2885] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_interface_def, 3, 0, 0),
    [2887] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(326),
    [2889] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_interface_header, 3, 0, 0),
    [2891] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_connector_header, 3, 0, 0),
    [2893] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(342),
    [2895] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(323),
    [2897] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(321),
    [2899] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(232),
    [2901] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(747),
    [2903] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(314),
    [2905] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(313),
    [2907] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(392),
    [2909] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(276),
    [2911] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(300),
    [2913] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(490),
    [2915] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_type_prefix_dcl, 3, 0, 0),
    [2917] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(301),
    [2919] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_type_id_dcl, 3, 0, 0),
    [2921] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_component_def, 3, 0, 0),
    [2923] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(275),
    [2925] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(231),
    [2927] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_min_expr, 3, 0, 0),
    [2929] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(311),
    [2931] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(297),
    [2933] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(296),
    [2935] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_verbatim_language, 1, 0, 0),
    [2937] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_placement_kind, 1, 0, 0),
    [2939] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(295),
    [2941] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(88),
    [2943] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(227),
    [2945] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_readonly_attr_spec, 4, 0, 0),
    [2947] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(528),
    [2949] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(108),
    [2951] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_template_module_dcl, 8, 0, 0),
    [2953] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(306),
    [2955] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_service_platform, 1, 0, 0),
    [2957] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_event_abs_def, 6, 0, 0),
    [2959] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(290),
    [2961] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_provides_dcl, 3, 0, 0),
    [2963] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(92),
    [2965] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(289),
    [2967] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(288),
    [2969] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(285),
    [2971] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_type_declarator, 2, 0, 0),
    [2973] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(176),
    [2975] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(152),
    [2977] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_interface_def, 5, 0, 0),
    [2979] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_max_expr, 3, 0, 0),
    [2981] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(254),
    [2983] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(838),
    [2985] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_destination_type, 1, 0, 0),
    [2987] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1024),
    [2989] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_port_dcl, 3, 0, 0),
    [2991] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(904),
    [2993] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_consumes_dcl, 3, 0, 0),
    [2995] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(245),
    [2997] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_publishes_dcl, 3, 0, 0),
    [2999] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_emits_dcl, 3, 0, 0),
    [3001] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(869),
    [3003] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(861),
    [3005] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_uses_dcl, 3, 0, 0),
    [3007] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1071),
    [3009] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1182),
    [3011] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(722),
    [3013] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(10),
    [3015] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(712),
    [3017] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(745),
    [3019] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1176),
    [3021] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(330),
    [3023] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_native_dcl, 2, 0, 0),
    [3025] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(209),
    [3027] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_import_dcl, 2, 0, 0),
    [3029] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_typedef_dcl, 2, 0, 0),
    [3031] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(78),
    [3033] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(171),
    [3035] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(845),
    [3037] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_kind, 2, 0, 0),
    [3039] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(927),
    [3041] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_fixed_pt_const_type, 1, 0, 0),
    [3043] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(349),
    [3045] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(54),
    [3047] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(762),
    [3049] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(206),
    [3051] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_module_dcl, 4, 0, 0),
    [3053] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(451),
    [3055] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(938),
    [3057] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(604),
    [3059] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_context_expr, 3, 0, 0),
    [3061] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_attr_spec, 3, 0, 0),
    [3063] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1020),
    [3065] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(234),
    [3067] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(243),
    [3069] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_supports, 2, 0, 0),
    [3071] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(791),
    [3073] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(417),
    [3075] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(244),
    [3077] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(694),
    [3079] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(944),
    [3081] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(251),
    [3083] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(255),
    [3085] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(312),
    [3087] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_porttype_def, 5, 0, 0),
    [3089] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(49),
    [3091] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(273),
    [3093] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_header, 3, 0, 0),
    [3095] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(679),
    [3097] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(484),
    [3099] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1179),
    [3101] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_home_dcl, 3, 0, 0),
    [3103] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_const_dcl, 5, 0, 0),
    [3105] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(893),
    [3107] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(436),
    [3109] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_context_expr, 4, 0, 0),
    [3111] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_dcl, 4, 0, 0),
    [3113] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(411),
    [3115] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(860),
    [3117] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_any_const_type, 1, 0, 0),
    [3119] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(816),
    [3121] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1147),
    [3123] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_event_header, 4, 0, 0),
    [3125] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(170),
    [3127] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(79),
    [3129] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(876),
    [3131] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_module_dcl, 5, 0, 0),
    [3133] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(697),
    [3135] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_component_header, 4, 0, 0),
    [3137] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(24),
    [3139] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_formal_parameter_type, 2, 0, 0),
    [3141] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(281),
    [3143] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(347),
    [3145] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_interface_kind, 2, 0, 0),
    [3147] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(43),
    [3149] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(155),
    [3151] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(426),
    [3153] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(948),
    [3155] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(154),
    [3157] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(381),
    [3159] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1259),
    [3161] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(726),
    [3163] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_attr_raises_expr, 2, 0, 0),
    [3165] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_type_dcl, 1, 0, 0),
    [3167] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(217),
    [3169] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(382),
    [3171] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_porttype_dcl, 1, 0, 0),
    [3173] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_set_excep_expr, 2, 0, 0),
    [3175] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(583),
    [3177] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(3),
    [3179] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(639),
    [3181] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(638),
    [3183] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(637),
    [3185] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(636),
    [3187] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(317),
    [3189] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(634),
    [3191] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(633),
    [3193] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(631),
    [3195] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(630),
    [3197] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(629),
    [3199] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(628),
    [3201] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(627),
    [3203] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(626),
    [3205] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(624),
    [3207] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(623),
    [3209] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(622),
    [3211] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(621),
    [3213] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(620),
    [3215] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(619),
    [3217] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(617),
    [3219] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_porttype_def, 4, 0, 0),
    [3221] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(994),
    [3223] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(616),
    [3225] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(615),
    [3227] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(614),
    [3229] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_uses_dcl, 4, 0, 0),
    [3231] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(613),
    [3233] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_event_dcl, 1, 0, 0),
    [3235] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(274),
    [3237] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(4),
    [3239] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(184),
    [3241] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_component_dcl, 1, 0, 0),
    [3243] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(260),
    [3245] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(977),
    [3247] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(136),
    [3249] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(112),
    [3251] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(138),
    [3253] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(142),
    [3255] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(149),
    [3257] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(146),
    [3259] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(145),
    [3261] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(144),
    [3263] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(140),
    [3265] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(134),
    [3267] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(132),
    [3269] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(130),
    [3271] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(129),
    [3273] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(128),
    [3275] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(127),
    [3277] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(125),
    [3279] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(122),
    [3281] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(121),
    [3283] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(119),
    [3285] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(118),
    [3287] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(115),
    [3289] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(114),
    [3291] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(147),
    [3293] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(141),
    [3295] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1258),
    [3297] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(181),
    [3299] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(135),
    [3301] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(5),
    [3303] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(45),
    [3305] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(182),
    [3307] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_dcl, 1, 0, 0),
    [3309] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(573),
    [3311] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(572),
    [3313] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(571),
    [3315] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(570),
    [3317] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(569),
    [3319] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(567),
    [3321] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(566),
    [3323] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(564),
    [3325] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(563),
    [3327] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(562),
    [3329] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(561),
    [3331] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(560),
    [3333] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(558),
    [3335] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(557),
    [3337] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(556),
    [3339] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(555),
    [3341] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(554),
    [3343] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(551),
    [3345] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(549),
    [3347] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(548),
    [3349] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(546),
    [3351] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(545),
    [3353] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(544),
    [3355] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(542),
    [3357] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(107),
    [3359] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(357),
    [3361] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(356),
    [3363] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(690),
    [3365] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(11),
    [3367] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1047),
    [3369] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(840),
    [3371] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_interface_dcl, 1, 0, 0),
    [3373] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(428),
    [3375] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(391),
    [3377] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_interface_def, 4, 0, 0),
    [3379] = { .entry = { .count = 1, .reusable = true } },
    ACCEPT_INPUT(),
    [3381] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(396),
    [3383] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1058),
    [3385] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_op_with_context, 2, 0, 0),
    [3387] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(46),
    [3389] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_home_header, 7, 0, 0),
    [3391] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(597),
    [3393] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(394),
    [3395] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_def, 4, 0, 0),
    [3397] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(790),
    [3399] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(379),
    [3401] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1211),
    [3403] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(344),
    [3405] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(61),
    [3407] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(920),
    [3409] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(945),
    [3411] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_event_def, 3, 0, 0),
    [3413] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1083),
    [3415] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1086),
    [3417] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_enum_anno, 1, 0, 0),
    [3419] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(316),
    [3421] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(310),
    [3423] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_autoid_kind, 1, 0, 0),
    [3425] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(971),
    [3427] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(596),
    [3429] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(261),
    [3431] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1094),
    [3433] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(158),
    [3435] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_component_def, 4, 0, 0),
    [3437] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(452),
    [3439] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(299),
    [3441] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_system_lib_string, 3, 0, 0),
    [3443] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_dcl, 5, 0, 0),
    [3445] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_kind, 1, 0, 0),
    [3447] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_template_module_dcl, 7, 0, 0),
    [3449] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_except_dcl, 4, 0, 0),
    [3451] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(20),
    [3453] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(995),
    [3455] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(996),
    [3457] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1114),
    [3459] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1117),
    [3461] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(778),
    [3463] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_interface_kind, 1, 0, 0),
    [3465] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(19),
    [3467] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(137),
    [3469] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_event_abs_def, 5, 0, 0),
    [3471] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_abs_def, 5, 0, 0),
    [3473] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1125),
    [3475] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_except_dcl, 5, 0, 0),
    [3477] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1029),
    [3479] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(165),
    [3481] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(929),
    [3483] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_connector_dcl, 4, 0, 0),
    [3485] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(151),
    [3487] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_event_abs_def, 7, 0, 0),
    [3489] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1035),
    [3491] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_event_def, 4, 0, 0),
    [3493] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_home_dcl, 4, 0, 0),
    [3495] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(233),
    [3497] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1143),
    [3499] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1144),
    [3501] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(240),
    [3503] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(481),
    [3505] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(237),
    [3507] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(242),
    [3509] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(529),
    [3511] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1152),
    [3513] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(215),
    [3515] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(752),
    [3517] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(236),
    [3519] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(523),
    [3521] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(521),
    [3523] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(238),
    [3525] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1168),
    [3527] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1169),
    [3529] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(239),
    [3531] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(486),
    [3533] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(241),
    [3535] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(226),
    [3537] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(516),
    [3539] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1177),
    [3541] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(200),
    [3543] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(741),
    [3545] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(248),
    [3547] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(506),
    [3549] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(504),
    [3551] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(249),
    [3553] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1191),
    [3555] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1192),
    [3557] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(250),
    [3559] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(488),
    [3561] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(247),
    [3563] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(246),
    [3565] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(500),
    [3567] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1200),
    [3569] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(194),
    [3571] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(729),
    [3573] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(229),
    [3575] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(492),
    [3577] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(491),
    [3579] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_abs_def, 7, 0, 0),
    [3581] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(96),
    [3583] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_default, 2, 0, 0),
    [3585] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(728),
    [3587] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_comment, 2, 0, 0),
    [3589] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_comment, 3, 0, 0),
};

#ifdef __cplusplus
extern "C" {
#endif
#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_idl(void) {
    static const TSLanguage language = {
        .version = LANGUAGE_VERSION,
        .symbol_count = SYMBOL_COUNT,
        .alias_count = ALIAS_COUNT,
        .token_count = TOKEN_COUNT,
        .external_token_count = EXTERNAL_TOKEN_COUNT,
        .state_count = STATE_COUNT,
        .large_state_count = LARGE_STATE_COUNT,
        .production_id_count = PRODUCTION_ID_COUNT,
        .field_count = FIELD_COUNT,
        .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
        .parse_table = &ts_parse_table[0][0],
        .small_parse_table = ts_small_parse_table,
        .small_parse_table_map = ts_small_parse_table_map,
        .parse_actions = ts_parse_actions,
        .symbol_names = ts_symbol_names,
        .field_names = ts_field_names,
        .field_map_slices = ts_field_map_slices,
        .field_map_entries = ts_field_map_entries,
        .symbol_metadata = ts_symbol_metadata,
        .public_symbol_map = ts_symbol_map,
        .alias_map = ts_non_terminal_alias_map,
        .alias_sequences = &ts_alias_sequences[0][0],
        .lex_modes = ts_lex_modes,
        .lex_fn = ts_lex,
        .primary_state_ids = ts_primary_state_ids,
    };
    return &language;
}
#ifdef __cplusplus
}
#endif
